Method: Aws::Connect::Client#create_queue

Defined in:
lib/aws-sdk-connect/client.rb

#create_queue(params = {}) ⇒ Types::CreateQueueResponse

Creates a new queue for the specified Amazon Connect instance.

  • If the phone number is claimed to a traffic distribution group that was created in the same Region as the Amazon Connect instance where you are calling this API, then you can use a full phone number ARN or a UUID for OutboundCallerIdNumberId. However, if the phone number is claimed to a traffic distribution group that is in one Region, and you are calling this API from an instance in another Amazon Web Services Region that is associated with the traffic distribution group, you must provide a full phone number ARN. If a UUID is provided in this scenario, you will receive a ResourceNotFoundException.

  • Only use the phone number ARN format that doesn’t contain instance in the path, for example, arn:aws:connect:us-east-1:1234567890:phone-number/uuid. This is the same ARN format that is returned when you call the

    ListPhoneNumbersV2][1

    API.

  • If you plan to use IAM policies to allow/deny access to this API for phone number resources claimed to a traffic distribution group, see [Allow or Deny queue API actions for phone numbers in a replica Region].

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html [2]: docs.aws.amazon.com/connect/latest/adminguide/security_iam_resource-level-policy-examples.html#allow-deny-queue-actions-replica-region

Examples:

Request syntax with placeholder values


resp = client.create_queue({
  instance_id: "InstanceId", # required
  name: "CommonNameLength127", # required
  description: "QueueDescription",
  outbound_caller_config: {
    outbound_caller_id_name: "OutboundCallerIdName",
    outbound_caller_id_number_id: "PhoneNumberId",
    outbound_flow_id: "ContactFlowId",
  },
  outbound_email_config: {
    outbound_email_address_id: "EmailAddressId",
  },
  hours_of_operation_id: "HoursOfOperationId", # required
  max_contacts: 1,
  quick_connect_ids: ["QuickConnectId"],
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.queue_arn #=> String
resp.queue_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :instance_id (required, String)

    The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

    [1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

  • :name (required, String)

    The name of the queue.

  • :description (String)

    The description of the queue.

  • :outbound_caller_config (Types::OutboundCallerConfig)

    The outbound caller ID name, number, and outbound whisper flow.

  • :outbound_email_config (Types::OutboundEmailConfig)

    The outbound email address ID for a specified queue.

  • :hours_of_operation_id (required, String)

    The identifier for the hours of operation.

  • :max_contacts (Integer)

    The maximum number of contacts that can be in the queue before it is considered full.

  • :quick_connect_ids (Array<String>)

    The quick connects available to agents who are working the queue.

  • :tags (Hash<String,String>)

    The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.

Returns:

See Also:



4394
4395
4396
4397
# File 'lib/aws-sdk-connect/client.rb', line 4394

def create_queue(params = {}, options = {})
  req = build_request(:create_queue, params)
  req.send_request(options)
end