Class: Aws::Connect::Types::AgentInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the agent who accepted the contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accepted_by_agent_timestampTime

The timestamp when the contact was accepted by the agent.

Returns:

  • (Time)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#active_regionString

The Region where the agent was active when they handled the contact. For Amazon Connect Global Resiliency instances enabled for global routing, this indicates the Region in which the agent's session was established at the time of the contact.

Returns:

  • (String)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#after_contact_work_durationInteger

The difference in time, in whole seconds, between AfterContactWorkStartTimestamp and AfterContactWorkEndTimestamp.

Returns:

  • (Integer)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#after_contact_work_end_timestampTime

The date and time when the agent ended After Contact Work for the contact, in UTC time. In cases when agent finishes doing AfterContactWork for chat contacts and switches their activity status to offline or equivalent without clearing the contact in CCP, discrepancies may be noticed for AfterContactWorkEndTimestamp.

Returns:

  • (Time)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#after_contact_work_start_timestampTime

The date and time when the agent started doing After Contact Work for the contact, in UTC time.

Returns:

  • (Time)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#agent_initiated_hold_durationInteger

The total hold duration in seconds initiated by the agent.

Returns:

  • (Integer)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#agent_pause_duration_in_secondsInteger

Agent pause duration for a contact in seconds.

Returns:

  • (Integer)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#capabilitiesTypes::ParticipantCapabilities

The configuration for the allowed video and screen sharing capabilities for participants present over the call. For more information, see Set up in-app, web, video calling, and screen sharing capabilities in the Connect Customer Administrator Guide.



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#connected_to_agent_timestampTime

The timestamp when the contact was connected to the agent.

Returns:

  • (Time)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#device_infoTypes::DeviceInfo

Information regarding Agent’s device.

Returns:



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_groupsTypes::HierarchyGroups

The agent hierarchy groups for the agent.



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the agent who accepted the contact.

Returns:

  • (String)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#preview_end_timestampTime

The timestamp when the agent finished previewing the contact.

Returns:

  • (Time)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#state_transitionsArray<Types::StateTransition>

List of StateTransition for a supervisor.

Returns:



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end

#voice_enhancement_modeString

The voice enhancement mode used by the agent as the call is ending. Valid values: VOICE_ISOLATION | NOISE_SUPPRESSION | NONE. A value of null indicates this mode has not yet been set for this user.

Returns:

  • (String)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/aws-sdk-connect/types.rb', line 379

class AgentInfo < Struct.new(
  :id,
  :accepted_by_agent_timestamp,
  :preview_end_timestamp,
  :connected_to_agent_timestamp,
  :agent_pause_duration_in_seconds,
  :hierarchy_groups,
  :device_info,
  :capabilities,
  :after_contact_work_duration,
  :after_contact_work_start_timestamp,
  :after_contact_work_end_timestamp,
  :agent_initiated_hold_duration,
  :state_transitions,
  :voice_enhancement_mode,
  :active_region)
  SENSITIVE = []
  include Aws::Structure
end