Class: Aws::Connect::Types::AgentStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about an agent status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_status_arnString

The Amazon Resource Name (ARN) of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#agent_status_idString

The identifier of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#display_orderInteger

The display order of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of agent status.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/aws-sdk-connect/types.rb', line 480

class AgentStatus < Struct.new(
  :agent_status_arn,
  :agent_status_id,
  :name,
  :description,
  :type,
  :display_order,
  :state,
  :tags,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end