Class: Aws::Connect::Types::AgentsCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Can be used to define a list of preferred agents to target the contact to within the queue. Note that agents must have the queue in their routing profile in order to be offered the contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_idsArray<String>

An object to specify a list of agents, by user ID.

Returns:

  • (Array<String>)


627
628
629
630
631
# File 'lib/aws-sdk-connect/types.rb', line 627

class AgentsCriteria < Struct.new(
  :agent_ids)
  SENSITIVE = []
  include Aws::Structure
end