Class: Aws::Connect::Types::AssociateContactWithUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateContactWithUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#user_id ⇒ String
The identifier for the user.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-connect/types.rb', line 1047 class AssociateContactWithUserRequest < Struct.new( :instance_id, :contact_id, :user_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-connect/types.rb', line 1047 class AssociateContactWithUserRequest < Struct.new( :instance_id, :contact_id, :user_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier for the user. This can be the ID or the ARN of the user.
1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-connect/types.rb', line 1047 class AssociateContactWithUserRequest < Struct.new( :instance_id, :contact_id, :user_id) SENSITIVE = [] include Aws::Structure end |