Class: Aws::Connect::Types::AssociateDefaultVocabularyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1119
1120
1121
1122
1123
1124
1125
# File 'lib/aws-sdk-connect/types.rb', line 1119

class AssociateDefaultVocabularyRequest < Struct.new(
  :instance_id,
  :language_code,
  :vocabulary_id)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see What is Amazon Transcribe?

Returns:

  • (String)


1119
1120
1121
1122
1123
1124
1125
# File 'lib/aws-sdk-connect/types.rb', line 1119

class AssociateDefaultVocabularyRequest < Struct.new(
  :instance_id,
  :language_code,
  :vocabulary_id)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_idString

The identifier of the custom vocabulary. If this is empty, the default is set to none.

Returns:

  • (String)


1119
1120
1121
1122
1123
1124
1125
# File 'lib/aws-sdk-connect/types.rb', line 1119

class AssociateDefaultVocabularyRequest < Struct.new(
  :instance_id,
  :language_code,
  :vocabulary_id)
  SENSITIVE = []
  include Aws::Structure
end