Class: Aws::Connect::Types::AssociateEmailAddressAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_configurationTypes::AliasConfiguration

Configuration object that specifies which email address will serve as the alias. The specified email address must already exist in the Amazon Connect instance and cannot already be configured as an alias or have an alias of its own.



1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-connect/types.rb', line 1071

class AssociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs][1].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-connect/types.rb', line 1071

class AssociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#email_address_idString

The identifier of the email address.

Returns:

  • (String)


1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-connect/types.rb', line 1071

class AssociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID][1] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-connect/types.rb', line 1071

class AssociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end