Class: Aws::Connect::Types::AssociateInstanceStorageConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateInstanceStorageConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#resource_type ⇒ String
A valid resource type.
-
#storage_config ⇒ Types::InstanceStorageConfig
A valid storage type.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'lib/aws-sdk-connect/types.rb', line 1327 class AssociateInstanceStorageConfigRequest < Struct.new( :instance_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'lib/aws-sdk-connect/types.rb', line 1327 class AssociateInstanceStorageConfigRequest < Struct.new( :instance_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
A valid resource type. To enable streaming for real-time analysis of contacts, use the following types:
-
For chat contacts, use
REAL_TIME_CONTACT_ANALYSIS_CHAT_SEGMENTS. -
For voice contacts, use
REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS.
REAL_TIME_CONTACT_ANALYSIS_SEGMENTS is deprecated, but it is still
supported and will apply only to VOICE channel contacts. Use
REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS for voice contacts
moving forward.
If you have previously associated a stream with
REAL_TIME_CONTACT_ANALYSIS_SEGMENTS, no action is needed to update
the stream to REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS.
1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'lib/aws-sdk-connect/types.rb', line 1327 class AssociateInstanceStorageConfigRequest < Struct.new( :instance_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#storage_config ⇒ Types::InstanceStorageConfig
A valid storage type.
1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'lib/aws-sdk-connect/types.rb', line 1327 class AssociateInstanceStorageConfigRequest < Struct.new( :instance_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |