Class: Aws::Connect::Types::AssociateLexBotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateLexBotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#lex_bot ⇒ Types::LexBot
The Amazon Lex bot to associate with the instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-connect/types.rb', line 1416 class AssociateLexBotRequest < Struct.new( :instance_id, :lex_bot, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-connect/types.rb', line 1416 class AssociateLexBotRequest < Struct.new( :instance_id, :lex_bot, :client_token) SENSITIVE = [] include Aws::Structure end |
#lex_bot ⇒ Types::LexBot
The Amazon Lex bot to associate with the instance.
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-connect/types.rb', line 1416 class AssociateLexBotRequest < Struct.new( :instance_id, :lex_bot, :client_token) SENSITIVE = [] include Aws::Structure end |