Class: Aws::Connect::Types::AssociateQueueEmailAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateQueueEmailAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#email_addresses_config ⇒ Array<Types::EmailAddressConfig>
Configuration list containing the email addresses to associate with the queue.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#queue_id ⇒ String
The identifier for the queue.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-connect/types.rb', line 1506 class AssociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_addresses_config ⇒ Array<Types::EmailAddressConfig>
Configuration list containing the email addresses to associate with the queue. Each configuration specifies an email address ID that should be linked to this queue for routing purposes.
1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-connect/types.rb', line 1506 class AssociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-connect/types.rb', line 1506 class AssociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-connect/types.rb', line 1506 class AssociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_config, :client_token) SENSITIVE = [] include Aws::Structure end |