Class: Aws::Connect::Types::AssociateSecurityKeyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1589
1590
1591
1592
1593
1594
1595
# File 'lib/aws-sdk-connect/types.rb', line 1589

class AssociateSecurityKeyRequest < Struct.new(
  :instance_id,
  :key,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1589
1590
1591
1592
1593
1594
1595
# File 'lib/aws-sdk-connect/types.rb', line 1589

class AssociateSecurityKeyRequest < Struct.new(
  :instance_id,
  :key,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

A valid security key in PEM format as a String.

Returns:

  • (String)


1589
1590
1591
1592
1593
1594
1595
# File 'lib/aws-sdk-connect/types.rb', line 1589

class AssociateSecurityKeyRequest < Struct.new(
  :instance_id,
  :key,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end