Class: Aws::Connect::Types::AssociateWorkspaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_listArray<Types::FailedBatchAssociationSummary>

A list of resources that failed to be associated with the workspace, including error details.

Returns:



1604
1605
1606
1607
1608
1609
# File 'lib/aws-sdk-connect/types.rb', line 1604

class AssociateWorkspaceResponse < Struct.new(
  :successful_list,
  :failed_list)
  SENSITIVE = []
  include Aws::Structure
end

#successful_listArray<Types::SuccessfulBatchAssociationSummary>

A list of resources that were successfully associated with the workspace.

Returns:



1604
1605
1606
1607
1608
1609
# File 'lib/aws-sdk-connect/types.rb', line 1604

class AssociateWorkspaceResponse < Struct.new(
  :successful_list,
  :failed_list)
  SENSITIVE = []
  include Aws::Structure
end