Class: Aws::Connect::Types::AttachedFilesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AttachedFilesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The configuration for attached files for a specific attachment scope.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_scope ⇒ String
The scope of the attachment.
-
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
-
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
Instance Attribute Details
#attachment_scope ⇒ String
The scope of the attachment. Valid values are ‘EMAIL`, `CHAT`, `CASE`, and `TASK`.
1817 1818 1819 1820 1821 1822 1823 1824 1825 |
# File 'lib/aws-sdk-connect/types.rb', line 1817 class AttachedFilesConfiguration < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
1817 1818 1819 1820 1821 1822 1823 1824 1825 |
# File 'lib/aws-sdk-connect/types.rb', line 1817 class AttachedFilesConfiguration < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
1817 1818 1819 1820 1821 1822 1823 1824 1825 |
# File 'lib/aws-sdk-connect/types.rb', line 1817 class AttachedFilesConfiguration < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
1817 1818 1819 1820 1821 1822 1823 1824 1825 |
# File 'lib/aws-sdk-connect/types.rb', line 1817 class AttachedFilesConfiguration < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
1817 1818 1819 1820 1821 1822 1823 1824 1825 |
# File 'lib/aws-sdk-connect/types.rb', line 1817 class AttachedFilesConfiguration < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |