Class: Aws::Connect::Types::AttachedFilesConfigurationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AttachedFilesConfigurationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A summary of the attached files configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_scope ⇒ String
The scope of the attachment.
-
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
Instance Attribute Details
#attachment_scope ⇒ String
The scope of the attachment. Valid values are ‘EMAIL`, `CHAT`, `CASE`, and `TASK`.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connect/types.rb', line 1849 class AttachedFilesConfigurationSummary < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connect/types.rb', line 1849 class AttachedFilesConfigurationSummary < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connect/types.rb', line 1849 class AttachedFilesConfigurationSummary < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes. The minimum value is 1 and the maximum value is 104857600 (100 MB).
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connect/types.rb', line 1849 class AttachedFilesConfigurationSummary < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |