Class: Aws::Connect::Types::Attendee
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Attendee
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The attendee information, including attendee ID and join token.
Constant Summary collapse
- SENSITIVE =
[:join_token]
Instance Attribute Summary collapse
-
#attendee_id ⇒ String
The Amazon Chime SDK attendee ID.
-
#join_token ⇒ String
The join token used by the Amazon Chime SDK attendee.
Instance Attribute Details
#attendee_id ⇒ String
The Amazon Chime SDK attendee ID.
2028 2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-connect/types.rb', line 2028 class Attendee < Struct.new( :attendee_id, :join_token) SENSITIVE = [:join_token] include Aws::Structure end |
#join_token ⇒ String
The join token used by the Amazon Chime SDK attendee.
2028 2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-connect/types.rb', line 2028 class Attendee < Struct.new( :attendee_id, :join_token) SENSITIVE = [:join_token] include Aws::Structure end |