Class: Aws::Connect::Types::AttributeCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AttributeCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An object to specify the predefined attribute condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The operator of the condition.
-
#match_criteria ⇒ Types::MatchCriteria
An object to define
AgentsCriteria. -
#name ⇒ String
The name of predefined attribute.
-
#proficiency_level ⇒ Float
The proficiency level of the condition.
-
#range ⇒ Types::Range
An Object to define the minimum and maximum proficiency levels.
-
#value ⇒ String
The value of predefined attribute.
Instance Attribute Details
#comparison_operator ⇒ String
The operator of the condition.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#match_criteria ⇒ Types::MatchCriteria
An object to define AgentsCriteria.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of predefined attribute.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#proficiency_level ⇒ Float
The proficiency level of the condition.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#range ⇒ Types::Range
An Object to define the minimum and maximum proficiency levels.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of predefined attribute.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-connect/types.rb', line 2075 class AttributeCondition < Struct.new( :name, :value, :proficiency_level, :range, :match_criteria, :comparison_operator) SENSITIVE = [] include Aws::Structure end |