Class: Aws::Connect::Types::AudioFeatures

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Has audio-specific configurations as the operating parameter for Echo Reduction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#echo_reductionString

Makes echo reduction available to clients who connect to the meeting.

Returns:

  • (String)


2042
2043
2044
2045
2046
# File 'lib/aws-sdk-connect/types.rb', line 2042

class AudioFeatures < Struct.new(
  :echo_reduction)
  SENSITIVE = []
  include Aws::Structure
end