Class: Aws::Connect::Types::AuthScope
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AuthScope
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains the scope configuration for an authorization code. Defines the permissions and access boundaries for the session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of the Customer Profiles domain to scope the session to.
-
#entity_id ⇒ String
The identifier of the entity to scope the session to.
-
#entity_type ⇒ String
The type of entity to scope the session to.
-
#security_profile_ids ⇒ Array<String>
The list of security profile identifiers to scope the session to.
Instance Attribute Details
#domain_name ⇒ String
The name of the Customer Profiles domain to scope the session to.
2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'lib/aws-sdk-connect/types.rb', line 2128 class AuthScope < Struct.new( :security_profile_ids, :entity_type, :entity_id, :domain_name) SENSITIVE = [] include Aws::Structure end |
#entity_id ⇒ String
The identifier of the entity to scope the session to.
2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'lib/aws-sdk-connect/types.rb', line 2128 class AuthScope < Struct.new( :security_profile_ids, :entity_type, :entity_id, :domain_name) SENSITIVE = [] include Aws::Structure end |
#entity_type ⇒ String
The type of entity to scope the session to.
2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'lib/aws-sdk-connect/types.rb', line 2128 class AuthScope < Struct.new( :security_profile_ids, :entity_type, :entity_id, :domain_name) SENSITIVE = [] include Aws::Structure end |
#security_profile_ids ⇒ Array<String>
The list of security profile identifiers to scope the session to. Maximum of 10 security profiles.
2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'lib/aws-sdk-connect/types.rb', line 2128 class AuthScope < Struct.new( :security_profile_ids, :entity_type, :entity_id, :domain_name) SENSITIVE = [] include Aws::Structure end |