Class: Aws::Connect::Types::BatchCreateDataTableValueResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failedArray<Types::BatchCreateDataTableValueFailureResult>

A list of values that failed to be created with error messages explaining the failure reason.



2322
2323
2324
2325
2326
2327
# File 'lib/aws-sdk-connect/types.rb', line 2322

class BatchCreateDataTableValueResponse < Struct.new(
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#successfulArray<Types::BatchCreateDataTableValueSuccessResult>

A list of successfully created values with their identifiers and lock versions.



2322
2323
2324
2325
2326
2327
# File 'lib/aws-sdk-connect/types.rb', line 2322

class BatchCreateDataTableValueResponse < Struct.new(
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end