Class: Aws::Connect::Types::BatchDeleteDataTableValueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_table_idString

The unique identifier for the data table. Must also accept the table ARN with or without a version alias.

Returns:

  • (String)


2643
2644
2645
2646
2647
2648
2649
# File 'lib/aws-sdk-connect/types.rb', line 2643

class BatchDeleteDataTableValueRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The unique identifier for the Amazon Connect instance.

Returns:

  • (String)


2643
2644
2645
2646
2647
2648
2649
# File 'lib/aws-sdk-connect/types.rb', line 2643

class BatchDeleteDataTableValueRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Types::DataTableDeleteValueIdentifier>

A list of value identifiers to delete, each specifying primary values, attribute name, and lock version information.



2643
2644
2645
2646
2647
2648
2649
# File 'lib/aws-sdk-connect/types.rb', line 2643

class BatchDeleteDataTableValueRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :values)
  SENSITIVE = []
  include Aws::Structure
end