Class: Aws::Connect::Types::BatchDisassociateAnalyticsDataSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_set_idsArray<String>

An array of associated dataset identifiers to remove.



2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-connect/types.rb', line 2473

class BatchDisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_ids,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html



2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-connect/types.rb', line 2473

class BatchDisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_ids,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_account_idString

The identifier of the target account. Use to disassociate a dataset from a different account than the one containing the Amazon Connect instance. If not specified, by default this value is the Amazon Web Services account that has the Amazon Connect instance.



2473
2474
2475
2476
2477
2478
2479
# File 'lib/aws-sdk-connect/types.rb', line 2473

class BatchDisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_ids,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end