Class: Aws::Connect::Types::ChatEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ChatEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Chat integration event containing payload to perform different chat actions such as:
-
Sending a chat message
-
Sending a chat event, such as typing
-
Disconnecting from a chat
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
Content of the message or event.
-
#content_type ⇒ String
Type of content.
-
#type ⇒ String
Type of chat integration event.
Instance Attribute Details
#content ⇒ String
Content of the message or event. This is required when Type is
MESSAGE and for certain ContentTypes when Type is EVENT.
-
For allowed message content, see the
Contentparameter in the SendMessage topic in the Connect Customer Participant Service API Reference. -
For allowed event content, see the
Contentparameter in the SendEvent topic in the Connect Customer Participant Service API Reference.
3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-connect/types.rb', line 3212 class ChatEvent < Struct.new( :type, :content_type, :content) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
Type of content. This is required when Type is MESSAGE or
EVENT.
-
For allowed message content types, see the
ContentTypeparameter in the SendMessage topic in the Connect Customer Participant Service API Reference. -
For allowed event content types, see the
ContentTypeparameter in the SendEvent topic in the Connect Customer Participant Service API Reference.
3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-connect/types.rb', line 3212 class ChatEvent < Struct.new( :type, :content_type, :content) SENSITIVE = [] include Aws::Structure end |