Class: Aws::Connect::Types::ClaimedPhoneNumberSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ClaimedPhoneNumberSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a phone number that has been claimed to your Connect Customer instance or traffic distribution group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to.
-
#phone_number ⇒ String
The phone number.
-
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the phone number.
-
#phone_number_country_code ⇒ String
The ISO country code.
-
#phone_number_description ⇒ String
The description of the phone number.
-
#phone_number_id ⇒ String
A unique identifier for the phone number.
-
#phone_number_status ⇒ Types::PhoneNumberStatus
The status of the phone number.
-
#phone_number_type ⇒ String
The type of phone number.
-
#source_phone_number_arn ⇒ String
The claimed phone number ARN that was previously imported from the external service, such as Amazon Web Services End User Messaging.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
The phone number. Phone numbers are formatted ‘[+] [country code] [subscriber number including area code]`.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the phone number.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_code ⇒ String
The ISO country code.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_description ⇒ String
The description of the phone number.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
A unique identifier for the phone number.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_status ⇒ Types::PhoneNumberStatus
The status of the phone number.
-
‘CLAIMED` means the previous [ClaimPhoneNumber] or
- UpdatePhoneNumber][2
-
operation succeeded.
-
‘IN_PROGRESS` means a [ClaimPhoneNumber],
- UpdatePhoneNumber], or [UpdatePhoneNumberMetadata][3
-
operation is still in progress and has not yet completed. You can call [DescribePhoneNumber] at a later time to verify if the previous operation has completed.
-
‘FAILED` indicates that the previous [ClaimPhoneNumber] or
- UpdatePhoneNumber][2
-
operation has failed. It will include a
message indicating the failure reason. A common reason for a failure may be that the ‘TargetArn` value you are claiming or updating a phone number to has reached its limit of total claimed numbers. If you received a `FAILED` status from a `ClaimPhoneNumber` API call, you have one day to retry claiming the phone number before the number is released back to the inventory for other customers to claim.
<note markdown=“1”> You will not be billed for the phone number during the 1-day period if number claiming fails.
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_ClaimPhoneNumber.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumber.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumberMetadata.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_type ⇒ String
The type of phone number.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#source_phone_number_arn ⇒ String
The claimed phone number ARN that was previously imported from the external service, such as Amazon Web Services End User Messaging. If it is from Amazon Web Services End User Messaging, it looks like the ARN of the phone number that was imported from Amazon Web Services End User Messaging.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-connect/types.rb', line 3451 class ClaimedPhoneNumberSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :phone_number_description, :target_arn, :instance_id, :tags, :phone_number_status, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |