Class: Aws::Connect::Types::CommonAttributeAndCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CommonAttributeAndCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A list of conditions which would be applied together with an AND
condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tag_conditions ⇒ Array<Types::TagCondition>
A leaf node condition which can be used to specify a tag condition.
Instance Attribute Details
#tag_conditions ⇒ Array<Types::TagCondition>
A leaf node condition which can be used to specify a tag condition.
3547 3548 3549 3550 3551 |
# File 'lib/aws-sdk-connect/types.rb', line 3547 class CommonAttributeAndCondition < Struct.new( :tag_conditions) SENSITIVE = [] include Aws::Structure end |