Class: Aws::Connect::Types::Condition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A leaf node condition which can be used to specify a ProficiencyName, ProficiencyValue and ProficiencyLimit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#number_conditionTypes::NumberCondition

A leaf node condition which can be used to specify a numeric condition.



3275
3276
3277
3278
3279
3280
# File 'lib/aws-sdk-connect/types.rb', line 3275

class Condition < Struct.new(
  :string_condition,
  :number_condition)
  SENSITIVE = []
  include Aws::Structure
end

#string_conditionTypes::StringCondition

A leaf node condition which can be used to specify a string condition.

<note markdown=“1”> The currently supported values for FieldName are name and value.

</note>


3275
3276
3277
3278
3279
3280
# File 'lib/aws-sdk-connect/types.rb', line 3275

class Condition < Struct.new(
  :string_condition,
  :number_condition)
  SENSITIVE = []
  include Aws::Structure
end