Class: Aws::Connect::Types::ContactAnalysisReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactAnalysisReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a reference when the referenceType is
CONTACT_ANALYSIS. Otherwise, null.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_mode ⇒ String
The analytics mode of the contact analysis.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the contact analysis reference.
-
#is_redacted ⇒ Boolean
Indicates whether sensitive data has been redacted from the contact analysis.
-
#name ⇒ String
Identifier of the contact analysis reference.
-
#status ⇒ String
Status of the contact analysis reference type.
-
#value ⇒ String
The location path of the contact analysis reference.
Instance Attribute Details
#analytics_mode ⇒ String
The analytics mode of the contact analysis.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the contact analysis reference.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |
#is_redacted ⇒ Boolean
Indicates whether sensitive data has been redacted from the contact analysis.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Identifier of the contact analysis reference.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the contact analysis reference type.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The location path of the contact analysis reference.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/aws-sdk-connect/types.rb', line 4121 class ContactAnalysisReference < Struct.new( :name, :value, :status, :arn, :analytics_mode, :is_redacted) SENSITIVE = [] include Aws::Structure end |