Class: Aws::Connect::Types::ContactConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The contact configuration for push notification registration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact within the Amazon Connect instance.
-
#include_raw_message ⇒ Boolean
Whether to include raw connect message in the push notification payload.
-
#participant_role ⇒ String
The role of the participant in the chat conversation.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact within the Amazon Connect instance.
4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/aws-sdk-connect/types.rb', line 4007 class ContactConfiguration < Struct.new( :contact_id, :participant_role, :include_raw_message) SENSITIVE = [] include Aws::Structure end |
#include_raw_message ⇒ Boolean
Whether to include raw connect message in the push notification
payload. Default is False.
4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/aws-sdk-connect/types.rb', line 4007 class ContactConfiguration < Struct.new( :contact_id, :participant_role, :include_raw_message) SENSITIVE = [] include Aws::Structure end |
#participant_role ⇒ String
The role of the participant in the chat conversation.
CUSTOMER is currently supported. Any other values other than
CUSTOMER will result in an exception (4xx error).
4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/aws-sdk-connect/types.rb', line 4007 class ContactConfiguration < Struct.new( :contact_id, :participant_role, :include_raw_message) SENSITIVE = [] include Aws::Structure end |