Class: Aws::Connect::Types::ContactDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Request object with information to create a contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
List of attributes to be stored in a contact.
-
#campaign ⇒ Types::Campaign
Structure to store information associated with a campaign.
-
#customer_endpoint ⇒ Types::Endpoint
Endpoint of the customer for which contact will be initiated.
-
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
-
#queue_id ⇒ String
The identifier of the queue associated with the Connect Customer instance in which contacts that are created will be queued.
-
#request_identifier ⇒ String
Identifier to uniquely identify individual requests in the batch.
-
#system_endpoint ⇒ Types::Endpoint
Endpoint associated with the Connect Customer instance from which outbound contact will be initiated for the campaign.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
List of attributes to be stored in a contact.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#campaign ⇒ Types::Campaign
Structure to store information associated with a campaign.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#customer_endpoint ⇒ Types::Endpoint
Endpoint of the customer for which contact will be initiated.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier of the queue associated with the Connect Customer instance in which contacts that are created will be queued.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#request_identifier ⇒ String
Identifier to uniquely identify individual requests in the batch.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#system_endpoint ⇒ Types::Endpoint
Endpoint associated with the Connect Customer instance from which outbound contact will be initiated for the campaign.
4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 |
# File 'lib/aws-sdk-connect/types.rb', line 4196 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |