Class: Aws::Connect::Types::ContactFlowAttributeFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactFlowAttributeFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Filter for contact flow attributes with multiple condition types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_condition ⇒ Types::ContactFlowAttributeAndCondition
A list of conditions which would be applied together with a AND condition.
-
#contact_flow_type_condition ⇒ Types::ContactFlowTypeCondition
Contact flow type condition within attribute filter.
-
#or_conditions ⇒ Array<Types::ContactFlowAttributeAndCondition>
A list of conditions which would be applied together with an OR condition.
-
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition, for example, ‘HAVE BPO = 123`.
Instance Attribute Details
#and_condition ⇒ Types::ContactFlowAttributeAndCondition
A list of conditions which would be applied together with a AND condition.
3955 3956 3957 3958 3959 3960 3961 3962 |
# File 'lib/aws-sdk-connect/types.rb', line 3955 class ContactFlowAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition, :contact_flow_type_condition) SENSITIVE = [] include Aws::Structure end |
#contact_flow_type_condition ⇒ Types::ContactFlowTypeCondition
Contact flow type condition within attribute filter.
3955 3956 3957 3958 3959 3960 3961 3962 |
# File 'lib/aws-sdk-connect/types.rb', line 3955 class ContactFlowAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition, :contact_flow_type_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::ContactFlowAttributeAndCondition>
A list of conditions which would be applied together with an OR condition.
3955 3956 3957 3958 3959 3960 3961 3962 |
# File 'lib/aws-sdk-connect/types.rb', line 3955 class ContactFlowAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition, :contact_flow_type_condition) SENSITIVE = [] include Aws::Structure end |
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition, for example, ‘HAVE BPO = 123`.
3955 3956 3957 3958 3959 3960 3961 3962 |
# File 'lib/aws-sdk-connect/types.rb', line 3955 class ContactFlowAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition, :contact_flow_type_condition) SENSITIVE = [] include Aws::Structure end |