Class: Aws::Connect::Types::ContactFlowModuleSearchCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The search criteria to be used to return flow modules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#and_conditionsArray<Types::ContactFlowModuleSearchCriteria>

A list of conditions which would be applied together with an AND condition.



4738
4739
4740
4741
4742
4743
4744
4745
4746
# File 'lib/aws-sdk-connect/types.rb', line 4738

class ContactFlowModuleSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition,
  :state_condition,
  :status_condition)
  SENSITIVE = []
  include Aws::Structure
end

#or_conditionsArray<Types::ContactFlowModuleSearchCriteria>

A list of conditions which would be applied together with an OR condition.



4738
4739
4740
4741
4742
4743
4744
4745
4746
# File 'lib/aws-sdk-connect/types.rb', line 4738

class ContactFlowModuleSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition,
  :state_condition,
  :status_condition)
  SENSITIVE = []
  include Aws::Structure
end

#state_conditionString

The state of the flow.

Returns:

  • (String)


4738
4739
4740
4741
4742
4743
4744
4745
4746
# File 'lib/aws-sdk-connect/types.rb', line 4738

class ContactFlowModuleSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition,
  :state_condition,
  :status_condition)
  SENSITIVE = []
  include Aws::Structure
end

#status_conditionString

The status of the flow.

Returns:

  • (String)


4738
4739
4740
4741
4742
4743
4744
4745
4746
# File 'lib/aws-sdk-connect/types.rb', line 4738

class ContactFlowModuleSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition,
  :state_condition,
  :status_condition)
  SENSITIVE = []
  include Aws::Structure
end

#string_conditionTypes::StringCondition

A leaf node condition which can be used to specify a string condition.



4738
4739
4740
4741
4742
4743
4744
4745
4746
# File 'lib/aws-sdk-connect/types.rb', line 4738

class ContactFlowModuleSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition,
  :state_condition,
  :status_condition)
  SENSITIVE = []
  include Aws::Structure
end