Class: Aws::Connect::Types::ContactFlowSearchFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactFlowSearchFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Filters to be applied to search results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_attribute_filter ⇒ Types::ContactFlowAttributeFilter
Flow attribute filter for contact flow search operations.
-
#tag_filter ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the
SearchFilter.
Instance Attribute Details
#flow_attribute_filter ⇒ Types::ContactFlowAttributeFilter
Flow attribute filter for contact flow search operations.
4321 4322 4323 4324 4325 4326 |
# File 'lib/aws-sdk-connect/types.rb', line 4321 class ContactFlowSearchFilter < Struct.new( :tag_filter, :flow_attribute_filter) SENSITIVE = [] include Aws::Structure end |
#tag_filter ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:
-
Top level list specifies conditions that need to be applied with
ORoperator -
Inner list specifies conditions that need to be applied with
ANDoperator.
4321 4322 4323 4324 4325 4326 |
# File 'lib/aws-sdk-connect/types.rb', line 4321 class ContactFlowSearchFilter < Struct.new( :tag_filter, :flow_attribute_filter) SENSITIVE = [] include Aws::Structure end |