Class: Aws::Connect::Types::ContactMetricValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactMetricValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
ContactMetricValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContactMetricValue corresponding to the set member.
Object which contains the number.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#number ⇒ Float
The number of type Double.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#number ⇒ Float
The number of type Double. This number is the contact’s position in queue.
4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/aws-sdk-connect/types.rb', line 4456 class ContactMetricValue < Struct.new( :number, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Number < ContactMetricValue; end class Unknown < ContactMetricValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4456 4457 4458 |
# File 'lib/aws-sdk-connect/types.rb', line 4456 def unknown @unknown end |