Class: Aws::Connect::Types::ContactSearchSummaryAiAgentInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information of the AI agent involved in the contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_agent_escalatedBoolean

A boolean flag indicating whether the contact initially handled by this AI agent was escalated to a human agent.

Returns:

  • (Boolean)


4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-connect/types.rb', line 4909

class ContactSearchSummaryAiAgentInfo < Struct.new(
  :ai_agent_version_id,
  :ai_agent_escalated,
  :ai_use_case)
  SENSITIVE = []
  include Aws::Structure
end

#ai_agent_version_idString

The unique identifier that specifies both the AI agent ID and its version number that was involved in the contact.

Returns:

  • (String)


4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-connect/types.rb', line 4909

class ContactSearchSummaryAiAgentInfo < Struct.new(
  :ai_agent_version_id,
  :ai_agent_escalated,
  :ai_use_case)
  SENSITIVE = []
  include Aws::Structure
end

#ai_use_caseString

The use case or scenario for which the AI agent is involved in the contact. Valid values are ‘AgentAssistance` and `SelfService`.

Returns:

  • (String)


4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-connect/types.rb', line 4909

class ContactSearchSummaryAiAgentInfo < Struct.new(
  :ai_agent_version_id,
  :ai_agent_escalated,
  :ai_use_case)
  SENSITIVE = []
  include Aws::Structure
end