Class: Aws::Connect::Types::ContentAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Optional attributes used to populate the content of an outbound web notification, such as recommender configuration for personalized content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recommender_configTypes::RecommenderConfig

Configuration for the recommender used to generate personalized recommendations for the notification content.



5131
5132
5133
5134
5135
# File 'lib/aws-sdk-connect/types.rb', line 5131

class ContentAttributes < Struct.new(
  :recommender_config)
  SENSITIVE = []
  include Aws::Structure
end