Class: Aws::Connect::Types::ControlPlaneAttributeFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ControlPlaneAttributeFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR or AND (List of List) input where:
-
The top level list specifies conditions that need to be applied with
ORoperator. -
The inner list specifies conditions that need to be applied with
ANDoperator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_condition ⇒ Types::CommonAttributeAndCondition
A list of conditions which would be applied together with an
ANDcondition. -
#or_conditions ⇒ Array<Types::CommonAttributeAndCondition>
A list of conditions which would be applied together with an
ORcondition. -
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition, for example, ‘HAVE BPO = 123`.
Instance Attribute Details
#and_condition ⇒ Types::CommonAttributeAndCondition
A list of conditions which would be applied together with an AND condition.
4665 4666 4667 4668 4669 4670 4671 |
# File 'lib/aws-sdk-connect/types.rb', line 4665 class ControlPlaneAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::CommonAttributeAndCondition>
A list of conditions which would be applied together with an OR condition.
4665 4666 4667 4668 4669 4670 4671 |
# File 'lib/aws-sdk-connect/types.rb', line 4665 class ControlPlaneAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition) SENSITIVE = [] include Aws::Structure end |
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition, for example, ‘HAVE BPO = 123`.
4665 4666 4667 4668 4669 4670 4671 |
# File 'lib/aws-sdk-connect/types.rb', line 4665 class ControlPlaneAttributeFilter < Struct.new( :or_conditions, :and_condition, :tag_condition) SENSITIVE = [] include Aws::Structure end |