Class: Aws::Connect::Types::CreateAuthCodeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:auth_code]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_codeString

The authorization code to use for establishing a session.

Returns:

  • (String)


5464
5465
5466
5467
5468
5469
5470
5471
# File 'lib/aws-sdk-connect/types.rb', line 5464

class CreateAuthCodeResponse < Struct.new(
  :auth_code,
  :session_id,
  :entity_type,
  :entity_id)
  SENSITIVE = [:auth_code]
  include Aws::Structure
end

#entity_idString

The identifier of the entity associated with the authorization code.

Returns:

  • (String)


5464
5465
5466
5467
5468
5469
5470
5471
# File 'lib/aws-sdk-connect/types.rb', line 5464

class CreateAuthCodeResponse < Struct.new(
  :auth_code,
  :session_id,
  :entity_type,
  :entity_id)
  SENSITIVE = [:auth_code]
  include Aws::Structure
end

#entity_typeString

The type of entity associated with the authorization code.

Returns:

  • (String)


5464
5465
5466
5467
5468
5469
5470
5471
# File 'lib/aws-sdk-connect/types.rb', line 5464

class CreateAuthCodeResponse < Struct.new(
  :auth_code,
  :session_id,
  :entity_type,
  :entity_id)
  SENSITIVE = [:auth_code]
  include Aws::Structure
end

#session_idString

The identifier of the session created with the authorization code.

Returns:

  • (String)


5464
5465
5466
5467
5468
5469
5470
5471
# File 'lib/aws-sdk-connect/types.rb', line 5464

class CreateAuthCodeResponse < Struct.new(
  :auth_code,
  :session_id,
  :entity_type,
  :entity_id)
  SENSITIVE = [:auth_code]
  include Aws::Structure
end