Class: Aws::Connect::Types::CreateContactFlowModuleVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateContactFlowModuleVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_module_id ⇒ String
The identifier of the flow module.
-
#description ⇒ String
The description of the flow module version.
-
#flow_module_content_sha_256 ⇒ String
Indicates the checksum value of the flow module content.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#contact_flow_module_id ⇒ String
The identifier of the flow module.
5817 5818 5819 5820 5821 5822 5823 5824 |
# File 'lib/aws-sdk-connect/types.rb', line 5817 class CreateContactFlowModuleVersionRequest < Struct.new( :instance_id, :description, :contact_flow_module_id, :flow_module_content_sha_256) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the flow module version.
5817 5818 5819 5820 5821 5822 5823 5824 |
# File 'lib/aws-sdk-connect/types.rb', line 5817 class CreateContactFlowModuleVersionRequest < Struct.new( :instance_id, :description, :contact_flow_module_id, :flow_module_content_sha_256) SENSITIVE = [] include Aws::Structure end |
#flow_module_content_sha_256 ⇒ String
Indicates the checksum value of the flow module content.
5817 5818 5819 5820 5821 5822 5823 5824 |
# File 'lib/aws-sdk-connect/types.rb', line 5817 class CreateContactFlowModuleVersionRequest < Struct.new( :instance_id, :description, :contact_flow_module_id, :flow_module_content_sha_256) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
5817 5818 5819 5820 5821 5822 5823 5824 |
# File 'lib/aws-sdk-connect/types.rb', line 5817 class CreateContactFlowModuleVersionRequest < Struct.new( :instance_id, :description, :contact_flow_module_id, :flow_module_content_sha_256) SENSITIVE = [] include Aws::Structure end |