Class: Aws::Connect::Types::CreateDataTableAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_table_idString

The unique identifier for the data table. Must also accept the table ARN with or without a version alias. If the version is provided as part of the identifier or ARN, the version must be one of the two available system managed aliases, $SAVED or $LATEST.

Returns:

  • (String)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description for the attribute. Must conform to Connect human readable string specification and have 0-250 characters. Whitespace trimmed before persisting.

Returns:

  • (String)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The unique identifier for the Amazon Connect instance.

Returns:

  • (String)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the attribute. Must conform to Connect human readable string specification and have 1-127 characters. Must not start with the reserved case insensitive values 'connect:' and 'aws:'. Whitespace trimmed before persisting. Must be unique for the data table using case-insensitive comparison.

Returns:

  • (String)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#primaryBoolean

Optional boolean that defaults to false. Determines if the value is used to identify a record in the table. Values for primary attributes must not be expressions.

Returns:

  • (Boolean)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#validationTypes::Validation

Optional validation rules for the attribute. Borrows heavily from JSON Schema - Draft 2020-12. The maximum length of arrays within validations and depth of validations is 5. There are default limits that apply to all types. Customer specified limits in excess of the default limits are not permitted.

Returns:



6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#value_typeString

The type of value allowed or the resultant type after the value's expression is evaluated. Must be one of TEXT, TEXT_LIST, NUMBER, NUMBER_LIST, and BOOLEAN.

Returns:

  • (String)


6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
# File 'lib/aws-sdk-connect/types.rb', line 6133

class CreateDataTableAttributeRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :name,
  :value_type,
  :description,
  :primary,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end