Class: Aws::Connect::Types::CreateDataTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description for the data table. Must conform to Connect human readable string specification and have 0-250 characters. Whitespace must be trimmed first.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The unique identifier for the Amazon Connect instance where the data table will be created.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the data table. Must conform to Connect human readable string specification and have 1-127 characters. Whitespace must be trimmed first. Must not start with the reserved case insensitive values 'connect:' and 'aws:'. Must be unique for the instance using case-insensitive comparison.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data table. One of PUBLISHED or SAVED. Required parameter that determines the initial state of the table.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Key value pairs for attribute based access control (TBAC or ABAC). Optional tags to apply to the data table for organization and access control purposes.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The IANA timezone identifier to use when resolving time based dynamic values. Required even if no time slices are specified.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#value_lock_levelString

The data level that concurrent value edits are locked on. One of DATA_TABLE, PRIMARY_VALUE, ATTRIBUTE, VALUE, and NONE. NONE is the default if unspecified. This determines how concurrent edits are handled when multiple users attempt to modify values simultaneously.



6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/aws-sdk-connect/types.rb', line 6275

class CreateDataTableRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :value_lock_level,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end