Class: Aws::Connect::Types::CreateNotificationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateNotificationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#content ⇒ Hash<String,String>
The localized content of the notification.
-
#expires_at ⇒ Time
The timestamp when the notification should expire and no longer be displayed to users.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#predefined_notification_id ⇒ String
The unique identifier for a notification.
-
#priority ⇒ String
The priority level of the notification.
-
#recipients ⇒ Array<String>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Hash<String,String>
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#predefined_notification_id ⇒ String
The unique identifier for a notification.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#recipients ⇒ Array<String>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this
resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 |
# File 'lib/aws-sdk-connect/types.rb', line 6994 class CreateNotificationRequest < Struct.new( :instance_id, :expires_at, :recipients, :priority, :content, :tags, :predefined_notification_id, :client_token) SENSITIVE = [] include Aws::Structure end |