Class: Aws::Connect::Types::CreatePredefinedAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_configurationTypes::InputPredefinedAttributeConfiguration

Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.



7241
7242
7243
7244
7245
7246
7247
7248
7249
# File 'lib/aws-sdk-connect/types.rb', line 7241

class CreatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



7241
7242
7243
7244
7245
7246
7247
7248
7249
# File 'lib/aws-sdk-connect/types.rb', line 7241

class CreatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the predefined attribute.



7241
7242
7243
7244
7245
7246
7247
7248
7249
# File 'lib/aws-sdk-connect/types.rb', line 7241

class CreatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#purposesArray<String>

Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Connect Customer admin website.



7241
7242
7243
7244
7245
7246
7247
7248
7249
# File 'lib/aws-sdk-connect/types.rb', line 7241

class CreatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#valuesTypes::PredefinedAttributeValues

The values of the predefined attribute.



7241
7242
7243
7244
7245
7246
7247
7248
7249
# File 'lib/aws-sdk-connect/types.rb', line 7241

class CreatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end