Class: Aws::Connect::Types::CreateQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the queue.

Returns:

  • (String)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#email_addresses_configArray<Types::EmailAddressConfig>

Configuration list containing the email addresses to associate with the queue during creation. Each configuration specifies an email address ID that agents can select when handling email contacts in this queue.

Returns:



7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operation_idString

The identifier for the hours of operation.

Returns:

  • (String)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#max_contactsInteger

The maximum number of contacts that can be in the queue before it is considered full.

Returns:

  • (Integer)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the queue.

Returns:

  • (String)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outbound_caller_configTypes::OutboundCallerConfig

The outbound caller ID name, number, and outbound whisper flow.



7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outbound_email_configTypes::OutboundEmailConfig

The outbound email address ID for a specified queue.



7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#quick_connect_idsArray<String>

The quick connects available to agents who are working the queue.

Returns:

  • (Array<String>)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-connect/types.rb', line 7120

class CreateQueueRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :outbound_caller_config,
  :outbound_email_config,
  :hours_of_operation_id,
  :max_contacts,
  :quick_connect_ids,
  :email_addresses_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end