Class: Aws::Connect::Types::CreateQuickConnectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateQuickConnectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the quick connect.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
A unique name of the quick connect.
-
#quick_connect_config ⇒ Types::QuickConnectConfig
Configuration settings for the quick connect.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the quick connect.
7491 7492 7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/aws-sdk-connect/types.rb', line 7491 class CreateQuickConnectRequest < Struct.new( :instance_id, :name, :description, :quick_connect_config, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7491 7492 7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/aws-sdk-connect/types.rb', line 7491 class CreateQuickConnectRequest < Struct.new( :instance_id, :name, :description, :quick_connect_config, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name of the quick connect.
7491 7492 7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/aws-sdk-connect/types.rb', line 7491 class CreateQuickConnectRequest < Struct.new( :instance_id, :name, :description, :quick_connect_config, :tags) SENSITIVE = [] include Aws::Structure end |
#quick_connect_config ⇒ Types::QuickConnectConfig
Configuration settings for the quick connect.
7491 7492 7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/aws-sdk-connect/types.rb', line 7491 class CreateQuickConnectRequest < Struct.new( :instance_id, :name, :description, :quick_connect_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
7491 7492 7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/aws-sdk-connect/types.rb', line 7491 class CreateQuickConnectRequest < Struct.new( :instance_id, :name, :description, :quick_connect_config, :tags) SENSITIVE = [] include Aws::Structure end |