Class: Aws::Connect::Types::CreateRuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::RuleAction>

A list of actions to be run when the rule is triggered.

Returns:



7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#functionString

The conditions of the rule.

Returns:

  • (String)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name for the rule.

Returns:

  • (String)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#pre_evaluation_filtersTypes::PreEvaluationFilters

The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact. The pre-evaluation filters are applied even before rule conditions are evaluated and are used to enforce tag-based-access-control while applying rules.



7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status of the rule.

Returns:

  • (String)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_event_sourceTypes::RuleTriggerEventSource

The event source to trigger the rule.



7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
# File 'lib/aws-sdk-connect/types.rb', line 7682

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end