Class: Aws::Connect::Types::CreateVocabularyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs. If a create request is received more than once with same client token, subsequent requests return the previous response without creating a vocabulary again.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The content of the custom vocabulary in plain-text format with a table of values. Each row in the table represents a word or a phrase, described with Phrase, IPA, SoundsLike, and DisplayAs fields. Separate the fields with TAB characters. The size limit is 50KB. For more information, see Create a custom vocabulary using a table.

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see What is Amazon Transcribe?

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_nameString

A unique name of the custom vocabulary.

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-connect/types.rb', line 8394

class CreateVocabularyRequest < Struct.new(
  :client_token,
  :instance_id,
  :vocabulary_name,
  :language_code,
  :content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end