Class: Aws::Connect::Types::CreateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the workspace.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#name ⇒ String
The name of the workspace.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#theme ⇒ Types::WorkspaceTheme
The theme configuration for the workspace, including colors and styling.
-
#title ⇒ String
The title displayed for the workspace.
Instance Attribute Details
#description ⇒ String
The description of the workspace. Maximum length is 250 characters.
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID][1] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workspace. Must be unique within the instance and can contain 1-127 characters.
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, ‘{ “Tags”: “key2”:“value2” }`.
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#theme ⇒ Types::WorkspaceTheme
The theme configuration for the workspace, including colors and styling.
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title displayed for the workspace.
7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/aws-sdk-connect/types.rb', line 7745 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |