Class: Aws::Connect::Types::CreatedByInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreatedByInfo
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
CreatedByInfo is a union - when making an API calls you must set exactly one of the members.
CreatedByInfo is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CreatedByInfo corresponding to the set member.
Information on the identity that created the file.
Direct Known Subclasses
Defined Under Namespace
Classes: AwsIdentityArn, ConnectUserArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_identity_arn ⇒ String
STS or IAM ARN representing the identity of API Caller.
-
#connect_user_arn ⇒ String
An agent ARN representing a [connect user].
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#aws_identity_arn ⇒ String
STS or IAM ARN representing the identity of API Caller. SDK users cannot populate this and this value is calculated automatically if ConnectUserArn is not provided.
7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 |
# File 'lib/aws-sdk-connect/types.rb', line 7530 class CreatedByInfo < Struct.new( :connect_user_arn, :aws_identity_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < CreatedByInfo; end class AwsIdentityArn < CreatedByInfo; end class Unknown < CreatedByInfo; end end |
#connect_user_arn ⇒ String
An agent ARN representing a [connect user].
7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 |
# File 'lib/aws-sdk-connect/types.rb', line 7530 class CreatedByInfo < Struct.new( :connect_user_arn, :aws_identity_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < CreatedByInfo; end class AwsIdentityArn < CreatedByInfo; end class Unknown < CreatedByInfo; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7530 7531 7532 |
# File 'lib/aws-sdk-connect/types.rb', line 7530 def unknown @unknown end |