Class: Aws::Connect::Types::CurrentMetric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about a real-time metric. For a description of each metric, see [Metrics definitions] in the *Amazon Connect Administrator Guide*.

Only one of either the Name or MetricId is required.

[1]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_idString

Out of the box current metrics or custom metrics can be referenced via this field. This field is a valid AWS Connect Arn or a UUID.

Returns:

  • (String)


7447
7448
7449
7450
7451
7452
7453
# File 'lib/aws-sdk-connect/types.rb', line 7447

class CurrentMetric < Struct.new(
  :name,
  :metric_id,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the metric.

Returns:

  • (String)


7447
7448
7449
7450
7451
7452
7453
# File 'lib/aws-sdk-connect/types.rb', line 7447

class CurrentMetric < Struct.new(
  :name,
  :metric_id,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

<note markdown=“1”> The Unit parameter is not supported for custom metrics.

</note>

The unit for the metric.

Returns:

  • (String)


7447
7448
7449
7450
7451
7452
7453
# File 'lib/aws-sdk-connect/types.rb', line 7447

class CurrentMetric < Struct.new(
  :name,
  :metric_id,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end