Class: Aws::Connect::Types::DataTableAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DataTableAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Represents an attribute (column) in a data table. Attributes define the schema and validation rules for values that can be stored in the table. They specify the data type, constraints, and whether the attribute is used as a primary key for record identification.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_id ⇒ String
The unique identifier for the attribute within the data table.
-
#data_table_arn ⇒ String
The Amazon Resource Name (ARN) of the data table that contains this attribute.
-
#data_table_id ⇒ String
The unique identifier of the data table that contains this attribute.
-
#description ⇒ String
An optional description explaining the purpose and usage of this attribute.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this attribute was last modified, used for region replication.
-
#last_modified_time ⇒ Time
The timestamp when this attribute was last modified.
-
#lock_version ⇒ Types::DataTableLockVersion
The lock version for this attribute, used for optimistic locking to prevent concurrent modification conflicts.
-
#name ⇒ String
The human-readable name of the attribute.
-
#primary ⇒ Boolean
Boolean indicating whether this attribute is used as a primary key for record identification.
-
#validation ⇒ Types::Validation
The validation rules applied to values of this attribute.
-
#value_type ⇒ String
The type of value allowed for this attribute.
-
#version ⇒ String
The version identifier for this attribute, used for versioning and change tracking.
Instance Attribute Details
#attribute_id ⇒ String
The unique identifier for the attribute within the data table.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#data_table_arn ⇒ String
The Amazon Resource Name (ARN) of the data table that contains this attribute.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#data_table_id ⇒ String
The unique identifier of the data table that contains this attribute.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description explaining the purpose and usage of this attribute.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this attribute was last modified, used for region replication.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this attribute was last modified.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#lock_version ⇒ Types::DataTableLockVersion
The lock version for this attribute, used for optimistic locking to prevent concurrent modification conflicts.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The human-readable name of the attribute. Must be unique within the data table and conform to Connect naming standards.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#primary ⇒ Boolean
Boolean indicating whether this attribute is used as a primary key for record identification. Primary attributes must have unique value combinations and cannot contain expressions.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#validation ⇒ Types::Validation
The validation rules applied to values of this attribute. Based on JSON Schema Draft 2020-12 with additional Connect-specific validations for data integrity.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#value_type ⇒ String
The type of value allowed for this attribute. Must be one of TEXT, TEXT_LIST, NUMBER, NUMBER_LIST, or BOOLEAN. Determines how values are validated and processed.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version identifier for this attribute, used for versioning and change tracking.
9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-connect/types.rb', line 9074 class DataTableAttribute < Struct.new( :attribute_id, :name, :value_type, :description, :data_table_id, :data_table_arn, :primary, :version, :lock_version, :last_modified_time, :last_modified_region, :validation) SENSITIVE = [] include Aws::Structure end |