Class: Aws::Connect::Types::DataTableSearchFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A data table search filter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_filterTypes::ControlPlaneAttributeFilter

An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR or AND (List of List) input where:

  • The top level list specifies conditions that need to be applied with OR operator.

  • The inner list specifies conditions that need to be applied with AND operator.



7993
7994
7995
7996
7997
# File 'lib/aws-sdk-connect/types.rb', line 7993

class DataTableSearchFilter < Struct.new(
  :attribute_filter)
  SENSITIVE = []
  include Aws::Structure
end