Class: Aws::Connect::Types::DateCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DateCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An object to specify the hours of operation override date condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_type ⇒ String
An object to specify the hours of operation override date condition ‘comparisonType`.
-
#field_name ⇒ String
An object to specify the hours of operation override date field.
-
#value ⇒ String
An object to specify the hours of operation override date value.
Instance Attribute Details
#comparison_type ⇒ String
An object to specify the hours of operation override date condition ‘comparisonType`.
8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-connect/types.rb', line 8475 class DateCondition < Struct.new( :field_name, :value, :comparison_type) SENSITIVE = [] include Aws::Structure end |
#field_name ⇒ String
An object to specify the hours of operation override date field.
8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-connect/types.rb', line 8475 class DateCondition < Struct.new( :field_name, :value, :comparison_type) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
An object to specify the hours of operation override date value.
8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-connect/types.rb', line 8475 class DateCondition < Struct.new( :field_name, :value, :comparison_type) SENSITIVE = [] include Aws::Structure end |