Class: Aws::Connect::Types::DateTimeCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DateTimeCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A datetime search condition for Search APIs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_type ⇒ String
Datetime property comparison type.
-
#field_name ⇒ String
A name of the datetime property to be searched.
-
#max_value ⇒ String
A maximum value of the property.
-
#min_value ⇒ String
A minimum value of the property.
Instance Attribute Details
#comparison_type ⇒ String
Datetime property comparison type.
8589 8590 8591 8592 8593 8594 8595 8596 |
# File 'lib/aws-sdk-connect/types.rb', line 8589 class DateTimeCondition < Struct.new( :field_name, :min_value, :max_value, :comparison_type) SENSITIVE = [] include Aws::Structure end |
#field_name ⇒ String
A name of the datetime property to be searched
8589 8590 8591 8592 8593 8594 8595 8596 |
# File 'lib/aws-sdk-connect/types.rb', line 8589 class DateTimeCondition < Struct.new( :field_name, :min_value, :max_value, :comparison_type) SENSITIVE = [] include Aws::Structure end |
#max_value ⇒ String
A maximum value of the property.
8589 8590 8591 8592 8593 8594 8595 8596 |
# File 'lib/aws-sdk-connect/types.rb', line 8589 class DateTimeCondition < Struct.new( :field_name, :min_value, :max_value, :comparison_type) SENSITIVE = [] include Aws::Structure end |
#min_value ⇒ String
A minimum value of the property.
8589 8590 8591 8592 8593 8594 8595 8596 |
# File 'lib/aws-sdk-connect/types.rb', line 8589 class DateTimeCondition < Struct.new( :field_name, :min_value, :max_value, :comparison_type) SENSITIVE = [] include Aws::Structure end |