Class: Aws::Connect::Types::DeleteContactDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_fieldsArray<String>

The categories of PII to redact from the contact. Valid values are CUSTOMER_ENDPOINT, ADDITIONAL_EMAIL_RECIPIENTS, and EMAIL_SUBJECT. ADDITIONAL_EMAIL_RECIPIENTS and EMAIL_SUBJECT are supported only for contacts in the email channel.

Returns:

  • (Array<String>)


9305
9306
9307
9308
9309
9310
9311
# File 'lib/aws-sdk-connect/types.rb', line 9305

class DeleteContactDataRequest < Struct.new(
  :instance_id,
  :contact_id,
  :contact_fields)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact. PII can be deleted only from a contact that has been disconnected (is in a terminated state).

Returns:

  • (String)


9305
9306
9307
9308
9309
9310
9311
# File 'lib/aws-sdk-connect/types.rb', line 9305

class DeleteContactDataRequest < Struct.new(
  :instance_id,
  :contact_id,
  :contact_fields)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


9305
9306
9307
9308
9309
9310
9311
# File 'lib/aws-sdk-connect/types.rb', line 9305

class DeleteContactDataRequest < Struct.new(
  :instance_id,
  :contact_id,
  :contact_fields)
  SENSITIVE = []
  include Aws::Structure
end