Class: Aws::Connect::Types::DescribeDataTableAttributeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeDataTableAttributeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ Types::DataTableAttribute
The complete attribute information including configuration, validation rules, lock version, and metadata.
Instance Attribute Details
#attribute ⇒ Types::DataTableAttribute
The complete attribute information including configuration, validation rules, lock version, and metadata.
10057 10058 10059 10060 10061 |
# File 'lib/aws-sdk-connect/types.rb', line 10057 class DescribeDataTableAttributeResponse < Struct.new( :attribute) SENSITIVE = [] include Aws::Structure end |