Class: Aws::Connect::Types::DescribeInstanceStorageConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeInstanceStorageConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#resource_type ⇒ String
A valid resource type.
Instance Attribute Details
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
10704 10705 10706 10707 10708 10709 10710 |
# File 'lib/aws-sdk-connect/types.rb', line 10704 class DescribeInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
10704 10705 10706 10707 10708 10709 10710 |
# File 'lib/aws-sdk-connect/types.rb', line 10704 class DescribeInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
A valid resource type.
10704 10705 10706 10707 10708 10709 10710 |
# File 'lib/aws-sdk-connect/types.rb', line 10704 class DescribeInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type) SENSITIVE = [] include Aws::Structure end |