Class: Aws::Connect::Types::DescribeNotificationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeNotificationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notification ⇒ Types::Notification
The complete notification information including content, priority, recipients, and metadata.
Instance Attribute Details
#notification ⇒ Types::Notification
The complete notification information including content, priority, recipients, and metadata.
11163 11164 11165 11166 11167 |
# File 'lib/aws-sdk-connect/types.rb', line 11163 class DescribeNotificationResponse < Struct.new( :notification) SENSITIVE = [] include Aws::Structure end |