Class: Aws::Connect::Types::DescribeTestCaseResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeTestCaseResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#test_case ⇒ Types::TestCase
The test case object containing all test case information.
Instance Attribute Details
#test_case ⇒ Types::TestCase
The test case object containing all test case information.
11608 11609 11610 11611 11612 |
# File 'lib/aws-sdk-connect/types.rb', line 11608 class DescribeTestCaseResponse < Struct.new( :test_case) SENSITIVE = [] include Aws::Structure end |