Class: Aws::Connect::Types::DeviceInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information regarding the device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operating_systemString

Operating system that the participant used for the call.

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
# File 'lib/aws-sdk-connect/types.rb', line 11735

class DeviceInfo < Struct.new(
  :platform_name,
  :platform_version,
  :operating_system)
  SENSITIVE = []
  include Aws::Structure
end

#platform_nameString

Name of the platform that the participant used for the call.

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
# File 'lib/aws-sdk-connect/types.rb', line 11735

class DeviceInfo < Struct.new(
  :platform_name,
  :platform_version,
  :operating_system)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

Version of the platform that the participant used for the call.

Returns:

  • (String)


11735
11736
11737
11738
11739
11740
11741
# File 'lib/aws-sdk-connect/types.rb', line 11735

class DeviceInfo < Struct.new(
  :platform_name,
  :platform_version,
  :operating_system)
  SENSITIVE = []
  include Aws::Structure
end