Class: Aws::Connect::Types::Dimensions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about the dimensions for a set of metrics.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_statusTypes::AgentStatusIdentifier

Information about the agent status assigned to the user.



10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#channelString

The channel used for grouping and filters.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#queueTypes::QueueReference

Information about the queue for which metrics are returned.



10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profileTypes::RoutingProfileReference

Information about the routing profile assigned to the user.



10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#routing_step_expressionString

The expression of a step in a routing criteria.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#subtypeString

The subtype of the channel used for the contact.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end

#validation_test_typeString

The testing and simulation type

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
# File 'lib/aws-sdk-connect/types.rb', line 10834

class Dimensions < Struct.new(
  :queue,
  :channel,
  :routing_profile,
  :routing_step_expression,
  :agent_status,
  :subtype,
  :validation_test_type)
  SENSITIVE = []
  include Aws::Structure
end