Class: Aws::Connect::Types::DisassociateAnalyticsDataSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_set_idString

The identifier of the dataset to remove.



12049
12050
12051
12052
12053
12054
12055
# File 'lib/aws-sdk-connect/types.rb', line 12049

class DisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_id,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



12049
12050
12051
12052
12053
12054
12055
# File 'lib/aws-sdk-connect/types.rb', line 12049

class DisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_id,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_account_idString

The identifier of the target account. Use to associate a dataset to a different account than the one containing the Connect Customer instance. If not specified, by default this value is the Amazon Web Services account that has the Connect Customer instance.



12049
12050
12051
12052
12053
12054
12055
# File 'lib/aws-sdk-connect/types.rb', line 12049

class DisassociateAnalyticsDataSetRequest < Struct.new(
  :instance_id,
  :data_set_id,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end