Class: Aws::Connect::Types::DisassociateLexBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_nameString

The name of the Amazon Lex bot. Maximum character limit of 50.

Returns:

  • (String)


12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-connect/types.rb', line 12125

class DisassociateLexBotRequest < Struct.new(
  :instance_id,
  :bot_name,
  :lex_region,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-connect/types.rb', line 12125

class DisassociateLexBotRequest < Struct.new(
  :instance_id,
  :bot_name,
  :lex_region,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-connect/types.rb', line 12125

class DisassociateLexBotRequest < Struct.new(
  :instance_id,
  :bot_name,
  :lex_region,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#lex_regionString

The Amazon Web Services Region in which the Amazon Lex bot has been created.

Returns:

  • (String)


12125
12126
12127
12128
12129
12130
12131
12132
# File 'lib/aws-sdk-connect/types.rb', line 12125

class DisassociateLexBotRequest < Struct.new(
  :instance_id,
  :bot_name,
  :lex_region,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end