Class: Aws::Connect::Types::DisassociateWorkspaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_listArray<Types::FailedBatchAssociationSummary>

A list of resources that failed to be disassociated from the workspace, including error details.

Returns:



11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-connect/types.rb', line 11547

class DisassociateWorkspaceResponse < Struct.new(
  :successful_list,
  :failed_list)
  SENSITIVE = []
  include Aws::Structure
end

#successful_listArray<Types::SuccessfulBatchAssociationSummary>

A list of resources that were successfully disassociated from the workspace.

Returns:



11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-connect/types.rb', line 11547

class DisassociateWorkspaceResponse < Struct.new(
  :successful_list,
  :failed_list)
  SENSITIVE = []
  include Aws::Structure
end