Class: Aws::Connect::Types::EffectiveHoursOfOperations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the hours of operations with the effective override applied.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateString

The date that the hours of operation or overrides applies to.

Returns:

  • (String)


12250
12251
12252
12253
12254
12255
# File 'lib/aws-sdk-connect/types.rb', line 12250

class EffectiveHoursOfOperations < Struct.new(
  :date,
  :operational_hours)
  SENSITIVE = []
  include Aws::Structure
end

#operational_hoursArray<Types::OperationalHour>

Information about the hours of operations with the effective override applied.

Returns:



12250
12251
12252
12253
12254
12255
# File 'lib/aws-sdk-connect/types.rb', line 12250

class EffectiveHoursOfOperations < Struct.new(
  :date,
  :operational_hours)
  SENSITIVE = []
  include Aws::Structure
end