Class: Aws::Connect::Types::EmailAddressConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Configuration object that specifies an email address to be associated with a queue. This configuration contains the identifier of the email address that should be linked to the queue for routing email contacts.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_address_idString

The identifier of the email address that should be associated with the queue. This email address must already exist in the Amazon Connect instance and will be used to route incoming email contacts to the specified queue.

Returns:

  • (String)


11720
11721
11722
11723
11724
# File 'lib/aws-sdk-connect/types.rb', line 11720

class EmailAddressConfig < Struct.new(
  :email_address_id)
  SENSITIVE = []
  include Aws::Structure
end