Class: Aws::Connect::Types::EmailAddressSearchFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Filters to be applied to search results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tag_filterTypes::ControlPlaneTagFilter

An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:

  • Top level list specifies conditions that need to be applied with OR operator

  • Inner list specifies conditions that need to be applied with AND operator.



11287
11288
11289
11290
11291
# File 'lib/aws-sdk-connect/types.rb', line 11287

class EmailAddressSearchFilter < Struct.new(
  :tag_filter)
  SENSITIVE = []
  include Aws::Structure
end