Class: Aws::Connect::Types::EvaluationAcknowledgementSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationAcknowledgementSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Summary information about an evaluation acknowledgement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
-
#acknowledged_time ⇒ Time
The time when an agent acknowledged the evaluation.
-
#acknowledger_comment ⇒ String
A comment from the agent when they confirmed they acknowledged the evaluation.
Instance Attribute Details
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
11794 11795 11796 11797 11798 11799 11800 |
# File 'lib/aws-sdk-connect/types.rb', line 11794 class EvaluationAcknowledgementSummary < Struct.new( :acknowledged_time, :acknowledged_by, :acknowledger_comment) SENSITIVE = [] include Aws::Structure end |
#acknowledged_time ⇒ Time
The time when an agent acknowledged the evaluation.
11794 11795 11796 11797 11798 11799 11800 |
# File 'lib/aws-sdk-connect/types.rb', line 11794 class EvaluationAcknowledgementSummary < Struct.new( :acknowledged_time, :acknowledged_by, :acknowledger_comment) SENSITIVE = [] include Aws::Structure end |
#acknowledger_comment ⇒ String
A comment from the agent when they confirmed they acknowledged the evaluation.
11794 11795 11796 11797 11798 11799 11800 |
# File 'lib/aws-sdk-connect/types.rb', line 11794 class EvaluationAcknowledgementSummary < Struct.new( :acknowledged_time, :acknowledged_by, :acknowledger_comment) SENSITIVE = [] include Aws::Structure end |