Class: Aws::Connect::Types::EvaluationAutomationRuleCategory
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationAutomationRuleCategory
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The Contact Lens category used by evaluation automation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
A category label.
-
#condition ⇒ String
An automation condition for a Contact Lens category.
-
#points_of_interest ⇒ Array<Types::EvaluationTranscriptPointOfInterest>
A point of interest in a contact transcript that indicates match of condition.
Instance Attribute Details
#category ⇒ String
A category label.
11765 11766 11767 11768 11769 11770 11771 |
# File 'lib/aws-sdk-connect/types.rb', line 11765 class EvaluationAutomationRuleCategory < Struct.new( :category, :condition, :points_of_interest) SENSITIVE = [] include Aws::Structure end |
#condition ⇒ String
An automation condition for a Contact Lens category.
11765 11766 11767 11768 11769 11770 11771 |
# File 'lib/aws-sdk-connect/types.rb', line 11765 class EvaluationAutomationRuleCategory < Struct.new( :category, :condition, :points_of_interest) SENSITIVE = [] include Aws::Structure end |
#points_of_interest ⇒ Array<Types::EvaluationTranscriptPointOfInterest>
A point of interest in a contact transcript that indicates match of condition.
11765 11766 11767 11768 11769 11770 11771 |
# File 'lib/aws-sdk-connect/types.rb', line 11765 class EvaluationAutomationRuleCategory < Struct.new( :category, :condition, :points_of_interest) SENSITIVE = [] include Aws::Structure end |