Class: Aws::Connect::Types::EvaluationFormAIVersionLifecycle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains the status and availability dates for an AI version, indicating when the version became active and when it reaches end of life.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_of_life_timeTime

The timestamp when this AI version reaches or reached end of life.

Returns:

  • (Time)


13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-connect/types.rb', line 13650

class EvaluationFormAIVersionLifecycle < Struct.new(
  :status,
  :start_of_life_time,
  :end_of_life_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_of_life_timeTime

The timestamp for when this AI version became available.

Returns:

  • (Time)


13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-connect/types.rb', line 13650

class EvaluationFormAIVersionLifecycle < Struct.new(
  :status,
  :start_of_life_time,
  :end_of_life_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the AI version. Valid values:

  • Latest - The most recent AI version.

  • Preview - An AI version available for preview.

  • Active - An AI version that is currently available.

  • Deprecated - An AI version that is no longer recommended for use.

  • Removed - An AI version that is no longer available.

Returns:

  • (String)


13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-connect/types.rb', line 13650

class EvaluationFormAIVersionLifecycle < Struct.new(
  :status,
  :start_of_life_time,
  :end_of_life_time)
  SENSITIVE = []
  include Aws::Structure
end