Class: Aws::Connect::Types::EvaluationFormAIVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormAIVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains the name and lifecycle information for an AI version that you can use when creating or updating an evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_version_lifecycle ⇒ Types::EvaluationFormAIVersionLifecycle
The lifecycle information for this AI version, including its status and availability dates.
-
#ai_version_name ⇒ String
The name of the AI version.
Instance Attribute Details
#ai_version_lifecycle ⇒ Types::EvaluationFormAIVersionLifecycle
The lifecycle information for this AI version, including its status and availability dates.
13647 13648 13649 13650 13651 13652 |
# File 'lib/aws-sdk-connect/types.rb', line 13647 class EvaluationFormAIVersionSummary < Struct.new( :ai_version_name, :ai_version_lifecycle) SENSITIVE = [] include Aws::Structure end |
#ai_version_name ⇒ String
The name of the AI version.
13647 13648 13649 13650 13651 13652 |
# File 'lib/aws-sdk-connect/types.rb', line 13647 class EvaluationFormAIVersionSummary < Struct.new( :ai_version_name, :ai_version_lifecycle) SENSITIVE = [] include Aws::Structure end |