Class: Aws::Connect::Types::EvaluationFormItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
EvaluationFormItem is a union - when making an API calls you must set exactly one of the members.
Note:
EvaluationFormItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormItem corresponding to the set member.
Information about an item from an evaluation form. The item must be either a section or a question.
Defined Under Namespace
Classes: Question, Section, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#question ⇒ Types::EvaluationFormQuestion
The information of the question.
-
#section ⇒ Types::EvaluationFormSection
The information of the section.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#question ⇒ Types::EvaluationFormQuestion
The information of the question.
13049 13050 13051 13052 13053 13054 13055 13056 13057 13058 13059 13060 |
# File 'lib/aws-sdk-connect/types.rb', line 13049 class EvaluationFormItem < Struct.new( :section, :question, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Section < EvaluationFormItem; end class Question < EvaluationFormItem; end class Unknown < EvaluationFormItem; end end |
#section ⇒ Types::EvaluationFormSection
The information of the section.
13049 13050 13051 13052 13053 13054 13055 13056 13057 13058 13059 13060 |
# File 'lib/aws-sdk-connect/types.rb', line 13049 class EvaluationFormItem < Struct.new( :section, :question, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Section < EvaluationFormItem; end class Question < EvaluationFormItem; end class Unknown < EvaluationFormItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
13049 13050 13051 |
# File 'lib/aws-sdk-connect/types.rb', line 13049 def unknown @unknown end |