Class: Aws::Connect::Types::EvaluationFormItemEnablementCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormItemEnablementCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A condition for item enablement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operands ⇒ Array<Types::EvaluationFormItemEnablementConditionOperand>
Operands of the enablement condition.
-
#operator ⇒ String
The operator to be used to be applied to operands if more than one provided.
Instance Attribute Details
#operands ⇒ Array<Types::EvaluationFormItemEnablementConditionOperand>
Operands of the enablement condition.
12039 12040 12041 12042 12043 12044 |
# File 'lib/aws-sdk-connect/types.rb', line 12039 class EvaluationFormItemEnablementCondition < Struct.new( :operands, :operator) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ String
The operator to be used to be applied to operands if more than one provided.
12039 12040 12041 12042 12043 12044 |
# File 'lib/aws-sdk-connect/types.rb', line 12039 class EvaluationFormItemEnablementCondition < Struct.new( :operands, :operator) SENSITIVE = [] include Aws::Structure end |