Class: Aws::Connect::Types::EvaluationFormMetricConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the metric configuration for an evaluation form question. Use this to associate a business outcome metric with a question.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_nameString

The name of the metric. Valid values are:

  • SALE_SUCCESS – Sale success.

  • CSAT – Customer satisfaction.

  • CHURN_PROPENSITY – Churn propensity.

  • SELF_SERVICE_SUCCESS – Self-service success.

  • PARTIAL_SELF_SERVICE_SUCCESS – Partial self-service success.

Returns:

  • (String)


13971
13972
13973
13974
13975
13976
# File 'lib/aws-sdk-connect/types.rb', line 13971

class EvaluationFormMetricConfiguration < Struct.new(
  :metric_type,
  :metric_name)
  SENSITIVE = []
  include Aws::Structure
end

#metric_typeString

The type of metric. Currently, only BUSINESS_OUTCOME is supported.

Returns:

  • (String)


13971
13972
13973
13974
13975
13976
# File 'lib/aws-sdk-connect/types.rb', line 13971

class EvaluationFormMetricConfiguration < Struct.new(
  :metric_type,
  :metric_name)
  SENSITIVE = []
  include Aws::Structure
end