Class: Aws::Connect::Types::EvaluationFormMultiSelectQuestionAutomationOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormMultiSelectQuestionAutomationOption
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
EvaluationFormMultiSelectQuestionAutomationOption is a union - when making an API calls you must set exactly one of the members.
Note:
EvaluationFormMultiSelectQuestionAutomationOption is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormMultiSelectQuestionAutomationOption corresponding to the set member.
An automation option for a multi-select question.
Direct Known Subclasses
Defined Under Namespace
Classes: RuleCategory, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rule_category ⇒ Types::MultiSelectQuestionRuleCategoryAutomation
Rule category configuration for this automation option.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#rule_category ⇒ Types::MultiSelectQuestionRuleCategoryAutomation
Rule category configuration for this automation option.
12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-connect/types.rb', line 12915 class EvaluationFormMultiSelectQuestionAutomationOption < Struct.new( :rule_category, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RuleCategory < EvaluationFormMultiSelectQuestionAutomationOption; end class Unknown < EvaluationFormMultiSelectQuestionAutomationOption; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12915 12916 12917 |
# File 'lib/aws-sdk-connect/types.rb', line 12915 def unknown @unknown end |