Class: Aws::Connect::Types::EvaluationFormNumericQuestionOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the option range used for scoring in numeric questions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automatic_failBoolean

The flag to mark the option as automatic fail. If an automatic fail answer is provided, the overall evaluation gets a score of 0.

Returns:

  • (Boolean)


13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#automatic_fail_configurationTypes::AutomaticFailConfiguration

A configuration for automatic fail.



13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#max_valueInteger

The maximum answer value of the range option.

Returns:

  • (Integer)


13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#min_valueInteger

The minimum answer value of the range option.

Returns:

  • (Integer)


13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#points_configurationTypes::QuestionOptionPointsConfiguration

The points configuration for point-based scoring.



13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scoreInteger

The score assigned to answer values within the range option.

Returns:

  • (Integer)


13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
# File 'lib/aws-sdk-connect/types.rb', line 13238

class EvaluationFormNumericQuestionOption < Struct.new(
  :min_value,
  :max_value,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end