Class: Aws::Connect::Types::EvaluationFormQuestion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a question from an evaluation form.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enablementTypes::EvaluationFormItemEnablementConfiguration

A question conditional enablement.



14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instructionsString

The instructions of the section.

Returns:

  • (String)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#metric_configurationTypes::EvaluationFormMetricConfiguration

The metric configuration for the question. Use this to associate a business outcome metric with the question.



14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#not_applicable_enabledBoolean

The flag to enable not applicable answers to the question.

Returns:

  • (Boolean)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_typeString

The type of the question.

Returns:

  • (String)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_type_propertiesTypes::EvaluationFormQuestionTypeProperties

The properties of the type of question. Text questions do not have to define question type properties.



14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the question. An identifier must be unique within the evaluation form.

Returns:

  • (String)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scoring_configurationTypes::EvaluationFormQuestionScoringConfiguration

The scoring configuration of the question.



14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the question.

Returns:

  • (String)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The scoring weight of the section.

Returns:

  • (Float)


14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
# File 'lib/aws-sdk-connect/types.rb', line 14237

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration,
  :metric_configuration)
  SENSITIVE = []
  include Aws::Structure
end