Class: Aws::Connect::Types::EvaluationFormSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the returned evaluation forms.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_version ⇒ Integer
Active version of the evaluation form.
-
#ai_version ⇒ String
The AI version to use for the evaluation form.
-
#auto_evaluation_enabled ⇒ Boolean
Whether automated evaluation is enabled.
-
#contact_interaction_type ⇒ String
The contact interaction type for this evaluation form.
-
#created_by ⇒ String
Who created the evaluation form.
-
#created_time ⇒ Time
When the evaluation form was created.
-
#description ⇒ String
The description of the evaluation form.
-
#evaluation_form_arn ⇒ String
The Amazon Resource Name (ARN) for the evaluation form resource.
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#evaluation_form_language ⇒ String
The language of the evaluation form.
-
#last_activated_by ⇒ String
The ID of user who last activated evaluation form.
-
#last_activated_time ⇒ Time
When the evaluation format was last activated.
-
#last_modified_by ⇒ String
Who changed the evaluation form.
-
#last_modified_time ⇒ Time
When the evaluation form was last changed.
-
#latest_version ⇒ Integer
Latest version of the evaluation form.
-
#status ⇒ String
The status of the evaluation form.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#title ⇒ String
The title of the evaluation form.
Instance Attribute Details
#active_version ⇒ Integer
Active version of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#ai_version ⇒ String
The AI version to use for the evaluation form. This specifies which AI model version is used for automated evaluations.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_enabled ⇒ Boolean
Whether automated evaluation is enabled.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#contact_interaction_type ⇒ String
The contact interaction type for this evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
Who created the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
When the evaluation form was created.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_arn ⇒ String
The Amazon Resource Name (ARN) for the evaluation form resource.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_language ⇒ String
The language of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#last_activated_by ⇒ String
The ID of user who last activated evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#last_activated_time ⇒ Time
When the evaluation format was last activated.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ String
Who changed the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the evaluation form was last changed.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#latest_version ⇒ Integer
Latest version of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the evaluation form.
14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 14545 14546 14547 14548 14549 14550 |
# File 'lib/aws-sdk-connect/types.rb', line 14529 class EvaluationFormSearchSummary < Struct.new( :evaluation_form_id, :evaluation_form_arn, :title, :status, :description, :created_time, :created_by, :last_modified_time, :last_modified_by, :last_activated_time, :last_activated_by, :latest_version, :active_version, :auto_evaluation_enabled, :evaluation_form_language, :contact_interaction_type, :tags, :ai_version) SENSITIVE = [] include Aws::Structure end |