Class: Aws::Connect::Types::EvaluationFormSection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a section from an evaluation form. A section can contain sections and/or questions. Evaluation forms can only contain sections and subsections (two level nesting).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instructionsString

The instructions of the section.

Returns:

  • (String)


14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#is_excluded_from_scoringBoolean

The flag to exclude the section from scoring.

Returns:

  • (Boolean)


14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::EvaluationFormItem>

The items of the section.

Returns:



14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the section. An identifier must be unique within the evaluation form.

Returns:

  • (String)


14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#score_thresholdsArray<Types::EvaluationFormScoreThreshold>

The score thresholds for performance categories.



14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the section.

Returns:

  • (String)


14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The scoring weight of the section.

Returns:

  • (Float)


14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
# File 'lib/aws-sdk-connect/types.rb', line 14010

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end