Class: Aws::Connect::Types::EvaluationFormSingleSelectQuestionAutomation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormSingleSelectQuestionAutomation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the automation configuration in single select questions. Automation options are evaluated in order, and the first matched option is applied. If no automation option matches, and there is a default option, then the default option is applied.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answer_source ⇒ Types::EvaluationFormQuestionAutomationAnswerSource
Automation answer source.
-
#default_option_ref_id ⇒ String
The identifier of the default answer option, when none of the automation options match the criteria.
-
#options ⇒ Array<Types::EvaluationFormSingleSelectQuestionAutomationOption>
The automation options of the single select question.
Instance Attribute Details
#answer_source ⇒ Types::EvaluationFormQuestionAutomationAnswerSource
Automation answer source.
14594 14595 14596 14597 14598 14599 14600 |
# File 'lib/aws-sdk-connect/types.rb', line 14594 class EvaluationFormSingleSelectQuestionAutomation < Struct.new( :options, :default_option_ref_id, :answer_source) SENSITIVE = [] include Aws::Structure end |
#default_option_ref_id ⇒ String
The identifier of the default answer option, when none of the automation options match the criteria.
14594 14595 14596 14597 14598 14599 14600 |
# File 'lib/aws-sdk-connect/types.rb', line 14594 class EvaluationFormSingleSelectQuestionAutomation < Struct.new( :options, :default_option_ref_id, :answer_source) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Array<Types::EvaluationFormSingleSelectQuestionAutomationOption>
The automation options of the single select question.
14594 14595 14596 14597 14598 14599 14600 |
# File 'lib/aws-sdk-connect/types.rb', line 14594 class EvaluationFormSingleSelectQuestionAutomation < Struct.new( :options, :default_option_ref_id, :answer_source) SENSITIVE = [] include Aws::Structure end |