Class: Aws::Connect::Types::EvaluationFormSingleSelectQuestionOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the automation configuration in single select questions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automatic_failBoolean

The flag to mark the option as automatic fail. If an automatic fail answer is provided, the overall evaluation gets a score of 0.

Returns:

  • (Boolean)


13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#automatic_fail_configurationTypes::AutomaticFailConfiguration

Whether automatic fail is configured on a single select question.



13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#points_configurationTypes::QuestionOptionPointsConfiguration

The points configuration for point-based scoring.



13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the answer option. An identifier must be unique within the question.

Returns:

  • (String)


13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scoreInteger

The score assigned to the answer option.

Returns:

  • (Integer)


13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#textString

The title of the answer option.

Returns:

  • (String)


13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
# File 'lib/aws-sdk-connect/types.rb', line 13904

class EvaluationFormSingleSelectQuestionOption < Struct.new(
  :ref_id,
  :text,
  :score,
  :automatic_fail,
  :automatic_fail_configuration,
  :points_configuration)
  SENSITIVE = []
  include Aws::Structure
end