Class: Aws::Connect::Types::EvaluationFormValidationFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormValidationFinding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a finding from the evaluation form validation process. Each finding identifies a structural issue or quality improvement opportunity for the evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the validation issue.
-
#issue_code ⇒ String
A code that identifies the type of validation issue found.
-
#items ⇒ Array<Types::EvaluationFormValidationFindingItem>
A list of evaluation form items affected by this finding.
-
#severity ⇒ String
The severity of the finding.
-
#suggestion ⇒ String
A suggested fix for the validation issue.
Instance Attribute Details
#description ⇒ String
A description of the validation issue.
14075 14076 14077 14078 14079 14080 14081 14082 14083 |
# File 'lib/aws-sdk-connect/types.rb', line 14075 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#issue_code ⇒ String
A code that identifies the type of validation issue found.
14075 14076 14077 14078 14079 14080 14081 14082 14083 |
# File 'lib/aws-sdk-connect/types.rb', line 14075 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::EvaluationFormValidationFindingItem>
A list of evaluation form items affected by this finding.
14075 14076 14077 14078 14079 14080 14081 14082 14083 |
# File 'lib/aws-sdk-connect/types.rb', line 14075 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the finding. Valid values: WARNING, ERROR.
14075 14076 14077 14078 14079 14080 14081 14082 14083 |
# File 'lib/aws-sdk-connect/types.rb', line 14075 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#suggestion ⇒ String
A suggested fix for the validation issue.
14075 14076 14077 14078 14079 14080 14081 14082 14083 |
# File 'lib/aws-sdk-connect/types.rb', line 14075 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |