Class: Aws::Connect::Types::EvaluationFormValidationFindingItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormValidationFindingItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about an evaluation form item affected by a validation finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#property ⇒ String
The specific property of the evaluation form item that the finding relates to.
-
#ref_id ⇒ String
The identifier of the evaluation form item (question or section) affected by the finding.
Instance Attribute Details
#property ⇒ String
The specific property of the evaluation form item that the finding relates to.
14100 14101 14102 14103 14104 14105 |
# File 'lib/aws-sdk-connect/types.rb', line 14100 class EvaluationFormValidationFindingItem < Struct.new( :ref_id, :property) SENSITIVE = [] include Aws::Structure end |
#ref_id ⇒ String
The identifier of the evaluation form item (question or section) affected by the finding.
14100 14101 14102 14103 14104 14105 |
# File 'lib/aws-sdk-connect/types.rb', line 14100 class EvaluationFormValidationFindingItem < Struct.new( :ref_id, :property) SENSITIVE = [] include Aws::Structure end |