Class: Aws::Connect::Types::EvaluationReviewRequestComment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A comment provided when requesting an evaluation review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commentString

The text content of the review request comment.

Returns:

  • (String)


13798
13799
13800
13801
13802
13803
13804
# File 'lib/aws-sdk-connect/types.rb', line 13798

class EvaluationReviewRequestComment < Struct.new(
  :comment,
  :created_time,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the evaluation review request comment.

Returns:

  • (String)


13798
13799
13800
13801
13802
13803
13804
# File 'lib/aws-sdk-connect/types.rb', line 13798

class EvaluationReviewRequestComment < Struct.new(
  :comment,
  :created_time,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp when the evaluation review request comment was created.

Returns:

  • (Time)


13798
13799
13800
13801
13802
13803
13804
# File 'lib/aws-sdk-connect/types.rb', line 13798

class EvaluationReviewRequestComment < Struct.new(
  :comment,
  :created_time,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end