Class: Aws::Connect::Types::EvaluationSearchFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Filters to be applied to search results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_filterTypes::ControlPlaneAttributeFilter

An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR or AND (List of List) input where:

  • The top level list specifies conditions that need to be applied with OR operator.

  • The inner list specifies conditions that need to be applied with AND operator.



13320
13321
13322
13323
13324
# File 'lib/aws-sdk-connect/types.rb', line 13320

class EvaluationSearchFilter < Struct.new(
  :attribute_filter)
  SENSITIVE = []
  include Aws::Structure
end