Class: Aws::Connect::Types::EvaluationSearchMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Metadata information about an evaluation search.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acknowledged_byString

The agent who acknowledged the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#acknowledged_timeTime

When the evaluation was acknowledged by the agent.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#acknowledger_commentString

The comment from the agent when they acknowledged the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#auto_evaluation_enabledBoolean

Whether auto-evaluation is enabled.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#auto_evaluation_statusString

The status of the contact auto evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#calibration_session_idString

The calibration session ID that this evaluation belongs to.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_agent_idString

The unique ID of the agent who handled the contact.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Connect Customer.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_participant_idString

Identifier for a contact participant in the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_participant_roleString

Role of a contact participant in the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#earned_pointsInteger

The points earned for the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#evaluator_arnString

The Amazon Resource Name (ARN) of the person who evaluated the contact.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#max_base_pointInteger

The maximum base points possible for the evaluation.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#performance_categoryString

The performance category for the evaluation score.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#review_idString

Identifier for the review.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#sampling_job_idString

Identifier of the sampling job.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_automatic_failBoolean

The flag that marks the item as automatic fail. If the item or a child item gets an automatic fail answer, this flag is true.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_not_applicableBoolean

The flag to mark the item as not applicable for scoring.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_percentageFloat

The total evaluation score expressed as a percentage.



15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/aws-sdk-connect/types.rb', line 15404

class  < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end