Class: Aws::Connect::Types::EvaluationSuggestedAnswerTranscriptMillisecondOffsets
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationSuggestedAnswerTranscriptMillisecondOffsets
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The milliseconds offset for transcript reference in suggested answer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#begin_offset_millis ⇒ Integer
Offset in milliseconds from the beginning of the transcript.
Instance Attribute Details
#begin_offset_millis ⇒ Integer
Offset in milliseconds from the beginning of the transcript.
15170 15171 15172 15173 15174 |
# File 'lib/aws-sdk-connect/types.rb', line 15170 class EvaluationSuggestedAnswerTranscriptMillisecondOffsets < Struct.new( :begin_offset_millis) SENSITIVE = [] include Aws::Structure end |