Class: Aws::Connect::Types::ExtractionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The extraction configuration that defines how data is extracted from customer interactions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#not_found_behaviorTypes::ExtractionDefinitionNotFoundBehavior

The behavior when the extraction cannot find the specified data in the interaction.



15604
15605
15606
15607
15608
15609
# File 'lib/aws-sdk-connect/types.rb', line 15604

class ExtractionConfiguration < Struct.new(
  :prompt_hint,
  :not_found_behavior)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_hintString

The prompt hint that guides the extraction. This text tells the generative AI model what data to look for in the customer interaction.

Returns:

  • (String)


15604
15605
15606
15607
15608
15609
# File 'lib/aws-sdk-connect/types.rb', line 15604

class ExtractionConfiguration < Struct.new(
  :prompt_hint,
  :not_found_behavior)
  SENSITIVE = []
  include Aws::Structure
end