Class: Aws::Connect::Types::ExtractionDefinitionDisplay
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ExtractionDefinitionDisplay
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The display configuration for an extraction definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#label ⇒ String
The label displayed in the agent workspace for this extraction definition.
Instance Attribute Details
#label ⇒ String
The label displayed in the agent workspace for this extraction definition.
15668 15669 15670 15671 15672 |
# File 'lib/aws-sdk-connect/types.rb', line 15668 class ExtractionDefinitionDisplay < Struct.new( :label) SENSITIVE = [] include Aws::Structure end |