Class: Aws::Connect::Types::ExtractionDefinitionNotFoundBehavior

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The behavior configuration when an extraction definition cannot find the target value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#behaviorString

The behavior type. USE_DEFAULT_VALUE returns the specified default value. OMIT excludes the field from the output.

Returns:

  • (String)


15688
15689
15690
15691
15692
15693
# File 'lib/aws-sdk-connect/types.rb', line 15688

class ExtractionDefinitionNotFoundBehavior < Struct.new(
  :behavior,
  :default_value)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueString

The default value to use when the behavior is USE_DEFAULT_VALUE.

Returns:

  • (String)


15688
15689
15690
15691
15692
15693
# File 'lib/aws-sdk-connect/types.rb', line 15688

class ExtractionDefinitionNotFoundBehavior < Struct.new(
  :behavior,
  :default_value)
  SENSITIVE = []
  include Aws::Structure
end