Class: Aws::Connect::Types::ExtractionDefinitionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ExtractionDefinitionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Summary information about an extraction definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_time ⇒ Time
The timestamp when the extraction definition was created.
-
#extraction_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the extraction definition.
-
#extraction_definition_id ⇒ String
The identifier of the extraction definition.
-
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the extraction definition.
-
#last_updated_time ⇒ Time
The timestamp when the extraction definition was last updated.
-
#name ⇒ String
The name of the extraction definition.
Instance Attribute Details
#created_time ⇒ Time
The timestamp when the extraction definition was created.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the extraction definition.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_id ⇒ String
The identifier of the extraction definition.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the extraction definition.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp when the extraction definition was last updated.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the extraction definition.
15724 15725 15726 15727 15728 15729 15730 15731 15732 15733 |
# File 'lib/aws-sdk-connect/types.rb', line 15724 class ExtractionDefinitionSummary < Struct.new( :name, :extraction_definition_id, :extraction_definition_arn, :created_time, :last_updated_time, :last_updated_by) SENSITIVE = [] include Aws::Structure end |