Class: Aws::Connect::Types::FilterV2

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains the filter to apply when retrieving metrics with the

GetMetricDataV2][1

API.

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_GetMetricDataV2.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_keyString

The key to use for filtering data. For example, QUEUE, ‘ROUTING_PROFILE, AGENT`, CHANNEL, AGENT_HIERARCHY_LEVEL_ONE, AGENT_HIERARCHY_LEVEL_TWO, AGENT_HIERARCHY_LEVEL_THREE, AGENT_HIERARCHY_LEVEL_FOUR, AGENT_HIERARCHY_LEVEL_FIVE. There must be at least 1 key and a maximum 5 keys.

Returns:

  • (String)


13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-connect/types.rb', line 13866

class FilterV2 < Struct.new(
  :filter_key,
  :filter_values,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#filter_valuesArray<String>

The identifiers to use for filtering data. For example, if you have a filter key of QUEUE, you would add queue IDs or ARNs in FilterValues.

Returns:

  • (Array<String>)


13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-connect/types.rb', line 13866

class FilterV2 < Struct.new(
  :filter_key,
  :filter_values,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#string_conditionTypes::FilterV2StringCondition

System defined filtering condition. For example, the NOT_EXISTS StringCondition returns documents where the field specified by FilterKey does not exist in the document.

When the NOT_EXISTS StringCondition is added to a FilterV2 object, FilterValues must be null or empty.



13866
13867
13868
13869
13870
13871
13872
# File 'lib/aws-sdk-connect/types.rb', line 13866

class FilterV2 < Struct.new(
  :filter_key,
  :filter_values,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end