Class: Aws::Connect::Types::FontFamily
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::FontFamily
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains font family configuration for workspace themes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default ⇒ String
The default font family to use in the workspace theme.
Instance Attribute Details
#default ⇒ String
The default font family to use in the workspace theme.
16009 16010 16011 16012 16013 |
# File 'lib/aws-sdk-connect/types.rb', line 16009 class FontFamily < Struct.new( :default) SENSITIVE = [] include Aws::Structure end |