Class: Aws::Connect::Types::GetContactMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


15455
15456
15457
15458
15459
15460
15461
# File 'lib/aws-sdk-connect/types.rb', line 15455

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


15455
15456
15457
15458
15459
15460
15461
# File 'lib/aws-sdk-connect/types.rb', line 15455

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<Types::ContactMetricInfo>

A list of contact level metrics to retrieve.Supported metrics include POSITION_IN_QUEUE (the contact's current position in the queue) and ESTIMATED_WAIT_TIME (the predicted time in seconds until the contact is connected to an agent)

Returns:



15455
15456
15457
15458
15459
15460
15461
# File 'lib/aws-sdk-connect/types.rb', line 15455

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end