Class: Aws::Connect::Types::GetCurrentMetricDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetCurrentMetricDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_metrics ⇒ Array<Types::CurrentMetric>
The metrics to retrieve.
-
#filters ⇒ Types::Filters
The filters to apply to returned metrics.
-
#groupings ⇒ Array<String>
Defines the level of aggregation for metrics data by a dimension(s).
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#sort_criteria ⇒ Array<Types::CurrentMetricSortCriteria>
The way to sort the resulting response based on metrics.
Instance Attribute Details
#current_metrics ⇒ Array<Types::CurrentMetric>
The metrics to retrieve. Specify the name or metricId, and unit for each metric. The following metrics are available. For a description of all the metrics, see Metrics definitions in the Connect Customer Administrator Guide.
AGENTS_AFTER_CONTACT_WORK
: Unit: COUNT
Name in real-time metrics report: [ACW][2]
AGENTS_AVAILABLE
: Unit: COUNT
Name in real-time metrics report: [Available][3]
AGENTS_ERROR
: Unit: COUNT
Name in real-time metrics report: [Error][4]
AGENTS_NON_PRODUCTIVE
: Unit: COUNT
Name in real-time metrics report: [NPT (Non-Productive Time)][5]
AGENTS_ON_CALL
: Unit: COUNT
Name in real-time metrics report: [On contact][6]
AGENTS_ON_CONTACT
: Unit: COUNT
Name in real-time metrics report: [On contact][6]
AGENTS_ONLINE
: Unit: COUNT
Name in real-time metrics report: [Online][7]
AGENTS_STAFFED
: Unit: COUNT
Name in real-time metrics report: [Staffed][8]
CONTACTS_IN_QUEUE
: Unit: COUNT
Name in real-time metrics report: [In queue][9]
CONTACTS_SCHEDULED
: Unit: COUNT
Name in real-time metrics report: [Scheduled][10]
ESTIMATED_WAIT_TIME
: Unit: SECONDS
This metric supports filter and grouping combination only used for
core routing purpose. Valid filter and grouping use cases:
* Filter by a list of \[Queues\] and a list of \[Channels\], group
by \[“QUEUE”, “CHANNEL”\]
* Filter by a singleton list of \[Queue\], a singleton list of
\[Channel\], a list of \[RoutingStepExpression\], group by
\[“ROUTING\_STEP\_EXPRESSION”\].
OLDEST_CONTACT_AGE
: Unit: SECONDS
When you use groupings, Unit says SECONDS and the Value is
returned in SECONDS.
When you do not use groupings, Unit says SECONDS but the Value is
returned in MILLISECONDS. For example, if you get a response like
this:
`{ "Metric": { "Name": "OLDEST_CONTACT_AGE", "Unit": "SECONDS" },
"Value": 24113.0 `}
The actual OLDEST\_CONTACT\_AGE is 24 seconds.
When the filter `RoutingStepExpression` is used, this metric is
still calculated from enqueue time. For example, if a contact that
has been queued under `<Expression 1>` for 10 seconds has expired
and `<Expression 2>` becomes active, then `OLDEST_CONTACT_AGE` for
this queue will be counted starting from 10, not 0.
Name in real-time metrics report: [Oldest][11]
SLOTS_ACTIVE
: Unit: COUNT
Name in real-time metrics report: [Active][12]
SLOTS_AVAILABLE
: Unit: COUNT
Name in real-time metrics report: [Availability][13]
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::Filters
The filters to apply to returned metrics. You can filter up to the following limits:
-
Queues: 100
-
Routing profiles: 100
-
Channels: 3 (VOICE, CHAT, and TASK channels are supported.)
-
RoutingStepExpressions: 50
-
AgentStatuses: 50
-
Subtypes: 10
-
ValidationTestTypes: 10
Metric data is retrieved only for the resources associated with the queues or routing profiles, and by any channels included in the filter. (You cannot filter by both queue AND routing profile.) You can include both resource IDs and resource ARNs in the same request.
When using AgentStatuses as filter make sure Queues is added as
primary filter.
When using Subtypes as filter make sure Queues is added as primary
filter.
When using ValidationTestTypes as filter make sure Queues is added
as primary filter.
When using the RoutingStepExpression filter, you need to pass
exactly one QueueId. The filter is also case sensitive so when
using the RoutingStepExpression filter, grouping by
ROUTING_STEP_EXPRESSION is required.
Currently tagging is only supported on the resources that are passed in the filter.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#groupings ⇒ Array<String>
Defines the level of aggregation for metrics data by a dimension(s).
Its similar to sorting items into buckets based on a common
characteristic, then counting or calculating something for each
bucket. For example, when grouped by QUEUE, the metrics returned
apply to each queue rather than aggregated for all queues.
The grouping list is an ordered list, with the first item in the list defined as the primary grouping. If no grouping is included in the request, the aggregation happens at the instance-level.
-
If you group by
CHANNEL, you should include a Channels filter. VOICE, CHAT, and TASK channels are supported. -
If you group by
AGENT_STATUS, you must include theQUEUEas the primary grouping and use queue filter. When you group byAGENT_STATUS, the only metric available is theAGENTS_ONLINEmetric. -
If you group by
SUBTYPEorVALIDATION_TEST_TYPEas secondary grouping then you must includeQUEUEas primary grouping and use Queue as filter -
If you group by
ROUTING_PROFILE, you must include either a queue or routing profile filter. In addition, a routing profile filter is required for metricsCONTACTS_SCHEDULED,CONTACTS_IN_QUEUE, andOLDEST_CONTACT_AGE. -
When using the
RoutingStepExpressionfilter, group byROUTING_STEP_EXPRESSIONis required.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
The token expires after 5 minutes from the time it is created. Subsequent requests that use the token must use the same request parameters as the request that generated the token.
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Array<Types::CurrentMetricSortCriteria>
The way to sort the resulting response based on metrics. You can
enter one sort criteria. By default resources are sorted based on
AGENTS_ONLINE, DESCENDING. The metric collection is sorted based
on the input metrics.
Note the following:
- Sorting on
SLOTS_ACTIVEandSLOTS_AVAILABLEis not supported.
^
15740 15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 |
# File 'lib/aws-sdk-connect/types.rb', line 15740 class GetCurrentMetricDataRequest < Struct.new( :instance_id, :filters, :groupings, :current_metrics, :next_token, :max_results, :sort_criteria) SENSITIVE = [] include Aws::Structure end |