Class: Aws::Connect::Types::GetCurrentUserDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total count of the result, regardless of the current page size.

Returns:

  • (Integer)


16023
16024
16025
16026
16027
16028
16029
# File 'lib/aws-sdk-connect/types.rb', line 16023

class GetCurrentUserDataResponse < Struct.new(
  :next_token,
  :user_data_list,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


16023
16024
16025
16026
16027
16028
16029
# File 'lib/aws-sdk-connect/types.rb', line 16023

class GetCurrentUserDataResponse < Struct.new(
  :next_token,
  :user_data_list,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#user_data_listArray<Types::UserData>

A list of the user data that is returned.

Returns:



16023
16024
16025
16026
16027
16028
16029
# File 'lib/aws-sdk-connect/types.rb', line 16023

class GetCurrentUserDataResponse < Struct.new(
  :next_token,
  :user_data_list,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end