Class: Aws::Connect::Types::GetTaskTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN).

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#constraintsTypes::TaskTemplateConstraints

Constraints that are applicable to the fields listed. Although this parameter is marked as optional in the API model, the service requires it when calling CreateTaskTemplate or UpdateTaskTemplate. The RequiredFields array must contain at least one element, and the field of type NAME must be included in RequiredFields.



19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow that runs by default when a task is created by referencing this template.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp when the task template was created.

Returns:

  • (Time)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#defaultsTypes::TaskTemplateDefaults

The default values for fields when a task is created by referencing this template.



19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the task template.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsArray<Types::TaskTemplateField>

Fields that are part of the template.

Returns:



19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the task template.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the task template was last modified.

Returns:

  • (Time)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the task template.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#self_assign_flow_idString

The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Marks a template as ACTIVE or INACTIVE for a task to refer to it. Tasks can only be created from ACTIVE templates. If a template is marked as INACTIVE, then a task that refers to this template cannot be created.

Returns:

  • (String)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
# File 'lib/aws-sdk-connect/types.rb', line 19296

class GetTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end