Class: Aws::Connect::Types::GetTrafficDistributionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


19373
19374
19375
19376
19377
# File 'lib/aws-sdk-connect/types.rb', line 19373

class GetTrafficDistributionRequest < Struct.new(
  :id)
  SENSITIVE = []
  include Aws::Structure
end