Class: Aws::Connect::Types::GetTrafficDistributionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetTrafficDistributionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_config ⇒ Types::AgentConfig
The distribution of agents between the instance and its replica(s).
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
-
#id ⇒ String
The identifier of the traffic distribution group.
-
#sign_in_config ⇒ Types::SignInConfig
The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).
-
#telephony_config ⇒ Types::TelephonyConfig
The distribution of traffic between the instance and its replicas.
Instance Attribute Details
#agent_config ⇒ Types::AgentConfig
The distribution of agents between the instance and its replica(s).
19144 19145 19146 19147 19148 19149 19150 19151 19152 |
# File 'lib/aws-sdk-connect/types.rb', line 19144 class GetTrafficDistributionResponse < Struct.new( :telephony_config, :id, :arn, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
19144 19145 19146 19147 19148 19149 19150 19151 19152 |
# File 'lib/aws-sdk-connect/types.rb', line 19144 class GetTrafficDistributionResponse < Struct.new( :telephony_config, :id, :arn, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
19144 19145 19146 19147 19148 19149 19150 19151 19152 |
# File 'lib/aws-sdk-connect/types.rb', line 19144 class GetTrafficDistributionResponse < Struct.new( :telephony_config, :id, :arn, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#sign_in_config ⇒ Types::SignInConfig
The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).
19144 19145 19146 19147 19148 19149 19150 19151 19152 |
# File 'lib/aws-sdk-connect/types.rb', line 19144 class GetTrafficDistributionResponse < Struct.new( :telephony_config, :id, :arn, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#telephony_config ⇒ Types::TelephonyConfig
The distribution of traffic between the instance and its replicas.
19144 19145 19146 19147 19148 19149 19150 19151 19152 |
# File 'lib/aws-sdk-connect/types.rb', line 19144 class GetTrafficDistributionResponse < Struct.new( :telephony_config, :id, :arn, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |