Class: Aws::Connect::Types::HoursOfOperationOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the hours of operations override.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configArray<Types::HoursOfOperationOverrideConfig>

Configuration information for the hours of operation override: day, start time, and end time.



18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the hours of operation override.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#effective_fromString

The date from which the hours of operation override would be effective.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#effective_tillString

The date until the hours of operation override is effective.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operation_arnString

The Amazon Resource Name (ARN) for the hours of operation.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operation_idString

The identifier for the hours of operation.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operation_override_idString

The identifier for the hours of operation override.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the hours of operation override.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#override_typeString

Whether the override will be defined as a standard or as a *recurring event*.

Returns:

  • (String)


18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end

#recurrence_configTypes::RecurrenceConfig

Configuration for a recurring event.



18743
18744
18745
18746
18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
# File 'lib/aws-sdk-connect/types.rb', line 18743

class HoursOfOperationOverride < Struct.new(
  :hours_of_operation_override_id,
  :hours_of_operation_id,
  :hours_of_operation_arn,
  :name,
  :description,
  :config,
  :effective_from,
  :effective_till,
  :recurrence_config,
  :override_type)
  SENSITIVE = []
  include Aws::Structure
end