Class: Aws::Connect::Types::InputPredefinedAttributeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_value_validation_on_associationBoolean

When this parameter is set to true, Connect Customer enforces strict validation on the specific values, if the values are predefined in attributes. The contact will store only valid and predefined values for the predefined attribute key.

Returns:

  • (Boolean)


19536
19537
19538
19539
19540
# File 'lib/aws-sdk-connect/types.rb', line 19536

class InputPredefinedAttributeConfiguration < Struct.new(
  :enable_value_validation_on_association)
  SENSITIVE = []
  include Aws::Structure
end