Class: Aws::Connect::Types::Instance
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Instance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The Connect Customer instance.
Constant Summary collapse
- SENSITIVE =
[:instance_alias]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the instance.
-
#created_time ⇒ Time
When the instance was created.
-
#id ⇒ String
The identifier of the Connect Customer instance.
-
#identity_management_type ⇒ String
The identity management type.
-
#inbound_calls_enabled ⇒ Boolean
Whether inbound calls are enabled.
-
#instance_access_url ⇒ String
This URL allows contact center users to access the Connect Customer admin website.
-
#instance_alias ⇒ String
The alias of instance.
-
#instance_status ⇒ String
The state of the instance.
-
#outbound_calls_enabled ⇒ Boolean
Whether outbound calls are enabled.
-
#service_role ⇒ String
The service role of the instance.
-
#status_reason ⇒ Types::InstanceStatusReason
Relevant details why the instance was not successfully created.
-
#tags ⇒ Hash<String,String>
The tags of an instance.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#created_time ⇒ Time
When the instance was created.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#identity_management_type ⇒ String
The identity management type.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#inbound_calls_enabled ⇒ Boolean
Whether inbound calls are enabled.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#instance_access_url ⇒ String
This URL allows contact center users to access the Connect Customer admin website.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#instance_alias ⇒ String
The alias of instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#instance_status ⇒ String
The state of the instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#outbound_calls_enabled ⇒ Boolean
Whether outbound calls are enabled.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#service_role ⇒ String
The service role of the instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#status_reason ⇒ Types::InstanceStatusReason
Relevant details why the instance was not successfully created.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of an instance.
21051 21052 21053 21054 21055 21056 21057 21058 21059 21060 21061 21062 21063 21064 21065 21066 |
# File 'lib/aws-sdk-connect/types.rb', line 21051 class Instance < Struct.new( :id, :arn, :identity_management_type, :instance_alias, :created_time, :service_role, :instance_status, :status_reason, :inbound_calls_enabled, :outbound_calls_enabled, :instance_access_url, :tags) SENSITIVE = [:instance_alias] include Aws::Structure end |