Class: Aws::Connect::Types::IntervalDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::IntervalDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the interval period to use for returning results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interval_period ⇒ String
IntervalPeriod: An aggregated grouping applied to request metrics. -
#time_zone ⇒ String
The timezone applied to requested metrics.
Instance Attribute Details
#interval_period ⇒ String
IntervalPeriod: An aggregated grouping applied to request metrics. Valid IntervalPeriod values are: FIFTEEN_MIN | THIRTY_MIN | HOUR | DAY | WEEK | TOTAL.
For example, if IntervalPeriod is selected THIRTY_MIN, StartTime and EndTime differs by 1 day, then Amazon Connect returns 48 results in the response. Each result is aggregated by the THIRTY_MIN period. By default Amazon Connect aggregates results based on the TOTAL interval period.
The following list describes restrictions on StartTime and EndTime based on what IntervalPeriod is requested.
-
FIFTEEN_MIN: The difference betweenStartTimeandEndTimemust be less than 3 days. -
THIRTY_MIN: The difference betweenStartTimeandEndTimemust be less than 3 days. -
HOUR: The difference betweenStartTimeandEndTimemust be less than 3 days. -
DAY: The difference betweenStartTimeandEndTimemust be less than 35 days. -
WEEK: The difference betweenStartTimeandEndTimemust be less than 35 days. -
TOTAL: The difference betweenStartTimeandEndTimemust be less than 35 days.
19191 19192 19193 19194 19195 19196 |
# File 'lib/aws-sdk-connect/types.rb', line 19191 class IntervalDetails < Struct.new( :time_zone, :interval_period) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The timezone applied to requested metrics.
19191 19192 19193 19194 19195 19196 |
# File 'lib/aws-sdk-connect/types.rb', line 19191 class IntervalDetails < Struct.new( :time_zone, :interval_period) SENSITIVE = [] include Aws::Structure end |