Class: Aws::Connect::Types::ListAgentStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAgentStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_status_types ⇒ Array<String>
Available agent status types.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#agent_status_types ⇒ Array<String>
Available agent status types.
19470 19471 19472 19473 19474 19475 19476 19477 |
# File 'lib/aws-sdk-connect/types.rb', line 19470 class ListAgentStatusRequest < Struct.new( :instance_id, :next_token, :max_results, :agent_status_types) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19470 19471 19472 19473 19474 19475 19476 19477 |
# File 'lib/aws-sdk-connect/types.rb', line 19470 class ListAgentStatusRequest < Struct.new( :instance_id, :next_token, :max_results, :agent_status_types) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
19470 19471 19472 19473 19474 19475 19476 19477 |
# File 'lib/aws-sdk-connect/types.rb', line 19470 class ListAgentStatusRequest < Struct.new( :instance_id, :next_token, :max_results, :agent_status_types) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19470 19471 19472 19473 19474 19475 19476 19477 |
# File 'lib/aws-sdk-connect/types.rb', line 19470 class ListAgentStatusRequest < Struct.new( :instance_id, :next_token, :max_results, :agent_status_types) SENSITIVE = [] include Aws::Structure end |