Class: Aws::Connect::Types::ListAnalyticsDataAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAnalyticsDataAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_id ⇒ String
The identifier of the dataset to get the association status.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#data_set_id ⇒ String
The identifier of the dataset to get the association status.
19561 19562 19563 19564 19565 19566 19567 19568 |
# File 'lib/aws-sdk-connect/types.rb', line 19561 class ListAnalyticsDataAssociationsRequest < Struct.new( :instance_id, :data_set_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19561 19562 19563 19564 19565 19566 19567 19568 |
# File 'lib/aws-sdk-connect/types.rb', line 19561 class ListAnalyticsDataAssociationsRequest < Struct.new( :instance_id, :data_set_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
19561 19562 19563 19564 19565 19566 19567 19568 |
# File 'lib/aws-sdk-connect/types.rb', line 19561 class ListAnalyticsDataAssociationsRequest < Struct.new( :instance_id, :data_set_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19561 19562 19563 19564 19565 19566 19567 19568 |
# File 'lib/aws-sdk-connect/types.rb', line 19561 class ListAnalyticsDataAssociationsRequest < Struct.new( :instance_id, :data_set_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |