Class: Aws::Connect::Types::ListAnalyticsDataLakeDataSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAnalyticsDataLakeDataSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
21880 21881 21882 21883 21884 21885 21886 |
# File 'lib/aws-sdk-connect/types.rb', line 21880 class ListAnalyticsDataLakeDataSetsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
21880 21881 21882 21883 21884 21885 21886 |
# File 'lib/aws-sdk-connect/types.rb', line 21880 class ListAnalyticsDataLakeDataSetsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21880 21881 21882 21883 21884 21885 21886 |
# File 'lib/aws-sdk-connect/types.rb', line 21880 class ListAnalyticsDataLakeDataSetsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |