Class: Aws::Connect::Types::ListAnalyticsDataLakeDataSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAnalyticsDataLakeDataSetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#results ⇒ Array<Types::AnalyticsDataSetsResult>
An array of successful results:
DataSetId,DataSetName.
Instance Attribute Details
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
20057 20058 20059 20060 20061 20062 |
# File 'lib/aws-sdk-connect/types.rb', line 20057 class ListAnalyticsDataLakeDataSetsResponse < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |
#results ⇒ Array<Types::AnalyticsDataSetsResult>
An array of successful results: DataSetId, DataSetName. This is a paginated API, so nextToken is given if there are more results to be returned.
20057 20058 20059 20060 20061 20062 |
# File 'lib/aws-sdk-connect/types.rb', line 20057 class ListAnalyticsDataLakeDataSetsResponse < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |