Class: Aws::Connect::Types::ListAssociatedContactsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAssociatedContactsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
19672 19673 19674 19675 19676 19677 19678 19679 |
# File 'lib/aws-sdk-connect/types.rb', line 19672 class ListAssociatedContactsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19672 19673 19674 19675 19676 19677 19678 19679 |
# File 'lib/aws-sdk-connect/types.rb', line 19672 class ListAssociatedContactsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
19672 19673 19674 19675 19676 19677 19678 19679 |
# File 'lib/aws-sdk-connect/types.rb', line 19672 class ListAssociatedContactsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19672 19673 19674 19675 19676 19677 19678 19679 |
# File 'lib/aws-sdk-connect/types.rb', line 19672 class ListAssociatedContactsRequest < Struct.new( :instance_id, :contact_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |