Class: Aws::Connect::Types::ListAuthenticationProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListAuthenticationProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19189 19190 19191 19192 19193 19194 19195 |
# File 'lib/aws-sdk-connect/types.rb', line 19189 class ListAuthenticationProfilesRequest < Struct.new( :instance_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
19189 19190 19191 19192 19193 19194 19195 |
# File 'lib/aws-sdk-connect/types.rb', line 19189 class ListAuthenticationProfilesRequest < Struct.new( :instance_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19189 19190 19191 19192 19193 19194 19195 |
# File 'lib/aws-sdk-connect/types.rb', line 19189 class ListAuthenticationProfilesRequest < Struct.new( :instance_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |