Class: Aws::Connect::Types::ListBotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



22194
22195
22196
22197
22198
22199
22200
22201
# File 'lib/aws-sdk-connect/types.rb', line 22194

class ListBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :lex_version)
  SENSITIVE = []
  include Aws::Structure
end

#lex_versionString

The version of Amazon Lex or Amazon Lex V2.



22194
22195
22196
22197
22198
22199
22200
22201
# File 'lib/aws-sdk-connect/types.rb', line 22194

class ListBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :lex_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



22194
22195
22196
22197
22198
22199
22200
22201
# File 'lib/aws-sdk-connect/types.rb', line 22194

class ListBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :lex_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



22194
22195
22196
22197
22198
22199
22200
22201
# File 'lib/aws-sdk-connect/types.rb', line 22194

class ListBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :lex_version)
  SENSITIVE = []
  include Aws::Structure
end