Class: Aws::Connect::Types::ListChildHoursOfOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListChildHoursOfOperationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hours_of_operation_id ⇒ String
The identifier of the parent hours of operation.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#hours_of_operation_id ⇒ String
The identifier of the parent hours of operation.
20290 20291 20292 20293 20294 20295 20296 20297 |
# File 'lib/aws-sdk-connect/types.rb', line 20290 class ListChildHoursOfOperationsRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
20290 20291 20292 20293 20294 20295 20296 20297 |
# File 'lib/aws-sdk-connect/types.rb', line 20290 class ListChildHoursOfOperationsRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
20290 20291 20292 20293 20294 20295 20296 20297 |
# File 'lib/aws-sdk-connect/types.rb', line 20290 class ListChildHoursOfOperationsRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20290 20291 20292 20293 20294 20295 20296 20297 |
# File 'lib/aws-sdk-connect/types.rb', line 20290 class ListChildHoursOfOperationsRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |