Class: Aws::Connect::Types::ListChildHoursOfOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#child_hours_of_operations_summary_listArray<Types::HoursOfOperationsIdentifier>

Information about the hours of operation.



19996
19997
19998
19999
20000
20001
20002
20003
# File 'lib/aws-sdk-connect/types.rb', line 19996

class ListChildHoursOfOperationsResponse < Struct.new(
  :next_token,
  :child_hours_of_operations_summary_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.

Returns:

  • (String)


19996
19997
19998
19999
20000
20001
20002
20003
# File 'lib/aws-sdk-connect/types.rb', line 19996

class ListChildHoursOfOperationsResponse < Struct.new(
  :next_token,
  :child_hours_of_operations_summary_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.

Returns:

  • (Time)


19996
19997
19998
19999
20000
20001
20002
20003
# File 'lib/aws-sdk-connect/types.rb', line 19996

class ListChildHoursOfOperationsResponse < Struct.new(
  :next_token,
  :child_hours_of_operations_summary_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


19996
19997
19998
19999
20000
20001
20002
20003
# File 'lib/aws-sdk-connect/types.rb', line 19996

class ListChildHoursOfOperationsResponse < Struct.new(
  :next_token,
  :child_hours_of_operations_summary_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end