Class: Aws::Connect::Types::ListContactEvaluationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


22331
22332
22333
22334
22335
22336
22337
# File 'lib/aws-sdk-connect/types.rb', line 22331

class ListContactEvaluationsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


22331
22332
22333
22334
22335
22336
22337
# File 'lib/aws-sdk-connect/types.rb', line 22331

class ListContactEvaluationsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

This is not expected to be set because the value returned in the previous response is always null.

Returns:

  • (String)


22331
22332
22333
22334
22335
22336
22337
# File 'lib/aws-sdk-connect/types.rb', line 22331

class ListContactEvaluationsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end