Class: Aws::Connect::Types::ListContactEvaluationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactEvaluationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_summary_list ⇒ Array<Types::EvaluationSummary>
Provides details about a list of contact evaluations belonging to an instance.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#evaluation_summary_list ⇒ Array<Types::EvaluationSummary>
Provides details about a list of contact evaluations belonging to an instance.
22353 22354 22355 22356 22357 22358 |
# File 'lib/aws-sdk-connect/types.rb', line 22353 class ListContactEvaluationsResponse < Struct.new( :evaluation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
This is always returned as null in the response.
22353 22354 22355 22356 22357 22358 |
# File 'lib/aws-sdk-connect/types.rb', line 22353 class ListContactEvaluationsResponse < Struct.new( :evaluation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |