Class: Aws::Connect::Types::ListContactFlowModuleAliasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactFlowModuleAliasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_module_id ⇒ String
The identifier of the flow module.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_flow_module_id ⇒ String
The identifier of the flow module.
22385 22386 22387 22388 22389 22390 22391 22392 |
# File 'lib/aws-sdk-connect/types.rb', line 22385 class ListContactFlowModuleAliasesRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
22385 22386 22387 22388 22389 22390 22391 22392 |
# File 'lib/aws-sdk-connect/types.rb', line 22385 class ListContactFlowModuleAliasesRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22385 22386 22387 22388 22389 22390 22391 22392 |
# File 'lib/aws-sdk-connect/types.rb', line 22385 class ListContactFlowModuleAliasesRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22385 22386 22387 22388 22389 22390 22391 22392 |
# File 'lib/aws-sdk-connect/types.rb', line 22385 class ListContactFlowModuleAliasesRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |