Class: Aws::Connect::Types::ListContactFlowModulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_flow_module_stateString

The state of the flow module.



22489
22490
22491
22492
22493
22494
22495
22496
# File 'lib/aws-sdk-connect/types.rb', line 22489

class ListContactFlowModulesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :contact_flow_module_state)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



22489
22490
22491
22492
22493
22494
22495
22496
# File 'lib/aws-sdk-connect/types.rb', line 22489

class ListContactFlowModulesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :contact_flow_module_state)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



22489
22490
22491
22492
22493
22494
22495
22496
# File 'lib/aws-sdk-connect/types.rb', line 22489

class ListContactFlowModulesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :contact_flow_module_state)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



22489
22490
22491
22492
22493
22494
22495
22496
# File 'lib/aws-sdk-connect/types.rb', line 22489

class ListContactFlowModulesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :contact_flow_module_state)
  SENSITIVE = []
  include Aws::Structure
end