Class: Aws::Connect::Types::ListContactFlowVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactFlowVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_id ⇒ String
The identifier of the flow.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_flow_id ⇒ String
The identifier of the flow.
22537 22538 22539 22540 22541 22542 22543 22544 |
# File 'lib/aws-sdk-connect/types.rb', line 22537 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance.
22537 22538 22539 22540 22541 22542 22543 22544 |
# File 'lib/aws-sdk-connect/types.rb', line 22537 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
22537 22538 22539 22540 22541 22542 22543 22544 |
# File 'lib/aws-sdk-connect/types.rb', line 22537 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22537 22538 22539 22540 22541 22542 22543 22544 |
# File 'lib/aws-sdk-connect/types.rb', line 22537 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |