Class: Aws::Connect::Types::ListContactReferencesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the initial contact.

Returns:

  • (String)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-connect/types.rb', line 22645

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-connect/types.rb', line 22645

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

This is not expected to be set, because the value returned in the previous response is always null.

Returns:

  • (String)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-connect/types.rb', line 22645

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reference_typesArray<String>

The type of reference.

Returns:

  • (Array<String>)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-connect/types.rb', line 22645

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end