Class: Aws::Connect::Types::ListContactReferencesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactReferencesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#reference_summary_list ⇒ Array<Types::ReferenceSummary>
Information about the flows.
Instance Attribute Details
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
This is always returned as null in the response.
22642 22643 22644 22645 22646 22647 |
# File 'lib/aws-sdk-connect/types.rb', line 22642 class ListContactReferencesResponse < Struct.new( :reference_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#reference_summary_list ⇒ Array<Types::ReferenceSummary>
Information about the flows.
22642 22643 22644 22645 22646 22647 |
# File 'lib/aws-sdk-connect/types.rb', line 22642 class ListContactReferencesResponse < Struct.new( :reference_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |