Class: Aws::Connect::Types::ListDataTableAttributesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesArray<Types::DataTableAttribute>

A list of data table attributes with their complete configuration and metadata.

Returns:



22723
22724
22725
22726
22727
22728
# File 'lib/aws-sdk-connect/types.rb', line 22723

class ListDataTableAttributesResponse < Struct.new(
  :next_token,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


22723
22724
22725
22726
22727
22728
# File 'lib/aws-sdk-connect/types.rb', line 22723

class ListDataTableAttributesResponse < Struct.new(
  :next_token,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end