Class: Aws::Connect::Types::ListDataTablePrimaryValuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListDataTablePrimaryValuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_table_id ⇒ String
The unique identifier for the data table whose primary values should be listed.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of data table primary values to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
-
#primary_attribute_values ⇒ Array<Types::PrimaryAttributeValueFilter>
Optional filter to retrieve primary values matching specific criteria.
-
#record_ids ⇒ Array<String>
Optional list of specific record IDs to retrieve.
Instance Attribute Details
#data_table_id ⇒ String
The unique identifier for the data table whose primary values should be listed.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data table primary values to return in one page of results.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#primary_attribute_values ⇒ Array<Types::PrimaryAttributeValueFilter>
Optional filter to retrieve primary values matching specific criteria.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#record_ids ⇒ Array<String>
Optional list of specific record IDs to retrieve. Used for CloudFormation to effectively describe records by ID. If NextToken is provided, this parameter is ignored.
22762 22763 22764 22765 22766 22767 22768 22769 22770 22771 |
# File 'lib/aws-sdk-connect/types.rb', line 22762 class ListDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |