Class: Aws::Connect::Types::ListDataTableValuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListDataTableValuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_table_id ⇒ String
The unique identifier for the data table whose values should be listed.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of data table values to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
-
#primary_attribute_values ⇒ Array<Types::PrimaryAttributeValueFilter>
Optional filter to retrieve values for records matching specific primary attribute criteria.
-
#record_ids ⇒ Array<String>
Optional list of specific record IDs to retrieve values for.
Instance Attribute Details
#data_table_id ⇒ String
The unique identifier for the data table whose values should be listed.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data table values to return in one page of results.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#primary_attribute_values ⇒ Array<Types::PrimaryAttributeValueFilter>
Optional filter to retrieve values for records matching specific primary attribute criteria.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#record_ids ⇒ Array<String>
Optional list of specific record IDs to retrieve values for.
20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 |
# File 'lib/aws-sdk-connect/types.rb', line 20864 class ListDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :record_ids, :primary_attribute_values, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |