Class: Aws::Connect::Types::ListDataTableValuesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-connect/types.rb', line 20887

class ListDataTableValuesResponse < Struct.new(
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Types::DataTableValueSummary>

A list of data table values with their associated metadata, lock versions, and modification details.

Returns:



20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-connect/types.rb', line 20887

class ListDataTableValuesResponse < Struct.new(
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end