Class: Aws::Connect::Types::ListDataTablesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The unique identifier for the Amazon Connect instance whose data tables should be listed.

Returns:

  • (String)


20910
20911
20912
20913
20914
20915
20916
# File 'lib/aws-sdk-connect/types.rb', line 20910

class ListDataTablesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of data tables to return in one page of results.

Returns:

  • (Integer)


20910
20911
20912
20913
20914
20915
20916
# File 'lib/aws-sdk-connect/types.rb', line 20910

class ListDataTablesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


20910
20911
20912
20913
20914
20915
20916
# File 'lib/aws-sdk-connect/types.rb', line 20910

class ListDataTablesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end