Class: Aws::Connect::Types::ListDefaultVocabulariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListDefaultVocabulariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#language_code ⇒ String
The language code of the vocabulary entries.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
22926 22927 22928 22929 22930 22931 22932 22933 |
# File 'lib/aws-sdk-connect/types.rb', line 22926 class ListDefaultVocabulariesRequest < Struct.new( :instance_id, :language_code, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see What is Amazon Transcribe?
22926 22927 22928 22929 22930 22931 22932 22933 |
# File 'lib/aws-sdk-connect/types.rb', line 22926 class ListDefaultVocabulariesRequest < Struct.new( :instance_id, :language_code, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22926 22927 22928 22929 22930 22931 22932 22933 |
# File 'lib/aws-sdk-connect/types.rb', line 22926 class ListDefaultVocabulariesRequest < Struct.new( :instance_id, :language_code, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22926 22927 22928 22929 22930 22931 22932 22933 |
# File 'lib/aws-sdk-connect/types.rb', line 22926 class ListDefaultVocabulariesRequest < Struct.new( :instance_id, :language_code, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |