Class: Aws::Connect::Types::ListEntitySecurityProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entity_arnString

ARN of a Q in Connect AI Agent.



20325
20326
20327
20328
20329
20330
20331
20332
20333
# File 'lib/aws-sdk-connect/types.rb', line 20325

class ListEntitySecurityProfilesRequest < Struct.new(
  :instance_id,
  :entity_type,
  :entity_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#entity_typeString

Only supported type is AI_AGENT.



20325
20326
20327
20328
20329
20330
20331
20332
20333
# File 'lib/aws-sdk-connect/types.rb', line 20325

class ListEntitySecurityProfilesRequest < Struct.new(
  :instance_id,
  :entity_type,
  :entity_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



20325
20326
20327
20328
20329
20330
20331
20332
20333
# File 'lib/aws-sdk-connect/types.rb', line 20325

class ListEntitySecurityProfilesRequest < Struct.new(
  :instance_id,
  :entity_type,
  :entity_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. The default MaxResult size is 100.



20325
20326
20327
20328
20329
20330
20331
20332
20333
# File 'lib/aws-sdk-connect/types.rb', line 20325

class ListEntitySecurityProfilesRequest < Struct.new(
  :instance_id,
  :entity_type,
  :entity_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



20325
20326
20327
20328
20329
20330
20331
20332
20333
# File 'lib/aws-sdk-connect/types.rb', line 20325

class ListEntitySecurityProfilesRequest < Struct.new(
  :instance_id,
  :entity_type,
  :entity_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end