Class: Aws::Connect::Types::ListEvaluationFormVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListEvaluationFormVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
20379 20380 20381 20382 20383 20384 20385 20386 |
# File 'lib/aws-sdk-connect/types.rb', line 20379 class ListEvaluationFormVersionsRequest < Struct.new( :instance_id, :evaluation_form_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
20379 20380 20381 20382 20383 20384 20385 20386 |
# File 'lib/aws-sdk-connect/types.rb', line 20379 class ListEvaluationFormVersionsRequest < Struct.new( :instance_id, :evaluation_form_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
20379 20380 20381 20382 20383 20384 20385 20386 |
# File 'lib/aws-sdk-connect/types.rb', line 20379 class ListEvaluationFormVersionsRequest < Struct.new( :instance_id, :evaluation_form_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20379 20380 20381 20382 20383 20384 20385 20386 |
# File 'lib/aws-sdk-connect/types.rb', line 20379 class ListEvaluationFormVersionsRequest < Struct.new( :instance_id, :evaluation_form_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |