Class: Aws::Connect::Types::ListEvaluationFormVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListEvaluationFormVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_form_version_summary_list ⇒ Array<Types::EvaluationFormVersionSummary>
Provides details about a list of evaluation forms belonging to an instance.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#evaluation_form_version_summary_list ⇒ Array<Types::EvaluationFormVersionSummary>
Provides details about a list of evaluation forms belonging to an instance.
20400 20401 20402 20403 20404 20405 |
# File 'lib/aws-sdk-connect/types.rb', line 20400 class ListEvaluationFormVersionsResponse < Struct.new( :evaluation_form_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
20400 20401 20402 20403 20404 20405 |
# File 'lib/aws-sdk-connect/types.rb', line 20400 class ListEvaluationFormVersionsResponse < Struct.new( :evaluation_form_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |