Class: Aws::Connect::Types::ListFlowAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



23234
23235
23236
23237
23238
23239
23240
23241
# File 'lib/aws-sdk-connect/types.rb', line 23234

class ListFlowAssociationsRequest < Struct.new(
  :instance_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



23234
23235
23236
23237
23238
23239
23240
23241
# File 'lib/aws-sdk-connect/types.rb', line 23234

class ListFlowAssociationsRequest < Struct.new(
  :instance_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



23234
23235
23236
23237
23238
23239
23240
23241
# File 'lib/aws-sdk-connect/types.rb', line 23234

class ListFlowAssociationsRequest < Struct.new(
  :instance_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

A valid resource type.



23234
23235
23236
23237
23238
23239
23240
23241
# File 'lib/aws-sdk-connect/types.rb', line 23234

class ListFlowAssociationsRequest < Struct.new(
  :instance_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end