Class: Aws::Connect::Types::ListHoursOfOperationOverridesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListHoursOfOperationOverridesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
23256 23257 23258 23259 23260 23261 23262 23263 |
# File 'lib/aws-sdk-connect/types.rb', line 23256 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance.
23256 23257 23258 23259 23260 23261 23262 23263 |
# File 'lib/aws-sdk-connect/types.rb', line 23256 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23256 23257 23258 23259 23260 23261 23262 23263 |
# File 'lib/aws-sdk-connect/types.rb', line 23256 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23256 23257 23258 23259 23260 23261 23262 23263 |
# File 'lib/aws-sdk-connect/types.rb', line 23256 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |