Class: Aws::Connect::Types::ListHoursOfOperationOverridesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hours_of_operation_override_listArray<Types::HoursOfOperationOverride>

Information about the hours of operation override.



23311
23312
23313
23314
23315
23316
23317
23318
# File 'lib/aws-sdk-connect/types.rb', line 23311

class ListHoursOfOperationOverridesResponse < Struct.new(
  :next_token,
  :hours_of_operation_override_list,
  :last_modified_region,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.

Returns:

  • (String)


23311
23312
23313
23314
23315
23316
23317
23318
# File 'lib/aws-sdk-connect/types.rb', line 23311

class ListHoursOfOperationOverridesResponse < Struct.new(
  :next_token,
  :hours_of_operation_override_list,
  :last_modified_region,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.

Returns:

  • (Time)


23311
23312
23313
23314
23315
23316
23317
23318
# File 'lib/aws-sdk-connect/types.rb', line 23311

class ListHoursOfOperationOverridesResponse < Struct.new(
  :next_token,
  :hours_of_operation_override_list,
  :last_modified_region,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


23311
23312
23313
23314
23315
23316
23317
23318
# File 'lib/aws-sdk-connect/types.rb', line 23311

class ListHoursOfOperationOverridesResponse < Struct.new(
  :next_token,
  :hours_of_operation_override_list,
  :last_modified_region,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end