Class: Aws::Connect::Types::ListInstanceStorageConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListInstanceStorageConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#resource_type ⇒ String
A valid resource type.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
20957 20958 20959 20960 20961 20962 20963 20964 |
# File 'lib/aws-sdk-connect/types.rb', line 20957 class ListInstanceStorageConfigsRequest < Struct.new( :instance_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
20957 20958 20959 20960 20961 20962 20963 20964 |
# File 'lib/aws-sdk-connect/types.rb', line 20957 class ListInstanceStorageConfigsRequest < Struct.new( :instance_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20957 20958 20959 20960 20961 20962 20963 20964 |
# File 'lib/aws-sdk-connect/types.rb', line 20957 class ListInstanceStorageConfigsRequest < Struct.new( :instance_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
A valid resource type.
20957 20958 20959 20960 20961 20962 20963 20964 |
# File 'lib/aws-sdk-connect/types.rb', line 20957 class ListInstanceStorageConfigsRequest < Struct.new( :instance_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |