Class: Aws::Connect::Types::ListIntegrationAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListIntegrationAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
-
#integration_type ⇒ String
The integration type.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23508 23509 23510 23511 23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-connect/types.rb', line 23508 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
23508 23509 23510 23511 23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-connect/types.rb', line 23508 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#integration_type ⇒ String
The integration type.
23508 23509 23510 23511 23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-connect/types.rb', line 23508 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23508 23509 23510 23511 23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-connect/types.rb', line 23508 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23508 23509 23510 23511 23512 23513 23514 23515 23516 |
# File 'lib/aws-sdk-connect/types.rb', line 23508 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |