Class: Aws::Connect::Types::ListLexBotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


23630
23631
23632
23633
23634
23635
23636
# File 'lib/aws-sdk-connect/types.rb', line 23630

class ListLexBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. If no value is specified, the default is 10.

Returns:

  • (Integer)


23630
23631
23632
23633
23634
23635
23636
# File 'lib/aws-sdk-connect/types.rb', line 23630

class ListLexBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


23630
23631
23632
23633
23634
23635
23636
# File 'lib/aws-sdk-connect/types.rb', line 23630

class ListLexBotsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end