Class: Aws::Connect::Types::ListMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



23683
23684
23685
23686
23687
23688
23689
23690
# File 'lib/aws-sdk-connect/types.rb', line 23683

class ListMetricsRequest < Struct.new(
  :instance_id,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



23683
23684
23685
23686
23687
23688
23689
23690
# File 'lib/aws-sdk-connect/types.rb', line 23683

class ListMetricsRequest < Struct.new(
  :instance_id,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



23683
23684
23685
23686
23687
23688
23689
23690
# File 'lib/aws-sdk-connect/types.rb', line 23683

class ListMetricsRequest < Struct.new(
  :instance_id,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of metrics to list. Valid values: AWS_MANAGED | CUSTOMER_MANAGED.



23683
23684
23685
23686
23687
23688
23689
23690
# File 'lib/aws-sdk-connect/types.rb', line 23683

class ListMetricsRequest < Struct.new(
  :instance_id,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end