Class: Aws::Connect::Types::ListMetricsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListMetricsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_summary_list ⇒ Array<Types::MetricSummary>
The list of metric summaries.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#metric_summary_list ⇒ Array<Types::MetricSummary>
The list of metric summaries.
23703 23704 23705 23706 23707 23708 |
# File 'lib/aws-sdk-connect/types.rb', line 23703 class ListMetricsResponse < Struct.new( :metric_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
23703 23704 23705 23706 23707 23708 |
# File 'lib/aws-sdk-connect/types.rb', line 23703 class ListMetricsResponse < Struct.new( :metric_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |