Class: Aws::Connect::Types::ListNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23731 23732 23733 23734 23735 23736 23737 |
# File 'lib/aws-sdk-connect/types.rb', line 23731 class ListNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. Valid range is 1-100.
23731 23732 23733 23734 23735 23736 23737 |
# File 'lib/aws-sdk-connect/types.rb', line 23731 class ListNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.
23731 23732 23733 23734 23735 23736 23737 |
# File 'lib/aws-sdk-connect/types.rb', line 23731 class ListNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |