Class: Aws::Connect::Types::ListPhoneNumbersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPhoneNumbersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
-
#phone_number_types ⇒ Array<String>
The type of phone number.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23798 23799 23800 23801 23802 23803 23804 23805 23806 |
# File 'lib/aws-sdk-connect/types.rb', line 23798 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
23798 23799 23800 23801 23802 23803 23804 23805 23806 |
# File 'lib/aws-sdk-connect/types.rb', line 23798 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23798 23799 23800 23801 23802 23803 23804 23805 23806 |
# File 'lib/aws-sdk-connect/types.rb', line 23798 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
23798 23799 23800 23801 23802 23803 23804 23805 23806 |
# File 'lib/aws-sdk-connect/types.rb', line 23798 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#phone_number_types ⇒ Array<String>
The type of phone number.
UIFN, SHARED,
THIRD_PARTY_TF, and THIRD_PARTY_DID, it incorrectly lists them
as TOLL_FREE or DID.
23798 23799 23800 23801 23802 23803 23804 23805 23806 |
# File 'lib/aws-sdk-connect/types.rb', line 23798 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |