Class: Aws::Connect::Types::ListPhoneNumbersSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about phone numbers that have been claimed to your Connect Customer instance or traffic distribution group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance that phone numbers are claimed to. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberString

The phone number. Phone numbers are formatted [+] [country code] [subscriber number including area code].

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_arnString

The Amazon Resource Name (ARN) of the phone number.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_country_codeString

The ISO country code.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_descriptionString

The description of the phone number.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

A unique identifier for the phone number.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_typeString

The type of phone number.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_phone_number_arnString

The claimed phone number ARN that was previously imported from the external service, such as Amazon Web Services End User Messaging. If it is from Amazon Web Services End User Messaging, it looks like the ARN of the phone number that was imported from Amazon Web Services End User Messaging.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.

Returns:

  • (String)


23880
23881
23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
# File 'lib/aws-sdk-connect/types.rb', line 23880

class ListPhoneNumbersSummary < Struct.new(
  :phone_number_id,
  :phone_number_arn,
  :phone_number,
  :phone_number_country_code,
  :phone_number_type,
  :target_arn,
  :instance_id,
  :phone_number_description,
  :source_phone_number_arn)
  SENSITIVE = []
  include Aws::Structure
end