Class: Aws::Connect::Types::ListPredefinedAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPredefinedAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23989 23990 23991 23992 23993 23994 23995 |
# File 'lib/aws-sdk-connect/types.rb', line 23989 class ListPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23989 23990 23991 23992 23993 23994 23995 |
# File 'lib/aws-sdk-connect/types.rb', line 23989 class ListPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23989 23990 23991 23992 23993 23994 23995 |
# File 'lib/aws-sdk-connect/types.rb', line 23989 class ListPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |