Class: Aws::Connect::Types::ListQueueEmailAddressesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_address_metadata_listArray<Types::EmailAddressSummary>

List of email address summary information for all email addresses associated with the queue. Each item contains the email address identifier, ARN, and configuration details.



24114
24115
24116
24117
24118
24119
24120
24121
# File 'lib/aws-sdk-connect/types.rb', line 24114

class ListQueueEmailAddressesResponse < Struct.new(
  :next_token,
  :email_address_metadata_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.



24114
24115
24116
24117
24118
24119
24120
24121
# File 'lib/aws-sdk-connect/types.rb', line 24114

class ListQueueEmailAddressesResponse < Struct.new(
  :next_token,
  :email_address_metadata_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.



24114
24115
24116
24117
24118
24119
24120
24121
# File 'lib/aws-sdk-connect/types.rb', line 24114

class ListQueueEmailAddressesResponse < Struct.new(
  :next_token,
  :email_address_metadata_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.



24114
24115
24116
24117
24118
24119
24120
24121
# File 'lib/aws-sdk-connect/types.rb', line 24114

class ListQueueEmailAddressesResponse < Struct.new(
  :next_token,
  :email_address_metadata_list,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end