Class: Aws::Connect::Types::ListQueueQuickConnectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQueueQuickConnectsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#queue_id ⇒ String
The identifier for the queue.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24149 24150 24151 24152 24153 24154 24155 24156 |
# File 'lib/aws-sdk-connect/types.rb', line 24149 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24149 24150 24151 24152 24153 24154 24155 24156 |
# File 'lib/aws-sdk-connect/types.rb', line 24149 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24149 24150 24151 24152 24153 24154 24155 24156 |
# File 'lib/aws-sdk-connect/types.rb', line 24149 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
24149 24150 24151 24152 24153 24154 24155 24156 |
# File 'lib/aws-sdk-connect/types.rb', line 24149 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |