Class: Aws::Connect::Types::ListQuickConnectsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. Both Instance ID and Instance ARN are supported input formats.

Returns:

  • (String)


24270
24271
24272
24273
24274
24275
24276
24277
# File 'lib/aws-sdk-connect/types.rb', line 24270

class ListQuickConnectsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :quick_connect_types)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. The default MaxResult size is 100.

Returns:

  • (Integer)


24270
24271
24272
24273
24274
24275
24276
24277
# File 'lib/aws-sdk-connect/types.rb', line 24270

class ListQuickConnectsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :quick_connect_types)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


24270
24271
24272
24273
24274
24275
24276
24277
# File 'lib/aws-sdk-connect/types.rb', line 24270

class ListQuickConnectsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :quick_connect_types)
  SENSITIVE = []
  include Aws::Structure
end

#quick_connect_typesArray<String>

The type of quick connect. In the Connect Customer admin website, when you create a quick connect, you are prompted to assign one of the following types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE).

Returns:

  • (Array<String>)


24270
24271
24272
24273
24274
24275
24276
24277
# File 'lib/aws-sdk-connect/types.rb', line 24270

class ListQuickConnectsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :quick_connect_types)
  SENSITIVE = []
  include Aws::Structure
end