Class: Aws::Connect::Types::ListRealtimeContactAnalysisSegmentsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRealtimeContactAnalysisSegmentsV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#output_type ⇒ String
The Contact Lens output type to be returned.
-
#segment_types ⇒ Array<String>
Enum with segment types .
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |
#output_type ⇒ String
The Contact Lens output type to be returned.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |
#segment_types ⇒ Array<String>
Enum with segment types . Each value corresponds to a segment type returned in the segments list of the API. Each segment type has its own structure. Different channels may have different sets of supported segment types.
24308 24309 24310 24311 24312 24313 24314 24315 24316 24317 |
# File 'lib/aws-sdk-connect/types.rb', line 24308 class ListRealtimeContactAnalysisSegmentsV2Request < Struct.new( :instance_id, :contact_id, :max_results, :next_token, :output_type, :segment_types) SENSITIVE = [] include Aws::Structure end |