Class: Aws::Connect::Types::ListRealtimeContactAnalysisSegmentsV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRealtimeContactAnalysisSegmentsV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel ⇒ String
The channel of the contact.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#segments ⇒ Array<Types::RealtimeContactAnalysisSegment>
An analyzed transcript or category.
-
#status ⇒ String
Status of real-time contact analysis.
Instance Attribute Details
#channel ⇒ String
The channel of the contact.
Only CHAT is supported. This API does not support VOICE. If you
attempt to use it for the VOICE channel, an
InvalidRequestException error occurs.
24367 24368 24369 24370 24371 24372 24373 24374 |
# File 'lib/aws-sdk-connect/types.rb', line 24367 class ListRealtimeContactAnalysisSegmentsV2Response < Struct.new( :channel, :status, :segments, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
24367 24368 24369 24370 24371 24372 24373 24374 |
# File 'lib/aws-sdk-connect/types.rb', line 24367 class ListRealtimeContactAnalysisSegmentsV2Response < Struct.new( :channel, :status, :segments, :next_token) SENSITIVE = [] include Aws::Structure end |
#segments ⇒ Array<Types::RealtimeContactAnalysisSegment>
An analyzed transcript or category.
24367 24368 24369 24370 24371 24372 24373 24374 |
# File 'lib/aws-sdk-connect/types.rb', line 24367 class ListRealtimeContactAnalysisSegmentsV2Response < Struct.new( :channel, :status, :segments, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of real-time contact analysis.
24367 24368 24369 24370 24371 24372 24373 24374 |
# File 'lib/aws-sdk-connect/types.rb', line 24367 class ListRealtimeContactAnalysisSegmentsV2Response < Struct.new( :channel, :status, :segments, :next_token) SENSITIVE = [] include Aws::Structure end |