Class: Aws::Connect::Types::ListRoutingProfileQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRoutingProfileQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24441 24442 24443 24444 24445 24446 24447 24448 |
# File 'lib/aws-sdk-connect/types.rb', line 24441 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24441 24442 24443 24444 24445 24446 24447 24448 |
# File 'lib/aws-sdk-connect/types.rb', line 24441 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24441 24442 24443 24444 24445 24446 24447 24448 |
# File 'lib/aws-sdk-connect/types.rb', line 24441 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
24441 24442 24443 24444 24445 24446 24447 24448 |
# File 'lib/aws-sdk-connect/types.rb', line 24441 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |