Class: Aws::Connect::Types::ListRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_source_name ⇒ String
The name of the event source.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#publish_status ⇒ String
The publish status of the rule.
Instance Attribute Details
#event_source_name ⇒ String
The name of the event source.
24581 24582 24583 24584 24585 24586 24587 24588 24589 |
# File 'lib/aws-sdk-connect/types.rb', line 24581 class ListRulesRequest < Struct.new( :instance_id, :publish_status, :event_source_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24581 24582 24583 24584 24585 24586 24587 24588 24589 |
# File 'lib/aws-sdk-connect/types.rb', line 24581 class ListRulesRequest < Struct.new( :instance_id, :publish_status, :event_source_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
24581 24582 24583 24584 24585 24586 24587 24588 24589 |
# File 'lib/aws-sdk-connect/types.rb', line 24581 class ListRulesRequest < Struct.new( :instance_id, :publish_status, :event_source_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24581 24582 24583 24584 24585 24586 24587 24588 24589 |
# File 'lib/aws-sdk-connect/types.rb', line 24581 class ListRulesRequest < Struct.new( :instance_id, :publish_status, :event_source_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
24581 24582 24583 24584 24585 24586 24587 24588 24589 |
# File 'lib/aws-sdk-connect/types.rb', line 24581 class ListRulesRequest < Struct.new( :instance_id, :publish_status, :event_source_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |