Class: Aws::Connect::Types::ListSecurityProfileAIAgentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_ai_agentsArray<Types::AIAgent>

A list of the allowed AI agents and their types.

Returns:



24710
24711
24712
24713
24714
24715
24716
24717
# File 'lib/aws-sdk-connect/types.rb', line 24710

class ListSecurityProfileAIAgentsResponse < Struct.new(
  :allowed_ai_agents,
  :next_token,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.

Returns:

  • (String)


24710
24711
24712
24713
24714
24715
24716
24717
# File 'lib/aws-sdk-connect/types.rb', line 24710

class ListSecurityProfileAIAgentsResponse < Struct.new(
  :allowed_ai_agents,
  :next_token,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.

Returns:

  • (Time)


24710
24711
24712
24713
24714
24715
24716
24717
# File 'lib/aws-sdk-connect/types.rb', line 24710

class ListSecurityProfileAIAgentsResponse < Struct.new(
  :allowed_ai_agents,
  :next_token,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


24710
24711
24712
24713
24714
24715
24716
24717
# File 'lib/aws-sdk-connect/types.rb', line 24710

class ListSecurityProfileAIAgentsResponse < Struct.new(
  :allowed_ai_agents,
  :next_token,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end