Class: Aws::Connect::Types::ListSecurityProfileFlowModulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfileFlowModulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#security_profile_id ⇒ String
The identifier for the security profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24808 24809 24810 24811 24812 24813 24814 24815 |
# File 'lib/aws-sdk-connect/types.rb', line 24808 class ListSecurityProfileFlowModulesRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24808 24809 24810 24811 24812 24813 24814 24815 |
# File 'lib/aws-sdk-connect/types.rb', line 24808 class ListSecurityProfileFlowModulesRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24808 24809 24810 24811 24812 24813 24814 24815 |
# File 'lib/aws-sdk-connect/types.rb', line 24808 class ListSecurityProfileFlowModulesRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#security_profile_id ⇒ String
The identifier for the security profile.
24808 24809 24810 24811 24812 24813 24814 24815 |
# File 'lib/aws-sdk-connect/types.rb', line 24808 class ListSecurityProfileFlowModulesRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |