Class: Aws::Connect::Types::ListSecurityProfileFlowModulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfileFlowModulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool.
-
#last_modified_region ⇒ String
The Region that flow module was last modified in.
-
#last_modified_time ⇒ Time
The time the flow module was last modified.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool.
24837 24838 24839 24840 24841 24842 24843 24844 |
# File 'lib/aws-sdk-connect/types.rb', line 24837 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Region that flow module was last modified in.
24837 24838 24839 24840 24841 24842 24843 24844 |
# File 'lib/aws-sdk-connect/types.rb', line 24837 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the flow module was last modified.
24837 24838 24839 24840 24841 24842 24843 24844 |
# File 'lib/aws-sdk-connect/types.rb', line 24837 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24837 24838 24839 24840 24841 24842 24843 24844 |
# File 'lib/aws-sdk-connect/types.rb', line 24837 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |