Class: Aws::Connect::Types::ListSecurityProfilePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


24871
24872
24873
24874
24875
24876
24877
24878
# File 'lib/aws-sdk-connect/types.rb', line 24871

class ListSecurityProfilePermissionsRequest < Struct.new(
  :security_profile_id,
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


24871
24872
24873
24874
24875
24876
24877
24878
# File 'lib/aws-sdk-connect/types.rb', line 24871

class ListSecurityProfilePermissionsRequest < Struct.new(
  :security_profile_id,
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


24871
24872
24873
24874
24875
24876
24877
24878
# File 'lib/aws-sdk-connect/types.rb', line 24871

class ListSecurityProfilePermissionsRequest < Struct.new(
  :security_profile_id,
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_idString

The identifier for the security profle.

Returns:

  • (String)


24871
24872
24873
24874
24875
24876
24877
24878
# File 'lib/aws-sdk-connect/types.rb', line 24871

class ListSecurityProfilePermissionsRequest < Struct.new(
  :security_profile_id,
  :instance_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end