Class: Aws::Connect::Types::ListSecurityProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24848 24849 24850 24851 24852 24853 24854 |
# File 'lib/aws-sdk-connect/types.rb', line 24848 class ListSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24848 24849 24850 24851 24852 24853 24854 |
# File 'lib/aws-sdk-connect/types.rb', line 24848 class ListSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24848 24849 24850 24851 24852 24853 24854 |
# File 'lib/aws-sdk-connect/types.rb', line 24848 class ListSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |