Class: Aws::Connect::Types::ListTestCaseExecutionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeInteger

Filter executions that started before this time.

Returns:

  • (Integer)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance.

Returns:

  • (String)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeInteger

Filter executions that started after this time.

Returns:

  • (Integer)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter executions by status.

Returns:

  • (String)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_idString

Filter executions by test case identifier.

Returns:

  • (String)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_nameString

Filter executions by test case name.

Returns:

  • (String)


25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
# File 'lib/aws-sdk-connect/types.rb', line 25154

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end