Class: Aws::Connect::Types::ListTestCaseExecutionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTestCaseExecutionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#test_case_executions ⇒ Array<Types::TestCaseExecution>
An array of test case execution summary objects.
Instance Attribute Details
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
23004 23005 23006 23007 23008 23009 |
# File 'lib/aws-sdk-connect/types.rb', line 23004 class ListTestCaseExecutionsResponse < Struct.new( :test_case_executions, :next_token) SENSITIVE = [] include Aws::Structure end |
#test_case_executions ⇒ Array<Types::TestCaseExecution>
An array of test case execution summary objects.
23004 23005 23006 23007 23008 23009 |
# File 'lib/aws-sdk-connect/types.rb', line 23004 class ListTestCaseExecutionsResponse < Struct.new( :test_case_executions, :next_token) SENSITIVE = [] include Aws::Structure end |