Class: Aws::Connect::Types::ListTestCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTestCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
23027 23028 23029 23030 23031 23032 23033 |
# File 'lib/aws-sdk-connect/types.rb', line 23027 class ListTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23027 23028 23029 23030 23031 23032 23033 |
# File 'lib/aws-sdk-connect/types.rb', line 23027 class ListTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23027 23028 23029 23030 23031 23032 23033 |
# File 'lib/aws-sdk-connect/types.rb', line 23027 class ListTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |