Class: Aws::Connect::Types::ListTrafficDistributionGroupUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTrafficDistributionGroupUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per page.
25246 25247 25248 25249 25250 25251 25252 |
# File 'lib/aws-sdk-connect/types.rb', line 25246 class ListTrafficDistributionGroupUsersRequest < Struct.new( :traffic_distribution_group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25246 25247 25248 25249 25250 25251 25252 |
# File 'lib/aws-sdk-connect/types.rb', line 25246 class ListTrafficDistributionGroupUsersRequest < Struct.new( :traffic_distribution_group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
25246 25247 25248 25249 25250 25251 25252 |
# File 'lib/aws-sdk-connect/types.rb', line 25246 class ListTrafficDistributionGroupUsersRequest < Struct.new( :traffic_distribution_group_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |