Class: Aws::Connect::Types::ListTrafficDistributionGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTrafficDistributionGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22543 22544 22545 22546 22547 22548 22549 |
# File 'lib/aws-sdk-connect/types.rb', line 22543 class ListTrafficDistributionGroupsRequest < Struct.new( :max_results, :next_token, :instance_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22543 22544 22545 22546 22547 22548 22549 |
# File 'lib/aws-sdk-connect/types.rb', line 22543 class ListTrafficDistributionGroupsRequest < Struct.new( :max_results, :next_token, :instance_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22543 22544 22545 22546 22547 22548 22549 |
# File 'lib/aws-sdk-connect/types.rb', line 22543 class ListTrafficDistributionGroupsRequest < Struct.new( :max_results, :next_token, :instance_id) SENSITIVE = [] include Aws::Structure end |