Class: Aws::Connect::Types::ListUseCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUseCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Provides summary information about the use cases for the specified integration association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#integration_association_id ⇒ String
The identifier for the integration association.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
25259 25260 25261 25262 25263 25264 25265 25266 |
# File 'lib/aws-sdk-connect/types.rb', line 25259 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#integration_association_id ⇒ String
The identifier for the integration association.
25259 25260 25261 25262 25263 25264 25265 25266 |
# File 'lib/aws-sdk-connect/types.rb', line 25259 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
25259 25260 25261 25262 25263 25264 25265 25266 |
# File 'lib/aws-sdk-connect/types.rb', line 25259 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25259 25260 25261 25262 25263 25264 25265 25266 |
# File 'lib/aws-sdk-connect/types.rb', line 25259 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |