Class: Aws::Connect::Types::ListUserNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUserNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#user_id ⇒ String
The identifier of the user.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
25359 25360 25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-connect/types.rb', line 25359 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. Valid range is 1-1000.
25359 25360 25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-connect/types.rb', line 25359 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.
25359 25360 25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-connect/types.rb', line 25359 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user.
25359 25360 25361 25362 25363 25364 25365 25366 |
# File 'lib/aws-sdk-connect/types.rb', line 25359 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |