Class: Aws::Connect::Types::ListUserNotificationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUserNotificationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results.
-
#user_notifications ⇒ Array<Types::UserNotificationSummary>
A list of notifications sent to the specified user.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results. If present, there are more results available.
23293 23294 23295 23296 23297 23298 |
# File 'lib/aws-sdk-connect/types.rb', line 23293 class ListUserNotificationsResponse < Struct.new( :user_notifications, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_notifications ⇒ Array<Types::UserNotificationSummary>
A list of notifications sent to the specified user.
23293 23294 23295 23296 23297 23298 |
# File 'lib/aws-sdk-connect/types.rb', line 23293 class ListUserNotificationsResponse < Struct.new( :user_notifications, :next_token) SENSITIVE = [] include Aws::Structure end |