Class: Aws::Connect::Types::ListUserProficienciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



25495
25496
25497
25498
25499
25500
25501
25502
# File 'lib/aws-sdk-connect/types.rb', line 25495

class ListUserProficienciesRequest < Struct.new(
  :instance_id,
  :user_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



25495
25496
25497
25498
25499
25500
25501
25502
# File 'lib/aws-sdk-connect/types.rb', line 25495

class ListUserProficienciesRequest < Struct.new(
  :instance_id,
  :user_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



25495
25496
25497
25498
25499
25500
25501
25502
# File 'lib/aws-sdk-connect/types.rb', line 25495

class ListUserProficienciesRequest < Struct.new(
  :instance_id,
  :user_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier of the user account.



25495
25496
25497
25498
25499
25500
25501
25502
# File 'lib/aws-sdk-connect/types.rb', line 25495

class ListUserProficienciesRequest < Struct.new(
  :instance_id,
  :user_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end