Class: Aws::Connect::Types::ListViewVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListViewVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#view_id ⇒ String
The identifier of the view.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
25514 25515 25516 25517 25518 25519 25520 25521 |
# File 'lib/aws-sdk-connect/types.rb', line 25514 class ListViewVersionsRequest < Struct.new( :instance_id, :view_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
25514 25515 25516 25517 25518 25519 25520 25521 |
# File 'lib/aws-sdk-connect/types.rb', line 25514 class ListViewVersionsRequest < Struct.new( :instance_id, :view_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25514 25515 25516 25517 25518 25519 25520 25521 |
# File 'lib/aws-sdk-connect/types.rb', line 25514 class ListViewVersionsRequest < Struct.new( :instance_id, :view_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#view_id ⇒ String
The identifier of the view. Both ViewArn and ViewId can be used.
25514 25515 25516 25517 25518 25519 25520 25521 |
# File 'lib/aws-sdk-connect/types.rb', line 25514 class ListViewVersionsRequest < Struct.new( :instance_id, :view_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |