Class: Aws::Connect::Types::ListViewVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListViewVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results.
-
#view_version_summary_list ⇒ Array<Types::ViewVersionSummary>
A list of view version summaries.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25623 25624 25625 25626 25627 25628 |
# File 'lib/aws-sdk-connect/types.rb', line 25623 class ListViewVersionsResponse < Struct.new( :view_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#view_version_summary_list ⇒ Array<Types::ViewVersionSummary>
A list of view version summaries.
25623 25624 25625 25626 25627 25628 |
# File 'lib/aws-sdk-connect/types.rb', line 25623 class ListViewVersionsResponse < Struct.new( :view_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |