Class: Aws::Connect::Types::ListViewsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListViewsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results.
-
#views_summary_list ⇒ Array<Types::ViewSummary>
A list of view summaries.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25673 25674 25675 25676 25677 25678 |
# File 'lib/aws-sdk-connect/types.rb', line 25673 class ListViewsResponse < Struct.new( :views_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#views_summary_list ⇒ Array<Types::ViewSummary>
A list of view summaries.
25673 25674 25675 25676 25677 25678 |
# File 'lib/aws-sdk-connect/types.rb', line 25673 class ListViewsResponse < Struct.new( :views_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |