Class: Aws::Connect::Types::ListWorkspacePagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListWorkspacePagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#workspace_id ⇒ String
The identifier of the workspace.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22539 22540 22541 22542 22543 22544 22545 22546 |
# File 'lib/aws-sdk-connect/types.rb', line 22539 class ListWorkspacePagesRequest < Struct.new( :instance_id, :workspace_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22539 22540 22541 22542 22543 22544 22545 22546 |
# File 'lib/aws-sdk-connect/types.rb', line 22539 class ListWorkspacePagesRequest < Struct.new( :instance_id, :workspace_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22539 22540 22541 22542 22543 22544 22545 22546 |
# File 'lib/aws-sdk-connect/types.rb', line 22539 class ListWorkspacePagesRequest < Struct.new( :instance_id, :workspace_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace.
22539 22540 22541 22542 22543 22544 22545 22546 |
# File 'lib/aws-sdk-connect/types.rb', line 22539 class ListWorkspacePagesRequest < Struct.new( :instance_id, :workspace_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |