Class: Aws::Connect::Types::ListWorkspacePagesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListWorkspacePagesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#workspace_page_list ⇒ Array<Types::WorkspacePage>
A list of page configurations in the workspace.
Instance Attribute Details
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
22957 22958 22959 22960 22961 22962 |
# File 'lib/aws-sdk-connect/types.rb', line 22957 class ListWorkspacePagesResponse < Struct.new( :next_token, :workspace_page_list) SENSITIVE = [] include Aws::Structure end |
#workspace_page_list ⇒ Array<Types::WorkspacePage>
A list of page configurations in the workspace.
22957 22958 22959 22960 22961 22962 |
# File 'lib/aws-sdk-connect/types.rb', line 22957 class ListWorkspacePagesResponse < Struct.new( :next_token, :workspace_page_list) SENSITIVE = [] include Aws::Structure end |