Class: Aws::Connect::Types::ListWorkspacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListWorkspacesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22587 22588 22589 22590 22591 22592 22593 |
# File 'lib/aws-sdk-connect/types.rb', line 22587 class ListWorkspacesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22587 22588 22589 22590 22591 22592 22593 |
# File 'lib/aws-sdk-connect/types.rb', line 22587 class ListWorkspacesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22587 22588 22589 22590 22591 22592 22593 |
# File 'lib/aws-sdk-connect/types.rb', line 22587 class ListWorkspacesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |