Class: Aws::Connect::Types::MediaConcurrency

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about which channels are supported, and how many contacts an agent can have on a channel simultaneously.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channelString

The channels that agents can handle in the Contact Control Panel (CCP).



25875
25876
25877
25878
25879
25880
25881
25882
# File 'lib/aws-sdk-connect/types.rb', line 25875

class MediaConcurrency < Struct.new(
  :channel,
  :concurrency,
  :cross_channel_behavior,
  :workload_type_concurrencies)
  SENSITIVE = []
  include Aws::Structure
end

#concurrencyInteger

The number of contacts an agent can have on a channel simultaneously.

Valid Range for VOICE: Minimum value of 1. Maximum value of 1.

Valid Range for CHAT: Minimum value of 1. Maximum value of 10.

Valid Range for TASK: Minimum value of 1. Maximum value of 10.



25875
25876
25877
25878
25879
25880
25881
25882
# File 'lib/aws-sdk-connect/types.rb', line 25875

class MediaConcurrency < Struct.new(
  :channel,
  :concurrency,
  :cross_channel_behavior,
  :workload_type_concurrencies)
  SENSITIVE = []
  include Aws::Structure
end

#cross_channel_behaviorTypes::CrossChannelBehavior

Defines the cross-channel routing behavior for each channel that is enabled for this Routing Profile. For example, this allows you to offer an agent a different contact from another channel when they are currently working with a contact from a Voice channel.



25875
25876
25877
25878
25879
25880
25881
25882
# File 'lib/aws-sdk-connect/types.rb', line 25875

class MediaConcurrency < Struct.new(
  :channel,
  :concurrency,
  :cross_channel_behavior,
  :workload_type_concurrencies)
  SENSITIVE = []
  include Aws::Structure
end

#workload_type_concurrenciesArray<Types::WorkloadTypeConcurrency>

Defines the list of workload type concurrency configurations for a channel. When provided, enables granular concurrency control based on workload type values.



25875
25876
25877
25878
25879
25880
25881
25882
# File 'lib/aws-sdk-connect/types.rb', line 25875

class MediaConcurrency < Struct.new(
  :channel,
  :concurrency,
  :cross_channel_behavior,
  :workload_type_concurrencies)
  SENSITIVE = []
  include Aws::Structure
end