Class: Aws::Connect::Types::MeetingFeaturesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::MeetingFeaturesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The configuration settings of the features available to a meeting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio ⇒ Types::AudioFeatures
The configuration settings for the audio features available to a meeting.
Instance Attribute Details
#audio ⇒ Types::AudioFeatures
The configuration settings for the audio features available to a meeting.
25234 25235 25236 25237 25238 |
# File 'lib/aws-sdk-connect/types.rb', line 25234 class MeetingFeaturesConfiguration < Struct.new( :audio) SENSITIVE = [] include Aws::Structure end |