Class: Aws::Connect::Types::MetricInterval
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::MetricInterval
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The interval period with the start and end time for the metrics.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The timestamp, in UNIX Epoch time format.
-
#interval ⇒ String
The interval period provided in the API request.
-
#start_time ⇒ Time
The timestamp, in UNIX Epoch time format.
Instance Attribute Details
#end_time ⇒ Time
The timestamp, in UNIX Epoch time format. End time is based on the
interval period selected. For example, If IntervalPeriod is
selected THIRTY_MIN, StartTime and EndTime in the API request
differs by 1 day, then 48 results are returned in the response. Each
result is aggregated by the 30 minutes period, with each StartTime
and EndTime differing by 30 minutes.
25056 25057 25058 25059 25060 25061 25062 |
# File 'lib/aws-sdk-connect/types.rb', line 25056 class MetricInterval < Struct.new( :interval, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#interval ⇒ String
The interval period provided in the API request.
25056 25057 25058 25059 25060 25061 25062 |
# File 'lib/aws-sdk-connect/types.rb', line 25056 class MetricInterval < Struct.new( :interval, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp, in UNIX Epoch time format. Start time is based on the interval period selected.
25056 25057 25058 25059 25060 25061 25062 |
# File 'lib/aws-sdk-connect/types.rb', line 25056 class MetricInterval < Struct.new( :interval, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |