Class: Aws::Connect::Types::MetricV2

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about the metric.

Only one of either the Name or MetricId is required.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_filtersArray<Types::MetricFilterV2>

Contains the filters to be used when returning data.

Returns:



25111
25112
25113
25114
25115
25116
25117
25118
# File 'lib/aws-sdk-connect/types.rb', line 25111

class MetricV2 < Struct.new(
  :name,
  :threshold,
  :metric_id,
  :metric_filters)
  SENSITIVE = []
  include Aws::Structure
end

#metric_idString

Historical metrics or custom metrics can be referenced via this field. This field is a valid Connect Customer Arn or a UUID

Returns:

  • (String)


25111
25112
25113
25114
25115
25116
25117
25118
# File 'lib/aws-sdk-connect/types.rb', line 25111

class MetricV2 < Struct.new(
  :name,
  :threshold,
  :metric_id,
  :metric_filters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the metric.

Returns:

  • (String)


25111
25112
25113
25114
25115
25116
25117
25118
# File 'lib/aws-sdk-connect/types.rb', line 25111

class MetricV2 < Struct.new(
  :name,
  :threshold,
  :metric_id,
  :metric_filters)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdArray<Types::ThresholdV2>

Contains information about the threshold for service level metrics.

Returns:



25111
25112
25113
25114
25115
25116
25117
25118
# File 'lib/aws-sdk-connect/types.rb', line 25111

class MetricV2 < Struct.new(
  :name,
  :threshold,
  :metric_id,
  :metric_filters)
  SENSITIVE = []
  include Aws::Structure
end