Class: Aws::Connect::Types::Notification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about a notification, including its content, priority, recipients, and metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the notification.

Returns:

  • (String)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#contentHash<String,String>

The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.

Returns:

  • (Hash<String,String>)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the notification was created.

Returns:

  • (Time)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp when the notification expires and is no longer displayed to users.

Returns:

  • (Time)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier for the notification.

Returns:

  • (String)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The AWS Region where the notification was last modified.

Returns:

  • (String)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the notification was last modified.

Returns:

  • (Time)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#priorityString

The priority level of the notification. Valid values are URGENT, HIGH, and LOW.

Returns:

  • (String)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recipientsArray<String>

A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.

Returns:

  • (Array<String>)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, ‘{ “Tags”: “key2”:“value2” }`.

Returns:

  • (Hash<String,String>)


24225
24226
24227
24228
24229
24230
24231
24232
24233
24234
24235
24236
24237
24238
# File 'lib/aws-sdk-connect/types.rb', line 24225

class Notification < Struct.new(
  :content,
  :id,
  :arn,
  :priority,
  :recipients,
  :last_modified_time,
  :created_at,
  :expires_at,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end