Class: Aws::Connect::Types::OverrideHour
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::OverrideHour
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about hours of operation override
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end ⇒ Types::OverrideTimeSlice
The start time or end time for an hours of operation override.
-
#operational_status ⇒ String
Indicates whether the status is open or closed during the override period.
-
#override_name ⇒ String
Unique identifier name for the override.
-
#start ⇒ Types::OverrideTimeSlice
The start time or end time for an hours of operation override.
Instance Attribute Details
#end ⇒ Types::OverrideTimeSlice
The start time or end time for an hours of operation override.
26861 26862 26863 26864 26865 26866 26867 26868 |
# File 'lib/aws-sdk-connect/types.rb', line 26861 class OverrideHour < Struct.new( :start, :end, :override_name, :operational_status) SENSITIVE = [] include Aws::Structure end |
#operational_status ⇒ String
Indicates whether the status is open or closed during the override period. This status determines how the override modifies the base hours of operation schedule.
26861 26862 26863 26864 26865 26866 26867 26868 |
# File 'lib/aws-sdk-connect/types.rb', line 26861 class OverrideHour < Struct.new( :start, :end, :override_name, :operational_status) SENSITIVE = [] include Aws::Structure end |
#override_name ⇒ String
Unique identifier name for the override.
26861 26862 26863 26864 26865 26866 26867 26868 |
# File 'lib/aws-sdk-connect/types.rb', line 26861 class OverrideHour < Struct.new( :start, :end, :override_name, :operational_status) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Types::OverrideTimeSlice
The start time or end time for an hours of operation override.
26861 26862 26863 26864 26865 26866 26867 26868 |
# File 'lib/aws-sdk-connect/types.rb', line 26861 class OverrideHour < Struct.new( :start, :end, :override_name, :operational_status) SENSITIVE = [] include Aws::Structure end |