Class: Aws::Connect::Types::PaletteHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::PaletteHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains color configuration for header elements in a workspace theme.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#background ⇒ String
The background color of the header.
-
#invert_actions_colors ⇒ Boolean
Whether to invert the colors of action buttons in the header.
-
#text ⇒ String
The text color in the header.
-
#text_hover ⇒ String
The text color when hovering over header elements.
Instance Attribute Details
#background ⇒ String
The background color of the header.
27185 27186 27187 27188 27189 27190 27191 27192 |
# File 'lib/aws-sdk-connect/types.rb', line 27185 class PaletteHeader < Struct.new( :background, :text, :text_hover, :invert_actions_colors) SENSITIVE = [] include Aws::Structure end |
#invert_actions_colors ⇒ Boolean
Whether to invert the colors of action buttons in the header.
27185 27186 27187 27188 27189 27190 27191 27192 |
# File 'lib/aws-sdk-connect/types.rb', line 27185 class PaletteHeader < Struct.new( :background, :text, :text_hover, :invert_actions_colors) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The text color in the header.
27185 27186 27187 27188 27189 27190 27191 27192 |
# File 'lib/aws-sdk-connect/types.rb', line 27185 class PaletteHeader < Struct.new( :background, :text, :text_hover, :invert_actions_colors) SENSITIVE = [] include Aws::Structure end |
#text_hover ⇒ String
The text color when hovering over header elements.
27185 27186 27187 27188 27189 27190 27191 27192 |
# File 'lib/aws-sdk-connect/types.rb', line 27185 class PaletteHeader < Struct.new( :background, :text, :text_hover, :invert_actions_colors) SENSITIVE = [] include Aws::Structure end |