Class: Aws::Connect::Types::PaletteNavigation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains color configuration for navigation elements in a workspace theme.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backgroundString

The background color of the navigation area.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#invert_actions_colorsBoolean

Whether to invert the colors of action buttons in the navigation area.

Returns:

  • (Boolean)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#textString

The text color in the navigation area.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#text_activeString

The text color for active navigation items.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#text_background_activeString

The background color for active navigation items.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#text_background_hoverString

The background color when hovering over navigation text.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end

#text_hoverString

The text color when hovering over navigation items.

Returns:

  • (String)


23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
# File 'lib/aws-sdk-connect/types.rb', line 23186

class PaletteNavigation < Struct.new(
  :background,
  :text_background_hover,
  :text_background_active,
  :text,
  :text_hover,
  :text_active,
  :invert_actions_colors)
  SENSITIVE = []
  include Aws::Structure
end