Class: Aws::Connect::Types::ParticipantCapabilities

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The configuration for the allowed video and screen sharing capabilities for participants present over the call. For more information, see Set up in-app, web, video calling, and screen sharing capabilities in the Connect Customer Administrator Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#screen_shareString

The screen sharing capability that is enabled for the participant. SEND indicates the participant can share their screen.

Returns:

  • (String)


25957
25958
25959
25960
25961
25962
# File 'lib/aws-sdk-connect/types.rb', line 25957

class ParticipantCapabilities < Struct.new(
  :video,
  :screen_share)
  SENSITIVE = []
  include Aws::Structure
end

#videoString

The configuration having the video and screen sharing capabilities for participants over the call.

Returns:

  • (String)


25957
25958
25959
25960
25961
25962
# File 'lib/aws-sdk-connect/types.rb', line 25957

class ParticipantCapabilities < Struct.new(
  :video,
  :screen_share)
  SENSITIVE = []
  include Aws::Structure
end