Class: Aws::Connect::Types::ParticipantTimerConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ParticipantTimerConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Configuration information for the timer. After the timer configuration is set, it persists for the duration of the chat. It persists across new contacts in the chain, for example, transfer contacts.
For more information about how chat timeouts work, see [Set up chat timeouts for human participants].
[1]: docs.aws.amazon.com/connect/latest/adminguide/setup-chat-timeouts.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#participant_role ⇒ String
The role of the participant in the chat conversation.
-
#timer_type ⇒ String
The type of timer.
-
#timer_value ⇒ Types::ParticipantTimerValue
The value of the timer.
Instance Attribute Details
#participant_role ⇒ String
The role of the participant in the chat conversation.
24802 24803 24804 24805 24806 24807 24808 |
# File 'lib/aws-sdk-connect/types.rb', line 24802 class ParticipantTimerConfiguration < Struct.new( :participant_role, :timer_type, :timer_value) SENSITIVE = [] include Aws::Structure end |
#timer_type ⇒ String
The type of timer. ‘IDLE` indicates the timer applies for considering a human chat participant as idle. `DISCONNECT_NONCUSTOMER` indicates the timer applies to automatically disconnecting a chat participant due to idleness.
24802 24803 24804 24805 24806 24807 24808 |
# File 'lib/aws-sdk-connect/types.rb', line 24802 class ParticipantTimerConfiguration < Struct.new( :participant_role, :timer_type, :timer_value) SENSITIVE = [] include Aws::Structure end |
#timer_value ⇒ Types::ParticipantTimerValue
The value of the timer. Either the timer action (Unset to delete the timer), or the duration of the timer in minutes. Only one value can be set.
24802 24803 24804 24805 24806 24807 24808 |
# File 'lib/aws-sdk-connect/types.rb', line 24802 class ParticipantTimerConfiguration < Struct.new( :participant_role, :timer_type, :timer_value) SENSITIVE = [] include Aws::Structure end |