Class: Aws::Connect::Types::PhoneNumberStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::PhoneNumberStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The status of the phone number.
-
CLAIMEDmeans the previous [ClaimPhoneNumber] or- UpdatePhoneNumber][2
-
operation succeeded.
-
IN_PROGRESSmeans a [ClaimPhoneNumber], [UpdatePhoneNumber], or [UpdatePhoneNumberMetadata] operation is still in progress and has not yet completed. You can call [DescribePhoneNumber] at a later time to verify if the previous operation has completed. -
FAILEDindicates that the previous [ClaimPhoneNumber] or- UpdatePhoneNumber][2
-
operation has failed. It will include a
message indicating the failure reason. A common reason for a failure may be that the
TargetArnvalue you are claiming or updating a phone number to has reached its limit of total claimed numbers. If you received aFAILEDstatus from aClaimPhoneNumberAPI call, you have one day to retry claiming the phone number before the number is released back to the inventory for other customers to claim.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_ClaimPhoneNumber.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumber.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumberMetadata.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The status message.
-
#status ⇒ String
The status.
Instance Attribute Details
#message ⇒ String
The status message.
25264 25265 25266 25267 25268 25269 |
# File 'lib/aws-sdk-connect/types.rb', line 25264 class PhoneNumberStatus < Struct.new( :status, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
25264 25265 25266 25267 25268 25269 |
# File 'lib/aws-sdk-connect/types.rb', line 25264 class PhoneNumberStatus < Struct.new( :status, :message) SENSITIVE = [] include Aws::Structure end |