Class: Aws::Connect::Types::PostAcceptTimeoutConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Countdown timer configuration after the agent accepted the contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration_in_secondsInteger

Duration in seconds for the countdown timer after the agent accepted the contact.

Returns:

  • (Integer)


23637
23638
23639
23640
23641
# File 'lib/aws-sdk-connect/types.rb', line 23637

class PostAcceptTimeoutConfig < Struct.new(
  :duration_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end