Class: Aws::Connect::Types::PredefinedAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::PredefinedAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a predefined attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_configuration ⇒ Types::PredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
-
#last_modified_region ⇒ String
Last modified region.
-
#last_modified_time ⇒ Time
Last modified time.
-
#name ⇒ String
The name of the predefined attribute.
-
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes.
-
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
Instance Attribute Details
#attribute_configuration ⇒ Types::PredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
Last modified region.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Last modified time.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the predefined attribute.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Connect Customer admin website.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 |
# File 'lib/aws-sdk-connect/types.rb', line 26532 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |