Class: Aws::Connect::Types::PredefinedAttributeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::PredefinedAttributeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_value_validation_on_association ⇒ Boolean
When this parameter is set to true, Connect Customer enforces strict validation on the specific values, if the values are predefined in attributes.
-
#is_read_only ⇒ Boolean
A boolean flag used to indicate whether a predefined attribute should be displayed in the Connect Customer admin website.
Instance Attribute Details
#enable_value_validation_on_association ⇒ Boolean
When this parameter is set to true, Connect Customer enforces strict validation on the specific values, if the values are predefined in attributes. The contact will store only valid and predefined values for teh predefined attribute key.
26466 26467 26468 26469 26470 26471 |
# File 'lib/aws-sdk-connect/types.rb', line 26466 class PredefinedAttributeConfiguration < Struct.new( :enable_value_validation_on_association, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#is_read_only ⇒ Boolean
A boolean flag used to indicate whether a predefined attribute should be displayed in the Connect Customer admin website.
26466 26467 26468 26469 26470 26471 |
# File 'lib/aws-sdk-connect/types.rb', line 26466 class PredefinedAttributeConfiguration < Struct.new( :enable_value_validation_on_association, :is_read_only) SENSITIVE = [] include Aws::Structure end |