Class: Aws::Connect::Types::PredefinedAttributeValues

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

PredefinedAttributeValues is a union - when making an API calls you must set exactly one of the members.

Note:

PredefinedAttributeValues is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PredefinedAttributeValues corresponding to the set member.

Information about values of a predefined attribute.

Defined Under Namespace

Classes: StringList, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#string_listArray<String>

Predefined attribute values of type string list.

Returns:

  • (Array<String>)


27628
27629
27630
27631
27632
27633
27634
27635
27636
27637
# File 'lib/aws-sdk-connect/types.rb', line 27628

class PredefinedAttributeValues < Struct.new(
  :string_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringList < PredefinedAttributeValues; end
  class Unknown < PredefinedAttributeValues; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



27628
27629
27630
# File 'lib/aws-sdk-connect/types.rb', line 27628

def unknown
  @unknown
end