Class: Aws::Connect::Types::Preview

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about agent-first preview mode outbound strategy configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_user_actionsArray<String>

The actions the agent can perform after accepting the preview outbound contact.

Returns:

  • (Array<String>)


25715
25716
25717
25718
25719
25720
# File 'lib/aws-sdk-connect/types.rb', line 25715

class Preview < Struct.new(
  :post_accept_timeout_config,
  :allowed_user_actions)
  SENSITIVE = []
  include Aws::Structure
end

#post_accept_timeout_configTypes::PostAcceptTimeoutConfig

Countdown timer configuration after the agent accepted the preview outbound contact.



25715
25716
25717
25718
25719
25720
# File 'lib/aws-sdk-connect/types.rb', line 25715

class Preview < Struct.new(
  :post_accept_timeout_config,
  :allowed_user_actions)
  SENSITIVE = []
  include Aws::Structure
end