Class: Aws::Connect::Types::PropertyValidationExceptionProperty

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about why a property is not valid.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message describing why the property is not valid.

Returns:

  • (String)


26856
26857
26858
26859
26860
26861
26862
# File 'lib/aws-sdk-connect/types.rb', line 26856

class PropertyValidationExceptionProperty < Struct.new(
  :property_path,
  :reason,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#property_pathString

The full property path.

Returns:

  • (String)


26856
26857
26858
26859
26860
26861
26862
# File 'lib/aws-sdk-connect/types.rb', line 26856

class PropertyValidationExceptionProperty < Struct.new(
  :property_path,
  :reason,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

Why the property is not valid.

Returns:

  • (String)


26856
26857
26858
26859
26860
26861
26862
# File 'lib/aws-sdk-connect/types.rb', line 26856

class PropertyValidationExceptionProperty < Struct.new(
  :property_path,
  :reason,
  :message)
  SENSITIVE = []
  include Aws::Structure
end