Class: Aws::Connect::Types::QuestionOptionPointsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the points configuration for an answer option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_bonusBoolean

The flag to mark the option as a bonus option.

Returns:

  • (Boolean)


26646
26647
26648
26649
26650
26651
# File 'lib/aws-sdk-connect/types.rb', line 26646

class QuestionOptionPointsConfiguration < Struct.new(
  :point_value,
  :is_bonus)
  SENSITIVE = []
  include Aws::Structure
end

#point_valueInteger

The point value assigned to the answer option.

Returns:

  • (Integer)


26646
26647
26648
26649
26650
26651
# File 'lib/aws-sdk-connect/types.rb', line 26646

class QuestionOptionPointsConfiguration < Struct.new(
  :point_value,
  :is_bonus)
  SENSITIVE = []
  include Aws::Structure
end