Class: Aws::Connect::Types::QuestionPointsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::QuestionPointsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the points configuration for a question.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_bonus ⇒ Boolean
The flag to mark the question as a bonus question.
-
#max_point_value ⇒ Integer
The maximum point value.
-
#min_point_value ⇒ Integer
The minimum point value.
Instance Attribute Details
#is_bonus ⇒ Boolean
The flag to mark the question as a bonus question.
26669 26670 26671 26672 26673 26674 26675 |
# File 'lib/aws-sdk-connect/types.rb', line 26669 class QuestionPointsConfiguration < Struct.new( :max_point_value, :min_point_value, :is_bonus) SENSITIVE = [] include Aws::Structure end |
#max_point_value ⇒ Integer
The maximum point value.
26669 26670 26671 26672 26673 26674 26675 |
# File 'lib/aws-sdk-connect/types.rb', line 26669 class QuestionPointsConfiguration < Struct.new( :max_point_value, :min_point_value, :is_bonus) SENSITIVE = [] include Aws::Structure end |
#min_point_value ⇒ Integer
The minimum point value.
26669 26670 26671 26672 26673 26674 26675 |
# File 'lib/aws-sdk-connect/types.rb', line 26669 class QuestionPointsConfiguration < Struct.new( :max_point_value, :min_point_value, :is_bonus) SENSITIVE = [] include Aws::Structure end |