Class: Aws::Connect::Types::QuickConnectSearchCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The search criteria to be used to return quick connects.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#and_conditionsArray<Types::QuickConnectSearchCriteria>

A list of conditions which would be applied together with an AND condition.



25425
25426
25427
25428
25429
25430
25431
# File 'lib/aws-sdk-connect/types.rb', line 25425

class QuickConnectSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#or_conditionsArray<Types::QuickConnectSearchCriteria>

A list of conditions which would be applied together with an OR condition.



25425
25426
25427
25428
25429
25430
25431
# File 'lib/aws-sdk-connect/types.rb', line 25425

class QuickConnectSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#string_conditionTypes::StringCondition

A leaf node condition which can be used to specify a string condition.

<note markdown=“1”> The currently supported values for FieldName are name, description, and resourceID.

</note>


25425
25426
25427
25428
25429
25430
25431
# File 'lib/aws-sdk-connect/types.rb', line 25425

class QuickConnectSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end