Class: Aws::Connect::Types::QuickConnectSearchFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Filters to be applied to search results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tag_filterTypes::ControlPlaneTagFilter

An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:

  • Top level list specifies conditions that need to be applied with OR operator

  • Inner list specifies conditions that need to be applied with AND operator.



24988
24989
24990
24991
24992
# File 'lib/aws-sdk-connect/types.rb', line 24988

class QuickConnectSearchFilter < Struct.new(
  :tag_filter)
  SENSITIVE = []
  include Aws::Structure
end