Class: Aws::Connect::Types::RealTimeContactAnalysisExtractedInformationValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

An individual value extracted from the conversation, including its content and the locations where it was found.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The text content of the extracted value.

Returns:

  • (String)


29080
29081
29082
29083
29084
29085
# File 'lib/aws-sdk-connect/types.rb', line 29080

class RealTimeContactAnalysisExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end

#points_of_interestArray<Types::RealTimeContactAnalysisTranscriptItemWithCharacterOffsets>

The sections in the conversation that indicate where the extracted value was found.



29080
29081
29082
29083
29084
29085
# File 'lib/aws-sdk-connect/types.rb', line 29080

class RealTimeContactAnalysisExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end