Class: Aws::Connect::Types::RealTimeContactAnalysisSegmentPostContactSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisSegmentPostContactSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the post-contact summary for a real-time contact segment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the summary.
-
#failure_code ⇒ String
If the summary failed to be generated, one of the following failure codes occurs:.
-
#status ⇒ String
Whether the summary was successfully COMPLETED or FAILED to be generated.
Instance Attribute Details
#content ⇒ String
The content of the summary.
25323 25324 25325 25326 25327 25328 25329 |
# File 'lib/aws-sdk-connect/types.rb', line 25323 class RealTimeContactAnalysisSegmentPostContactSummary < Struct.new( :content, :status, :failure_code) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
If the summary failed to be generated, one of the following failure codes occurs:
-
QUOTA_EXCEEDED: The number of concurrent analytics jobs reached your service quota. -
INSUFFICIENT_CONVERSATION_CONTENT: The conversation needs to have at least one turn from both the participants in order to generate the summary. -
FAILED_SAFETY_GUIDELINES: The generated summary cannot be provided because it failed to meet system safety guidelines. -
INVALID_ANALYSIS_CONFIGURATION: This code occurs when, for example, you’re using a [language] that isn’t supported by generative AI-powered post-contact summaries. -
INTERNAL_ERROR: Internal system error.
25323 25324 25325 25326 25327 25328 25329 |
# File 'lib/aws-sdk-connect/types.rb', line 25323 class RealTimeContactAnalysisSegmentPostContactSummary < Struct.new( :content, :status, :failure_code) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Whether the summary was successfully COMPLETED or FAILED to be generated.
25323 25324 25325 25326 25327 25328 25329 |
# File 'lib/aws-sdk-connect/types.rb', line 25323 class RealTimeContactAnalysisSegmentPostContactSummary < Struct.new( :content, :status, :failure_code) SENSITIVE = [] include Aws::Structure end |