Class: Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemRedaction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Object describing redaction applied to the segment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#character_offsetsArray<Types::RealTimeContactAnalysisCharacterInterval>

List of character intervals each describing a part of the text that was redacted. For OutputType.Raw, part of the original text that contains data that can be redacted. For OutputType.Redacted, part of the string with redaction tag.



29028
29029
29030
29031
29032
# File 'lib/aws-sdk-connect/types.rb', line 29028

class RealTimeContactAnalysisTranscriptItemRedaction < Struct.new(
  :character_offsets)
  SENSITIVE = []
  include Aws::Structure
end