Class: Aws::Connect::Types::RealtimeContactAnalysisSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

RealtimeContactAnalysisSegment is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RealtimeContactAnalysisSegment corresponding to the set member.

An analyzed segment for a real-time analysis session.

Defined Under Namespace

Classes: Attachments, Categories, Event, ExtractedInformation, Issues, PostContactSummary, Transcript, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachmentsTypes::RealTimeContactAnalysisSegmentAttachments

The analyzed attachments.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#categoriesTypes::RealTimeContactAnalysisSegmentCategories

The matched category rules.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#eventTypes::RealTimeContactAnalysisSegmentEvent

Segment type describing a contact event.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#extracted_informationTypes::RealTimeContactAnalysisSegmentExtractedInformation

The extracted information from the conversation.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#issuesTypes::RealTimeContactAnalysisSegmentIssues

Segment type containing a list of detected issues.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#post_contact_summaryTypes::RealTimeContactAnalysisSegmentPostContactSummary

Information about the post-contact summary.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#transcriptTypes::RealTimeContactAnalysisSegmentTranscript

The analyzed transcript segment.



29520
29521
29522
29523
29524
29525
29526
29527
29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
# File 'lib/aws-sdk-connect/types.rb', line 29520

class RealtimeContactAnalysisSegment < Struct.new(
  :transcript,
  :categories,
  :issues,
  :event,
  :attachments,
  :post_contact_summary,
  :extracted_information,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Transcript < RealtimeContactAnalysisSegment; end
  class Categories < RealtimeContactAnalysisSegment; end
  class Issues < RealtimeContactAnalysisSegment; end
  class Event < RealtimeContactAnalysisSegment; end
  class Attachments < RealtimeContactAnalysisSegment; end
  class PostContactSummary < RealtimeContactAnalysisSegment; end
  class ExtractedInformation < RealtimeContactAnalysisSegment; end
  class Unknown < RealtimeContactAnalysisSegment; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



29520
29521
29522
# File 'lib/aws-sdk-connect/types.rb', line 29520

def unknown
  @unknown
end