Class: Aws::Connect::Types::RecurrenceConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Defines the recurrence configuration for overrides. This configuration uses a recurrence pattern to specify when and how frequently an event should repeat.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recurrence_patternTypes::RecurrencePattern

The recurrence pattern that defines how the event repeats. Example: Frequency, Interval, ByMonth, ByMonthDay, ByWeekdayOccurrence



26928
26929
26930
26931
26932
# File 'lib/aws-sdk-connect/types.rb', line 26928

class RecurrenceConfig < Struct.new(
  :recurrence_pattern)
  SENSITIVE = []
  include Aws::Structure
end