Class: Aws::Connect::Types::RoutingCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RoutingCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Latest routing criteria on the contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activation_timestamp ⇒ Time
The timestamp indicating when the routing criteria is set to active.
-
#index ⇒ Integer
Information about the index of the routing criteria.
-
#steps ⇒ Array<Types::Step>
List of routing steps.
Instance Attribute Details
#activation_timestamp ⇒ Time
The timestamp indicating when the routing criteria is set to active. A routing criteria is activated when contact is transferred to a queue. ActivationTimestamp will be set on routing criteria for contacts in agent queue even though Routing criteria is never activated for contacts in agent queue.
29408 29409 29410 29411 29412 29413 29414 |
# File 'lib/aws-sdk-connect/types.rb', line 29408 class RoutingCriteria < Struct.new( :steps, :activation_timestamp, :index) SENSITIVE = [] include Aws::Structure end |
#index ⇒ Integer
Information about the index of the routing criteria.
29408 29409 29410 29411 29412 29413 29414 |
# File 'lib/aws-sdk-connect/types.rb', line 29408 class RoutingCriteria < Struct.new( :steps, :activation_timestamp, :index) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::Step>
List of routing steps. When Connect Customer does not find an available agent meeting the requirements in a step for a given step duration, the routing criteria will move on to the next step sequentially until a join is completed with an agent. When all steps are exhausted, the contact will be offered to any agent in the queue.
29408 29409 29410 29411 29412 29413 29414 |
# File 'lib/aws-sdk-connect/types.rb', line 29408 class RoutingCriteria < Struct.new( :steps, :activation_timestamp, :index) SENSITIVE = [] include Aws::Structure end |