Class: Aws::Connect::Types::RoutingCriteriaInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

An object to define the RoutingCriteria.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stepsArray<Types::RoutingCriteriaInputStep>

When Amazon Connect does not find an available agent meeting the requirements in a step for a given step duration, the routing criteria will move on to the next step sequentially until a join is completed with an agent. When all steps are exhausted, the contact will be offered to any agent in the queue.



27269
27270
27271
27272
27273
# File 'lib/aws-sdk-connect/types.rb', line 27269

class RoutingCriteriaInput < Struct.new(
  :steps)
  SENSITIVE = []
  include Aws::Structure
end