Class: Aws::Connect::Types::RoutingProfileManualAssignmentQueueConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RoutingProfileManualAssignmentQueueConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about the queue and channel for manual assignment behaviour can be enabled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#queue_reference ⇒ Types::RoutingProfileQueueReference
Contains the channel and queue identifier for a routing profile.
Instance Attribute Details
#queue_reference ⇒ Types::RoutingProfileQueueReference
Contains the channel and queue identifier for a routing profile.
27897 27898 27899 27900 27901 |
# File 'lib/aws-sdk-connect/types.rb', line 27897 class RoutingProfileManualAssignmentQueueConfig < Struct.new( :queue_reference) SENSITIVE = [] include Aws::Structure end |