Class: Aws::Connect::Types::RuleAttributeAndCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A list of conditions which would be applied together with an AND condition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tag_conditionsArray<Types::TagCondition>

A list of tag conditions that need to be applied with AND condition.

Returns:



29371
29372
29373
29374
29375
# File 'lib/aws-sdk-connect/types.rb', line 29371

class RuleAttributeAndCondition < Struct.new(
  :tag_conditions)
  SENSITIVE = []
  include Aws::Structure
end