Class: Aws::Connect::Types::RulesSearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RulesSearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The search criteria to be used to return rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_conditions ⇒ Array<Types::RulesSearchCriteria>
A list of conditions which would be applied together with an AND condition.
-
#or_conditions ⇒ Array<Types::RulesSearchCriteria>
A list of conditions which would be applied together with an OR condition.
-
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
Instance Attribute Details
#and_conditions ⇒ Array<Types::RulesSearchCriteria>
A list of conditions which would be applied together with an AND condition.
29616 29617 29618 29619 29620 29621 29622 |
# File 'lib/aws-sdk-connect/types.rb', line 29616 class RulesSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::RulesSearchCriteria>
A list of conditions which would be applied together with an OR condition.
29616 29617 29618 29619 29620 29621 29622 |
# File 'lib/aws-sdk-connect/types.rb', line 29616 class RulesSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
FieldName are Name,
PublishStatus, EventSourceName, RuleId,
IntegrationAssociationId, ActionSummaries, and
RuleCapabilityTiers.
29616 29617 29618 29619 29620 29621 29622 |
# File 'lib/aws-sdk-connect/types.rb', line 29616 class RulesSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |