Class: Aws::Connect::Types::SearchAgentStatusesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_statusesArray<Types::AgentStatus>

The search criteria to be used to return agent statuses.

Returns:



28461
28462
28463
28464
28465
28466
28467
# File 'lib/aws-sdk-connect/types.rb', line 28461

class SearchAgentStatusesResponse < Struct.new(
  :agent_statuses,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#approximate_total_countInteger

The total number of agent statuses which matched your search query.

Returns:

  • (Integer)


28461
28462
28463
28464
28465
28466
28467
# File 'lib/aws-sdk-connect/types.rb', line 28461

class SearchAgentStatusesResponse < Struct.new(
  :agent_statuses,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


28461
28462
28463
28464
28465
28466
28467
# File 'lib/aws-sdk-connect/types.rb', line 28461

class SearchAgentStatusesResponse < Struct.new(
  :agent_statuses,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end