Class: Aws::Connect::Types::SearchContactFlowModulesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of flows which matched your search query.

Returns:

  • (Integer)


31477
31478
31479
31480
31481
31482
31483
# File 'lib/aws-sdk-connect/types.rb', line 31477

class SearchContactFlowModulesResponse < Struct.new(
  :contact_flow_modules,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_modulesArray<Types::ContactFlowModule>

The search criteria to be used to return flow modules.

Returns:



31477
31478
31479
31480
31481
31482
31483
# File 'lib/aws-sdk-connect/types.rb', line 31477

class SearchContactFlowModulesResponse < Struct.new(
  :contact_flow_modules,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


31477
31478
31479
31480
31481
31482
31483
# File 'lib/aws-sdk-connect/types.rb', line 31477

class SearchContactFlowModulesResponse < Struct.new(
  :contact_flow_modules,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end