Class: Aws::Connect::Types::SearchContactsAdditionalTimeRangeCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The criteria of the time range to additionally filter on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#time_rangeTypes::SearchContactsTimeRange

A structure of time range that you want to search results.



26767
26768
26769
26770
26771
26772
# File 'lib/aws-sdk-connect/types.rb', line 26767

class SearchContactsAdditionalTimeRangeCriteria < Struct.new(
  :time_range,
  :timestamp_condition)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp_conditionTypes::SearchContactsTimestampCondition

List of the timestamp conditions.



26767
26768
26769
26770
26771
26772
# File 'lib/aws-sdk-connect/types.rb', line 26767

class SearchContactsAdditionalTimeRangeCriteria < Struct.new(
  :time_range,
  :timestamp_condition)
  SENSITIVE = []
  include Aws::Structure
end