Class: Aws::Connect::Types::SearchContactsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::SearchCriteria

The search criteria to be used to return contacts.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#sortTypes::Sort

Specifies a field to sort by and a sort order.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#time_rangeTypes::SearchContactsTimeRange

Time range that you want to search results.



28566
28567
28568
28569
28570
28571
28572
28573
28574
28575
# File 'lib/aws-sdk-connect/types.rb', line 28566

class SearchContactsRequest < Struct.new(
  :instance_id,
  :time_range,
  :search_criteria,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end