Class: Aws::Connect::Types::SearchContactsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contactsArray<Types::ContactSearchSummary>

Information about the contacts.



31651
31652
31653
31654
31655
31656
31657
# File 'lib/aws-sdk-connect/types.rb', line 31651

class SearchContactsResponse < Struct.new(
  :contacts,
  :next_token,
  :total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.



31651
31652
31653
31654
31655
31656
31657
# File 'lib/aws-sdk-connect/types.rb', line 31651

class SearchContactsResponse < Struct.new(
  :contacts,
  :next_token,
  :total_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_countInteger

The total number of contacts which matched your search query.



31651
31652
31653
31654
31655
31656
31657
# File 'lib/aws-sdk-connect/types.rb', line 31651

class SearchContactsResponse < Struct.new(
  :contacts,
  :next_token,
  :total_count)
  SENSITIVE = []
  include Aws::Structure
end