Class: Aws::Connect::Types::SearchDataTablesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The approximate number of data tables that matched the search criteria.

Returns:



31727
31728
31729
31730
31731
31732
31733
# File 'lib/aws-sdk-connect/types.rb', line 31727

class SearchDataTablesResponse < Struct.new(
  :data_tables,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#data_tablesArray<Types::DataTable>

An array of data tables matching the search criteria with the same structure as DescribeTable except Version, VersionDescription, and LockVersion are omitted.

Returns:



31727
31728
31729
31730
31731
31732
31733
# File 'lib/aws-sdk-connect/types.rb', line 31727

class SearchDataTablesResponse < Struct.new(
  :data_tables,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:



31727
31728
31729
31730
31731
31732
31733
# File 'lib/aws-sdk-connect/types.rb', line 31727

class SearchDataTablesResponse < Struct.new(
  :data_tables,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end