Class: Aws::Connect::Types::SearchEvaluationFormsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html



27616
27617
27618
27619
27620
27621
27622
27623
27624
# File 'lib/aws-sdk-connect/types.rb', line 27616

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



27616
27617
27618
27619
27620
27621
27622
27623
27624
# File 'lib/aws-sdk-connect/types.rb', line 27616

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



27616
27617
27618
27619
27620
27621
27622
27623
27624
# File 'lib/aws-sdk-connect/types.rb', line 27616

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::EvaluationFormSearchCriteria

The search criteria to be used to return evaluation forms.



27616
27617
27618
27619
27620
27621
27622
27623
27624
# File 'lib/aws-sdk-connect/types.rb', line 27616

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::EvaluationFormSearchFilter

Filters to be applied to search results.



27616
27617
27618
27619
27620
27621
27622
27623
27624
# File 'lib/aws-sdk-connect/types.rb', line 27616

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end