Class: Aws::Connect::Types::SearchHoursOfOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of hours of operations which matched your search query.

Returns:

  • (Integer)


30107
30108
30109
30110
30111
30112
30113
# File 'lib/aws-sdk-connect/types.rb', line 30107

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operationsArray<Types::HoursOfOperation>

Information about the hours of operations.

Returns:



30107
30108
30109
30110
30111
30112
30113
# File 'lib/aws-sdk-connect/types.rb', line 30107

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


30107
30108
30109
30110
30111
30112
30113
# File 'lib/aws-sdk-connect/types.rb', line 30107

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end