Class: Aws::Connect::Types::SearchNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::NotificationSearchCriteria
The search criteria to apply when searching for notifications.
-
#search_filter ⇒ Types::NotificationSearchFilter
Filters to apply to the search results, such as tag-based filters.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
32212 32213 32214 32215 32216 32217 32218 32219 32220 |
# File 'lib/aws-sdk-connect/types.rb', line 32212 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. Valid range is 1-100.
32212 32213 32214 32215 32216 32217 32218 32219 32220 |
# File 'lib/aws-sdk-connect/types.rb', line 32212 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.
32212 32213 32214 32215 32216 32217 32218 32219 32220 |
# File 'lib/aws-sdk-connect/types.rb', line 32212 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::NotificationSearchCriteria
The search criteria to apply when searching for notifications. Supports filtering by notification ID and message content using comparison types such as STARTS_WITH, CONTAINS, and EXACT.
32212 32213 32214 32215 32216 32217 32218 32219 32220 |
# File 'lib/aws-sdk-connect/types.rb', line 32212 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::NotificationSearchFilter
Filters to apply to the search results, such as tag-based filters.
32212 32213 32214 32215 32216 32217 32218 32219 32220 |
# File 'lib/aws-sdk-connect/types.rb', line 32212 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |