Class: Aws::Connect::Types::SearchPredefinedAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



32267
32268
32269
32270
32271
32272
32273
32274
# File 'lib/aws-sdk-connect/types.rb', line 32267

class SearchPredefinedAttributesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



32267
32268
32269
32270
32271
32272
32273
32274
# File 'lib/aws-sdk-connect/types.rb', line 32267

class SearchPredefinedAttributesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



32267
32268
32269
32270
32271
32272
32273
32274
# File 'lib/aws-sdk-connect/types.rb', line 32267

class SearchPredefinedAttributesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::PredefinedAttributeSearchCriteria

The search criteria to be used to return predefined attributes.



32267
32268
32269
32270
32271
32272
32273
32274
# File 'lib/aws-sdk-connect/types.rb', line 32267

class SearchPredefinedAttributesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end