Class: Aws::Connect::Types::SearchPredefinedAttributesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchPredefinedAttributesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The approximate number of predefined attributes which matched your search query.
-
#next_token ⇒ String
The token for the next set of results.
-
#predefined_attributes ⇒ Array<Types::PredefinedAttribute>
Predefined attributes matched by the search criteria.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The approximate number of predefined attributes which matched your search query.
32293 32294 32295 32296 32297 32298 32299 |
# File 'lib/aws-sdk-connect/types.rb', line 32293 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
32293 32294 32295 32296 32297 32298 32299 |
# File 'lib/aws-sdk-connect/types.rb', line 32293 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#predefined_attributes ⇒ Array<Types::PredefinedAttribute>
Predefined attributes matched by the search criteria.
32293 32294 32295 32296 32297 32298 32299 |
# File 'lib/aws-sdk-connect/types.rb', line 32293 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |