Class: Aws::Connect::Types::SearchPromptsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.



32330
32331
32332
32333
32334
32335
32336
32337
32338
# File 'lib/aws-sdk-connect/types.rb', line 32330

class SearchPromptsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.



32330
32331
32332
32333
32334
32335
32336
32337
32338
# File 'lib/aws-sdk-connect/types.rb', line 32330

class SearchPromptsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



32330
32331
32332
32333
32334
32335
32336
32337
32338
# File 'lib/aws-sdk-connect/types.rb', line 32330

class SearchPromptsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::PromptSearchCriteria

The search criteria to be used to return prompts.



32330
32331
32332
32333
32334
32335
32336
32337
32338
# File 'lib/aws-sdk-connect/types.rb', line 32330

class SearchPromptsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::PromptSearchFilter

Filters to be applied to search results.



32330
32331
32332
32333
32334
32335
32336
32337
32338
# File 'lib/aws-sdk-connect/types.rb', line 32330

class SearchPromptsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end