Class: Aws::Connect::Types::SearchQuickConnectsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of quick connects which matched your search query.



29359
29360
29361
29362
29363
29364
29365
# File 'lib/aws-sdk-connect/types.rb', line 29359

class SearchQuickConnectsResponse < Struct.new(
  :quick_connects,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.



29359
29360
29361
29362
29363
29364
29365
# File 'lib/aws-sdk-connect/types.rb', line 29359

class SearchQuickConnectsResponse < Struct.new(
  :quick_connects,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#quick_connectsArray<Types::QuickConnect>

Information about the quick connects.



29359
29360
29361
29362
29363
29364
29365
# File 'lib/aws-sdk-connect/types.rb', line 29359

class SearchQuickConnectsResponse < Struct.new(
  :quick_connects,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end