Class: Aws::Connect::Types::SearchResourceTagsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchResourceTagsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#resource_types ⇒ Array<String>
The list of resource types to be used to search tags from.
-
#search_criteria ⇒ Types::ResourceTagsSearchCriteria
The search criteria to be used to return tags.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instanceId in the Amazon Resource Name (ARN) of the instance.
28070 28071 28072 28073 28074 28075 28076 28077 28078 |
# File 'lib/aws-sdk-connect/types.rb', line 28070 class SearchResourceTagsRequest < Struct.new( :instance_id, :resource_types, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
28070 28071 28072 28073 28074 28075 28076 28077 28078 |
# File 'lib/aws-sdk-connect/types.rb', line 28070 class SearchResourceTagsRequest < Struct.new( :instance_id, :resource_types, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
28070 28071 28072 28073 28074 28075 28076 28077 28078 |
# File 'lib/aws-sdk-connect/types.rb', line 28070 class SearchResourceTagsRequest < Struct.new( :instance_id, :resource_types, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<String>
The list of resource types to be used to search tags from. If not provided or if any empty list is provided, this API will search from all supported resource types. Note that lowercase and - are required.
**Supported resource types**
-
agent
-
agent-state
-
routing-profile
-
standard-queue
-
security-profile
-
operating-hours
-
prompt
-
contact-flow
-
flow- module
-
transfer-destination (also known as quick connect)
28070 28071 28072 28073 28074 28075 28076 28077 28078 |
# File 'lib/aws-sdk-connect/types.rb', line 28070 class SearchResourceTagsRequest < Struct.new( :instance_id, :resource_types, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::ResourceTagsSearchCriteria
The search criteria to be used to return tags.
28070 28071 28072 28073 28074 28075 28076 28077 28078 |
# File 'lib/aws-sdk-connect/types.rb', line 28070 class SearchResourceTagsRequest < Struct.new( :instance_id, :resource_types, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |