Class: Aws::Connect::Types::SearchRoutingProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchRoutingProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::RoutingProfileSearchCriteria
The search criteria to be used to return routing profiles.
-
#search_filter ⇒ Types::RoutingProfileSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
28556 28557 28558 28559 28560 28561 28562 28563 28564 |
# File 'lib/aws-sdk-connect/types.rb', line 28556 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
28556 28557 28558 28559 28560 28561 28562 28563 28564 |
# File 'lib/aws-sdk-connect/types.rb', line 28556 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
28556 28557 28558 28559 28560 28561 28562 28563 28564 |
# File 'lib/aws-sdk-connect/types.rb', line 28556 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::RoutingProfileSearchCriteria
The search criteria to be used to return routing profiles.
<note markdown=“1”> The name and description fields support “contains” queries with a minimum of 2 characters and a maximum of 25 characters. Any queries with character lengths outside of this range will throw invalid results.
</note>
28556 28557 28558 28559 28560 28561 28562 28563 28564 |
# File 'lib/aws-sdk-connect/types.rb', line 28556 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::RoutingProfileSearchFilter
Filters to be applied to search results.
28556 28557 28558 28559 28560 28561 28562 28563 28564 |
# File 'lib/aws-sdk-connect/types.rb', line 28556 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |