Class: Aws::Connect::Types::SearchRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of rules which matched your search query.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#rules ⇒ Array<Types::RuleSearchSummary>
Information about the rules.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of rules which matched your search query.
31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31786 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31786 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::RuleSearchSummary>
Information about the rules.
31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31786 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |