Class: Aws::Connect::Types::SearchSecurityProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchSecurityProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of security profiles which matched your search query.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#security_profiles ⇒ Array<Types::SecurityProfileSearchSummary>
Information about the security profiles.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of security profiles which matched your search query.
30036 30037 30038 30039 30040 30041 30042 |
# File 'lib/aws-sdk-connect/types.rb', line 30036 class SearchSecurityProfilesResponse < Struct.new( :security_profiles, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
30036 30037 30038 30039 30040 30041 30042 |
# File 'lib/aws-sdk-connect/types.rb', line 30036 class SearchSecurityProfilesResponse < Struct.new( :security_profiles, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#security_profiles ⇒ Array<Types::SecurityProfileSearchSummary>
Information about the security profiles.
30036 30037 30038 30039 30040 30041 30042 |
# File 'lib/aws-sdk-connect/types.rb', line 30036 class SearchSecurityProfilesResponse < Struct.new( :security_profiles, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |