Class: Aws::Connect::Types::SearchTestCasesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of test cases which matched your search query.

Returns:

  • (Integer)


29638
29639
29640
29641
29642
29643
29644
# File 'lib/aws-sdk-connect/types.rb', line 29638

class SearchTestCasesResponse < Struct.new(
  :test_cases,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


29638
29639
29640
29641
29642
29643
29644
# File 'lib/aws-sdk-connect/types.rb', line 29638

class SearchTestCasesResponse < Struct.new(
  :test_cases,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#test_casesArray<Types::TestCase>

Information about the test cases.

Returns:



29638
29639
29640
29641
29642
29643
29644
# File 'lib/aws-sdk-connect/types.rb', line 29638

class SearchTestCasesResponse < Struct.new(
  :test_cases,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end