Class: Aws::Connect::Types::SearchUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::UserSearchCriteria
The search criteria to be used to return users.
-
#search_filter ⇒ Types::UserSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
29516 29517 29518 29519 29520 29521 29522 29523 29524 |
# File 'lib/aws-sdk-connect/types.rb', line 29516 class SearchUsersRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29516 29517 29518 29519 29520 29521 29522 29523 29524 |
# File 'lib/aws-sdk-connect/types.rb', line 29516 class SearchUsersRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29516 29517 29518 29519 29520 29521 29522 29523 29524 |
# File 'lib/aws-sdk-connect/types.rb', line 29516 class SearchUsersRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::UserSearchCriteria
The search criteria to be used to return users.
<note markdown=“1”> The name and description fields support “contains” queries with a minimum of 2 characters and a maximum of 25 characters. Any queries with character lengths outside of this range will throw invalid results.
</note>
29516 29517 29518 29519 29520 29521 29522 29523 29524 |
# File 'lib/aws-sdk-connect/types.rb', line 29516 class SearchUsersRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::UserSearchFilter
Filters to be applied to search results.
29516 29517 29518 29519 29520 29521 29522 29523 29524 |
# File 'lib/aws-sdk-connect/types.rb', line 29516 class SearchUsersRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |