Class: Aws::Connect::Types::SearchViewsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The approximate total number of views that match the search criteria.

Returns:

  • (Integer)


32597
32598
32599
32600
32601
32602
32603
# File 'lib/aws-sdk-connect/types.rb', line 32597

class SearchViewsResponse < Struct.new(
  :views,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


32597
32598
32599
32600
32601
32602
32603
# File 'lib/aws-sdk-connect/types.rb', line 32597

class SearchViewsResponse < Struct.new(
  :views,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#viewsArray<Types::View>

A list of views that match the search criteria.

Returns:



32597
32598
32599
32600
32601
32602
32603
# File 'lib/aws-sdk-connect/types.rb', line 32597

class SearchViewsResponse < Struct.new(
  :views,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end