Class: Aws::Connect::Types::SearchWorkspaceAssociationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The approximate total number of workspace associations that match the search criteria.

Returns:

  • (Integer)


28062
28063
28064
28065
28066
28067
28068
# File 'lib/aws-sdk-connect/types.rb', line 28062

class SearchWorkspaceAssociationsResponse < Struct.new(
  :next_token,
  :workspace_associations,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


28062
28063
28064
28065
28066
28067
28068
# File 'lib/aws-sdk-connect/types.rb', line 28062

class SearchWorkspaceAssociationsResponse < Struct.new(
  :next_token,
  :workspace_associations,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_associationsArray<Types::WorkspaceAssociationSearchSummary>

A list of workspace associations that match the search criteria.



28062
28063
28064
28065
28066
28067
28068
# File 'lib/aws-sdk-connect/types.rb', line 28062

class SearchWorkspaceAssociationsResponse < Struct.new(
  :next_token,
  :workspace_associations,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end