Class: Aws::Connect::Types::SearchableAgentCriteriaStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The agent criteria to search for preferred agents on the routing criteria.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_idsArray<String>

The identifiers of agents used in preferred agents matching.

Returns:

  • (Array<String>)


30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-connect/types.rb', line 30501

class SearchableAgentCriteriaStep < Struct.new(
  :agent_ids,
  :match_type)
  SENSITIVE = []
  include Aws::Structure
end

#match_typeString

The match type combining multiple agent criteria steps.

Returns:

  • (String)


30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-connect/types.rb', line 30501

class SearchableAgentCriteriaStep < Struct.new(
  :agent_ids,
  :match_type)
  SENSITIVE = []
  include Aws::Structure
end