Class: Aws::Connect::Types::SecurityKey

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Configuration information of the security key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.

Returns:

  • (String)


31049
31050
31051
31052
31053
31054
31055
# File 'lib/aws-sdk-connect/types.rb', line 31049

class SecurityKey < Struct.new(
  :association_id,
  :key,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the security key was created.

Returns:

  • (Time)


31049
31050
31051
31052
31053
31054
31055
# File 'lib/aws-sdk-connect/types.rb', line 31049

class SecurityKey < Struct.new(
  :association_id,
  :key,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The key of the security key.

Returns:

  • (String)


31049
31050
31051
31052
31053
31054
31055
# File 'lib/aws-sdk-connect/types.rb', line 31049

class SecurityKey < Struct.new(
  :association_id,
  :key,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end