Class: Aws::Connect::Types::SendChatIntegrationEventResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SendChatIntegrationEventResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#initial_contact_id ⇒ String
Identifier of chat contact used to handle integration event.
-
#new_chat_created ⇒ Boolean
Whether handling the integration event resulted in creating a new chat or acting on existing chat.
Instance Attribute Details
#initial_contact_id ⇒ String
Identifier of chat contact used to handle integration event. This may be null if the integration event is not valid without an already existing chat contact.
33280 33281 33282 33283 33284 33285 |
# File 'lib/aws-sdk-connect/types.rb', line 33280 class SendChatIntegrationEventResponse < Struct.new( :initial_contact_id, :new_chat_created) SENSITIVE = [] include Aws::Structure end |
#new_chat_created ⇒ Boolean
Whether handling the integration event resulted in creating a new chat or acting on existing chat.
33280 33281 33282 33283 33284 33285 |
# File 'lib/aws-sdk-connect/types.rb', line 33280 class SendChatIntegrationEventResponse < Struct.new( :initial_contact_id, :new_chat_created) SENSITIVE = [] include Aws::Structure end |