Class: Aws::Connect::Types::SendNotificationActionDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SendNotificationActionDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the send notification action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
Notification content.
-
#content_type ⇒ String
Content type format.
-
#delivery_method ⇒ String
Notification delivery method.
-
#exclusion ⇒ Types::NotificationRecipientType
Recipients to exclude from notification.
-
#recipient ⇒ Types::NotificationRecipientType
Notification recipient.
-
#subject ⇒ String
The subject of the email if the delivery method is
EMAIL.
Instance Attribute Details
#content ⇒ String
Notification content. Supports variable injection. For more information, see JSONPath reference in the Connect Customer Administrators Guide.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
Content type format.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#delivery_method ⇒ String
Notification delivery method.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#exclusion ⇒ Types::NotificationRecipientType
Recipients to exclude from notification.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#recipient ⇒ Types::NotificationRecipientType
Notification recipient.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#subject ⇒ String
The subject of the email if the delivery method is EMAIL. Supports
variable injection. For more information, see JSONPath
reference in the Connect Customer Administrators Guide.
33750 33751 33752 33753 33754 33755 33756 33757 33758 33759 |
# File 'lib/aws-sdk-connect/types.rb', line 33750 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |