Class: Aws::Connect::Types::ServiceQuotaExceededExceptionReason
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ServiceQuotaExceededExceptionReason
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The reason for the exception.
Direct Known Subclasses
Defined Under Namespace
Classes: AttachedFileServiceQuotaExceededExceptionReason, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attached_file_service_quota_exceeded_exception_reason ⇒ String
Total file size of all files or total number of files exceeds the service quota.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#attached_file_service_quota_exceeded_exception_reason ⇒ String
Total file size of all files or total number of files exceeds the service quota
30911 30912 30913 30914 30915 30916 30917 30918 30919 30920 |
# File 'lib/aws-sdk-connect/types.rb', line 30911 class ServiceQuotaExceededExceptionReason < Struct.new( :attached_file_service_quota_exceeded_exception_reason, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AttachedFileServiceQuotaExceededExceptionReason < ServiceQuotaExceededExceptionReason; end class Unknown < ServiceQuotaExceededExceptionReason; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
30911 30912 30913 |
# File 'lib/aws-sdk-connect/types.rb', line 30911 def unknown @unknown end |