Class: Aws::Connect::Types::SingleSelectQuestionRuleCategoryAutomation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the automation option based on a rule category for a single select question.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The category name, as defined in Rules.

Returns:

  • (String)


30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-connect/types.rb', line 30500

class SingleSelectQuestionRuleCategoryAutomation < Struct.new(
  :category,
  :condition,
  :option_ref_id)
  SENSITIVE = []
  include Aws::Structure
end

#conditionString

The condition to apply for the automation option. If the condition is PRESENT, then the option is applied when the contact data includes the category. Similarly, if the condition is NOT_PRESENT, then the option is applied when the contact data does not include the category.

Returns:

  • (String)


30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-connect/types.rb', line 30500

class SingleSelectQuestionRuleCategoryAutomation < Struct.new(
  :category,
  :condition,
  :option_ref_id)
  SENSITIVE = []
  include Aws::Structure
end

#option_ref_idString

The identifier of the answer option.

Returns:

  • (String)


30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-connect/types.rb', line 30500

class SingleSelectQuestionRuleCategoryAutomation < Struct.new(
  :category,
  :condition,
  :option_ref_id)
  SENSITIVE = []
  include Aws::Structure
end