Class: Aws::Connect::Types::StartAttachedFileUploadRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartAttachedFileUploadRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_arn ⇒ String
The resource to which the attached file is (being) uploaded to.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#created_by ⇒ Types::CreatedByInfo
Represents the identity that created the file.
-
#file_name ⇒ String
A case-sensitive name of the attached file being uploaded.
-
#file_size_in_bytes ⇒ Integer
The size of the attached file in bytes.
-
#file_use_case_type ⇒ String
The use case for the file.
-
#instance_id ⇒ String
The unique identifier of the Connect Customer instance.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#url_expiry_in_seconds ⇒ Integer
Optional override for the expiry of the pre-signed S3 URL in seconds.
Instance Attribute Details
#associated_resource_arn ⇒ String
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::CreatedByInfo
Represents the identity that created the file.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
A case-sensitive name of the attached file being uploaded.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#file_size_in_bytes ⇒ Integer
The size of the attached file in bytes.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#file_use_case_type ⇒ String
The use case for the file.
Only ATTACHMENTS are supported.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier of the Connect Customer instance.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this
resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |
#url_expiry_in_seconds ⇒ Integer
Optional override for the expiry of the pre-signed S3 URL in seconds. The default value is 300.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 |
# File 'lib/aws-sdk-connect/types.rb', line 33694 class StartAttachedFileUploadRequest < Struct.new( :client_token, :instance_id, :file_name, :file_size_in_bytes, :url_expiry_in_seconds, :file_use_case_type, :associated_resource_arn, :created_by, :tags) SENSITIVE = [] include Aws::Structure end |