Class: Aws::Connect::Types::StartChatContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartChatContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:customer_id]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#chat_duration_in_minutes ⇒ Integer
The total duration of the newly started chat session.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_flow_id ⇒ String
The identifier of the flow for initiating the chat.
-
#customer_id ⇒ String
The customer’s identification number.
-
#disconnect_on_customer_exit ⇒ Array<String>
A list of participant types to automatically disconnect when the end customer ends the chat session, allowing them to continue through disconnect flows such as surveys or feedback forms.
-
#initial_message ⇒ Types::ChatMessage
The initial message to be sent to the newly created chat.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#participant_configuration ⇒ Types::ParticipantConfiguration
The configuration of the participant.
-
#participant_details ⇒ Types::ParticipantDetails
Information identifying the participant.
-
#persistent_chat ⇒ Types::PersistentChat
Enable persistent chats.
-
#related_contact_id ⇒ String
The unique identifier for an Connect Customer contact.
-
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A set of system defined key-value pairs stored on individual contact segments using an attribute map.
-
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes. They can be accessed in flows just like any other contact attributes.
There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#chat_duration_in_minutes ⇒ Integer
The total duration of the newly started chat session. If not specified, the chat session duration defaults to 25 hour. The minimum configurable time is 60 minutes. The maximum configurable time is 10,080 minutes (7 days).
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow for initiating the chat. To see the ContactFlowId in the Connect Customer admin website, on the navigation menu go to Routing, Flows. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:
arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#customer_id ⇒ String
The customer’s identification number. For example, the ‘CustomerId` may be a customer number from your CRM.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#disconnect_on_customer_exit ⇒ Array<String>
A list of participant types to automatically disconnect when the end customer ends the chat session, allowing them to continue through disconnect flows such as surveys or feedback forms.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#initial_message ⇒ Types::ChatMessage
The initial message to be sent to the newly created chat.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#participant_configuration ⇒ Types::ParticipantConfiguration
The configuration of the participant.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
Information identifying the participant.
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#persistent_chat ⇒ Types::PersistentChat
Enable persistent chats. For more information about enabling persistent chat, and for example use cases and how to configure for them, see [Enable persistent chat].
[1]: docs.aws.amazon.com/connect/latest/adminguide/chat-persistence.html
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#related_contact_id ⇒ String
The unique identifier for an Connect Customer contact. This identifier is related to the chat starting.
<note markdown=“1”> You cannot provide data for both RelatedContactId and PersistentChat.
</note>
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A set of system defined key-value pairs stored on individual contact segments using an attribute map. The attributes are standard Connect Customer attributes. They can be accessed in flows.
Attribute keys can include only alphanumeric, -, and _.
This field can be used to show channel subtype, such as ‘connect:Guide`.
<note markdown=“1”> The types ‘application/vnd.amazonaws.connect.message.interactive` and `application/vnd.amazonaws.connect.message.interactive.response` must be present in the SupportedMessagingContentTypes field of this API in order to set `SegmentAttributes` as “connect:Subtype”: {“valueString” : “connect:Guide” }`.
</note>
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types. Supported types are ‘text/plain`, `text/markdown`, `application/json`, `application/vnd.amazonaws.connect.message.interactive`, and `application/vnd.amazonaws.connect.message.interactive.response`.
Content types must always contain ‘text/plain`. You can then put any other supported type in the list. For example, all the following lists are valid because they contain `text/plain`: `[text/plain, text/markdown, application/json]`, `[text/markdown, text/plain]`, `[text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response]`.
<note markdown=“1”> The type ‘application/vnd.amazonaws.connect.message.interactive` is required to use the [Show view] flow block.
</note>
[1]: docs.aws.amazon.com/connect/latest/adminguide/show-view-block.html
31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 31299 31300 31301 31302 31303 31304 31305 31306 |
# File 'lib/aws-sdk-connect/types.rb', line 31289 class StartChatContactRequest < Struct.new( :instance_id, :contact_flow_id, :attributes, :participant_details, :participant_configuration, :initial_message, :client_token, :chat_duration_in_minutes, :supported_messaging_content_types, :persistent_chat, :related_contact_id, :segment_attributes, :customer_id, :disconnect_on_customer_exit) SENSITIVE = [:customer_id] include Aws::Structure end |