Class: Aws::Connect::Types::StartContactStreamingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#chat_streaming_configurationTypes::ChatStreamingConfiguration

The streaming configuration, such as the Amazon SNS streaming endpoint.



34729
34730
34731
34732
34733
34734
34735
34736
# File 'lib/aws-sdk-connect/types.rb', line 34729

class StartContactStreamingRequest < Struct.new(
  :instance_id,
  :contact_id,
  :chat_streaming_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


34729
34730
34731
34732
34733
34734
34735
34736
# File 'lib/aws-sdk-connect/types.rb', line 34729

class StartContactStreamingRequest < Struct.new(
  :instance_id,
  :contact_id,
  :chat_streaming_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.

Returns:

  • (String)


34729
34730
34731
34732
34733
34734
34735
34736
# File 'lib/aws-sdk-connect/types.rb', line 34729

class StartContactStreamingRequest < Struct.new(
  :instance_id,
  :contact_id,
  :chat_streaming_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


34729
34730
34731
34732
34733
34734
34735
34736
# File 'lib/aws-sdk-connect/types.rb', line 34729

class StartContactStreamingRequest < Struct.new(
  :instance_id,
  :contact_id,
  :chat_streaming_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end