Class: Aws::Connect::Types::StartOutboundChatContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in flows just like any other contact attributes.

Returns:

  • (Hash<String,String>)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#chat_duration_in_minutesInteger

The total duration of the newly started chat session. If not specified, the chat session duration defaults to 25 hour. The minimum configurable time is 60 minutes. The maximum configurable time is 10,080 minutes (7 days).

Returns:

  • (Integer)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs][1]. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow for the call. To see the ContactFlowId in the Amazon Connect console user interface, on the navigation menu go to **Routing, Contact Flows**. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:

  • arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/123ec456-a007-89c0-1234-xxxxxxxxxxxx

^

Returns:

  • (String)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#destination_endpointTypes::Endpoint

Information about the endpoint.

Returns:



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#initial_system_messageTypes::ChatMessage

A chat message.

Returns:



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#initial_templated_system_messageTypes::TemplatedMessageConfig

Information about template message configuration.



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#participant_detailsTypes::ParticipantDetails

The customer’s details.



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier for an Amazon Connect contact. This identifier is related to the contact starting.

Returns:

  • (String)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#segment_attributesHash<String,Types::SegmentAttributeValue>

A set of system defined key-value pairs stored on individual contact segments using an attribute map. The attributes are standard Amazon Connect attributes. They can be accessed in flows.

  • Attribute keys can include only alphanumeric, -, and _.

  • This field can be used to show channel subtype, such as connect:SMS and connect:WhatsApp.

Returns:



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_endpointTypes::Endpoint

Information about the endpoint.

Returns:



31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#supported_messaging_content_typesArray<String>

The supported chat message content types. Supported types are:

  • text/plain

  • text/markdown

  • ‘application/json, application/vnd.amazonaws.connect.message.interactive`

  • application/vnd.amazonaws.connect.message.interactive.response

Content types must always contain text/plain. You can then put any other supported type in the list. For example, all the following lists are valid because they contain text/plain:

  • ‘[text/plain, text/markdown, application/json]`

  • ‘[text/markdown, text/plain]`

  • ‘[text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response]`

Returns:

  • (Array<String>)


31543
31544
31545
31546
31547
31548
31549
31550
31551
31552
31553
31554
31555
31556
31557
31558
31559
# File 'lib/aws-sdk-connect/types.rb', line 31543

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end