Class: Aws::Connect::Types::StartOutboundVoiceContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#answer_machine_detection_configTypes::AnswerMachineDetectionConfig

Configuration of the answering machine detection for this outbound call.



30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#attributesHash<String,String>

A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in flows just like any other contact attributes.

There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.

Returns:

  • (Hash<String,String>)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#campaign_idString

The campaign identifier of the outbound communication.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs]. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow for the outbound call. To see the ContactFlowId in the Amazon Connect admin website, on the navigation menu go to Routing, **Contact Flows**. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:

arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

A description of the voice contact that appears in the agent’s snapshot in the CCP logs. For more information about CCP logs, see

Download and review CCP logs][1

in the *Amazon Connect

Administrator Guide*.

[1]: docs.aws.amazon.com/connect/latest/adminguide/download-ccp-logs.html

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#destination_phone_numberString

The phone number of the customer, in E.164 format.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of a voice contact that is shown to an agent in the Contact Control Panel (CCP).

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#outbound_strategyTypes::OutboundStrategy

Information about the outbound strategy.



30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#queue_idString

The queue for the call. If you specify a queue, the phone displayed for caller ID is the phone number specified in the queue. If you do not specify a queue, the queue defined in the flow is used. If you do not specify a queue, you must specify a source phone number.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#referencesHash<String,Types::Reference>

A formatted URL that is shown to an agent in the Contact Control Panel (CCP). Contacts can have the following reference types at the time of creation: URL | NUMBER | STRING | DATE | EMAIL. ATTACHMENT is not a supported reference type during voice contact creation.

Returns:



30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

The contactId that is related to this contact. Linking voice, task, or chat by using RelatedContactID copies over contact attributes from the related contact to the new contact. All updates to user-defined attributes in the new contact are limited to the individual contact ID. There are no limits to the number of contacts that can be linked by using RelatedContactId.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#ring_timeout_in_secondsInteger

The maximum time the outbound call will wait for the destination to answer the call, in seconds

Returns:

  • (Integer)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#source_phone_numberString

The phone number associated with the Amazon Connect instance, in E.164 format. If you do not specify a source phone number, you must specify a queue.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#traffic_typeString

Denotes the class of traffic. Calls with different traffic types are handled differently by Amazon Connect. The default value is GENERAL. Use CAMPAIGN if EnableAnswerMachineDetection is set to true. For all other cases, use GENERAL.

Returns:

  • (String)


30360
30361
30362
30363
30364
30365
30366
30367
30368
30369
30370
30371
30372
30373
30374
30375
30376
30377
30378
30379
# File 'lib/aws-sdk-connect/types.rb', line 30360

class StartOutboundVoiceContactRequest < Struct.new(
  :name,
  :description,
  :references,
  :related_contact_id,
  :destination_phone_number,
  :contact_flow_id,
  :instance_id,
  :client_token,
  :source_phone_number,
  :queue_id,
  :attributes,
  :answer_machine_detection_config,
  :campaign_id,
  :traffic_type,
  :outbound_strategy,
  :ring_timeout_in_seconds)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end