Class: Aws::Connect::Types::StartScreenSharingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


35334
35335
35336
35337
35338
35339
35340
# File 'lib/aws-sdk-connect/types.rb', line 35334

class StartScreenSharingRequest < Struct.new(
  :client_token,
  :instance_id,
  :contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


35334
35335
35336
35337
35338
35339
35340
# File 'lib/aws-sdk-connect/types.rb', line 35334

class StartScreenSharingRequest < Struct.new(
  :client_token,
  :instance_id,
  :contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


35334
35335
35336
35337
35338
35339
35340
# File 'lib/aws-sdk-connect/types.rb', line 35334

class StartScreenSharingRequest < Struct.new(
  :client_token,
  :instance_id,
  :contact_id)
  SENSITIVE = []
  include Aws::Structure
end