Class: Aws::Connect::Types::StartTestCaseExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartTestCaseExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of a test case execution.
-
#test_case_execution_id ⇒ String
The identifier of the test case execution.
-
#test_case_id ⇒ String
The identifier of the test case resource that was executed.
Instance Attribute Details
#status ⇒ String
The status of a test case execution.
32055 32056 32057 32058 32059 32060 32061 |
# File 'lib/aws-sdk-connect/types.rb', line 32055 class StartTestCaseExecutionResponse < Struct.new( :test_case_execution_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |
#test_case_execution_id ⇒ String
The identifier of the test case execution.
32055 32056 32057 32058 32059 32060 32061 |
# File 'lib/aws-sdk-connect/types.rb', line 32055 class StartTestCaseExecutionResponse < Struct.new( :test_case_execution_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
The identifier of the test case resource that was executed.
32055 32056 32057 32058 32059 32060 32061 |
# File 'lib/aws-sdk-connect/types.rb', line 32055 class StartTestCaseExecutionResponse < Struct.new( :test_case_execution_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |