Class: Aws::Connect::Types::StopContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StopContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The ID of the contact.
-
#disconnect_reason ⇒ Types::DisconnectReason
The reason a contact can be disconnected.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#contact_id ⇒ String
The ID of the contact.
35843 35844 35845 35846 35847 35848 35849 |
# File 'lib/aws-sdk-connect/types.rb', line 35843 class StopContactRequest < Struct.new( :contact_id, :instance_id, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |
#disconnect_reason ⇒ Types::DisconnectReason
The reason a contact can be disconnected. Only Connect Customer outbound campaigns can provide this field. For a list and description of all the possible disconnect reasons by channel (including outbound campaign voice contacts) see DisconnectReason under ContactTraceRecord in the Connect Customer Administrator Guide.
35843 35844 35845 35846 35847 35848 35849 |
# File 'lib/aws-sdk-connect/types.rb', line 35843 class StopContactRequest < Struct.new( :contact_id, :instance_id, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35843 35844 35845 35846 35847 35848 35849 |
# File 'lib/aws-sdk-connect/types.rb', line 35843 class StopContactRequest < Struct.new( :contact_id, :instance_id, :disconnect_reason) SENSITIVE = [] include Aws::Structure end |