Class: Aws::Connect::Types::TagSearchCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TagSearchCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The search criteria to be used to return tags.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tag_key ⇒ String
The tag key used in the tag search condition.
-
#tag_key_comparison_type ⇒ String
The type of comparison to be made when evaluating the tag key in tag search condition.
-
#tag_value ⇒ String
The tag value used in the tag search condition.
-
#tag_value_comparison_type ⇒ String
The type of comparison to be made when evaluating the tag value in tag search condition.
Instance Attribute Details
#tag_key ⇒ String
The tag key used in the tag search condition.
30698 30699 30700 30701 30702 30703 30704 30705 |
# File 'lib/aws-sdk-connect/types.rb', line 30698 class TagSearchCondition < Struct.new( :tag_key, :tag_value, :tag_key_comparison_type, :tag_value_comparison_type) SENSITIVE = [] include Aws::Structure end |
#tag_key_comparison_type ⇒ String
The type of comparison to be made when evaluating the tag key in tag search condition.
30698 30699 30700 30701 30702 30703 30704 30705 |
# File 'lib/aws-sdk-connect/types.rb', line 30698 class TagSearchCondition < Struct.new( :tag_key, :tag_value, :tag_key_comparison_type, :tag_value_comparison_type) SENSITIVE = [] include Aws::Structure end |
#tag_value ⇒ String
The tag value used in the tag search condition.
30698 30699 30700 30701 30702 30703 30704 30705 |
# File 'lib/aws-sdk-connect/types.rb', line 30698 class TagSearchCondition < Struct.new( :tag_key, :tag_value, :tag_key_comparison_type, :tag_value_comparison_type) SENSITIVE = [] include Aws::Structure end |
#tag_value_comparison_type ⇒ String
The type of comparison to be made when evaluating the tag value in tag search condition.
30698 30699 30700 30701 30702 30703 30704 30705 |
# File 'lib/aws-sdk-connect/types.rb', line 30698 class TagSearchCondition < Struct.new( :tag_key, :tag_value, :tag_key_comparison_type, :tag_value_comparison_type) SENSITIVE = [] include Aws::Structure end |