Class: Aws::Connect::Types::TestCase
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TestCase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a test case.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the test case.
-
#content ⇒ String
The JSON string that represents the content of the test.
-
#description ⇒ String
The description of the test case.
-
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for the test, including channel type and parameters.
-
#id ⇒ String
The identifier of the test case.
-
#initialization_data ⇒ String
Defines the test attributes for precise data representation.
-
#last_modified_region ⇒ String
The region in which the test case was last modified.
-
#last_modified_time ⇒ Time
The time at which the test case was last modified.
-
#name ⇒ String
The name of the test case.
-
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#test_case_sha_256 ⇒ String
The SHA256 hash of the test case content.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the test case.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The JSON string that represents the content of the test.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the test case.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for the test, including channel type and parameters.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the test case.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#initialization_data ⇒ String
Defines the test attributes for precise data representation.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The region in which the test case was last modified.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time at which the test case was last modified.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test case.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |
#test_case_sha_256 ⇒ String
The SHA256 hash of the test case content.
33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 |
# File 'lib/aws-sdk-connect/types.rb', line 33068 class TestCase < Struct.new( :arn, :id, :name, :content, :entry_point, :initialization_data, :description, :status, :last_modified_time, :last_modified_region, :tags, :test_case_sha_256) SENSITIVE = [] include Aws::Structure end |