Class: Aws::Connect::Types::TestCaseSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains summary information about a test case.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the test case.

Returns:

  • (String)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the test case.

Returns:

  • (String)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The region in which the test case was last modified.

Returns:

  • (String)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time at which the test case was last modified.

Returns:

  • (Time)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the test case.

Returns:

  • (String)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the test case.

Returns:

  • (String)


34678
34679
34680
34681
34682
34683
34684
34685
34686
34687
# File 'lib/aws-sdk-connect/types.rb', line 34678

class TestCaseSummary < Struct.new(
  :id,
  :arn,
  :name,
  :status,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end