Class: Aws::Connect::Types::TrafficDistributionGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about traffic distribution groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Whether this is the default traffic distribution group created during instance replication. The default traffic distribution group cannot be deleted by the DeleteTrafficDistributionGroup API. The default traffic distribution group is deleted as part of the process for deleting a replica.

Returns:

  • (Boolean)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the traffic distribution group.

Returns:

  • (String)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the traffic distribution group.

  • CREATION_IN_PROGRESS means the previous

    CreateTrafficDistributionGroup][1

    operation is still in progress

    and has not yet completed.

  • ACTIVE means the previous [CreateTrafficDistributionGroup] operation has succeeded.

  • CREATION_FAILED indicates that the previous

    CreateTrafficDistributionGroup][1

    operation has failed.

  • PENDING_DELETION means the previous

    DeleteTrafficDistributionGroup][2

    operation is still in progress

    and has not yet completed.

  • DELETION_FAILED means the previous

    DeleteTrafficDistributionGroup][2

    operation has failed.

  • UPDATE_IN_PROGRESS means the previous

    UpdateTrafficDistributionGroup][3

    operation is still in progress

    and has not yet completed.

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_CreateTrafficDistributionGroup.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteTrafficDistributionGroup.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdateTrafficDistributionGroup.html

Returns:

  • (String)


32508
32509
32510
32511
32512
32513
32514
32515
32516
32517
# File 'lib/aws-sdk-connect/types.rb', line 32508

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end