Class: Aws::Connect::Types::Transcript

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A structure that defines search criteria and matching logic to search for contacts by matching text with transcripts analyzed by Amazon Connect Contact Lens.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#criteriaArray<Types::TranscriptCriteria>

The list of search criteria based on Contact Lens conversational analytics transcript.

Returns:



31268
31269
31270
31271
31272
31273
# File 'lib/aws-sdk-connect/types.rb', line 31268

class Transcript < Struct.new(
  :criteria,
  :match_type)
  SENSITIVE = []
  include Aws::Structure
end

#match_typeString

The match type combining search criteria using multiple transcript criteria.

Returns:

  • (String)


31268
31269
31270
31271
31272
31273
# File 'lib/aws-sdk-connect/types.rb', line 31268

class Transcript < Struct.new(
  :criteria,
  :match_type)
  SENSITIVE = []
  include Aws::Structure
end