Class: Aws::Connect::Types::UntagContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


37030
37031
37032
37033
37034
37035
37036
# File 'lib/aws-sdk-connect/types.rb', line 37030

class UntagContactRequest < Struct.new(
  :contact_id,
  :instance_id,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37030
37031
37032
37033
37034
37035
37036
# File 'lib/aws-sdk-connect/types.rb', line 37030

class UntagContactRequest < Struct.new(
  :contact_id,
  :instance_id,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

A list of tag keys. Existing tags on the contact whose keys are members of this list will be removed.

Returns:

  • (Array<String>)


37030
37031
37032
37033
37034
37035
37036
# File 'lib/aws-sdk-connect/types.rb', line 37030

class UntagContactRequest < Struct.new(
  :contact_id,
  :instance_id,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end