Class: Aws::Connect::Types::UpdateAttachedFilesConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateAttachedFilesConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_scope ⇒ String
The scope of the attachment.
-
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
-
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
Instance Attribute Details
#attachment_scope ⇒ String
The scope of the attachment.
36752 36753 36754 36755 36756 36757 36758 36759 36760 |
# File 'lib/aws-sdk-connect/types.rb', line 36752 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
36752 36753 36754 36755 36756 36757 36758 36759 36760 |
# File 'lib/aws-sdk-connect/types.rb', line 36752 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance.
36752 36753 36754 36755 36756 36757 36758 36759 36760 |
# File 'lib/aws-sdk-connect/types.rb', line 36752 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
36752 36753 36754 36755 36756 36757 36758 36759 36760 |
# File 'lib/aws-sdk-connect/types.rb', line 36752 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
36752 36753 36754 36755 36756 36757 36758 36759 36760 |
# File 'lib/aws-sdk-connect/types.rb', line 36752 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |