Class: Aws::Connect::Types::UpdateContactAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
The Connect Customer attributes.
-
#initial_contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
The Connect Customer attributes. These attributes can be accessed in flows just like any other contact attributes.
You can have up to 32,768 UTF-8 bytes across all attributes for a contact. Attribute keys can include only alphanumeric, dash, and underscore characters.
In the Set contact attributes block, when the attributes for a contact exceed 32 KB, the contact is routed down the Error branch of the flow. As a mitigation, consider the following options:
-
Remove unnecessary attributes by setting their values to empty.
-
If the attributes are only used in one flow and don't need to be referred to outside of that flow (for example, by a Lambda or another flow), then use flow attributes. This way you aren't needlessly persisting the 32 KB of information from one flow to another. For more information, see Flow block: Set contact attributes in the Connect Customer Administrator Guide.
35239 35240 35241 35242 35243 35244 35245 |
# File 'lib/aws-sdk-connect/types.rb', line 35239 class UpdateContactAttributesRequest < Struct.new( :initial_contact_id, :instance_id, :attributes) SENSITIVE = [] include Aws::Structure end |
#initial_contact_id ⇒ String
The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.
35239 35240 35241 35242 35243 35244 35245 |
# File 'lib/aws-sdk-connect/types.rb', line 35239 class UpdateContactAttributesRequest < Struct.new( :initial_contact_id, :instance_id, :attributes) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35239 35240 35241 35242 35243 35244 35245 |
# File 'lib/aws-sdk-connect/types.rb', line 35239 class UpdateContactAttributesRequest < Struct.new( :initial_contact_id, :instance_id, :attributes) SENSITIVE = [] include Aws::Structure end |