Class: Aws::Connect::Types::UpdateContactScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#scheduled_time ⇒ Time
The timestamp, in Unix Epoch seconds format, at which to start running the inbound flow.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact.
35719 35720 35721 35722 35723 35724 35725 |
# File 'lib/aws-sdk-connect/types.rb', line 35719 class UpdateContactScheduleRequest < Struct.new( :instance_id, :contact_id, :scheduled_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35719 35720 35721 35722 35723 35724 35725 |
# File 'lib/aws-sdk-connect/types.rb', line 35719 class UpdateContactScheduleRequest < Struct.new( :instance_id, :contact_id, :scheduled_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_time ⇒ Time
The timestamp, in Unix Epoch seconds format, at which to start running the inbound flow. The scheduled time cannot be in the past. It must be within up to 6 days in future.
35719 35720 35721 35722 35723 35724 35725 |
# File 'lib/aws-sdk-connect/types.rb', line 35719 class UpdateContactScheduleRequest < Struct.new( :instance_id, :contact_id, :scheduled_time) SENSITIVE = [] include Aws::Structure end |