Class: Aws::Connect::Types::UpdateDataTableAttributeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateDataTableAttributeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_version ⇒ Types::DataTableLockVersion
The new lock version for the attribute after the update.
-
#name ⇒ String
The trimmed name and identifier for the updated attribute.
Instance Attribute Details
#lock_version ⇒ Types::DataTableLockVersion
The new lock version for the attribute after the update.
33444 33445 33446 33447 33448 33449 |
# File 'lib/aws-sdk-connect/types.rb', line 33444 class UpdateDataTableAttributeResponse < Struct.new( :name, :lock_version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The trimmed name and identifier for the updated attribute.
33444 33445 33446 33447 33448 33449 |
# File 'lib/aws-sdk-connect/types.rb', line 33444 class UpdateDataTableAttributeResponse < Struct.new( :name, :lock_version) SENSITIVE = [] include Aws::Structure end |