Class: Aws::Connect::Types::UpdateDataTableMetadataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateDataTableMetadataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_version ⇒ Types::DataTableLockVersion
The new lock version for the data table after the update.
Instance Attribute Details
#lock_version ⇒ Types::DataTableLockVersion
The new lock version for the data table after the update.
34458 34459 34460 34461 34462 |
# File 'lib/aws-sdk-connect/types.rb', line 34458 class UpdateDataTableMetadataResponse < Struct.new( :lock_version) SENSITIVE = [] include Aws::Structure end |