Class: Aws::Connect::Types::UpdateDataTablePrimaryValuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_table_idString

The unique identifier for the data table. Must also accept the table ARN with or without a version alias. If the version is provided as part of the identifier or ARN, the version must be one of the two available system managed aliases, $SAVED or $LATEST.



33538
33539
33540
33541
33542
33543
33544
33545
33546
# File 'lib/aws-sdk-connect/types.rb', line 33538

class UpdateDataTablePrimaryValuesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :primary_values,
  :new_primary_values,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The unique identifier for the Amazon Connect instance.



33538
33539
33540
33541
33542
33543
33544
33545
33546
# File 'lib/aws-sdk-connect/types.rb', line 33538

class UpdateDataTablePrimaryValuesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :primary_values,
  :new_primary_values,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#lock_versionTypes::DataTableLockVersion

The lock version information required for optimistic locking to prevent concurrent modifications.



33538
33539
33540
33541
33542
33543
33544
33545
33546
# File 'lib/aws-sdk-connect/types.rb', line 33538

class UpdateDataTablePrimaryValuesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :primary_values,
  :new_primary_values,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#new_primary_valuesArray<Types::PrimaryValue>

The new primary values for the record. Required and must include values for all primary attributes. The combination must be unique within the table.



33538
33539
33540
33541
33542
33543
33544
33545
33546
# File 'lib/aws-sdk-connect/types.rb', line 33538

class UpdateDataTablePrimaryValuesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :primary_values,
  :new_primary_values,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#primary_valuesArray<Types::PrimaryValue>

The current primary values for the record. Required and must include values for all primary attributes. Fails if the table has primary attributes and some primary values are omitted.



33538
33539
33540
33541
33542
33543
33544
33545
33546
# File 'lib/aws-sdk-connect/types.rb', line 33538

class UpdateDataTablePrimaryValuesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :primary_values,
  :new_primary_values,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end