Class: Aws::Connect::Types::UpdateInstanceAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_typeString

The type of attribute.

Only allowlisted customers can consume USE_CUSTOM_TTS_VOICES. To access this feature, contact Amazon Web Services Support for allowlisting.

If you set the attribute type as MESSAGE_STREAMING, you need to update the Lex bot alias resource based policy to include the lex:RecognizeMessageAsync action for the connect instance ARN resource.

Returns:

  • (String)


36368
36369
36370
36371
36372
36373
36374
36375
# File 'lib/aws-sdk-connect/types.rb', line 36368

class UpdateInstanceAttributeRequest < Struct.new(
  :instance_id,
  :attribute_type,
  :value,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


36368
36369
36370
36371
36372
36373
36374
36375
# File 'lib/aws-sdk-connect/types.rb', line 36368

class UpdateInstanceAttributeRequest < Struct.new(
  :instance_id,
  :attribute_type,
  :value,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


36368
36369
36370
36371
36372
36373
36374
36375
# File 'lib/aws-sdk-connect/types.rb', line 36368

class UpdateInstanceAttributeRequest < Struct.new(
  :instance_id,
  :attribute_type,
  :value,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value for the attribute. Maximum character limit is 100.

Returns:

  • (String)


36368
36369
36370
36371
36372
36373
36374
36375
# File 'lib/aws-sdk-connect/types.rb', line 36368

class UpdateInstanceAttributeRequest < Struct.new(
  :instance_id,
  :attribute_type,
  :value,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end