Class: Aws::Connect::Types::UpdateParticipantAuthenticationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateParticipantAuthenticationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:code, :error, :error_description]
Instance Attribute Summary collapse
-
#code ⇒ String
The
codequery parameter provided by Cognito in theredirectUri. -
#error ⇒ String
The
errorquery parameter provided by Cognito in theredirectUri. -
#error_description ⇒ String
The
error_descriptionparameter provided by Cognito in theredirectUri. -
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#state ⇒ String
The
statequery parameter that was provided by Cognito in theredirectUri.
Instance Attribute Details
#code ⇒ String
The code query parameter provided by Cognito in the redirectUri.
37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37794 class UpdateParticipantAuthenticationRequest < Struct.new( :state, :instance_id, :code, :error, :error_description) SENSITIVE = [:code, :error, :error_description] include Aws::Structure end |
#error ⇒ String
The error query parameter provided by Cognito in the
redirectUri.
37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37794 class UpdateParticipantAuthenticationRequest < Struct.new( :state, :instance_id, :code, :error, :error_description) SENSITIVE = [:code, :error, :error_description] include Aws::Structure end |
#error_description ⇒ String
The error_description parameter provided by Cognito in the
redirectUri.
37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37794 class UpdateParticipantAuthenticationRequest < Struct.new( :state, :instance_id, :code, :error, :error_description) SENSITIVE = [:code, :error, :error_description] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37794 class UpdateParticipantAuthenticationRequest < Struct.new( :state, :instance_id, :code, :error, :error_description) SENSITIVE = [:code, :error, :error_description] include Aws::Structure end |
#state ⇒ String
The state query parameter that was provided by Cognito in the
redirectUri. This will also match the state parameter provided
in the AuthenticationUrl from the GetAuthenticationUrl
response.
37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37794 class UpdateParticipantAuthenticationRequest < Struct.new( :state, :instance_id, :code, :error, :error_description) SENSITIVE = [:code, :error, :error_description] include Aws::Structure end |