Class: Aws::Connect::Types::UpdateParticipantRoleConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateParticipantRoleConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_configuration ⇒ Types::UpdateParticipantRoleConfigChannelInfo
The Connect Customer channel you want to configure.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#channel_configuration ⇒ Types::UpdateParticipantRoleConfigChannelInfo
The Connect Customer channel you want to configure.
36599 36600 36601 36602 36603 36604 36605 |
# File 'lib/aws-sdk-connect/types.rb', line 36599 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
36599 36600 36601 36602 36603 36604 36605 |
# File 'lib/aws-sdk-connect/types.rb', line 36599 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
36599 36600 36601 36602 36603 36604 36605 |
# File 'lib/aws-sdk-connect/types.rb', line 36599 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |