Class: Aws::Connect::Types::UpdatePhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdatePhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance that phone numbers are claimed to.
-
#phone_number_id ⇒ String
A unique identifier for the phone number.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Amazon Connect instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
35094 35095 35096 35097 35098 35099 35100 35101 |
# File 'lib/aws-sdk-connect/types.rb', line 35094 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :target_arn, :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance that phone numbers are claimed to. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance. You must enter InstanceId or TargetArn.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
35094 35095 35096 35097 35098 35099 35100 35101 |
# File 'lib/aws-sdk-connect/types.rb', line 35094 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :target_arn, :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
A unique identifier for the phone number.
35094 35095 35096 35097 35098 35099 35100 35101 |
# File 'lib/aws-sdk-connect/types.rb', line 35094 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :target_arn, :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Amazon Connect instances or traffic distribution groups that phone number inbound traffic is routed through. You must enter InstanceId or TargetArn.
35094 35095 35096 35097 35098 35099 35100 35101 |
# File 'lib/aws-sdk-connect/types.rb', line 35094 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :target_arn, :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |