Class: Aws::Connect::Types::UpdatePredefinedAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdatePredefinedAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the predefined attribute.
-
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes.
-
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
Instance Attribute Details
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
37060 37061 37062 37063 37064 37065 37066 37067 37068 |
# File 'lib/aws-sdk-connect/types.rb', line 37060 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37060 37061 37062 37063 37064 37065 37066 37067 37068 |
# File 'lib/aws-sdk-connect/types.rb', line 37060 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the predefined attribute.
37060 37061 37062 37063 37064 37065 37066 37067 37068 |
# File 'lib/aws-sdk-connect/types.rb', line 37060 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Connect Customer admin website.
37060 37061 37062 37063 37064 37065 37066 37067 37068 |
# File 'lib/aws-sdk-connect/types.rb', line 37060 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
37060 37061 37062 37063 37064 37065 37066 37067 37068 |
# File 'lib/aws-sdk-connect/types.rb', line 37060 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |