Class: Aws::Connect::Types::UpdateRoutingProfileConcurrencyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateRoutingProfileConcurrencyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#media_concurrencies ⇒ Array<Types::MediaConcurrency>
The channels that agents can handle in the Contact Control Panel (CCP).
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UpdateRoutingProfileConcurrencyRequest < Struct.new( :instance_id, :routing_profile_id, :media_concurrencies) SENSITIVE = [] include Aws::Structure end |
#media_concurrencies ⇒ Array<Types::MediaConcurrency>
The channels that agents can handle in the Contact Control Panel (CCP).
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UpdateRoutingProfileConcurrencyRequest < Struct.new( :instance_id, :routing_profile_id, :media_concurrencies) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UpdateRoutingProfileConcurrencyRequest < Struct.new( :instance_id, :routing_profile_id, :media_concurrencies) SENSITIVE = [] include Aws::Structure end |