Class: Aws::Connect::Types::UpdateRuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::RuleAction>

A list of actions to be run when the rule is triggered.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#functionString

The conditions of the rule.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the rule. You can change the name only if TriggerEventSource is one of the following values: OnZendeskTicketCreate | OnZendeskTicketStatusUpdate | OnSalesforceCaseCreate

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#pre_evaluation_filtersTypes::PreEvaluationFilters

The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact. The pre-evaluation filters are applied even before rule conditions are evaluated and are used to enforce tag-based-access-control while applying rules.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status of the rule.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_idString

A unique identifier for the rule.

Returns:



39461
39462
39463
39464
39465
39466
39467
39468
39469
39470
39471
# File 'lib/aws-sdk-connect/types.rb', line 39461

class UpdateRuleRequest < Struct.new(
  :rule_id,
  :instance_id,
  :name,
  :function,
  :actions,
  :publish_status,
  :pre_evaluation_filters)
  SENSITIVE = []
  include Aws::Structure
end