Class: Aws::Connect::Types::UpdateSecurityProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateSecurityProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_access_control_hierarchy_group_id ⇒ String
The identifier of the hierarchy group that a security profile uses to restrict access to resources in Connect Customer.
-
#allowed_access_control_tags ⇒ Hash<String,String>
The list of tags that a security profile uses to restrict access to resources in Connect Customer.
-
#allowed_ai_agents ⇒ Array<Types::AIAgent>
A list of AI agents that the security profile will give access to.
-
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool.
-
#applications ⇒ Array<Types::Application>
A list of the third-party application's metadata.
-
#description ⇒ String
The description of the security profile.
-
#granular_access_control_configuration ⇒ Types::GranularAccessControlConfiguration
The granular access control configuration for the security profile, including data table permissions.
-
#hierarchy_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies hierarchy restrictions to in Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#permissions ⇒ Array<String>
The permissions granted to a security profile.
-
#security_profile_id ⇒ String
The identifier for the security profle.
-
#tag_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies tag restrictions to in Connect Customer.
Instance Attribute Details
#allowed_access_control_hierarchy_group_id ⇒ String
The identifier of the hierarchy group that a security profile uses to restrict access to resources in Connect Customer.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#allowed_access_control_tags ⇒ Hash<String,String>
The list of tags that a security profile uses to restrict access to resources in Connect Customer.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#allowed_ai_agents ⇒ Array<Types::AIAgent>
A list of AI agents that the security profile will give access to.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#applications ⇒ Array<Types::Application>
A list of the third-party application's metadata.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the security profile.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#granular_access_control_configuration ⇒ Types::GranularAccessControlConfiguration
The granular access control configuration for the security profile, including data table permissions.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#hierarchy_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies hierarchy
restrictions to in Connect Customer. Following are acceptable
ResourceNames: User.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The permissions granted to a security profile. For a list of valid permissions, see List of security profile permissions.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#security_profile_id ⇒ String
The identifier for the security profle.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#tag_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies tag restrictions to in Connect Customer.
39539 39540 39541 39542 39543 39544 39545 39546 39547 39548 39549 39550 39551 39552 39553 39554 |
# File 'lib/aws-sdk-connect/types.rb', line 39539 class UpdateSecurityProfileRequest < Struct.new( :description, :permissions, :security_profile_id, :instance_id, :allowed_access_control_tags, :tag_restricted_resources, :applications, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :allowed_flow_modules, :allowed_ai_agents, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |