Class: Aws::Connect::Types::UpdateTrafficDistributionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_configTypes::AgentConfig

The distribution of agents between the instance and its replica(s).

Returns:



39219
39220
39221
39222
39223
39224
39225
39226
# File 'lib/aws-sdk-connect/types.rb', line 39219

class UpdateTrafficDistributionRequest < Struct.new(
  :id,
  :telephony_config,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


39219
39220
39221
39222
39223
39224
39225
39226
# File 'lib/aws-sdk-connect/types.rb', line 39219

class UpdateTrafficDistributionRequest < Struct.new(
  :id,
  :telephony_config,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#sign_in_configTypes::SignInConfig

The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).

Returns:



39219
39220
39221
39222
39223
39224
39225
39226
# File 'lib/aws-sdk-connect/types.rb', line 39219

class UpdateTrafficDistributionRequest < Struct.new(
  :id,
  :telephony_config,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#telephony_configTypes::TelephonyConfig

The distribution of traffic between the instance and its replica(s).



39219
39220
39221
39222
39223
39224
39225
39226
# File 'lib/aws-sdk-connect/types.rb', line 39219

class UpdateTrafficDistributionRequest < Struct.new(
  :id,
  :telephony_config,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end