Class: Aws::Connect::Types::UpdateUserConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_contact_work_configsArray<Types::AfterContactWorkConfigPerChannel>

The list of after contact work (ACW) timeout configuration settings for each channel. ACW timeout specifies how many seconds agents have for after contact work, such as entering notes about the contact. The minimum setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter 0 for an indefinite amount of time, meaning agents must manually choose to end ACW.



36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#auto_accept_configsArray<Types::AutoAcceptConfig>

The list of auto-accept configuration settings for each channel. When auto-accept is enabled for a channel, available agents are automatically connected to contacts from that channel without needing to manually accept. Auto-accept connects agents to contacts in less than one second.

Returns:



36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#persistent_connection_configsArray<Types::PersistentConnectionConfig>

The list of persistent connection configuration settings for each channel.



36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_configsArray<Types::PhoneNumberConfig>

The list of phone number configuration settings for each channel.

Returns:



36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier of the user account.

Returns:

  • (String)


36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#voice_enhancement_configsArray<Types::VoiceEnhancementConfig>

The list of voice enhancement configuration settings for each channel.

Returns:



36030
36031
36032
36033
36034
36035
36036
36037
36038
36039
36040
# File 'lib/aws-sdk-connect/types.rb', line 36030

class UpdateUserConfigRequest < Struct.new(
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :user_id,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end