Class: Aws::Connect::Types::UpdateUserRoutingProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateUserRoutingProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
-
#user_id ⇒ String
The identifier of the user account.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37665 37666 37667 37668 37669 37670 37671 |
# File 'lib/aws-sdk-connect/types.rb', line 37665 class UpdateUserRoutingProfileRequest < Struct.new( :routing_profile_id, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
37665 37666 37667 37668 37669 37670 37671 |
# File 'lib/aws-sdk-connect/types.rb', line 37665 class UpdateUserRoutingProfileRequest < Struct.new( :routing_profile_id, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
37665 37666 37667 37668 37669 37670 37671 |
# File 'lib/aws-sdk-connect/types.rb', line 37665 class UpdateUserRoutingProfileRequest < Struct.new( :routing_profile_id, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |