Class: Aws::Connect::Types::UserData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Data for a user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_slots_by_channelHash<String,Integer>

A map of active slots by channel. The key is a channel name. The value is an integer: the number of active slots.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#available_slots_by_channelHash<String,Integer>

A map of available slots by channel. The key is a channel name. The value is an integer: the available number of slots.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#contactsArray<Types::AgentContactReference>

A list of contact reference information.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_pathTypes::HierarchyPathReference

Contains information about the levels of a hierarchy group assigned to a user.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#max_slots_by_channelHash<String,Integer>

A map of maximum slots by channel. The key is a channel name. The value is an integer: the maximum number of slots. This is calculated from [MediaConcurrency] of the RoutingProfile assigned to the agent.

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_MediaConcurrency.html



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#next_statusString

The Next status of the agent.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profileTypes::RoutingProfileReference

Information about the routing profile that is assigned to the user.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::AgentStatusReference

The status of the agent that they manually set in their Contact Control Panel (CCP), or that the supervisor manually changes in the real-time metrics report.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#userTypes::UserReference

Information about the user for the data that is returned. It contains the resourceId and ARN of the user.



36746
36747
36748
36749
36750
36751
36752
36753
36754
36755
36756
36757
36758
# File 'lib/aws-sdk-connect/types.rb', line 36746

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end