Class: Aws::Connect::Types::UserQuickConnectConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UserQuickConnectConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about the quick connect configuration settings for a user. The contact flow must be of type Transfer to Agent.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_id ⇒ String
The identifier of the flow.
-
#user_id ⇒ String
The identifier of the user.
Instance Attribute Details
#contact_flow_id ⇒ String
The identifier of the flow.
37664 37665 37666 37667 37668 37669 |
# File 'lib/aws-sdk-connect/types.rb', line 37664 class UserQuickConnectConfig < Struct.new( :user_id, :contact_flow_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user.
37664 37665 37666 37667 37668 37669 |
# File 'lib/aws-sdk-connect/types.rb', line 37664 class UserQuickConnectConfig < Struct.new( :user_id, :contact_flow_id) SENSITIVE = [] include Aws::Structure end |