Class: Aws::Connect::Types::UserSearchFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Filters to be applied to search results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tag_filterTypes::ControlPlaneTagFilter

An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:

  • Top level list specifies conditions that need to be applied with OR operator

  • Inner list specifies conditions that need to be applied with AND operator.



36142
36143
36144
36145
36146
36147
# File 'lib/aws-sdk-connect/types.rb', line 36142

class UserSearchFilter < Struct.new(
  :tag_filter,
  :user_attribute_filter)
  SENSITIVE = []
  include Aws::Structure
end

#user_attribute_filterTypes::ControlPlaneUserAttributeFilter

An object that can be used to specify Tag conditions or Hierarchy Group conditions inside the SearchFilter.

This accepts an OR of AND (List of List) input where:

  • The top level list specifies conditions that need to be applied with OR operator.

  • The inner list specifies conditions that need to be applied with AND operator.

<note markdown=“1”> Only one field can be populated. This object can’t be used along with TagFilter. Request can either contain TagFilter or UserAttributeFilter if SearchFilter is specified, combination of both is not supported and such request will throw AccessDeniedException.

</note>


36142
36143
36144
36145
36146
36147
# File 'lib/aws-sdk-connect/types.rb', line 36142

class UserSearchFilter < Struct.new(
  :tag_filter,
  :user_attribute_filter)
  SENSITIVE = []
  include Aws::Structure
end