Class: Aws::Connect::Types::UserSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains summary information about a user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the user account.

Returns:

  • (String)


40066
40067
40068
40069
40070
40071
40072
40073
40074
# File 'lib/aws-sdk-connect/types.rb', line 40066

class UserSummary < Struct.new(
  :id,
  :arn,
  :username,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the user account.

Returns:

  • (String)


40066
40067
40068
40069
40070
40071
40072
40073
40074
# File 'lib/aws-sdk-connect/types.rb', line 40066

class UserSummary < Struct.new(
  :id,
  :arn,
  :username,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this resource was last modified.

Returns:

  • (String)


40066
40067
40068
40069
40070
40071
40072
40073
40074
# File 'lib/aws-sdk-connect/types.rb', line 40066

class UserSummary < Struct.new(
  :id,
  :arn,
  :username,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this resource was last modified.

Returns:

  • (Time)


40066
40067
40068
40069
40070
40071
40072
40073
40074
# File 'lib/aws-sdk-connect/types.rb', line 40066

class UserSummary < Struct.new(
  :id,
  :arn,
  :username,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

The Connect Customer user name of the user account.

Returns:

  • (String)


40066
40067
40068
40069
40070
40071
40072
40073
40074
# File 'lib/aws-sdk-connect/types.rb', line 40066

class UserSummary < Struct.new(
  :id,
  :arn,
  :username,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end