Class: Aws::Connect::Types::ViewSearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ViewSearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines the search criteria for filtering views.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_conditions ⇒ Array<Types::ViewSearchCriteria>
A list of conditions that must all be satisfied.
-
#or_conditions ⇒ Array<Types::ViewSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
-
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
-
#view_status_condition ⇒ String
A condition that filters views by their status.
-
#view_type_condition ⇒ String
A condition that filters views by their type.
Instance Attribute Details
#and_conditions ⇒ Array<Types::ViewSearchCriteria>
A list of conditions that must all be satisfied.
35070 35071 35072 35073 35074 35075 35076 35077 35078 |
# File 'lib/aws-sdk-connect/types.rb', line 35070 class ViewSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition, :view_type_condition, :view_status_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::ViewSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
35070 35071 35072 35073 35074 35075 35076 35077 35078 |
# File 'lib/aws-sdk-connect/types.rb', line 35070 class ViewSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition, :view_type_condition, :view_status_condition) SENSITIVE = [] include Aws::Structure end |
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
35070 35071 35072 35073 35074 35075 35076 35077 35078 |
# File 'lib/aws-sdk-connect/types.rb', line 35070 class ViewSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition, :view_type_condition, :view_status_condition) SENSITIVE = [] include Aws::Structure end |
#view_status_condition ⇒ String
A condition that filters views by their status.
35070 35071 35072 35073 35074 35075 35076 35077 35078 |
# File 'lib/aws-sdk-connect/types.rb', line 35070 class ViewSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition, :view_type_condition, :view_status_condition) SENSITIVE = [] include Aws::Structure end |
#view_type_condition ⇒ String
A condition that filters views by their type.
35070 35071 35072 35073 35074 35075 35076 35077 35078 |
# File 'lib/aws-sdk-connect/types.rb', line 35070 class ViewSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition, :view_type_condition, :view_status_condition) SENSITIVE = [] include Aws::Structure end |