Class: Aws::Connect::Types::ViewSearchFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ViewSearchFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines filters to apply when searching for views, such as tag-based filters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_filter ⇒ Types::ControlPlaneAttributeFilter
An object that can be used to specify Tag conditions inside the
SearchFilter.
Instance Attribute Details
#attribute_filter ⇒ Types::ControlPlaneAttributeFilter
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR or AND (List of List) input where:
-
The top level list specifies conditions that need to be applied with
ORoperator. -
The inner list specifies conditions that need to be applied with
ANDoperator.
35615 35616 35617 35618 35619 |
# File 'lib/aws-sdk-connect/types.rb', line 35615 class ViewSearchFilter < Struct.new( :attribute_filter) SENSITIVE = [] include Aws::Structure end |