Class: Aws::Connect::Types::Vocabulary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Vocabulary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a custom vocabulary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the custom vocabulary.
-
#content ⇒ String
The content of the custom vocabulary in plain-text format with a table of values.
-
#failure_reason ⇒ String
The reason why the custom vocabulary was not created.
-
#id ⇒ String
The identifier of the custom vocabulary.
-
#language_code ⇒ String
The language code of the vocabulary entries.
-
#last_modified_time ⇒ Time
The timestamp when the custom vocabulary was last modified.
-
#name ⇒ String
A unique name of the custom vocabulary.
-
#state ⇒ String
The current state of the custom vocabulary.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the custom vocabulary.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The content of the custom vocabulary in plain-text format with a
table of values. Each row in the table represents a word or a
phrase, described with Phrase, IPA, SoundsLike, and
DisplayAs fields. Separate the fields with TAB characters. For
more information, see Create a custom vocabulary using a table.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason why the custom vocabulary was not created.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the custom vocabulary.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see What is Amazon Transcribe?
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the custom vocabulary was last modified.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name of the custom vocabulary.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the custom vocabulary.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
39342 39343 39344 39345 39346 39347 39348 39349 39350 39351 39352 39353 39354 |
# File 'lib/aws-sdk-connect/types.rb', line 39342 class Vocabulary < Struct.new( :name, :id, :arn, :language_code, :state, :last_modified_time, :failure_reason, :content, :tags) SENSITIVE = [] include Aws::Structure end |