Class: Aws::Connect::Types::WorkloadTypeConcurrency

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Defines the maximum number of contacts an agent can handle simultaneously for a specific channel and workload type combination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#concurrencyInteger

The maximum number of contacts an agent can handle simultaneously for a specific channel and workload type combination.

Valid Range for VOICE: Minimum value of 1. Maximum value of 1.

Valid Range for CHAT: Minimum value of 1. Maximum value of 10.

Valid Range for TASK: Minimum value of 1. Maximum value of 10.

Returns:

  • (Integer)


41909
41910
41911
41912
41913
41914
41915
# File 'lib/aws-sdk-connect/types.rb', line 41909

class WorkloadTypeConcurrency < Struct.new(
  :workload_type,
  :concurrency,
  :cross_channel_workload_behavior)
  SENSITIVE = []
  include Aws::Structure
end

#cross_channel_workload_behaviorTypes::CrossChannelWorkloadBehavior

Defines the cross-channel and workload type routing behavior for each channel and workload type combination that is enabled for this Routing Profile.



41909
41910
41911
41912
41913
41914
41915
# File 'lib/aws-sdk-connect/types.rb', line 41909

class WorkloadTypeConcurrency < Struct.new(
  :workload_type,
  :concurrency,
  :cross_channel_workload_behavior)
  SENSITIVE = []
  include Aws::Structure
end

#workload_typeString

The value of the workload type.

Returns:

  • (String)


41909
41910
41911
41912
41913
41914
41915
# File 'lib/aws-sdk-connect/types.rb', line 41909

class WorkloadTypeConcurrency < Struct.new(
  :workload_type,
  :concurrency,
  :cross_channel_workload_behavior)
  SENSITIVE = []
  include Aws::Structure
end