Class: Aws::Connect::Types::WorkspaceAssociationSearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::WorkspaceAssociationSearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines the search criteria for filtering workspace associations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_conditions ⇒ Array<Types::WorkspaceAssociationSearchCriteria>
A list of conditions that must all be satisfied.
-
#or_conditions ⇒ Array<Types::WorkspaceAssociationSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
-
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
Instance Attribute Details
#and_conditions ⇒ Array<Types::WorkspaceAssociationSearchCriteria>
A list of conditions that must all be satisfied.
35431 35432 35433 35434 35435 35436 35437 |
# File 'lib/aws-sdk-connect/types.rb', line 35431 class WorkspaceAssociationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::WorkspaceAssociationSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
35431 35432 35433 35434 35435 35436 35437 |
# File 'lib/aws-sdk-connect/types.rb', line 35431 class WorkspaceAssociationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
35431 35432 35433 35434 35435 35436 35437 |
# File 'lib/aws-sdk-connect/types.rb', line 35431 class WorkspaceAssociationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |