Class: Aws::Connect::Types::WorkspaceAssociationSearchFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::WorkspaceAssociationSearchFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines filters to apply when searching for workspace associations, such as tag-based filters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_filter ⇒ Types::ControlPlaneAttributeFilter
An object that can be used to specify Tag conditions inside the
SearchFilter.
Instance Attribute Details
#attribute_filter ⇒ Types::ControlPlaneAttributeFilter
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR or AND (List of List) input where:
-
The top level list specifies conditions that need to be applied with
ORoperator. -
The inner list specifies conditions that need to be applied with
ANDoperator.
36849 36850 36851 36852 36853 |
# File 'lib/aws-sdk-connect/types.rb', line 36849 class WorkspaceAssociationSearchFilter < Struct.new( :attribute_filter) SENSITIVE = [] include Aws::Structure end |