Class: Aws::Connect::Types::WorkspacePage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about a page configuration in a workspace, including the view assigned to the page.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#input_dataString

A JSON string containing input parameters passed to the view when the page is rendered.

Returns:

  • (String)


35527
35528
35529
35530
35531
35532
35533
35534
# File 'lib/aws-sdk-connect/types.rb', line 35527

class WorkspacePage < Struct.new(
  :resource_arn,
  :page,
  :slug,
  :input_data)
  SENSITIVE = []
  include Aws::Structure
end

#pageString

The page identifier. System pages include ‘HOME` and `AGENT_EXPERIENCE`.

Returns:

  • (String)


35527
35528
35529
35530
35531
35532
35533
35534
# File 'lib/aws-sdk-connect/types.rb', line 35527

class WorkspacePage < Struct.new(
  :resource_arn,
  :page,
  :slug,
  :input_data)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the view associated with this page.

Returns:

  • (String)


35527
35528
35529
35530
35531
35532
35533
35534
# File 'lib/aws-sdk-connect/types.rb', line 35527

class WorkspacePage < Struct.new(
  :resource_arn,
  :page,
  :slug,
  :input_data)
  SENSITIVE = []
  include Aws::Structure
end

#slugString

The URL-friendly identifier for the page.

Returns:

  • (String)


35527
35528
35529
35530
35531
35532
35533
35534
# File 'lib/aws-sdk-connect/types.rb', line 35527

class WorkspacePage < Struct.new(
  :resource_arn,
  :page,
  :slug,
  :input_data)
  SENSITIVE = []
  include Aws::Structure
end