Class: Aws::Connect::Types::AgentHierarchyGroups
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AgentHierarchyGroups
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A structure that defines search criteria for contacts using agent hierarchy group levels. For more information about agent hierarchies, see Set Up Agent Hierarchies in the Connect Customer Administrator Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#l1_ids ⇒ Array<String>
The identifiers for level 1 hierarchy groups.
-
#l2_ids ⇒ Array<String>
The identifiers for level 2 hierarchy groups.
-
#l3_ids ⇒ Array<String>
The identifiers for level 3 hierarchy groups.
-
#l4_ids ⇒ Array<String>
The identifiers for level 4 hierarchy groups.
-
#l5_ids ⇒ Array<String>
The identifiers for level 5 hierarchy groups.
Instance Attribute Details
#l1_ids ⇒ Array<String>
The identifiers for level 1 hierarchy groups.
305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-connect/types.rb', line 305 class AgentHierarchyGroups < Struct.new( :l1_ids, :l2_ids, :l3_ids, :l4_ids, :l5_ids) SENSITIVE = [] include Aws::Structure end |
#l2_ids ⇒ Array<String>
The identifiers for level 2 hierarchy groups.
305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-connect/types.rb', line 305 class AgentHierarchyGroups < Struct.new( :l1_ids, :l2_ids, :l3_ids, :l4_ids, :l5_ids) SENSITIVE = [] include Aws::Structure end |
#l3_ids ⇒ Array<String>
The identifiers for level 3 hierarchy groups.
305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-connect/types.rb', line 305 class AgentHierarchyGroups < Struct.new( :l1_ids, :l2_ids, :l3_ids, :l4_ids, :l5_ids) SENSITIVE = [] include Aws::Structure end |
#l4_ids ⇒ Array<String>
The identifiers for level 4 hierarchy groups.
305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-connect/types.rb', line 305 class AgentHierarchyGroups < Struct.new( :l1_ids, :l2_ids, :l3_ids, :l4_ids, :l5_ids) SENSITIVE = [] include Aws::Structure end |
#l5_ids ⇒ Array<String>
The identifiers for level 5 hierarchy groups.
305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-connect/types.rb', line 305 class AgentHierarchyGroups < Struct.new( :l1_ids, :l2_ids, :l3_ids, :l4_ids, :l5_ids) SENSITIVE = [] include Aws::Structure end |