Class: Aws::Connect::Types::AgentInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AgentInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the agent who accepted the contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accepted_by_agent_timestamp ⇒ Time
The timestamp when the contact was accepted by the agent.
-
#active_region ⇒ String
The Region where the agent was active when they handled the contact.
-
#after_contact_work_duration ⇒ Integer
The difference in time, in whole seconds, between
AfterContactWorkStartTimestampandAfterContactWorkEndTimestamp. -
#after_contact_work_end_timestamp ⇒ Time
The date and time when the agent ended After Contact Work for the contact, in UTC time.
-
#after_contact_work_start_timestamp ⇒ Time
The date and time when the agent started doing After Contact Work for the contact, in UTC time.
-
#agent_initiated_hold_duration ⇒ Integer
The total hold duration in seconds initiated by the agent.
-
#agent_pause_duration_in_seconds ⇒ Integer
Agent pause duration for a contact in seconds.
-
#capabilities ⇒ Types::ParticipantCapabilities
The configuration for the allowed video and screen sharing capabilities for participants present over the call.
-
#connected_to_agent_timestamp ⇒ Time
The timestamp when the contact was connected to the agent.
-
#device_info ⇒ Types::DeviceInfo
Information regarding Agent’s device.
-
#hierarchy_groups ⇒ Types::HierarchyGroups
The agent hierarchy groups for the agent.
-
#id ⇒ String
The identifier of the agent who accepted the contact.
-
#preview_end_timestamp ⇒ Time
The timestamp when the agent finished previewing the contact.
-
#state_transitions ⇒ Array<Types::StateTransition>
List of
StateTransitionfor a supervisor. -
#voice_enhancement_mode ⇒ String
The voice enhancement mode used by the agent as the call is ending.
Instance Attribute Details
#accepted_by_agent_timestamp ⇒ Time
The timestamp when the contact was accepted by the agent.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#active_region ⇒ String
The Region where the agent was active when they handled the contact. For Amazon Connect Global Resiliency instances enabled for global routing, this indicates the Region in which the agent's session was established at the time of the contact.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#after_contact_work_duration ⇒ Integer
The difference in time, in whole seconds, between
AfterContactWorkStartTimestamp and AfterContactWorkEndTimestamp.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#after_contact_work_end_timestamp ⇒ Time
The date and time when the agent ended After Contact Work for the
contact, in UTC time. In cases when agent finishes doing
AfterContactWork for chat contacts and switches their activity
status to offline or equivalent without clearing the contact in CCP,
discrepancies may be noticed for AfterContactWorkEndTimestamp.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#after_contact_work_start_timestamp ⇒ Time
The date and time when the agent started doing After Contact Work for the contact, in UTC time.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#agent_initiated_hold_duration ⇒ Integer
The total hold duration in seconds initiated by the agent.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#agent_pause_duration_in_seconds ⇒ Integer
Agent pause duration for a contact in seconds.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::ParticipantCapabilities
The configuration for the allowed video and screen sharing capabilities for participants present over the call. For more information, see Set up in-app, web, video calling, and screen sharing capabilities in the Connect Customer Administrator Guide.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#connected_to_agent_timestamp ⇒ Time
The timestamp when the contact was connected to the agent.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#device_info ⇒ Types::DeviceInfo
Information regarding Agent’s device.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#hierarchy_groups ⇒ Types::HierarchyGroups
The agent hierarchy groups for the agent.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the agent who accepted the contact.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#preview_end_timestamp ⇒ Time
The timestamp when the agent finished previewing the contact.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#state_transitions ⇒ Array<Types::StateTransition>
List of StateTransition for a supervisor.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |
#voice_enhancement_mode ⇒ String
The voice enhancement mode used by the agent as the call is ending. Valid values: VOICE_ISOLATION | NOISE_SUPPRESSION | NONE. A value of null indicates this mode has not yet been set for this user.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-connect/types.rb', line 379 class AgentInfo < Struct.new( :id, :accepted_by_agent_timestamp, :preview_end_timestamp, :connected_to_agent_timestamp, :agent_pause_duration_in_seconds, :hierarchy_groups, :device_info, :capabilities, :after_contact_work_duration, :after_contact_work_start_timestamp, :after_contact_work_end_timestamp, :agent_initiated_hold_duration, :state_transitions, :voice_enhancement_mode, :active_region) SENSITIVE = [] include Aws::Structure end |