Class: Aws::Connect::Types::AiAgentSearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AiAgentSearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The search criteria based on AI Agents metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_agent_escalated ⇒ Boolean
A boolean flag indicating whether the contact initially handled by this AI agent was escalated to a human agent.
-
#ai_use_case ⇒ String
The use case or scenario for which the AI agent is involved in the contact.
-
#id ⇒ String
ID of the AI Agent that was involved in the contact.
-
#version_number ⇒ Integer
Version of the AI agent that was involved in the contact.
Instance Attribute Details
#ai_agent_escalated ⇒ Boolean
A boolean flag indicating whether the contact initially handled by this AI agent was escalated to a human agent.
675 676 677 678 679 680 681 682 |
# File 'lib/aws-sdk-connect/types.rb', line 675 class AiAgentSearchCriteria < Struct.new( :id, :version_number, :ai_agent_escalated, :ai_use_case) SENSITIVE = [] include Aws::Structure end |
#ai_use_case ⇒ String
The use case or scenario for which the AI agent is involved in the contact.
675 676 677 678 679 680 681 682 |
# File 'lib/aws-sdk-connect/types.rb', line 675 class AiAgentSearchCriteria < Struct.new( :id, :version_number, :ai_agent_escalated, :ai_use_case) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
ID of the AI Agent that was involved in the contact.
675 676 677 678 679 680 681 682 |
# File 'lib/aws-sdk-connect/types.rb', line 675 class AiAgentSearchCriteria < Struct.new( :id, :version_number, :ai_agent_escalated, :ai_use_case) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
Version of the AI agent that was involved in the contact. ID is required if VersionNumber is passed.
675 676 677 678 679 680 681 682 |
# File 'lib/aws-sdk-connect/types.rb', line 675 class AiAgentSearchCriteria < Struct.new( :id, :version_number, :ai_agent_escalated, :ai_use_case) SENSITIVE = [] include Aws::Structure end |