Class: Aws::Connect::Types::AssociateApprovedOriginRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateApprovedOriginRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#origin ⇒ String
The domain to add to your allow list.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-connect/types.rb', line 1011 class AssociateApprovedOriginRequest < Struct.new( :instance_id, :origin, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-connect/types.rb', line 1011 class AssociateApprovedOriginRequest < Struct.new( :instance_id, :origin, :client_token) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
The domain to add to your allow list.
1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-connect/types.rb', line 1011 class AssociateApprovedOriginRequest < Struct.new( :instance_id, :origin, :client_token) SENSITIVE = [] include Aws::Structure end |