Class: Aws::Connect::Types::AssociateBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/aws-sdk-connect/types.rb', line 1067

class AssociateBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :lex_v2_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/aws-sdk-connect/types.rb', line 1067

class AssociateBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :lex_v2_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#lex_botTypes::LexBot

Configuration information of an Amazon Lex bot.

Returns:



1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/aws-sdk-connect/types.rb', line 1067

class AssociateBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :lex_v2_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#lex_v2_botTypes::LexV2Bot

The Amazon Lex V2 bot to associate with the instance.

Returns:



1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/aws-sdk-connect/types.rb', line 1067

class AssociateBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :lex_v2_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end