Class: Aws::Connect::Types::AssociateBotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateBotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#lex_bot ⇒ Types::LexBot
Configuration information of an Amazon Lex bot.
-
#lex_v2_bot ⇒ Types::LexV2Bot
The Amazon Lex V2 bot to associate with the instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-connect/types.rb', line 1052 class AssociateBotRequest < Struct.new( :instance_id, :lex_bot, :lex_v2_bot, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-connect/types.rb', line 1052 class AssociateBotRequest < Struct.new( :instance_id, :lex_bot, :lex_v2_bot, :client_token) SENSITIVE = [] include Aws::Structure end |
#lex_bot ⇒ Types::LexBot
Configuration information of an Amazon Lex bot.
1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-connect/types.rb', line 1052 class AssociateBotRequest < Struct.new( :instance_id, :lex_bot, :lex_v2_bot, :client_token) SENSITIVE = [] include Aws::Structure end |
#lex_v2_bot ⇒ Types::LexV2Bot
The Amazon Lex V2 bot to associate with the instance.
1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/aws-sdk-connect/types.rb', line 1052 class AssociateBotRequest < Struct.new( :instance_id, :lex_bot, :lex_v2_bot, :client_token) SENSITIVE = [] include Aws::Structure end |