Class: Aws::Connect::Types::AssociateEmailAddressAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateEmailAddressAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which email address will serve as the alias.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#email_address_id ⇒ String
The identifier of the email address.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which email address will serve as the alias. The specified email address must already exist in the Connect Customer instance and cannot already be configured as an alias or have an alias of its own.
1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-connect/types.rb', line 1182 class AssociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-connect/types.rb', line 1182 class AssociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_address_id ⇒ String
The identifier of the email address.
1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-connect/types.rb', line 1182 class AssociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-connect/types.rb', line 1182 class AssociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |