Class: Aws::Connect::Types::AssociateInstanceStorageConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-connect/types.rb', line 1304

class AssociateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-connect/types.rb', line 1304

class AssociateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

A valid resource type. To enable streaming for real-time analysis of contacts, use the following types:

  • For chat contacts, use REAL_TIME_CONTACT_ANALYSIS_CHAT_SEGMENTS.

  • For voice contacts, use REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS.

REAL_TIME_CONTACT_ANALYSIS_SEGMENTS is deprecated, but it is still supported and will apply only to VOICE channel contacts. Use REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS for voice contacts moving forward.

If you have previously associated a stream with REAL_TIME_CONTACT_ANALYSIS_SEGMENTS, no action is needed to update the stream to REAL_TIME_CONTACT_ANALYSIS_VOICE_SEGMENTS.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-connect/types.rb', line 1304

class AssociateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configTypes::InstanceStorageConfig

A valid storage type.



1304
1305
1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-connect/types.rb', line 1304

class AssociateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end