Class: Aws::Connect::Types::AssociateLambdaFunctionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1379
1380
1381
1382
1383
1384
1385
# File 'lib/aws-sdk-connect/types.rb', line 1379

class AssociateLambdaFunctionRequest < Struct.new(
  :instance_id,
  :function_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The Amazon Resource Name (ARN) for the Lambda function being associated. Maximum number of characters allowed is 140.

Returns:

  • (String)


1379
1380
1381
1382
1383
1384
1385
# File 'lib/aws-sdk-connect/types.rb', line 1379

class AssociateLambdaFunctionRequest < Struct.new(
  :instance_id,
  :function_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1379
1380
1381
1382
1383
1384
1385
# File 'lib/aws-sdk-connect/types.rb', line 1379

class AssociateLambdaFunctionRequest < Struct.new(
  :instance_id,
  :function_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end