Class: Aws::Connect::Types::AssociateLambdaFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateLambdaFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#function_arn ⇒ String
The Amazon Resource Name (ARN) for the Lambda function being associated.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
1356 1357 1358 1359 1360 1361 1362 |
# File 'lib/aws-sdk-connect/types.rb', line 1356 class AssociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The Amazon Resource Name (ARN) for the Lambda function being associated. Maximum number of characters allowed is 140.
1356 1357 1358 1359 1360 1361 1362 |
# File 'lib/aws-sdk-connect/types.rb', line 1356 class AssociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1356 1357 1358 1359 1360 1361 1362 |
# File 'lib/aws-sdk-connect/types.rb', line 1356 class AssociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |