Class: Aws::Connect::Types::AssociateLexBotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-connect/types.rb', line 1408

class AssociateLexBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-connect/types.rb', line 1408

class AssociateLexBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#lex_botTypes::LexBot

The Amazon Lex bot to associate with the instance.

Returns:



1408
1409
1410
1411
1412
1413
1414
# File 'lib/aws-sdk-connect/types.rb', line 1408

class AssociateLexBotRequest < Struct.new(
  :instance_id,
  :lex_bot,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end