Class: Aws::Connect::Types::AssociateQueueEmailAddressesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/aws-sdk-connect/types.rb', line 1463

class AssociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#email_addresses_configArray<Types::EmailAddressConfig>

Configuration list containing the email addresses to associate with the queue. Each configuration specifies an email address ID that should be linked to this queue for routing purposes.

Returns:



1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/aws-sdk-connect/types.rb', line 1463

class AssociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/aws-sdk-connect/types.rb', line 1463

class AssociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The identifier for the queue.

Returns:

  • (String)


1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/aws-sdk-connect/types.rb', line 1463

class AssociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end