Class: Aws::Connect::Types::AssociateRoutingProfileQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociateRoutingProfileQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#manual_assignment_queue_configs ⇒ Array<Types::RoutingProfileManualAssignmentQueueConfig>
The manual assignment queues to associate with this routing profile.
-
#queue_configs ⇒ Array<Types::RoutingProfileQueueConfig>
The queues to associate with this routing profile.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-connect/types.rb', line 1528 class AssociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_configs, :manual_assignment_queue_configs) SENSITIVE = [] include Aws::Structure end |
#manual_assignment_queue_configs ⇒ Array<Types::RoutingProfileManualAssignmentQueueConfig>
The manual assignment queues to associate with this routing profile.
1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-connect/types.rb', line 1528 class AssociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_configs, :manual_assignment_queue_configs) SENSITIVE = [] include Aws::Structure end |
#queue_configs ⇒ Array<Types::RoutingProfileQueueConfig>
The queues to associate with this routing profile.
1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-connect/types.rb', line 1528 class AssociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_configs, :manual_assignment_queue_configs) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/aws-sdk-connect/types.rb', line 1528 class AssociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_configs, :manual_assignment_queue_configs) SENSITIVE = [] include Aws::Structure end |