Class: Aws::Connect::Types::AssociatedContactSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AssociatedContactSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contact summary of a contact in contact tree associated with unique identifier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel ⇒ String
How the contact reached your contact center.
-
#contact_arn ⇒ String
The Amazon Resource Name (ARN) of the contact.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
-
#disconnect_timestamp ⇒ Time
The date and time that the customer endpoint disconnected from the current contact, in UTC time.
-
#initial_contact_id ⇒ String
If this contact is related to other contacts, this is the ID of the initial contact.
-
#initiation_method ⇒ String
Indicates how the contact was initiated.
-
#initiation_timestamp ⇒ Time
The date and time this contact was initiated, in UTC time.
-
#previous_contact_id ⇒ String
If this contact is not the first contact, this is the ID of the previous contact.
-
#related_contact_id ⇒ String
The contactId that is related to this contact.
Instance Attribute Details
#channel ⇒ String
How the contact reached your contact center.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#contact_arn ⇒ String
The Amazon Resource Name (ARN) of the contact
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#disconnect_timestamp ⇒ Time
The date and time that the customer endpoint disconnected from the current contact, in UTC time. In transfer scenarios, the DisconnectTimestamp of the previous contact indicates the date and time when that contact ended.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#initial_contact_id ⇒ String
If this contact is related to other contacts, this is the ID of the initial contact.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#initiation_method ⇒ String
Indicates how the contact was initiated.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#initiation_timestamp ⇒ Time
The date and time this contact was initiated, in UTC time.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#previous_contact_id ⇒ String
If this contact is not the first contact, this is the ID of the previous contact.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |
#related_contact_id ⇒ String
The contactId that is related to this contact.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 |
# File 'lib/aws-sdk-connect/types.rb', line 1681 class AssociatedContactSummary < Struct.new( :contact_id, :contact_arn, :initiation_timestamp, :disconnect_timestamp, :initial_contact_id, :previous_contact_id, :related_contact_id, :initiation_method, :channel) SENSITIVE = [] include Aws::Structure end |