Class: Aws::Connect::Types::AssociatedContactSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contact summary of a contact in contact tree associated with unique identifier.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channelString

How the contact reached your contact center.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#contact_arnString

The Amazon Resource Name (ARN) of the contact

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Amazon Connect.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#disconnect_timestampTime

The date and time that the customer endpoint disconnected from the current contact, in UTC time. In transfer scenarios, the DisconnectTimestamp of the previous contact indicates the date and time when that contact ended.

Returns:

  • (Time)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#initial_contact_idString

If this contact is related to other contacts, this is the ID of the initial contact.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#initiation_methodString

Indicates how the contact was initiated.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#initiation_timestampTime

The date and time this contact was initiated, in UTC time.

Returns:

  • (Time)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

#previous_contact_idString

If this contact is not the first contact, this is the ID of the previous contact.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end

The contactId that is related to this contact.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/aws-sdk-connect/types.rb', line 1571

class AssociatedContactSummary < Struct.new(
  :contact_id,
  :contact_arn,
  :initiation_timestamp,
  :disconnect_timestamp,
  :initial_contact_id,
  :previous_contact_id,
  :related_contact_id,
  :initiation_method,
  :channel)
  SENSITIVE = []
  include Aws::Structure
end