Class: Aws::Connect::Types::AuthenticationProfileSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

This API is in preview release for Connect Customer and is subject to change. To request access to this API, contact Amazon Web Services Support.

A summary of a given authentication profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the authentication profile summary.

Returns:

  • (String)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the authentication profile.

Returns:

  • (String)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Shows whether the authentication profile is the default authentication profile for the Connect Customer instance. The default authentication profile applies to all agents in an Connect Customer instance, unless overridden by another authentication profile.

Returns:

  • (Boolean)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region when the authentication profile summary was last modified.

Returns:

  • (String)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the authentication profile summary was last modified.

Returns:

  • (Time)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the authentication profile summary.

Returns:

  • (String)


2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
# File 'lib/aws-sdk-connect/types.rb', line 2237

class AuthenticationProfileSummary < Struct.new(
  :id,
  :arn,
  :name,
  :is_default,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end