Class: Aws::Connect::Types::AuthenticationProfileSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::AuthenticationProfileSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
This API is in preview release for Connect Customer and is subject to change. To request access to this API, contact Amazon Web Services Support.
A summary of a given authentication profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the authentication profile summary.
-
#id ⇒ String
The unique identifier of the authentication profile.
-
#is_default ⇒ Boolean
Shows whether the authentication profile is the default authentication profile for the Connect Customer instance.
-
#last_modified_region ⇒ String
The Amazon Web Services Region when the authentication profile summary was last modified.
-
#last_modified_time ⇒ Time
The timestamp when the authentication profile summary was last modified.
-
#name ⇒ String
The name of the authentication profile summary.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the authentication profile summary.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the authentication profile.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Shows whether the authentication profile is the default authentication profile for the Connect Customer instance. The default authentication profile applies to all agents in an Connect Customer instance, unless overridden by another authentication profile.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region when the authentication profile summary was last modified.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the authentication profile summary was last modified.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the authentication profile summary.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 |
# File 'lib/aws-sdk-connect/types.rb', line 2191 class AuthenticationProfileSummary < Struct.new( :id, :arn, :name, :is_default, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |