Class: Aws::Connect::Types::BatchAssociateAnalyticsDataSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::BatchAssociateAnalyticsDataSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_ids ⇒ Array<String>
An array of dataset identifiers to associate.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#target_account_id ⇒ String
The identifier of the target account.
Instance Attribute Details
#data_set_ids ⇒ Array<String>
An array of dataset identifiers to associate.
2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connect/types.rb', line 2324 class BatchAssociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connect/types.rb', line 2324 class BatchAssociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#target_account_id ⇒ String
The identifier of the target account. Use to associate a dataset to a different account than the one containing the Connect Customer instance. If not specified, by default this value is the Amazon Web Services account that has the Connect Customer instance.
2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/aws-sdk-connect/types.rb', line 2324 class BatchAssociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |