Class: Aws::Connect::Types::BatchDisassociateAnalyticsDataSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::BatchDisassociateAnalyticsDataSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_ids ⇒ Array<String>
An array of associated dataset identifiers to remove.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#target_account_id ⇒ String
The identifier of the target account.
Instance Attribute Details
#data_set_ids ⇒ Array<String>
An array of associated dataset identifiers to remove.
2840 2841 2842 2843 2844 2845 2846 |
# File 'lib/aws-sdk-connect/types.rb', line 2840 class BatchDisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
2840 2841 2842 2843 2844 2845 2846 |
# File 'lib/aws-sdk-connect/types.rb', line 2840 class BatchDisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#target_account_id ⇒ String
The identifier of the target account. Use to disassociate a dataset from a different account than the one containing the Connect Customer instance. If not specified, by default this value is the Amazon Web Services account that has the Connect Customer instance.
2840 2841 2842 2843 2844 2845 2846 |
# File 'lib/aws-sdk-connect/types.rb', line 2840 class BatchDisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_ids, :target_account_id) SENSITIVE = [] include Aws::Structure end |