Class: Aws::Connect::Types::BatchPutContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::BatchPutContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_data_request_list ⇒ Array<Types::ContactDataRequest>
List of individual contact requests.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
2907 2908 2909 2910 2911 2912 2913 |
# File 'lib/aws-sdk-connect/types.rb', line 2907 class BatchPutContactRequest < Struct.new( :client_token, :instance_id, :contact_data_request_list) SENSITIVE = [] include Aws::Structure end |
#contact_data_request_list ⇒ Array<Types::ContactDataRequest>
List of individual contact requests.
2907 2908 2909 2910 2911 2912 2913 |
# File 'lib/aws-sdk-connect/types.rb', line 2907 class BatchPutContactRequest < Struct.new( :client_token, :instance_id, :contact_data_request_list) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
2907 2908 2909 2910 2911 2912 2913 |
# File 'lib/aws-sdk-connect/types.rb', line 2907 class BatchPutContactRequest < Struct.new( :client_token, :instance_id, :contact_data_request_list) SENSITIVE = [] include Aws::Structure end |