Class: Aws::Connect::Types::CaseSlaConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CaseSlaConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The SLA configuration for Case SlaAssignmentType.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_id ⇒ String
Unique identifier of a Case field.
-
#name ⇒ String
Name of an SLA.
-
#target_field_values ⇒ Array<Types::FieldValueUnion>
Represents a list of target field values for the fieldId specified in CaseSlaConfiguration.
-
#target_sla_minutes ⇒ Integer
Target duration in minutes within which an SLA should be completed.
-
#type ⇒ String
Type of SLA for Case SlaAssignmentType.
Instance Attribute Details
#field_id ⇒ String
Unique identifier of a Case field.
3175 3176 3177 3178 3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-connect/types.rb', line 3175 class CaseSlaConfiguration < Struct.new( :name, :type, :field_id, :target_field_values, :target_sla_minutes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of an SLA.
3175 3176 3177 3178 3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-connect/types.rb', line 3175 class CaseSlaConfiguration < Struct.new( :name, :type, :field_id, :target_field_values, :target_sla_minutes) SENSITIVE = [] include Aws::Structure end |
#target_field_values ⇒ Array<Types::FieldValueUnion>
Represents a list of target field values for the fieldId specified in CaseSlaConfiguration. The SLA is considered met if any one of these target field values matches the actual field value.
3175 3176 3177 3178 3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-connect/types.rb', line 3175 class CaseSlaConfiguration < Struct.new( :name, :type, :field_id, :target_field_values, :target_sla_minutes) SENSITIVE = [] include Aws::Structure end |
#target_sla_minutes ⇒ Integer
Target duration in minutes within which an SLA should be completed.
3175 3176 3177 3178 3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-connect/types.rb', line 3175 class CaseSlaConfiguration < Struct.new( :name, :type, :field_id, :target_field_values, :target_sla_minutes) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Type of SLA for Case SlaAssignmentType.
3175 3176 3177 3178 3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-connect/types.rb', line 3175 class CaseSlaConfiguration < Struct.new( :name, :type, :field_id, :target_field_values, :target_sla_minutes) SENSITIVE = [] include Aws::Structure end |