Class: Aws::Connect::Types::ClaimPhoneNumberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Pattern: ^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance that phone numbers are claimed to. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. You must enter InstanceId or TargetArn.

Returns:

  • (String)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberString

The phone number you want to claim. Phone numbers are formatted [+] [country code] [subscriber number including area code].

Returns:

  • (String)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_descriptionString

The description of the phone number.

Returns:

  • (String)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through. You must enter InstanceId or TargetArn.

Returns:

  • (String)


3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/aws-sdk-connect/types.rb', line 3455

class ClaimPhoneNumberRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end