Class: Aws::Connect::Types::ClaimPhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ClaimPhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to.
-
#phone_number ⇒ String
The phone number you want to claim.
-
#phone_number_description ⇒ String
The description of the phone number.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
Pattern:
^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$
A suitable default value is auto-generated. You should normally not need to pass this option.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers
are claimed to. You can find the instance ID in the Amazon
Resource Name (ARN) of the instance. You must enter InstanceId or
TargetArn.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
The phone number you want to claim. Phone numbers are formatted [+] [country code] [subscriber number including area code].
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_description ⇒ String
The description of the phone number.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or
traffic distribution groups that phone number inbound traffic is
routed through. You must enter InstanceId or TargetArn.
3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 |
# File 'lib/aws-sdk-connect/types.rb', line 3396 class ClaimPhoneNumberRequest < Struct.new( :target_arn, :instance_id, :phone_number, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |