Class: Aws::Connect::Types::ContactDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Request object with information to create a contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
List of attributes to be stored in a contact.
-
#campaign ⇒ Types::Campaign
Structure to store information associated with a campaign.
-
#customer_endpoint ⇒ Types::Endpoint
Endpoint of the customer for which contact will be initiated.
-
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
-
#queue_id ⇒ String
The identifier of the queue associated with the Amazon Connect instance in which contacts that are created will be queued.
-
#request_identifier ⇒ String
Identifier to uniquely identify individual requests in the batch.
-
#system_endpoint ⇒ Types::Endpoint
Endpoint associated with the Amazon Connect instance from which outbound contact will be initiated for the campaign.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
List of attributes to be stored in a contact.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#campaign ⇒ Types::Campaign
Structure to store information associated with a campaign.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#customer_endpoint ⇒ Types::Endpoint
Endpoint of the customer for which contact will be initiated.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier of the queue associated with the Amazon Connect instance in which contacts that are created will be queued.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#request_identifier ⇒ String
Identifier to uniquely identify individual requests in the batch.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |
#system_endpoint ⇒ Types::Endpoint
Endpoint associated with the Amazon Connect instance from which outbound contact will be initiated for the campaign.
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/aws-sdk-connect/types.rb', line 3845 class ContactDataRequest < Struct.new( :system_endpoint, :customer_endpoint, :request_identifier, :queue_id, :attributes, :campaign, :outbound_strategy) SENSITIVE = [] include Aws::Structure end |