Class: Aws::Connect::Types::ContactFlowModule
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactFlowModule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a flow module.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN).
-
#content ⇒ String
The JSON string that represents the content of the flow.
-
#description ⇒ String
The description of the flow module.
-
#external_invocation_configuration ⇒ Types::ExternalInvocationConfiguration
The external invocation configuration for the flow module.
-
#flow_module_content_sha_256 ⇒ String
Hash of the module content for integrity verification.
-
#id ⇒ String
The identifier of the flow module.
-
#name ⇒ String
The name of the flow module.
-
#settings ⇒ String
The configuration settings for the flow module.
-
#state ⇒ String
The type of flow module.
-
#status ⇒ String
The status of the flow module.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#version ⇒ Integer
The version of the flow module.
-
#version_description ⇒ String
Description of the version.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN).
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The JSON string that represents the content of the flow. For an example, see Example flow in Connect Customer Flow language.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#external_invocation_configuration ⇒ Types::ExternalInvocationConfiguration
The external invocation configuration for the flow module
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#flow_module_content_sha_256 ⇒ String
Hash of the module content for integrity verification.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ String
The configuration settings for the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The type of flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the flow module.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |
#version_description ⇒ String
Description of the version.
4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-connect/types.rb', line 4457 class ContactFlowModule < Struct.new( :arn, :id, :name, :content, :description, :state, :status, :tags, :flow_module_content_sha_256, :version, :version_description, :settings, :external_invocation_configuration) SENSITIVE = [] include Aws::Structure end |