Class: Aws::Connect::Types::ContactMetricValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

ContactMetricValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContactMetricValue corresponding to the set member.

Object which contains the number.

Direct Known Subclasses

Number, Unknown

Defined Under Namespace

Classes: Number, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#numberFloat

The number of type Double. This number is the contact’s position in queue.

Returns:

  • (Float)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
# File 'lib/aws-sdk-connect/types.rb', line 4425

class ContactMetricValue < Struct.new(
  :number,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Number < ContactMetricValue; end
  class Unknown < ContactMetricValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4425
4426
4427
# File 'lib/aws-sdk-connect/types.rb', line 4425

def unknown
  @unknown
end