Class: Aws::Connect::Types::ContactNotTerminatedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The contact has not been disconnected and is not in a terminated state. To delete PII, disconnect the contact first. Wait for it to reach the terminated state, then retry the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


4941
4942
4943
4944
4945
# File 'lib/aws-sdk-connect/types.rb', line 4941

class ContactNotTerminatedException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end