Class: Aws::Connect::Types::ContactNotTerminatedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactNotTerminatedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The contact has not been disconnected and is not in a terminated state. PII can be deleted only from a contact that has been disconnected. This error is returned with an HTTP 409 status code.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4934 4935 4936 4937 4938 |
# File 'lib/aws-sdk-connect/types.rb', line 4934 class ContactNotTerminatedException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |