Class: Aws::Connect::Types::ContactSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ContactSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information of returned contact.
Constant Summary collapse
- SENSITIVE =
[:segment_attributes, :name]
Instance Attribute Summary collapse
-
#agent_info ⇒ Types::ContactSearchSummaryAgentInfo
Information about the agent who accepted the contact.
-
#ai_agent_info ⇒ Array<Types::ContactSearchSummaryAiAgentInfo>
Information about the AI agents involved in the contact.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the contact.
-
#channel ⇒ String
How the contact reached your contact center.
-
#disconnect_timestamp ⇒ Time
The timestamp when the customer endpoint disconnected from Connect Customer.
-
#global_resiliency_metadata ⇒ Types::GlobalResiliencyMetadata
Additional routing information for contacts created in ACGR instances.
-
#id ⇒ String
The identifier of the contact summary.
-
#initial_contact_id ⇒ String
If this contact is related to other contacts, this is the ID of the initial contact.
-
#initiation_method ⇒ String
Indicates how the contact was initiated.
-
#initiation_timestamp ⇒ Time
The date and time this contact was initiated, in UTC time.
-
#name ⇒ String
Indicates name of the contact.
-
#previous_contact_id ⇒ String
If this contact is not the first contact, this is the ID of the previous contact.
-
#queue_info ⇒ Types::ContactSearchSummaryQueueInfo
If this contact was queued, this contains information about the queue.
-
#routing_criteria ⇒ Types::RoutingCriteria
Latest routing criteria on the contact.
-
#scheduled_timestamp ⇒ Time
The timestamp, in Unix epoch time format, at which to start running the inbound flow.
-
#segment_attributes ⇒ Hash<String,Types::ContactSearchSummarySegmentAttributeValue>
Set of segment attributes for a contact.
-
#tags ⇒ Hash<String,String>
Tags associated with the contact.
Instance Attribute Details
#agent_info ⇒ Types::ContactSearchSummaryAgentInfo
Information about the agent who accepted the contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#ai_agent_info ⇒ Array<Types::ContactSearchSummaryAiAgentInfo>
Information about the AI agents involved in the contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#channel ⇒ String
How the contact reached your contact center.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#disconnect_timestamp ⇒ Time
The timestamp when the customer endpoint disconnected from Connect Customer.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#global_resiliency_metadata ⇒ Types::GlobalResiliencyMetadata
Additional routing information for contacts created in ACGR instances.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the contact summary.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#initial_contact_id ⇒ String
If this contact is related to other contacts, this is the ID of the initial contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#initiation_method ⇒ String
Indicates how the contact was initiated.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#initiation_timestamp ⇒ Time
The date and time this contact was initiated, in UTC time. For ‘INBOUND`, this is when the contact arrived. For `OUTBOUND`, this is when the agent began dialing. For `CALLBACK`, this is when the callback contact was created. For `TRANSFER` and `QUEUE_TRANSFER`, this is when the transfer was initiated. For API, this is when the request arrived. For `EXTERNAL_OUTBOUND`, this is when the agent started dialing the external participant. For `MONITOR`, this is when the supervisor started listening to a contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#name ⇒ String
Indicates name of the contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#previous_contact_id ⇒ String
If this contact is not the first contact, this is the ID of the previous contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#queue_info ⇒ Types::ContactSearchSummaryQueueInfo
If this contact was queued, this contains information about the queue.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#routing_criteria ⇒ Types::RoutingCriteria
Latest routing criteria on the contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#scheduled_timestamp ⇒ Time
The timestamp, in Unix epoch time format, at which to start running the inbound flow.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#segment_attributes ⇒ Hash<String,Types::ContactSearchSummarySegmentAttributeValue>
Set of segment attributes for a contact.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags associated with the contact. This contains both Amazon Web Services generated and user-defined tags.
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/aws-sdk-connect/types.rb', line 4849 class ContactSearchSummary < Struct.new( :arn, :id, :initial_contact_id, :previous_contact_id, :initiation_method, :channel, :queue_info, :agent_info, :initiation_timestamp, :disconnect_timestamp, :scheduled_timestamp, :segment_attributes, :name, :routing_criteria, :tags, :global_resiliency_metadata, :ai_agent_info) SENSITIVE = [:segment_attributes, :name] include Aws::Structure end |