Class: Aws::Connect::Types::ControlPlaneTagFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ControlPlaneTagFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:
-
Top level list specifies conditions that need to be applied with
ORoperator -
Inner list specifies conditions that need to be applied with
ANDoperator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_conditions ⇒ Array<Types::TagCondition>
A list of conditions which would be applied together with an
ANDcondition. -
#or_conditions ⇒ Array<Array<Types::TagCondition>>
A list of conditions which would be applied together with an
ORcondition. -
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition.
Instance Attribute Details
#and_conditions ⇒ Array<Types::TagCondition>
A list of conditions which would be applied together with an AND condition.
4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-connect/types.rb', line 4699 class ControlPlaneTagFilter < Struct.new( :or_conditions, :and_conditions, :tag_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Array<Types::TagCondition>>
A list of conditions which would be applied together with an OR condition.
4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-connect/types.rb', line 4699 class ControlPlaneTagFilter < Struct.new( :or_conditions, :and_conditions, :tag_condition) SENSITIVE = [] include Aws::Structure end |
#tag_condition ⇒ Types::TagCondition
A leaf node condition which can be used to specify a tag condition.
4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-connect/types.rb', line 4699 class ControlPlaneTagFilter < Struct.new( :or_conditions, :and_conditions, :tag_condition) SENSITIVE = [] include Aws::Structure end |