Class: Aws::Connect::Types::CreateAgentStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateAgentStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the status.
-
#display_order ⇒ Integer
The display order of the status.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the status.
-
#state ⇒ String
The state of the status.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the status.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |
#display_order ⇒ Integer
The display order of the status.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the status.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the status.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-connect/types.rb', line 5380 class CreateAgentStatusRequest < Struct.new( :instance_id, :name, :description, :state, :display_order, :tags) SENSITIVE = [] include Aws::Structure end |