Class: Aws::Connect::Types::CreateAttachedFileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_resource_arnString

The ARN of the completed voice contact to attach the file to. Only voice contacts with Telephony subtype are supported.

This value must be a valid ARN.

Returns:

  • (String)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#file_source_uriString

The S3 URI of the file to be attached. Only S3 source URIs are supported.

Returns:

  • (String)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#file_use_case_typeString

The use case for the file.

Only VOICE_RECORDING is supported.

Returns:

  • (String)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.

Returns:

  • (Hash<String,String>)


5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-connect/types.rb', line 5366

class CreateAttachedFileRequest < Struct.new(
  :client_token,
  :instance_id,
  :file_use_case_type,
  :file_source_uri,
  :associated_resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end