Class: Aws::Connect::Types::CreateAuthCodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateAuthCodeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_session_duration_minutes ⇒ Integer
The maximum duration of the session, in minutes.
-
#scope ⇒ Types::AuthScope
The scope for the authorization code.
-
#session_inactivity_duration_minutes ⇒ Integer
The duration of inactivity, in minutes, after which the session expires.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
5452 5453 5454 5455 5456 5457 5458 5459 |
# File 'lib/aws-sdk-connect/types.rb', line 5452 class CreateAuthCodeRequest < Struct.new( :instance_id, :scope, :max_session_duration_minutes, :session_inactivity_duration_minutes) SENSITIVE = [] include Aws::Structure end |
#max_session_duration_minutes ⇒ Integer
The maximum duration of the session, in minutes. Minimum value of 1440 (24 hours). Maximum value of 43200 (30 days). If no value is provided, the session will expire after 400 days.
5452 5453 5454 5455 5456 5457 5458 5459 |
# File 'lib/aws-sdk-connect/types.rb', line 5452 class CreateAuthCodeRequest < Struct.new( :instance_id, :scope, :max_session_duration_minutes, :session_inactivity_duration_minutes) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ Types::AuthScope
The scope for the authorization code. Defines the permissions and access boundaries for the session.
5452 5453 5454 5455 5456 5457 5458 5459 |
# File 'lib/aws-sdk-connect/types.rb', line 5452 class CreateAuthCodeRequest < Struct.new( :instance_id, :scope, :max_session_duration_minutes, :session_inactivity_duration_minutes) SENSITIVE = [] include Aws::Structure end |
#session_inactivity_duration_minutes ⇒ Integer
The duration of inactivity, in minutes, after which the session expires. Minimum value of 1440 (24 hours). Maximum value of 20160 (14 days).
5452 5453 5454 5455 5456 5457 5458 5459 |
# File 'lib/aws-sdk-connect/types.rb', line 5452 class CreateAuthCodeRequest < Struct.new( :instance_id, :scope, :max_session_duration_minutes, :session_inactivity_duration_minutes) SENSITIVE = [] include Aws::Structure end |