Class: Aws::Connect::Types::CreateAuthCodeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateAuthCodeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:auth_code]
Instance Attribute Summary collapse
-
#auth_code ⇒ String
The authorization code to use for establishing a session.
-
#entity_id ⇒ String
The identifier of the entity associated with the authorization code.
-
#entity_type ⇒ String
The type of entity associated with the authorization code.
-
#session_id ⇒ String
The identifier of the session created with the authorization code.
Instance Attribute Details
#auth_code ⇒ String
The authorization code to use for establishing a session.
5464 5465 5466 5467 5468 5469 5470 5471 |
# File 'lib/aws-sdk-connect/types.rb', line 5464 class CreateAuthCodeResponse < Struct.new( :auth_code, :session_id, :entity_type, :entity_id) SENSITIVE = [:auth_code] include Aws::Structure end |
#entity_id ⇒ String
The identifier of the entity associated with the authorization code.
5464 5465 5466 5467 5468 5469 5470 5471 |
# File 'lib/aws-sdk-connect/types.rb', line 5464 class CreateAuthCodeResponse < Struct.new( :auth_code, :session_id, :entity_type, :entity_id) SENSITIVE = [:auth_code] include Aws::Structure end |
#entity_type ⇒ String
The type of entity associated with the authorization code.
5464 5465 5466 5467 5468 5469 5470 5471 |
# File 'lib/aws-sdk-connect/types.rb', line 5464 class CreateAuthCodeResponse < Struct.new( :auth_code, :session_id, :entity_type, :entity_id) SENSITIVE = [:auth_code] include Aws::Structure end |
#session_id ⇒ String
The identifier of the session created with the authorization code.
5464 5465 5466 5467 5468 5469 5470 5471 |
# File 'lib/aws-sdk-connect/types.rb', line 5464 class CreateAuthCodeResponse < Struct.new( :auth_code, :session_id, :entity_type, :entity_id) SENSITIVE = [:auth_code] include Aws::Structure end |