Class: Aws::Connect::Types::CreateContactFlowModuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The JSON string that represents the content of the flow. For an example, see Example flow in Connect Customer Flow language.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the flow module.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#external_invocation_configurationTypes::ExternalInvocationConfiguration

The external invocation configuration for the flow module.



5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the flow module.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#settingsString

The configuration settings for the flow module.

Returns:

  • (String)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
# File 'lib/aws-sdk-connect/types.rb', line 5490

class CreateContactFlowModuleRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :content,
  :tags,
  :client_token,
  :settings,
  :external_invocation_configuration)
  SENSITIVE = []
  include Aws::Structure
end