Class: Aws::Connect::Types::CreateDataTableAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateDataTableAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_table_id ⇒ String
The unique identifier for the data table.
-
#description ⇒ String
An optional description for the attribute.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#name ⇒ String
The name for the attribute.
-
#primary ⇒ Boolean
Optional boolean that defaults to false.
-
#validation ⇒ Types::Validation
Optional validation rules for the attribute.
-
#value_type ⇒ String
The type of value allowed or the resultant type after the value’s expression is evaluated.
Instance Attribute Details
#data_table_id ⇒ String
The unique identifier for the data table. Must also accept the table ARN with or without a version alias. If the version is provided as part of the identifier or ARN, the version must be one of the two available system managed aliases, $SAVED or $LATEST.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description for the attribute. Must conform to Connect human readable string specification and have 0-250 characters. Whitespace trimmed before persisting.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the attribute. Must conform to Connect human readable string specification and have 1-127 characters. Must not start with the reserved case insensitive values ‘connect:’ and ‘aws:’. Whitespace trimmed before persisting. Must be unique for the data table using case-insensitive comparison.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#primary ⇒ Boolean
Optional boolean that defaults to false. Determines if the value is used to identify a record in the table. Values for primary attributes must not be expressions.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#validation ⇒ Types::Validation
Optional validation rules for the attribute. Borrows heavily from JSON Schema - Draft 2020-12. The maximum length of arrays within validations and depth of validations is 5. There are default limits that apply to all types. Customer specified limits in excess of the default limits are not permitted.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#value_type ⇒ String
The type of value allowed or the resultant type after the value’s expression is evaluated. Must be one of TEXT, TEXT_LIST, NUMBER, NUMBER_LIST, and BOOLEAN.
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/aws-sdk-connect/types.rb', line 5612 class CreateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |