Class: Aws::Connect::Types::CreateDataTableAttributeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_idString

The unique identifier assigned to the created attribute.

Returns:

  • (String)


6061
6062
6063
6064
6065
6066
6067
# File 'lib/aws-sdk-connect/types.rb', line 6061

class CreateDataTableAttributeResponse < Struct.new(
  :name,
  :attribute_id,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#lock_versionTypes::DataTableLockVersion

The lock version information for the data table and attribute, used for optimistic locking and versioning.



6061
6062
6063
6064
6065
6066
6067
# File 'lib/aws-sdk-connect/types.rb', line 6061

class CreateDataTableAttributeResponse < Struct.new(
  :name,
  :attribute_id,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the created attribute since it also serves as the identifier. This could be different than the parameter passed in since it will be trimmed for whitespace.

Returns:

  • (String)


6061
6062
6063
6064
6065
6066
6067
# File 'lib/aws-sdk-connect/types.rb', line 6061

class CreateDataTableAttributeResponse < Struct.new(
  :name,
  :attribute_id,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end