Class: Aws::Connect::Types::CreateDataTableAttributeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateDataTableAttributeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_id ⇒ String
The unique identifier assigned to the created attribute.
-
#lock_version ⇒ Types::DataTableLockVersion
The lock version information for the data table and attribute, used for optimistic locking and versioning.
-
#name ⇒ String
The name of the created attribute since it also serves as the identifier.
Instance Attribute Details
#attribute_id ⇒ String
The unique identifier assigned to the created attribute.
5821 5822 5823 5824 5825 5826 5827 |
# File 'lib/aws-sdk-connect/types.rb', line 5821 class CreateDataTableAttributeResponse < Struct.new( :name, :attribute_id, :lock_version) SENSITIVE = [] include Aws::Structure end |
#lock_version ⇒ Types::DataTableLockVersion
The lock version information for the data table and attribute, used for optimistic locking and versioning.
5821 5822 5823 5824 5825 5826 5827 |
# File 'lib/aws-sdk-connect/types.rb', line 5821 class CreateDataTableAttributeResponse < Struct.new( :name, :attribute_id, :lock_version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the created attribute since it also serves as the identifier. This could be different than the parameter passed in since it will be trimmed for whitespace.
5821 5822 5823 5824 5825 5826 5827 |
# File 'lib/aws-sdk-connect/types.rb', line 5821 class CreateDataTableAttributeResponse < Struct.new( :name, :attribute_id, :lock_version) SENSITIVE = [] include Aws::Structure end |