Class: Aws::Connect::Types::CreateDataTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateDataTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description for the data table.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance where the data table will be created.
-
#name ⇒ String
The name for the data table.
-
#status ⇒ String
The status of the data table.
-
#tags ⇒ Hash<String,String>
Key value pairs for attribute based access control (TBAC or ABAC).
-
#time_zone ⇒ String
The IANA timezone identifier to use when resolving time based dynamic values.
-
#value_lock_level ⇒ String
The data level that concurrent value edits are locked on.
Instance Attribute Details
#description ⇒ String
An optional description for the data table. Must conform to Connect human readable string specification and have 0-250 characters. Whitespace must be trimmed first.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance where the data table will be created.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the data table. Must conform to Connect human readable string specification and have 1-127 characters. Whitespace must be trimmed first. Must not start with the reserved case insensitive values ‘connect:’ and ‘aws:’. Must be unique for the instance using case-insensitive comparison.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data table. One of PUBLISHED or SAVED. Required parameter that determines the initial state of the table.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key value pairs for attribute based access control (TBAC or ABAC). Optional tags to apply to the data table for organization and access control purposes.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The IANA timezone identifier to use when resolving time based dynamic values. Required even if no time slices are specified.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#value_lock_level ⇒ String
The data level that concurrent value edits are locked on. One of DATA_TABLE, PRIMARY_VALUE, ATTRIBUTE, VALUE, and NONE. NONE is the default if unspecified. This determines how concurrent edits are handled when multiple users attempt to modify values simultaneously.
5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/aws-sdk-connect/types.rb', line 5611 class CreateDataTableRequest < Struct.new( :instance_id, :name, :description, :time_zone, :value_lock_level, :status, :tags) SENSITIVE = [] include Aws::Structure end |