Class: Aws::Connect::Types::CreateEmailAddressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateEmailAddressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :email_address, :display_name]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the email address.
-
#display_name ⇒ String
The display name of email address.
-
#email_address ⇒ String
The email address, including the domain.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |
#description ⇒ String
The description of the email address.
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |
#display_name ⇒ String
The display name of email address
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |
#email_address ⇒ String
The email address, including the domain.
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-connect/types.rb', line 6268 class CreateEmailAddressRequest < Struct.new( :description, :instance_id, :email_address, :display_name, :tags, :client_token) SENSITIVE = [:description, :email_address, :display_name] include Aws::Structure end |