Class: Aws::Connect::Types::CreateEmailAddressRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :email_address, :display_name]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Returns:

  • (String)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end

#descriptionString

The description of the email address.

Returns:

  • (String)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end

#display_nameString

The display name of email address

Returns:

  • (String)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end

#email_addressString

The email address, including the domain.

Returns:

  • (String)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
# File 'lib/aws-sdk-connect/types.rb', line 6190

class CreateEmailAddressRequest < Struct.new(
  :description,
  :instance_id,
  :email_address,
  :display_name,
  :tags,
  :client_token)
  SENSITIVE = [:description, :email_address, :display_name]
  include Aws::Structure
end