Class: Aws::Connect::Types::CreateEvaluationFormRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateEvaluationFormRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#as_draft ⇒ Boolean
A boolean flag indicating whether to create evaluation form in draft state.
-
#auto_evaluation_configuration ⇒ Types::EvaluationFormAutoEvaluationConfiguration
Configuration information about automated evaluations.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the evaluation form.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#items ⇒ Array<Types::EvaluationFormItem>
Items that are part of the evaluation form.
-
#language_configuration ⇒ Types::EvaluationFormLanguageConfiguration
Configuration for language settings of the evaluation form.
-
#review_configuration ⇒ Types::EvaluationReviewConfiguration
Configuration information about evaluation reviews.
-
#scoring_strategy ⇒ Types::EvaluationFormScoringStrategy
A scoring strategy of the evaluation form.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#target_configuration ⇒ Types::EvaluationFormTargetConfiguration
Configuration that specifies the target for the evaluation form.
-
#title ⇒ String
A title of the evaluation form.
Instance Attribute Details
#as_draft ⇒ Boolean
A boolean flag indicating whether to create evaluation form in draft state.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_configuration ⇒ Types::EvaluationFormAutoEvaluationConfiguration
Configuration information about automated evaluations.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the evaluation form.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::EvaluationFormItem>
Items that are part of the evaluation form. The total number of sections and questions must not exceed 100 each. Questions must be contained in a section.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#language_configuration ⇒ Types::EvaluationFormLanguageConfiguration
Configuration for language settings of the evaluation form.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#review_configuration ⇒ Types::EvaluationReviewConfiguration
Configuration information about evaluation reviews.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#scoring_strategy ⇒ Types::EvaluationFormScoringStrategy
A scoring strategy of the evaluation form.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#target_configuration ⇒ Types::EvaluationFormTargetConfiguration
Configuration that specifies the target for the evaluation form.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
A title of the evaluation form.
6193 6194 6195 6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-connect/types.rb', line 6193 class CreateEvaluationFormRequest < Struct.new( :instance_id, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :client_token, :as_draft, :tags, :review_configuration, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |