Class: Aws::Connect::Types::CreateExtractionDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateExtractionDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#display ⇒ Types::ExtractionDefinitionDisplay
The display settings for the extraction definition, including the label shown in the agent workspace.
-
#extraction_configuration ⇒ Types::ExtractionConfiguration
The configuration that defines how data is extracted, including the prompt hint and not-found behavior.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
A unique name of the extraction definition.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field.
A suitable default value is auto-generated. You should normally not need to pass this option.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |
#display ⇒ Types::ExtractionDefinitionDisplay
The display settings for the extraction definition, including the label shown in the agent workspace.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |
#extraction_configuration ⇒ Types::ExtractionConfiguration
The configuration that defines how data is extracted, including the prompt hint and not-found behavior.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name of the extraction definition.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 |
# File 'lib/aws-sdk-connect/types.rb', line 6462 class CreateExtractionDefinitionRequest < Struct.new( :client_token, :instance_id, :name, :extraction_configuration, :display, :tags) SENSITIVE = [] include Aws::Structure end |