Class: Aws::Connect::Types::CreateExtractionDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#displayTypes::ExtractionDefinitionDisplay

The display settings for the extraction definition, including the label shown in the agent workspace.



6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#extraction_configurationTypes::ExtractionConfiguration

The configuration that defines how data is extracted, including the prompt hint and not-found behavior.



6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name of the extraction definition.

Returns:

  • (String)


6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-connect/types.rb', line 6454

class CreateExtractionDefinitionRequest < Struct.new(
  :client_token,
  :instance_id,
  :name,
  :extraction_configuration,
  :display,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end