Class: Aws::Connect::Types::CreateHoursOfOperationOverrideRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateHoursOfOperationOverrideRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config ⇒ Array<Types::HoursOfOperationOverrideConfig>
Configuration information for the hours of operation override: day, start time, and end time.
-
#description ⇒ String
The description of the hours of operation override.
-
#effective_from ⇒ String
The date from when the hours of operation override is effective.
-
#effective_till ⇒ String
The date until when the hours of operation override is effective.
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the hours of operation override.
-
#override_type ⇒ String
Whether the override will be defined as a standard or as a recurring event.
-
#recurrence_config ⇒ Types::RecurrenceConfig
Configuration for a recurring event.
Instance Attribute Details
#config ⇒ Array<Types::HoursOfOperationOverrideConfig>
Configuration information for the hours of operation override: day, start time, and end time.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the hours of operation override.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#effective_from ⇒ String
The date from when the hours of operation override is effective.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#effective_till ⇒ String
The date until when the hours of operation override is effective.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_id ⇒ String
The identifier for the hours of operation
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the hours of operation override.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#override_type ⇒ String
Whether the override will be defined as a standard or as a recurring event.
For more information about how override types are applied, see Build your list of overrides in the Administrator Guide.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#recurrence_config ⇒ Types::RecurrenceConfig
Configuration for a recurring event.
6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-connect/types.rb', line 6370 class CreateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |