Class: Aws::Connect::Types::CreateHoursOfOperationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configArray<Types::HoursOfOperationConfig>

Configuration information for the hours of operation: day, start time, and end time.

Returns:



6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the hours of operation.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the hours of operation.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#parent_hours_of_operation_configsArray<Types::ParentHoursOfOperationConfig>

Configuration for parent hours of operations. Eg: ResourceArn.

For more information about parent hours of operations, see Link overrides from different hours of operation in the Administrator Guide.



6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The time zone of the hours of operation.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
# File 'lib/aws-sdk-connect/types.rb', line 6520

class CreateHoursOfOperationRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :time_zone,
  :config,
  :parent_hours_of_operation_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end