Class: Aws::Connect::Types::CreateHoursOfOperationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateHoursOfOperationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config ⇒ Array<Types::HoursOfOperationConfig>
Configuration information for the hours of operation: day, start time, and end time.
-
#description ⇒ String
The description of the hours of operation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the hours of operation.
-
#parent_hours_of_operation_configs ⇒ Array<Types::ParentHoursOfOperationConfig>
Configuration for parent hours of operations.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#time_zone ⇒ String
The time zone of the hours of operation.
Instance Attribute Details
#config ⇒ Array<Types::HoursOfOperationConfig>
Configuration information for the hours of operation: day, start time, and end time.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the hours of operation.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the hours of operation.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#parent_hours_of_operation_configs ⇒ Array<Types::ParentHoursOfOperationConfig>
Configuration for parent hours of operations. Eg: ResourceArn.
For more information about parent hours of operations, see Link overrides from different hours of operation in the Administrator Guide.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone of the hours of operation.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 |
# File 'lib/aws-sdk-connect/types.rb', line 6442 class CreateHoursOfOperationRequest < Struct.new( :instance_id, :name, :description, :time_zone, :config, :parent_hours_of_operation_configs, :tags) SENSITIVE = [] include Aws::Structure end |