Class: Aws::Connect::Types::CreateIntegrationAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateIntegrationAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
-
#integration_type ⇒ String
The type of information to be ingested.
-
#source_application_name ⇒ String
The name of the external application.
-
#source_application_url ⇒ String
The URL for the external application.
-
#source_type ⇒ String
The type of the data source.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#integration_type ⇒ String
The type of information to be ingested.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#source_application_name ⇒ String
The name of the external application. This field is only required for the EVENT integration type.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#source_application_url ⇒ String
The URL for the external application. This field is only required for the EVENT integration type.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of the data source. This field is only required for the EVENT integration type.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/aws-sdk-connect/types.rb', line 6486 class CreateIntegrationAssociationRequest < Struct.new( :instance_id, :integration_type, :integration_arn, :source_application_url, :source_application_name, :source_type, :tags) SENSITIVE = [] include Aws::Structure end |