Class: Aws::Connect::Types::CreateMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the metric.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#metric_calculation ⇒ Types::MetricCalculation
The calculation definition for the metric, including the formula expression and the component metrics it references.
-
#name ⇒ String
The name of the metric.
-
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted.
-
#status ⇒ String
The publish status of the metric.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#unit ⇒ String
The display unit for the metric's data.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the metric.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#metric_calculation ⇒ Types::MetricCalculation
The calculation definition for the metric, including the formula expression and the component metrics it references.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the metric.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted. Valid
values: POSITIVE, NEUTRAL, NEGATIVE.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The publish status of the metric. Set to PUBLISHED to make the
metric available for use in dashboards and reports, or SAVED to
keep it in draft state.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The display unit for the metric's data.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/aws-sdk-connect/types.rb', line 6829 class CreateMetricRequest < Struct.new( :instance_id, :name, :metric_calculation, :unit, :status, :client_token, :description, :positive_trend_indicator, :tags) SENSITIVE = [] include Aws::Structure end |