Class: Aws::Connect::Types::CreateMetricRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the metric.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#metric_calculationTypes::MetricCalculation

The calculation definition for the metric, including the formula expression and the component metrics it references.



6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the metric.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#positive_trend_indicatorString

How an increase in the metric value should be interpreted. Valid values: POSITIVE, NEUTRAL, NEGATIVE.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The publish status of the metric. Set to PUBLISHED to make the metric available for use in dashboards and reports, or SAVED to keep it in draft state.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

The display unit for the metric's data.

Returns:

  • (String)


6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
# File 'lib/aws-sdk-connect/types.rb', line 6762

class CreateMetricRequest < Struct.new(
  :instance_id,
  :name,
  :metric_calculation,
  :unit,
  :status,
  :client_token,
  :description,
  :positive_trend_indicator,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end