Class: Aws::Connect::Types::CreateNotificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentHash<String,String>

The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale. Content supports links. Maximum 250 characters per locale.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp when the notification should expire and no longer be displayed to users. If not specified, defaults to one week from creation.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_notification_idString

The unique identifier for a notification.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#priorityString

The priority level of the notification. Valid values are HIGH and LOW. High priority notifications are displayed above low priority notifications.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#recipientsArray<String>

A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Can include user ARNs or instance ARNs to target all users in an instance. Maximum of 200 recipients.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, ‘{ “Tags”: “key2”:“value2” }`.

Returns:



6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
# File 'lib/aws-sdk-connect/types.rb', line 6159

class CreateNotificationRequest < Struct.new(
  :instance_id,
  :expires_at,
  :recipients,
  :priority,
  :content,
  :tags,
  :predefined_notification_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end