Class: Aws::Connect::Types::CreateParticipantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateParticipantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#participant_details ⇒ Types::ParticipantDetailsToAdd
Information identifying the participant.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
6323 6324 6325 6326 6327 6328 6329 6330 |
# File 'lib/aws-sdk-connect/types.rb', line 6323 class CreateParticipantRequest < Struct.new( :instance_id, :contact_id, :client_token, :participant_details) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer. Supports contacts in the CHAT channel and VOICE (WebRTC) channels. For WebRTC calls, this should be the initial contact ID that was generated when the contact was first created (from the StartWebRTCContact API) in the VOICE channel
6323 6324 6325 6326 6327 6328 6329 6330 |
# File 'lib/aws-sdk-connect/types.rb', line 6323 class CreateParticipantRequest < Struct.new( :instance_id, :contact_id, :client_token, :participant_details) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
6323 6324 6325 6326 6327 6328 6329 6330 |
# File 'lib/aws-sdk-connect/types.rb', line 6323 class CreateParticipantRequest < Struct.new( :instance_id, :contact_id, :client_token, :participant_details) SENSITIVE = [] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetailsToAdd
Information identifying the participant.
The only valid value for ‘ParticipantRole` is `CUSTOM_BOT` for chat contact and `CUSTOMER` for voice contact.
6323 6324 6325 6326 6327 6328 6329 6330 |
# File 'lib/aws-sdk-connect/types.rb', line 6323 class CreateParticipantRequest < Struct.new( :instance_id, :contact_id, :client_token, :participant_details) SENSITIVE = [] include Aws::Structure end |