Class: Aws::Connect::Types::CreatePredefinedAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreatePredefinedAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Amazon Connect admin website.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#name ⇒ String
The name of the predefined attribute.
-
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes.
-
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
Instance Attribute Details
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Amazon Connect admin website.
6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/aws-sdk-connect/types.rb', line 6169 class CreatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/aws-sdk-connect/types.rb', line 6169 class CreatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the predefined attribute.
6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/aws-sdk-connect/types.rb', line 6169 class CreatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Amazon Connect admin website.
6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/aws-sdk-connect/types.rb', line 6169 class CreatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/aws-sdk-connect/types.rb', line 6169 class CreatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |