Class: Aws::Connect::Types::CreatePromptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreatePromptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the prompt.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the prompt.
-
#s3_uri ⇒ String
The URI for the S3 bucket where the prompt is stored.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the prompt.
7211 7212 7213 7214 7215 7216 7217 7218 7219 |
# File 'lib/aws-sdk-connect/types.rb', line 7211 class CreatePromptRequest < Struct.new( :instance_id, :name, :description, :s3_uri, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7211 7212 7213 7214 7215 7216 7217 7218 7219 |
# File 'lib/aws-sdk-connect/types.rb', line 7211 class CreatePromptRequest < Struct.new( :instance_id, :name, :description, :s3_uri, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the prompt.
7211 7212 7213 7214 7215 7216 7217 7218 7219 |
# File 'lib/aws-sdk-connect/types.rb', line 7211 class CreatePromptRequest < Struct.new( :instance_id, :name, :description, :s3_uri, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The URI for the S3 bucket where the prompt is stored. You can provide S3 pre-signed URLs returned by the GetPromptFile API instead of providing S3 URIs.
7211 7212 7213 7214 7215 7216 7217 7218 7219 |
# File 'lib/aws-sdk-connect/types.rb', line 7211 class CreatePromptRequest < Struct.new( :instance_id, :name, :description, :s3_uri, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
7211 7212 7213 7214 7215 7216 7217 7218 7219 |
# File 'lib/aws-sdk-connect/types.rb', line 7211 class CreatePromptRequest < Struct.new( :instance_id, :name, :description, :s3_uri, :tags) SENSITIVE = [] include Aws::Structure end |