Class: Aws::Connect::Types::CreatePushNotificationRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreatePushNotificationRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_configuration ⇒ Types::ContactConfiguration
The contact configuration for push notification registration.
-
#device_token ⇒ String
The push notification token issued by the Apple or Google gateways.
-
#device_type ⇒ String
The device type to use when sending the message.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#pinpoint_app_arn ⇒ String
The Amazon Resource Name (ARN) of the Pinpoint application.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |
#contact_configuration ⇒ Types::ContactConfiguration
The contact configuration for push notification registration.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |
#device_token ⇒ String
The push notification token issued by the Apple or Google gateways.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |
#device_type ⇒ String
The device type to use when sending the message.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |
#pinpoint_app_arn ⇒ String
The Amazon Resource Name (ARN) of the Pinpoint application.
7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 |
# File 'lib/aws-sdk-connect/types.rb', line 7279 class CreatePushNotificationRegistrationRequest < Struct.new( :instance_id, :client_token, :pinpoint_app_arn, :device_token, :device_type, :contact_configuration) SENSITIVE = [] include Aws::Structure end |