Class: Aws::Connect::Types::CreatePushNotificationRegistrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#contact_configurationTypes::ContactConfiguration

The contact configuration for push notification registration.



7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#device_tokenString

The push notification token issued by the Apple or Google gateways.

Returns:

  • (String)


7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#device_typeString

The device type to use when sending the message.

Returns:

  • (String)


7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pinpoint_app_arnString

The Amazon Resource Name (ARN) of the Pinpoint application.

Returns:

  • (String)


7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/aws-sdk-connect/types.rb', line 7047

class CreatePushNotificationRegistrationRequest < Struct.new(
  :instance_id,
  :client_token,
  :pinpoint_app_arn,
  :device_token,
  :device_type,
  :contact_configuration)
  SENSITIVE = []
  include Aws::Structure
end