Class: Aws::Connect::Types::CreateQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the queue.
-
#email_addresses_config ⇒ Array<Types::EmailAddressConfig>
Configuration list containing the email addresses to associate with the queue during creation.
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_contacts ⇒ Integer
The maximum number of contacts that can be in the queue before it is considered full.
-
#name ⇒ String
The name of the queue.
-
#outbound_caller_config ⇒ Types::OutboundCallerConfig
The outbound caller ID name, number, and outbound whisper flow.
-
#outbound_email_config ⇒ Types::OutboundEmailConfig
The outbound email address ID for a specified queue.
-
#quick_connect_ids ⇒ Array<String>
The quick connects available to agents who are working the queue.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the queue.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#email_addresses_config ⇒ Array<Types::EmailAddressConfig>
Configuration list containing the email addresses to associate with the queue during creation. Each configuration specifies an email address ID that agents can select when handling email contacts in this queue.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#max_contacts ⇒ Integer
The maximum number of contacts that can be in the queue before it is considered full.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the queue.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#outbound_caller_config ⇒ Types::OutboundCallerConfig
The outbound caller ID name, number, and outbound whisper flow.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#outbound_email_config ⇒ Types::OutboundEmailConfig
The outbound email address ID for a specified queue.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#quick_connect_ids ⇒ Array<String>
The quick connects available to agents who are working the queue.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 |
# File 'lib/aws-sdk-connect/types.rb', line 6865 class CreateQueueRequest < Struct.new( :instance_id, :name, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :quick_connect_ids, :email_addresses_config, :tags) SENSITIVE = [] include Aws::Structure end |