Class: Aws::Connect::Types::CreateRoutingProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_availability_timerString

Whether agents with this routing profile will have their routing order calculated based on *longest idle time* or *time since their last inbound contact*.

Returns:

  • (String)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#default_outbound_queue_idString

The default outbound queue for the routing profile.

Returns:

  • (String)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the routing profile. Must not be more than 250 characters.

Returns:

  • (String)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#manual_assignment_queue_configsArray<Types::RoutingProfileManualAssignmentQueueConfig>

The manual assignment queues associated with the routing profile. If no queue is added, agents and supervisors can’t pick or assign any contacts from this routing profile. The limit of 10 array members applies to the maximum number of RoutingProfileManualAssignmentQueueConfig objects that can be passed during a CreateRoutingProfile API request. It is different from the quota of 50 queues per routing profile per instance that is listed in Amazon Connect service quotas.



6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#media_concurrenciesArray<Types::MediaConcurrency>

The channels that agents can handle in the Contact Control Panel (CCP) for this routing profile.

Returns:



6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the routing profile. Must not be more than 127 characters.

Returns:

  • (String)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#queue_configsArray<Types::RoutingProfileQueueConfig>

The inbound queues associated with the routing profile. If no queue is added, the agent can make only outbound calls.

The limit of 10 array members applies to the maximum number of ‘RoutingProfileQueueConfig` objects that can be passed during a CreateRoutingProfile API request. It is different from the quota of 50 queues per routing profile per instance that is listed in [Amazon Connect service quotas].

[1]: docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html



6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.

Returns:

  • (Hash<String,String>)


6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/aws-sdk-connect/types.rb', line 6438

class CreateRoutingProfileRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :default_outbound_queue_id,
  :queue_configs,
  :manual_assignment_queue_configs,
  :media_concurrencies,
  :tags,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end