Class: Aws::Connect::Types::CreateRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#function ⇒ String
The conditions of the rule.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
A unique name for the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
Instance Attribute Details
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The conditions of the rule.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name for the rule.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 |
# File 'lib/aws-sdk-connect/types.rb', line 7340 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :client_token) SENSITIVE = [] include Aws::Structure end |