Class: Aws::Connect::Types::CreateRuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::RuleAction>

A list of actions to be run when the rule is triggered.

Returns:



7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#functionString

The conditions of the rule.

Returns:

  • (String)


7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name for the rule.

Returns:

  • (String)


7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status of the rule.

Returns:

  • (String)


7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_event_sourceTypes::RuleTriggerEventSource

The event source to trigger the rule.



7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
# File 'lib/aws-sdk-connect/types.rb', line 7245

class CreateRuleRequest < Struct.new(
  :instance_id,
  :name,
  :trigger_event_source,
  :function,
  :actions,
  :publish_status,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end