Class: Aws::Connect::Types::CreateRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#function ⇒ String
The conditions of the rule.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
A unique name for the rule.
-
#pre_evaluation_filters ⇒ Types::PreEvaluationFilters
The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact.
-
#publish_status ⇒ String
The publish status of the rule.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
Instance Attribute Details
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The conditions of the rule.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A unique name for the rule.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#pre_evaluation_filters ⇒ Types::PreEvaluationFilters
The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact. The pre-evaluation filters are applied even before rule conditions are evaluated and are used to enforce tag-based-access-control while applying rules.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 |
# File 'lib/aws-sdk-connect/types.rb', line 7682 class CreateRuleRequest < Struct.new( :instance_id, :name, :trigger_event_source, :function, :actions, :publish_status, :pre_evaluation_filters, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |