Class: Aws::Connect::Types::CreateTaskTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateTaskTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
-
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
-
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
-
#description ⇒ String
The description of the task template.
-
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the task template.
-
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed. Although this
parameter is marked as optional in the API model, the service
requires it when calling CreateTaskTemplate or
UpdateTaskTemplate. The RequiredFields array must contain at
least one element, and the field of type NAME must be included in
RequiredFields.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
Although this parameter is marked as optional, the request must
contain either a ContactFlowId or a field of type QUICK_CONNECT.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the task template.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
The request must contain exactly one field of type NAME. This
field must also be listed in the RequiredFields array within the
Constraints parameter.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to
it. Tasks can only be created from ACTIVE templates. If a template
is marked as INACTIVE, then a task that refers to this template
cannot be created.
7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-connect/types.rb', line 7739 class CreateTaskTemplateRequest < Struct.new( :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields, :client_token) SENSITIVE = [] include Aws::Structure end |