Class: Aws::Connect::Types::CreateTaskTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#constraintsTypes::TaskTemplateConstraints

Constraints that are applicable to the fields listed.



7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow that runs by default when a task is created by referencing this template.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#defaultsTypes::TaskTemplateDefaults

The default values for fields when a task is created by referencing this template.



7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the task template.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsArray<Types::TaskTemplateField>

Fields that are part of the template.

Returns:



7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the task template.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#self_assign_flow_idString

The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Marks a template as ACTIVE or INACTIVE for a task to refer to it. Tasks can only be created from ACTIVE templates. If a template is marked as INACTIVE, then a task that refers to this template cannot be created.

Returns:

  • (String)


7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
# File 'lib/aws-sdk-connect/types.rb', line 7556

class CreateTaskTemplateRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end