Class: Aws::Connect::Types::CreateTestCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateTestCaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The JSON string that represents the content of the test.
-
#description ⇒ String
The description of the test.
-
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for your test.
-
#initialization_data ⇒ String
Defines the initial custom attributes for your test.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_region ⇒ String
The region in which the resource was last modified.
-
#last_modified_time ⇒ Time
The time at which the resource was last modified.
-
#name ⇒ String
The name of the test.
-
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#test_case_id ⇒ String
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency.
Instance Attribute Details
#content ⇒ String
The JSON string that represents the content of the test.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the test.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for your test.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#initialization_data ⇒ String
Defines the initial custom attributes for your test.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The region in which the resource was last modified
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time at which the resource was last modified.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
Id of the test case if you want to create it in a replica region using Amazon Connect Global Resiliency
7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 |
# File 'lib/aws-sdk-connect/types.rb', line 7286 class CreateTestCaseRequest < Struct.new( :instance_id, :name, :description, :content, :entry_point, :initialization_data, :status, :test_case_id, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |