Class: Aws::Connect::Types::CreateTrafficDistributionGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7890
7891
7892
7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-connect/types.rb', line 7890

class CreateTrafficDistributionGroupRequest < Struct.new(
  :name,
  :description,
  :instance_id,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the traffic distribution group.

Returns:

  • (String)


7890
7891
7892
7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-connect/types.rb', line 7890

class CreateTrafficDistributionGroupRequest < Struct.new(
  :name,
  :description,
  :instance_id,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance that has been replicated. You can find the instanceId in the ARN of the instance.

Returns:

  • (String)


7890
7891
7892
7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-connect/types.rb', line 7890

class CreateTrafficDistributionGroupRequest < Struct.new(
  :name,
  :description,
  :instance_id,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the traffic distribution group.

Returns:

  • (String)


7890
7891
7892
7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-connect/types.rb', line 7890

class CreateTrafficDistributionGroupRequest < Struct.new(
  :name,
  :description,
  :instance_id,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


7890
7891
7892
7893
7894
7895
7896
7897
7898
# File 'lib/aws-sdk-connect/types.rb', line 7890

class CreateTrafficDistributionGroupRequest < Struct.new(
  :name,
  :description,
  :instance_id,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end