Class: Aws::Connect::Types::CreateTrafficDistributionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateTrafficDistributionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
A description for the traffic distribution group.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that has been replicated.
-
#name ⇒ String
The name for the traffic distribution group.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/aws-sdk-connect/types.rb', line 7692 class CreateTrafficDistributionGroupRequest < Struct.new( :name, :description, :instance_id, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the traffic distribution group.
7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/aws-sdk-connect/types.rb', line 7692 class CreateTrafficDistributionGroupRequest < Struct.new( :name, :description, :instance_id, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance that has been
replicated. You can find the instanceId in the ARN of the
instance.
7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/aws-sdk-connect/types.rb', line 7692 class CreateTrafficDistributionGroupRequest < Struct.new( :name, :description, :instance_id, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the traffic distribution group.
7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/aws-sdk-connect/types.rb', line 7692 class CreateTrafficDistributionGroupRequest < Struct.new( :name, :description, :instance_id, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/aws-sdk-connect/types.rb', line 7692 class CreateTrafficDistributionGroupRequest < Struct.new( :name, :description, :instance_id, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |