Class: Aws::Connect::Types::CreateUseCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateUseCaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#integration_association_id ⇒ String
The identifier for the integration association.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#use_case_type ⇒ String
The type of use case to associate to the integration association.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
7652 7653 7654 7655 7656 7657 7658 7659 |
# File 'lib/aws-sdk-connect/types.rb', line 7652 class CreateUseCaseRequest < Struct.new( :instance_id, :integration_association_id, :use_case_type, :tags) SENSITIVE = [] include Aws::Structure end |
#integration_association_id ⇒ String
The identifier for the integration association.
7652 7653 7654 7655 7656 7657 7658 7659 |
# File 'lib/aws-sdk-connect/types.rb', line 7652 class CreateUseCaseRequest < Struct.new( :instance_id, :integration_association_id, :use_case_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
7652 7653 7654 7655 7656 7657 7658 7659 |
# File 'lib/aws-sdk-connect/types.rb', line 7652 class CreateUseCaseRequest < Struct.new( :instance_id, :integration_association_id, :use_case_type, :tags) SENSITIVE = [] include Aws::Structure end |
#use_case_type ⇒ String
The type of use case to associate to the integration association. Each integration association can have only one of each use case type.
7652 7653 7654 7655 7656 7657 7658 7659 |
# File 'lib/aws-sdk-connect/types.rb', line 7652 class CreateUseCaseRequest < Struct.new( :instance_id, :integration_association_id, :use_case_type, :tags) SENSITIVE = [] include Aws::Structure end |