Class: Aws::Connect::Types::CreateUserHierarchyGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateUserHierarchyGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#name ⇒ String
The name of the user hierarchy group.
-
#parent_group_id ⇒ String
The identifier for the parent hierarchy group.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-connect/types.rb', line 6891 class CreateUserHierarchyGroupRequest < Struct.new( :name, :parent_group_id, :instance_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the user hierarchy group. Must not be more than 100 characters.
6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-connect/types.rb', line 6891 class CreateUserHierarchyGroupRequest < Struct.new( :name, :parent_group_id, :instance_id, :tags) SENSITIVE = [] include Aws::Structure end |
#parent_group_id ⇒ String
The identifier for the parent hierarchy group. The user hierarchy is created at level one if the parent group ID is null.
6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-connect/types.rb', line 6891 class CreateUserHierarchyGroupRequest < Struct.new( :name, :parent_group_id, :instance_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-connect/types.rb', line 6891 class CreateUserHierarchyGroupRequest < Struct.new( :name, :parent_group_id, :instance_id, :tags) SENSITIVE = [] include Aws::Structure end |