Class: Aws::Connect::Types::CreateUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#after_contact_work_configsArray<Types::AfterContactWorkConfigPerChannel>

The list of after contact work (ACW) timeout configuration settings for each channel.



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#auto_accept_configsArray<Types::AutoAcceptConfig>

The list of auto-accept configuration settings for each channel.

Returns:



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#directory_user_idString

The identifier of the user account in the directory used for identity management. If Connect Customer cannot access the directory, you can specify this identifier to authenticate users. If you include the identifier, we assume that Connect Customer cannot access the directory. Otherwise, the identity information is used to authenticate users from your directory.

This parameter is required if you are using an existing directory for identity management in Connect Customer when Connect Customer cannot access your directory to authenticate users. If you are using SAML for identity management and include this parameter, an error is returned.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#hierarchy_group_idString

The identifier of the hierarchy group for the user.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#identity_infoTypes::UserIdentityInfo

The information about the identity of the user.



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#passwordString

The password for the user account. A password is required if you are using Connect Customer for identity management. Otherwise, it is an error to include a password.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#persistent_connection_configsArray<Types::PersistentConnectionConfig>

The list of persistent connection configuration settings for each channel.



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#phone_configTypes::UserPhoneConfig

The phone settings for the user. This parameter is optional. If not provided, the user can be configured using channel-specific parameters such as AutoAcceptConfigs, AfterContactWorkConfigs, PhoneNumberConfigs, PersistentConnectionConfigs, and VoiceEnhancementConfigs.



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#phone_number_configsArray<Types::PhoneNumberConfig>

The list of phone number configuration settings for each channel.

Returns:



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#routing_profile_idString

The identifier of the routing profile for the user.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#security_profile_idsArray<String>

The identifier of the security profile for the user.

Returns:

  • (Array<String>)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#usernameString

The user name for the account. For instances not using SAML for identity management, the user name can include up to 20 characters. If you are using SAML for identity management, the user name can include up to 64 characters from [a-zA-Z0-9_-.\@]+.

Username can include @ only if used in an email format. For example:

  • Correct: testuser

  • Correct: testuser@example.com

  • Incorrect: testuser@example

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end

#voice_enhancement_configsArray<Types::VoiceEnhancementConfig>

The list of voice enhancement configuration settings for each channel.

Returns:



7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/aws-sdk-connect/types.rb', line 7831

class CreateUserRequest < Struct.new(
  :username,
  :password,
  :identity_info,
  :phone_config,
  :directory_user_id,
  :security_profile_ids,
  :routing_profile_id,
  :hierarchy_group_id,
  :instance_id,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs,
  :tags)
  SENSITIVE = [:password]
  include Aws::Structure
end