Class: Aws::Connect::Types::CreateUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
-
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
-
#directory_user_id ⇒ String
The identifier of the user account in the directory used for identity management.
-
#hierarchy_group_id ⇒ String
The identifier of the hierarchy group for the user.
-
#identity_info ⇒ Types::UserIdentityInfo
The information about the identity of the user.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#password ⇒ String
The password for the user account.
-
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
-
#phone_config ⇒ Types::UserPhoneConfig
The phone settings for the user.
-
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
-
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
-
#security_profile_ids ⇒ Array<String>
The identifier of the security profile for the user.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#username ⇒ String
The user name for the account.
-
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
Instance Attribute Details
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#directory_user_id ⇒ String
The identifier of the user account in the directory used for identity management. If Connect Customer cannot access the directory, you can specify this identifier to authenticate users. If you include the identifier, we assume that Connect Customer cannot access the directory. Otherwise, the identity information is used to authenticate users from your directory.
This parameter is required if you are using an existing directory for identity management in Connect Customer when Connect Customer cannot access your directory to authenticate users. If you are using SAML for identity management and include this parameter, an error is returned.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#hierarchy_group_id ⇒ String
The identifier of the hierarchy group for the user.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#identity_info ⇒ Types::UserIdentityInfo
The information about the identity of the user.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
The password for the user account. A password is required if you are using Connect Customer for identity management. Otherwise, it is an error to include a password.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#phone_config ⇒ Types::UserPhoneConfig
The phone settings for the user. This parameter is optional. If not provided, the user can be configured using channel-specific parameters such as ‘AutoAcceptConfigs`, `AfterContactWorkConfigs`, `PhoneNumberConfigs`, `PersistentConnectionConfigs`, and `VoiceEnhancementConfigs`.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#security_profile_ids ⇒ Array<String>
The identifier of the security profile for the user.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#username ⇒ String
The user name for the account. For instances not using SAML for identity management, the user name can include up to 20 characters. If you are using SAML for identity management, the user name can include up to 64 characters from [a-zA-Z0-9_-.\@]+.
Username can include @ only if used in an email format. For example:
-
Correct: testuser
-
Correct: testuser@example.com
-
Incorrect: testuser@example
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-connect/types.rb', line 7686 class CreateUserRequest < Struct.new( :username, :password, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :instance_id, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :tags) SENSITIVE = [:password] include Aws::Structure end |