Class: Aws::Connect::Types::CreateViewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateViewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique Id for each create view request to avoid duplicate view creation.
-
#content ⇒ Types::ViewInputContent
View content containing all content necessary to render a view except for runtime input data.
-
#description ⇒ String
The description of the view.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the view.
-
#status ⇒ String
Indicates the view status as either
SAVEDorPUBLISHED. -
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).These tags can be used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique Id for each create view request to avoid duplicate view creation. For example, the view is idempotent ClientToken is provided.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#content ⇒ Types::ViewInputContent
View content containing all content necessary to render a view except for runtime input data.
The total uncompressed content has a maximum file size of 400kB.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#description ⇒ String
The description of the view.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the view.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#status ⇒ String
Indicates the view status as either SAVED or PUBLISHED. The
PUBLISHED status will initiate validation on the content.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).These tags can be used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/aws-sdk-connect/types.rb', line 8186 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |