Class: Aws::Connect::Types::CreateViewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateViewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique Id for each create view request to avoid duplicate view creation.
-
#content ⇒ Types::ViewInputContent
View content containing all content necessary to render a view except for runtime input data.
-
#description ⇒ String
The description of the view.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the view.
-
#status ⇒ String
Indicates the view status as either
SAVEDorPUBLISHED. -
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).These tags can be used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique Id for each create view request to avoid duplicate view creation. For example, the view is idempotent ClientToken is provided.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#content ⇒ Types::ViewInputContent
View content containing all content necessary to render a view except for runtime input data.
The total uncompressed content has a maximum file size of 400kB.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#description ⇒ String
The description of the view.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the view.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#status ⇒ String
Indicates the view status as either SAVED or PUBLISHED. The
PUBLISHED status will initiate validation on the content.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).These tags can be used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.
7891 7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 |
# File 'lib/aws-sdk-connect/types.rb', line 7891 class CreateViewRequest < Struct.new( :instance_id, :client_token, :status, :content, :description, :name, :tags) SENSITIVE = [:name] include Aws::Structure end |