Class: Aws::Connect::Types::CreateWorkspacePageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateWorkspacePageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_data ⇒ String
A JSON string containing input parameters for the view, validated against the view's input schema.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#page ⇒ String
The page identifier.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
-
#slug ⇒ String
The URL-friendly identifier for the page.
-
#workspace_id ⇒ String
The identifier of the workspace.
Instance Attribute Details
#input_data ⇒ String
A JSON string containing input parameters for the view, validated against the view's input schema.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#page ⇒ String
The page identifier. Valid system pages include HOME and
AGENT_EXPERIENCE. Custom pages cannot use the aws: or connect:
prefixes.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#slug ⇒ String
The URL-friendly identifier for the page.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace.
8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/aws-sdk-connect/types.rb', line 8462 class CreateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :resource_arn, :page, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |