Class: Aws::Connect::Types::CreateWorkspaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the workspace. Maximum length is 250 characters.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workspace. Must be unique within the instance and can contain 1-127 characters.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.

Returns:

  • (Hash<String,String>)


8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#themeTypes::WorkspaceTheme

The theme configuration for the workspace, including colors and styling.



8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title displayed for the workspace.

Returns:

  • (String)


8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
# File 'lib/aws-sdk-connect/types.rb', line 8152

class CreateWorkspaceRequest < Struct.new(
  :instance_id,
  :name,
  :description,
  :theme,
  :title,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end