Class: Aws::Connect::Types::CreateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the workspace.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#name ⇒ String
The name of the workspace.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#theme ⇒ Types::WorkspaceTheme
The theme configuration for the workspace, including colors and styling.
-
#title ⇒ String
The title displayed for the workspace.
Instance Attribute Details
#description ⇒ String
The description of the workspace. Maximum length is 250 characters.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workspace. Must be unique within the instance and can contain 1-127 characters.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this
resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#theme ⇒ Types::WorkspaceTheme
The theme configuration for the workspace, including colors and styling.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title displayed for the workspace.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 |
# File 'lib/aws-sdk-connect/types.rb', line 8152 class CreateWorkspaceRequest < Struct.new( :instance_id, :name, :description, :theme, :title, :tags) SENSITIVE = [] include Aws::Structure end |