Class: Aws::Connect::Types::CreatedByInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CreatedByInfo
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
CreatedByInfo is a union - when making an API calls you must set exactly one of the members.
CreatedByInfo is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CreatedByInfo corresponding to the set member.
Information on the identity that created the file.
Defined Under Namespace
Classes: AwsIdentityArn, ConnectUserArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_identity_arn ⇒ String
STS or IAM ARN representing the identity of API Caller.
-
#connect_user_arn ⇒ String
An agent ARN representing a [connect user][1].
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#aws_identity_arn ⇒ String
STS or IAM ARN representing the identity of API Caller. SDK users
cannot populate this and this value is calculated automatically if
ConnectUserArn is not provided.
8480 8481 8482 8483 8484 8485 8486 8487 8488 8489 8490 8491 |
# File 'lib/aws-sdk-connect/types.rb', line 8480 class CreatedByInfo < Struct.new( :connect_user_arn, :aws_identity_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < CreatedByInfo; end class AwsIdentityArn < CreatedByInfo; end class Unknown < CreatedByInfo; end end |
#connect_user_arn ⇒ String
An agent ARN representing a connect user.
8480 8481 8482 8483 8484 8485 8486 8487 8488 8489 8490 8491 |
# File 'lib/aws-sdk-connect/types.rb', line 8480 class CreatedByInfo < Struct.new( :connect_user_arn, :aws_identity_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < CreatedByInfo; end class AwsIdentityArn < CreatedByInfo; end class Unknown < CreatedByInfo; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8480 8481 8482 |
# File 'lib/aws-sdk-connect/types.rb', line 8480 def unknown @unknown end |