Class: Aws::Connect::Types::CrossChannelWorkloadBehavior
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::CrossChannelWorkloadBehavior
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines the cross-channel and workload type routing behavior that allows an agent working on a contact to be offered a contact from a different channel or workload type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_workload_behavior_type ⇒ String
Specifies the routing behavior for an agent handling their current channel and workload type.
Instance Attribute Details
#channel_workload_behavior_type ⇒ String
Specifies the routing behavior for an agent handling their current channel and workload type.
8731 8732 8733 8734 8735 |
# File 'lib/aws-sdk-connect/types.rb', line 8731 class CrossChannelWorkloadBehavior < Struct.new( :channel_workload_behavior_type) SENSITIVE = [] include Aws::Structure end |