Class: Aws::Connect::Types::DataTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Represents a data table in Amazon Connect. A data table is a JSON-like data structure where attributes and values are dynamically set by customers. Customers can reference table values within call flows, applications, views, and workspaces to pinpoint dynamic configuration that changes their contact center’s behavior in a predetermined and safe way.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the data table. Does not include version aliases.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp when the data table was created.

Returns:

  • (Time)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description of the data table’s purpose and contents.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier for the data table. Does not include version aliases.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where the data table was last modified, used for region replication.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the data table or any of its properties were last modified.

Returns:

  • (Time)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#lock_versionTypes::DataTableLockVersion

The lock version information used for optimistic locking and table versioning. Changes with each update to prevent concurrent modification conflicts.



8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The human-readable name of the data table. Must be unique within the instance and conform to Connect naming standards.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the data table. One of PUBLISHED or SAVED.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Key-value pairs for attribute based access control (TBAC or ABAC) and organization.

Returns:

  • (Hash<String,String>)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The IANA timezone identifier used when resolving time based dynamic values. Required even if no time slices are specified.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#value_lock_levelString

The data level that concurrent value edits are locked on. One of DATA_TABLE, PRIMARY_VALUE, ATTRIBUTE, VALUE, and NONE. Determines how concurrent edits are handled when multiple users attempt to modify values simultaneously.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

A unique identifier and alias for customer managed versions (not $LATEST or $SAVED).

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#version_descriptionString

A description of the customer managed version.

Returns:

  • (String)


8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
# File 'lib/aws-sdk-connect/types.rb', line 8019

class DataTable < Struct.new(
  :name,
  :id,
  :arn,
  :time_zone,
  :description,
  :value_lock_level,
  :lock_version,
  :version,
  :version_description,
  :status,
  :created_time,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end