Class: Aws::Connect::Types::DataTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DataTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Represents a data table in Amazon Connect. A data table is a JSON-like data structure where attributes and values are dynamically set by customers. Customers can reference table values within call flows, applications, views, and workspaces to pinpoint dynamic configuration that changes their contact center’s behavior in a predetermined and safe way.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the data table.
-
#created_time ⇒ Time
The timestamp when the data table was created.
-
#description ⇒ String
An optional description of the data table’s purpose and contents.
-
#id ⇒ String
The unique identifier for the data table.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where the data table was last modified, used for region replication.
-
#last_modified_time ⇒ Time
The timestamp when the data table or any of its properties were last modified.
-
#lock_version ⇒ Types::DataTableLockVersion
The lock version information used for optimistic locking and table versioning.
-
#name ⇒ String
The human-readable name of the data table.
-
#status ⇒ String
The current status of the data table.
-
#tags ⇒ Hash<String,String>
Key-value pairs for attribute based access control (TBAC or ABAC) and organization.
-
#time_zone ⇒ String
The IANA timezone identifier used when resolving time based dynamic values.
-
#value_lock_level ⇒ String
The data level that concurrent value edits are locked on.
-
#version ⇒ String
A unique identifier and alias for customer managed versions (not $LATEST or $SAVED).
-
#version_description ⇒ String
A description of the customer managed version.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the data table. Does not include version aliases.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the data table was created.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description of the data table’s purpose and contents.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the data table. Does not include version aliases.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where the data table was last modified, used for region replication.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the data table or any of its properties were last modified.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#lock_version ⇒ Types::DataTableLockVersion
The lock version information used for optimistic locking and table versioning. Changes with each update to prevent concurrent modification conflicts.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The human-readable name of the data table. Must be unique within the instance and conform to Connect naming standards.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the data table. One of PUBLISHED or SAVED.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs for attribute based access control (TBAC or ABAC) and organization.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The IANA timezone identifier used when resolving time based dynamic values. Required even if no time slices are specified.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#value_lock_level ⇒ String
The data level that concurrent value edits are locked on. One of DATA_TABLE, PRIMARY_VALUE, ATTRIBUTE, VALUE, and NONE. Determines how concurrent edits are handled when multiple users attempt to modify values simultaneously.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
A unique identifier and alias for customer managed versions (not $LATEST or $SAVED).
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#version_description ⇒ String
A description of the customer managed version.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 |
# File 'lib/aws-sdk-connect/types.rb', line 7654 class DataTable < Struct.new( :name, :id, :arn, :time_zone, :description, :value_lock_level, :lock_version, :version, :version_description, :status, :created_time, :last_modified_time, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |