Class: Aws::Connect::Types::DataTableAttribute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Represents an attribute (column) in a data table. Attributes define the schema and validation rules for values that can be stored in the table. They specify the data type, constraints, and whether the attribute is used as a primary key for record identification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_idString

The unique identifier for the attribute within the data table.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#data_table_arnString

The Amazon Resource Name (ARN) of the data table that contains this attribute.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#data_table_idString

The unique identifier of the data table that contains this attribute.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description explaining the purpose and usage of this attribute.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where this attribute was last modified, used for region replication.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when this attribute was last modified.

Returns:

  • (Time)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#lock_versionTypes::DataTableLockVersion

The lock version for this attribute, used for optimistic locking to prevent concurrent modification conflicts.



8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The human-readable name of the attribute. Must be unique within the data table and conform to Connect naming standards.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#primaryBoolean

Boolean indicating whether this attribute is used as a primary key for record identification. Primary attributes must have unique value combinations and cannot contain expressions.

Returns:

  • (Boolean)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#validationTypes::Validation

The validation rules applied to values of this attribute. Based on JSON Schema Draft 2020-12 with additional Connect-specific validations for data integrity.

Returns:



8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#value_typeString

The type of value allowed for this attribute. Must be one of TEXT, TEXT_LIST, NUMBER, NUMBER_LIST, or BOOLEAN. Determines how values are validated and processed.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version identifier for this attribute, used for versioning and change tracking.

Returns:

  • (String)


8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/aws-sdk-connect/types.rb', line 8194

class DataTableAttribute < Struct.new(
  :attribute_id,
  :name,
  :value_type,
  :description,
  :data_table_id,
  :data_table_arn,
  :primary,
  :version,
  :lock_version,
  :last_modified_time,
  :last_modified_region,
  :validation)
  SENSITIVE = []
  include Aws::Structure
end