Class: Aws::Connect::Types::DateCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

An object to specify the hours of operation override date condition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_typeString

An object to specify the hours of operation override date condition ‘comparisonType`.

Returns:

  • (String)


8110
8111
8112
8113
8114
8115
8116
# File 'lib/aws-sdk-connect/types.rb', line 8110

class DateCondition < Struct.new(
  :field_name,
  :value,
  :comparison_type)
  SENSITIVE = []
  include Aws::Structure
end

#field_nameString

An object to specify the hours of operation override date field.

Returns:

  • (String)


8110
8111
8112
8113
8114
8115
8116
# File 'lib/aws-sdk-connect/types.rb', line 8110

class DateCondition < Struct.new(
  :field_name,
  :value,
  :comparison_type)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

An object to specify the hours of operation override date value.

Returns:

  • (String)


8110
8111
8112
8113
8114
8115
8116
# File 'lib/aws-sdk-connect/types.rb', line 8110

class DateCondition < Struct.new(
  :field_name,
  :value,
  :comparison_type)
  SENSITIVE = []
  include Aws::Structure
end