Class: Aws::Connect::Types::DeleteInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DeleteInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
9613 9614 9615 9616 9617 9618 |
# File 'lib/aws-sdk-connect/types.rb', line 9613 class DeleteInstanceRequest < Struct.new( :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
9613 9614 9615 9616 9617 9618 |
# File 'lib/aws-sdk-connect/types.rb', line 9613 class DeleteInstanceRequest < Struct.new( :instance_id, :client_token) SENSITIVE = [] include Aws::Structure end |