Class: Aws::Connect::Types::DescribeEmailAddressResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeEmailAddressResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:email_address, :display_name, :description]
Instance Attribute Summary collapse
-
#alias_configurations ⇒ Array<Types::AliasConfiguration>
A list of alias configurations associated with this email address.
-
#create_timestamp ⇒ String
The email address creation timestamp in ISO 8601 Datetime.
-
#description ⇒ String
The description of the email address.
-
#display_name ⇒ String
The display name of email address.
-
#email_address ⇒ String
The email address, including the domain.
-
#email_address_arn ⇒ String
The Amazon Resource Name (ARN) of the email address.
-
#email_address_id ⇒ String
The identifier of the email address.
-
#modified_timestamp ⇒ String
The email address last modification timestamp in ISO 8601 Datetime.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#alias_configurations ⇒ Array<Types::AliasConfiguration>
A list of alias configurations associated with this email address. Contains details about email addresses that forward to this primary email address. The list can contain at most one alias configuration per email address.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#create_timestamp ⇒ String
The email address creation timestamp in ISO 8601 Datetime.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#description ⇒ String
The description of the email address.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#display_name ⇒ String
The display name of email address
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#email_address ⇒ String
The email address, including the domain.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#email_address_arn ⇒ String
The Amazon Resource Name (ARN) of the email address.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#email_address_id ⇒ String
The identifier of the email address.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#modified_timestamp ⇒ String
The email address last modification timestamp in ISO 8601 Datetime.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 |
# File 'lib/aws-sdk-connect/types.rb', line 10674 class DescribeEmailAddressResponse < Struct.new( :email_address_id, :email_address_arn, :email_address, :display_name, :description, :create_timestamp, :modified_timestamp, :alias_configurations, :tags) SENSITIVE = [:email_address, :display_name, :description] include Aws::Structure end |