Class: Aws::Connect::Types::DescribeInstanceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeInstanceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance ⇒ Types::Instance
The name of the instance.
-
#replication_configuration ⇒ Types::ReplicationConfiguration
Status information about the replication process.
Instance Attribute Details
#instance ⇒ Types::Instance
The name of the instance.
10660 10661 10662 10663 10664 10665 |
# File 'lib/aws-sdk-connect/types.rb', line 10660 class DescribeInstanceResponse < Struct.new( :instance, :replication_configuration) SENSITIVE = [] include Aws::Structure end |
#replication_configuration ⇒ Types::ReplicationConfiguration
Status information about the replication process. This field is included only when you are using the ReplicateInstance API to replicate an Connect Customer instance across Amazon Web Services Regions. For information about replicating Connect Customer instances, see Create a replica of your existing Connect Customer instance in the Connect Customer Administrator Guide.
10660 10661 10662 10663 10664 10665 |
# File 'lib/aws-sdk-connect/types.rb', line 10660 class DescribeInstanceResponse < Struct.new( :instance, :replication_configuration) SENSITIVE = [] include Aws::Structure end |