Class: Aws::Connect::Types::DescribeMetricRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeMetricRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#metric_id ⇒ String
The identifier of the metric to describe.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-connect/types.rb', line 11115 class DescribeMetricRequest < Struct.new( :instance_id, :metric_id) SENSITIVE = [] include Aws::Structure end |
#metric_id ⇒ String
The identifier of the metric to describe. Adding the $SAVED
qualifier will describe the saved version of the metric. Adding
$LATEST or omitting a qualifier will describe the published
version.
11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-connect/types.rb', line 11115 class DescribeMetricRequest < Struct.new( :instance_id, :metric_id) SENSITIVE = [] include Aws::Structure end |