Class: Aws::Connect::Types::DescribeTestCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeTestCaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#status ⇒ String
The status of the test case version to retrieve.
-
#test_case_id ⇒ String
The identifier of the test case.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
11223 11224 11225 11226 11227 11228 11229 |
# File 'lib/aws-sdk-connect/types.rb', line 11223 class DescribeTestCaseRequest < Struct.new( :instance_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the test case version to retrieve. If not specified, returns the published version if available, otherwise returns the saved version.
11223 11224 11225 11226 11227 11228 11229 |
# File 'lib/aws-sdk-connect/types.rb', line 11223 class DescribeTestCaseRequest < Struct.new( :instance_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
The identifier of the test case.
11223 11224 11225 11226 11227 11228 11229 |
# File 'lib/aws-sdk-connect/types.rb', line 11223 class DescribeTestCaseRequest < Struct.new( :instance_id, :test_case_id, :status) SENSITIVE = [] include Aws::Structure end |