Class: Aws::Connect::Types::DescribeTrafficDistributionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DescribeTrafficDistributionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group.
Instance Attribute Details
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
10062 10063 10064 10065 10066 |
# File 'lib/aws-sdk-connect/types.rb', line 10062 class DescribeTrafficDistributionGroupRequest < Struct.new( :traffic_distribution_group_id) SENSITIVE = [] include Aws::Structure end |