Class: Aws::Connect::Types::DisassociateAnalyticsDataSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateAnalyticsDataSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_id ⇒ String
The identifier of the dataset to remove.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#target_account_id ⇒ String
The identifier of the target account.
Instance Attribute Details
#data_set_id ⇒ String
The identifier of the dataset to remove.
11555 11556 11557 11558 11559 11560 11561 |
# File 'lib/aws-sdk-connect/types.rb', line 11555 class DisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_id, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
11555 11556 11557 11558 11559 11560 11561 |
# File 'lib/aws-sdk-connect/types.rb', line 11555 class DisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_id, :target_account_id) SENSITIVE = [] include Aws::Structure end |
#target_account_id ⇒ String
The identifier of the target account. Use to associate a dataset to a different account than the one containing the Connect Customer instance. If not specified, by default this value is the Amazon Web Services account that has the Connect Customer instance.
11555 11556 11557 11558 11559 11560 11561 |
# File 'lib/aws-sdk-connect/types.rb', line 11555 class DisassociateAnalyticsDataSetRequest < Struct.new( :instance_id, :data_set_id, :target_account_id) SENSITIVE = [] include Aws::Structure end |