Class: Aws::Connect::Types::DisassociateApprovedOriginRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


11981
11982
11983
11984
11985
11986
11987
# File 'lib/aws-sdk-connect/types.rb', line 11981

class DisassociateApprovedOriginRequest < Struct.new(
  :instance_id,
  :origin,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


11981
11982
11983
11984
11985
11986
11987
# File 'lib/aws-sdk-connect/types.rb', line 11981

class DisassociateApprovedOriginRequest < Struct.new(
  :instance_id,
  :origin,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#originString

The domain URL of the integrated application.

Returns:

  • (String)


11981
11982
11983
11984
11985
11986
11987
# File 'lib/aws-sdk-connect/types.rb', line 11981

class DisassociateApprovedOriginRequest < Struct.new(
  :instance_id,
  :origin,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end