Class: Aws::Connect::Types::DisassociateEmailAddressAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateEmailAddressAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which alias relationship to remove.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#email_address_id ⇒ String
The identifier of the email address.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which alias relationship to remove. The alias association must currently exist between the primary email address and the specified alias email address.
11916 11917 11918 11919 11920 11921 11922 11923 |
# File 'lib/aws-sdk-connect/types.rb', line 11916 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
11916 11917 11918 11919 11920 11921 11922 11923 |
# File 'lib/aws-sdk-connect/types.rb', line 11916 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_address_id ⇒ String
The identifier of the email address.
11916 11917 11918 11919 11920 11921 11922 11923 |
# File 'lib/aws-sdk-connect/types.rb', line 11916 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
11916 11917 11918 11919 11920 11921 11922 11923 |
# File 'lib/aws-sdk-connect/types.rb', line 11916 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |