Class: Aws::Connect::Types::DisassociateEmailAddressAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateEmailAddressAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which alias relationship to remove.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#email_address_id ⇒ String
The identifier of the email address.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
Instance Attribute Details
#alias_configuration ⇒ Types::AliasConfiguration
Configuration object that specifies which alias relationship to remove. The alias association must currently exist between the primary email address and the specified alias email address.
11181 11182 11183 11184 11185 11186 11187 11188 |
# File 'lib/aws-sdk-connect/types.rb', line 11181 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
11181 11182 11183 11184 11185 11186 11187 11188 |
# File 'lib/aws-sdk-connect/types.rb', line 11181 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_address_id ⇒ String
The identifier of the email address.
11181 11182 11183 11184 11185 11186 11187 11188 |
# File 'lib/aws-sdk-connect/types.rb', line 11181 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
11181 11182 11183 11184 11185 11186 11187 11188 |
# File 'lib/aws-sdk-connect/types.rb', line 11181 class DisassociateEmailAddressAliasRequest < Struct.new( :email_address_id, :instance_id, :alias_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |