Class: Aws::Connect::Types::DisassociateEmailAddressAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_configurationTypes::AliasConfiguration

Configuration object that specifies which alias relationship to remove. The alias association must currently exist between the primary email address and the specified alias email address.



11064
11065
11066
11067
11068
11069
11070
11071
# File 'lib/aws-sdk-connect/types.rb', line 11064

class DisassociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


11064
11065
11066
11067
11068
11069
11070
11071
# File 'lib/aws-sdk-connect/types.rb', line 11064

class DisassociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#email_address_idString

The identifier of the email address.

Returns:

  • (String)


11064
11065
11066
11067
11068
11069
11070
11071
# File 'lib/aws-sdk-connect/types.rb', line 11064

class DisassociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


11064
11065
11066
11067
11068
11069
11070
11071
# File 'lib/aws-sdk-connect/types.rb', line 11064

class DisassociateEmailAddressAliasRequest < Struct.new(
  :email_address_id,
  :instance_id,
  :alias_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end