Class: Aws::Connect::Types::DisassociateLambdaFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateLambdaFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function being disassociated.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
12210 12211 12212 12213 12214 12215 12216 |
# File 'lib/aws-sdk-connect/types.rb', line 12210 class DisassociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function being disassociated.
12210 12211 12212 12213 12214 12215 12216 |
# File 'lib/aws-sdk-connect/types.rb', line 12210 class DisassociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance..
12210 12211 12212 12213 12214 12215 12216 |
# File 'lib/aws-sdk-connect/types.rb', line 12210 class DisassociateLambdaFunctionRequest < Struct.new( :instance_id, :function_arn, :client_token) SENSITIVE = [] include Aws::Structure end |