Class: Aws::Connect::Types::DisassociateQueueEmailAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateQueueEmailAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#email_addresses_id ⇒ Array<String>
List of email address identifiers to disassociate from the queue.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#queue_id ⇒ String
The identifier for the queue.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
12191 12192 12193 12194 12195 12196 12197 12198 |
# File 'lib/aws-sdk-connect/types.rb', line 12191 class DisassociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_addresses_id ⇒ Array<String>
List of email address identifiers to disassociate from the queue. These are the unique identifiers of email addresses that should no longer be routed to this queue.
12191 12192 12193 12194 12195 12196 12197 12198 |
# File 'lib/aws-sdk-connect/types.rb', line 12191 class DisassociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
12191 12192 12193 12194 12195 12196 12197 12198 |
# File 'lib/aws-sdk-connect/types.rb', line 12191 class DisassociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
12191 12192 12193 12194 12195 12196 12197 12198 |
# File 'lib/aws-sdk-connect/types.rb', line 12191 class DisassociateQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :email_addresses_id, :client_token) SENSITIVE = [] include Aws::Structure end |