Class: Aws::Connect::Types::DisassociateQueueEmailAddressesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


11766
11767
11768
11769
11770
11771
11772
11773
# File 'lib/aws-sdk-connect/types.rb', line 11766

class DisassociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#email_addresses_idArray<String>

List of email address identifiers to disassociate from the queue. These are the unique identifiers of email addresses that should no longer be routed to this queue.

Returns:

  • (Array<String>)


11766
11767
11768
11769
11770
11771
11772
11773
# File 'lib/aws-sdk-connect/types.rb', line 11766

class DisassociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


11766
11767
11768
11769
11770
11771
11772
11773
# File 'lib/aws-sdk-connect/types.rb', line 11766

class DisassociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The identifier for the queue.

Returns:

  • (String)


11766
11767
11768
11769
11770
11771
11772
11773
# File 'lib/aws-sdk-connect/types.rb', line 11766

class DisassociateQueueEmailAddressesRequest < Struct.new(
  :instance_id,
  :queue_id,
  :email_addresses_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end