Class: Aws::Connect::Types::DisassociateRoutingProfileQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateRoutingProfileQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#manual_assignment_queue_references ⇒ Array<Types::RoutingProfileQueueReference>
The manual assignment queues to disassociate with this routing profile.
-
#queue_references ⇒ Array<Types::RoutingProfileQueueReference>
The queues to disassociate from this routing profile.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
12386 12387 12388 12389 12390 12391 12392 12393 |
# File 'lib/aws-sdk-connect/types.rb', line 12386 class DisassociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_references, :manual_assignment_queue_references) SENSITIVE = [] include Aws::Structure end |
#manual_assignment_queue_references ⇒ Array<Types::RoutingProfileQueueReference>
The manual assignment queues to disassociate with this routing profile.
12386 12387 12388 12389 12390 12391 12392 12393 |
# File 'lib/aws-sdk-connect/types.rb', line 12386 class DisassociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_references, :manual_assignment_queue_references) SENSITIVE = [] include Aws::Structure end |
#queue_references ⇒ Array<Types::RoutingProfileQueueReference>
The queues to disassociate from this routing profile.
12386 12387 12388 12389 12390 12391 12392 12393 |
# File 'lib/aws-sdk-connect/types.rb', line 12386 class DisassociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_references, :manual_assignment_queue_references) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
12386 12387 12388 12389 12390 12391 12392 12393 |
# File 'lib/aws-sdk-connect/types.rb', line 12386 class DisassociateRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :queue_references, :manual_assignment_queue_references) SENSITIVE = [] include Aws::Structure end |