Class: Aws::Connect::Types::DisassociateSecurityKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateSecurityKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
12054 12055 12056 12057 12058 12059 12060 |
# File 'lib/aws-sdk-connect/types.rb', line 12054 class DisassociateSecurityKeyRequest < Struct.new( :instance_id, :association_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
12054 12055 12056 12057 12058 12059 12060 |
# File 'lib/aws-sdk-connect/types.rb', line 12054 class DisassociateSecurityKeyRequest < Struct.new( :instance_id, :association_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
12054 12055 12056 12057 12058 12059 12060 |
# File 'lib/aws-sdk-connect/types.rb', line 12054 class DisassociateSecurityKeyRequest < Struct.new( :instance_id, :association_id, :client_token) SENSITIVE = [] include Aws::Structure end |