Class: Aws::Connect::Types::DisassociateWorkspaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::DisassociateWorkspaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_list ⇒ Array<Types::FailedBatchAssociationSummary>
A list of resources that failed to be disassociated from the workspace, including error details.
-
#successful_list ⇒ Array<Types::SuccessfulBatchAssociationSummary>
A list of resources that were successfully disassociated from the workspace.
Instance Attribute Details
#failed_list ⇒ Array<Types::FailedBatchAssociationSummary>
A list of resources that failed to be disassociated from the workspace, including error details.
11163 11164 11165 11166 11167 11168 |
# File 'lib/aws-sdk-connect/types.rb', line 11163 class DisassociateWorkspaceResponse < Struct.new( :successful_list, :failed_list) SENSITIVE = [] include Aws::Structure end |
#successful_list ⇒ Array<Types::SuccessfulBatchAssociationSummary>
A list of resources that were successfully disassociated from the workspace.
11163 11164 11165 11166 11167 11168 |
# File 'lib/aws-sdk-connect/types.rb', line 11163 class DisassociateWorkspaceResponse < Struct.new( :successful_list, :failed_list) SENSITIVE = [] include Aws::Structure end |