Class: Aws::Connect::Types::EmailAddressConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EmailAddressConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Configuration object that specifies an email address to be associated with a queue. This configuration contains the identifier of the email address that should be linked to the queue for routing email contacts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_address_id ⇒ String
The identifier of the email address that should be associated with the queue.
Instance Attribute Details
#email_address_id ⇒ String
The identifier of the email address that should be associated with the queue. This email address must already exist in the Connect Customer instance and will be used to route incoming email contacts to the specified queue.
11849 11850 11851 11852 11853 |
# File 'lib/aws-sdk-connect/types.rb', line 11849 class EmailAddressConfig < Struct.new( :email_address_id) SENSITIVE = [] include Aws::Structure end |