Class: Aws::Connect::Types::EmailAddressSearchFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EmailAddressSearchFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Filters to be applied to search results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tag_filter ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the
SearchFilter.
Instance Attribute Details
#tag_filter ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the SearchFilter. This accepts an OR of AND (List of List) input where:
-
Top level list specifies conditions that need to be applied with
ORoperator -
Inner list specifies conditions that need to be applied with
ANDoperator.
11287 11288 11289 11290 11291 |
# File 'lib/aws-sdk-connect/types.rb', line 11287 class EmailAddressSearchFilter < Struct.new( :tag_filter) SENSITIVE = [] include Aws::Structure end |