Class: Aws::Connect::Types::EmailAddressSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EmailAddressSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Summary information about an email address associated with a queue. Contains the essential details needed to identify and manage the email address routing configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the email address associated with the queue.
-
#id ⇒ String
The unique identifier of the email address associated with the queue.
-
#is_default_outbound_email ⇒ Boolean
Indicates whether this email address is configured as the default outbound email address for the queue.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the email address associated with the queue.
12309 12310 12311 12312 12313 12314 12315 |
# File 'lib/aws-sdk-connect/types.rb', line 12309 class EmailAddressSummary < Struct.new( :id, :arn, :is_default_outbound_email) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the email address associated with the queue.
12309 12310 12311 12312 12313 12314 12315 |
# File 'lib/aws-sdk-connect/types.rb', line 12309 class EmailAddressSummary < Struct.new( :id, :arn, :is_default_outbound_email) SENSITIVE = [] include Aws::Structure end |
#is_default_outbound_email ⇒ Boolean
Indicates whether this email address is configured as the default outbound email address for the queue. When set to true, this email address is used as the default sender for outbound email contacts from this queue.
12309 12310 12311 12312 12313 12314 12315 |
# File 'lib/aws-sdk-connect/types.rb', line 12309 class EmailAddressSummary < Struct.new( :id, :arn, :is_default_outbound_email) SENSITIVE = [] include Aws::Structure end |