Class: Aws::Connect::Types::EmailAddressSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Summary information about an email address associated with a queue. Contains the essential details needed to identify and manage the email address routing configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the email address associated with the queue.

Returns:

  • (String)


12292
12293
12294
12295
12296
12297
12298
# File 'lib/aws-sdk-connect/types.rb', line 12292

class EmailAddressSummary < Struct.new(
  :id,
  :arn,
  :is_default_outbound_email)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the email address associated with the queue.

Returns:

  • (String)


12292
12293
12294
12295
12296
12297
12298
# File 'lib/aws-sdk-connect/types.rb', line 12292

class EmailAddressSummary < Struct.new(
  :id,
  :arn,
  :is_default_outbound_email)
  SENSITIVE = []
  include Aws::Structure
end

#is_default_outbound_emailBoolean

Indicates whether this email address is configured as the default outbound email address for the queue. When set to true, this email address is used as the default sender for outbound email contacts from this queue.

Returns:

  • (Boolean)


12292
12293
12294
12295
12296
12297
12298
# File 'lib/aws-sdk-connect/types.rb', line 12292

class EmailAddressSummary < Struct.new(
  :id,
  :arn,
  :is_default_outbound_email)
  SENSITIVE = []
  include Aws::Structure
end