Class: Aws::Connect::Types::EncryptionConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The encryption configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_typeString

The type of encryption.

Returns:

  • (String)


12853
12854
12855
12856
12857
12858
# File 'lib/aws-sdk-connect/types.rb', line 12853

class EncryptionConfig < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The full ARN of the encryption key.

Be sure to provide the full ARN of the encryption key, not just the ID.

Connect Customer supports only KMS keys with the default key spec of SYMMETRIC_DEFAULT .

Returns:

  • (String)


12853
12854
12855
12856
12857
12858
# File 'lib/aws-sdk-connect/types.rb', line 12853

class EncryptionConfig < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end