Class: Aws::Connect::Types::EncryptionConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The encryption configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_typeString

The type of encryption.

Returns:

  • (String)


12549
12550
12551
12552
12553
12554
# File 'lib/aws-sdk-connect/types.rb', line 12549

class EncryptionConfig < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The full ARN of the encryption key.

Be sure to provide the full ARN of the encryption key, not just the ID.

Connect Customer supports only KMS keys with the default key spec of SYMMETRIC_DEFAULT .

Returns:

  • (String)


12549
12550
12551
12552
12553
12554
# File 'lib/aws-sdk-connect/types.rb', line 12549

class EncryptionConfig < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end