Class: Aws::Connect::Types::EvaluateDataTableValuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluateDataTableValuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_table_id ⇒ String
The unique identifier for the data table.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of data table values to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
-
#time_zone ⇒ String
Optional IANA timezone identifier to use when resolving time based dynamic values.
-
#values ⇒ Array<Types::DataTableValueEvaluationSet>
A list of value evaluation sets specifying which primary values and attributes to evaluate.
Instance Attribute Details
#data_table_id ⇒ String
The unique identifier for the data table. Must also accept the table ARN with or without a version alias.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data table values to return in one page of results.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
Optional IANA timezone identifier to use when resolving time based dynamic values. Defaults to the data table time zone if not provided.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<Types::DataTableValueEvaluationSet>
A list of value evaluation sets specifying which primary values and attributes to evaluate.
12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 |
# File 'lib/aws-sdk-connect/types.rb', line 12098 class EvaluateDataTableValuesRequest < Struct.new( :instance_id, :data_table_id, :values, :time_zone, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |