Class: Aws::Connect::Types::EvaluationFormItemEnablementCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormItemEnablementCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A condition for item enablement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operands ⇒ Array<Types::EvaluationFormItemEnablementConditionOperand>
Operands of the enablement condition.
-
#operator ⇒ String
The operator to be used to be applied to operands if more than one provided.
Instance Attribute Details
#operands ⇒ Array<Types::EvaluationFormItemEnablementConditionOperand>
Operands of the enablement condition.
11906 11907 11908 11909 11910 11911 |
# File 'lib/aws-sdk-connect/types.rb', line 11906 class EvaluationFormItemEnablementCondition < Struct.new( :operands, :operator) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ String
The operator to be used to be applied to operands if more than one provided.
11906 11907 11908 11909 11910 11911 |
# File 'lib/aws-sdk-connect/types.rb', line 11906 class EvaluationFormItemEnablementCondition < Struct.new( :operands, :operator) SENSITIVE = [] include Aws::Structure end |