Class: Aws::Connect::Types::EvaluationFormMetricConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormMetricConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the metric configuration for an evaluation form question. Use this to associate a business outcome metric with a question.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metric.
-
#metric_type ⇒ String
The type of metric.
Instance Attribute Details
#metric_name ⇒ String
The name of the metric. Valid values are:
-
SALE_SUCCESS– Sale success. -
CSAT– Customer satisfaction. -
CHURN_PROPENSITY– Churn propensity. -
SELF_SERVICE_SUCCESS– Self-service success. -
PARTIAL_SELF_SERVICE_SUCCESS– Partial self-service success.
13971 13972 13973 13974 13975 13976 |
# File 'lib/aws-sdk-connect/types.rb', line 13971 class EvaluationFormMetricConfiguration < Struct.new( :metric_type, :metric_name) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
The type of metric. Currently, only BUSINESS_OUTCOME is supported.
13971 13972 13973 13974 13975 13976 |
# File 'lib/aws-sdk-connect/types.rb', line 13971 class EvaluationFormMetricConfiguration < Struct.new( :metric_type, :metric_name) SENSITIVE = [] include Aws::Structure end |