Class: Aws::Connect::Types::EvaluationFormNumericQuestionOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormNumericQuestionOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the option range used for scoring in numeric questions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automatic_fail ⇒ Boolean
The flag to mark the option as automatic fail.
-
#automatic_fail_configuration ⇒ Types::AutomaticFailConfiguration
A configuration for automatic fail.
-
#max_value ⇒ Integer
The maximum answer value of the range option.
-
#min_value ⇒ Integer
The minimum answer value of the range option.
-
#points_configuration ⇒ Types::QuestionOptionPointsConfiguration
The points configuration for point-based scoring.
-
#score ⇒ Integer
The score assigned to answer values within the range option.
Instance Attribute Details
#automatic_fail ⇒ Boolean
The flag to mark the option as automatic fail. If an automatic fail answer is provided, the overall evaluation gets a score of 0.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |
#automatic_fail_configuration ⇒ Types::AutomaticFailConfiguration
A configuration for automatic fail.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |
#max_value ⇒ Integer
The maximum answer value of the range option.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |
#min_value ⇒ Integer
The minimum answer value of the range option.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |
#points_configuration ⇒ Types::QuestionOptionPointsConfiguration
The points configuration for point-based scoring.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |
#score ⇒ Integer
The score assigned to answer values within the range option.
13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 |
# File 'lib/aws-sdk-connect/types.rb', line 13238 class EvaluationFormNumericQuestionOption < Struct.new( :min_value, :max_value, :score, :automatic_fail, :automatic_fail_configuration, :points_configuration) SENSITIVE = [] include Aws::Structure end |