Class: Aws::Connect::Types::EvaluationFormQuestion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormQuestion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a question from an evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
-
#instructions ⇒ String
The instructions of the section.
-
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
-
#question_type ⇒ String
The type of the question.
-
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question.
-
#ref_id ⇒ String
The identifier of the question.
-
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
-
#title ⇒ String
The title of the question.
-
#weight ⇒ Float
The scoring weight of the section.
Instance Attribute Details
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#instructions ⇒ String
The instructions of the section.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type ⇒ String
The type of the question.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question. Text questions do not have to define question type properties.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#ref_id ⇒ String
The identifier of the question. An identifier must be unique within the evaluation form.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the question.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Float
The scoring weight of the section.
14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 |
# File 'lib/aws-sdk-connect/types.rb', line 14026 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |