Class: Aws::Connect::Types::EvaluationFormQuestion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a question from an evaluation form.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enablementTypes::EvaluationFormItemEnablementConfiguration

A question conditional enablement.



13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instructionsString

The instructions of the section.

Returns:

  • (String)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#not_applicable_enabledBoolean

The flag to enable not applicable answers to the question.

Returns:

  • (Boolean)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_typeString

The type of the question.

Returns:

  • (String)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#question_type_propertiesTypes::EvaluationFormQuestionTypeProperties

The properties of the type of question. Text questions do not have to define question type properties.



13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the question. An identifier must be unique within the evaluation form.

Returns:

  • (String)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scoring_configurationTypes::EvaluationFormQuestionScoringConfiguration

The scoring configuration of the question.



13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the question.

Returns:

  • (String)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The scoring weight of the section.

Returns:

  • (Float)


13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/aws-sdk-connect/types.rb', line 13637

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight,
  :scoring_configuration)
  SENSITIVE = []
  include Aws::Structure
end