Class: Aws::Connect::Types::EvaluationFormQuestion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormQuestion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a question from an evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
-
#instructions ⇒ String
The instructions of the section.
-
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
-
#question_type ⇒ String
The type of the question.
-
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question.
-
#ref_id ⇒ String
The identifier of the question.
-
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
-
#title ⇒ String
The title of the question.
-
#weight ⇒ Float
The scoring weight of the section.
Instance Attribute Details
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#instructions ⇒ String
The instructions of the section.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type ⇒ String
The type of the question.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question. Text questions do not have to define question type properties.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#ref_id ⇒ String
The identifier of the question. An identifier must be unique within the evaluation form.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the question.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Float
The scoring weight of the section.
13466 13467 13468 13469 13470 13471 13472 13473 13474 13475 13476 13477 13478 |
# File 'lib/aws-sdk-connect/types.rb', line 13466 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration) SENSITIVE = [] include Aws::Structure end |