Class: Aws::Connect::Types::EvaluationFormQuestion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a question from an evaluation form.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enablementTypes::EvaluationFormItemEnablementConfiguration

A question conditional enablement.



12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#instructionsString

The instructions of the section.

Returns:

  • (String)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#not_applicable_enabledBoolean

The flag to enable not applicable answers to the question.

Returns:

  • (Boolean)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#question_typeString

The type of the question.

Returns:

  • (String)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#question_type_propertiesTypes::EvaluationFormQuestionTypeProperties

The properties of the type of question. Text questions do not have to define question type properties.



12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the question. An identifier must be unique within the evaluation form.

Returns:

  • (String)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the question.

Returns:

  • (String)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The scoring weight of the section.

Returns:

  • (Float)


12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
# File 'lib/aws-sdk-connect/types.rb', line 12266

class EvaluationFormQuestion < Struct.new(
  :title,
  :instructions,
  :ref_id,
  :not_applicable_enabled,
  :question_type,
  :question_type_properties,
  :enablement,
  :weight)
  SENSITIVE = []
  include Aws::Structure
end