Class: Aws::Connect::Types::EvaluationFormQuestion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormQuestion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a question from an evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
-
#instructions ⇒ String
The instructions of the section.
-
#metric_configuration ⇒ Types::EvaluationFormMetricConfiguration
The metric configuration for the question.
-
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
-
#question_type ⇒ String
The type of the question.
-
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question.
-
#ref_id ⇒ String
The identifier of the question.
-
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
-
#title ⇒ String
The title of the question.
-
#weight ⇒ Float
The scoring weight of the section.
Instance Attribute Details
#enablement ⇒ Types::EvaluationFormItemEnablementConfiguration
A question conditional enablement.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#instructions ⇒ String
The instructions of the section.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#metric_configuration ⇒ Types::EvaluationFormMetricConfiguration
The metric configuration for the question. Use this to associate a business outcome metric with the question.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#not_applicable_enabled ⇒ Boolean
The flag to enable not applicable answers to the question.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type ⇒ String
The type of the question.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#question_type_properties ⇒ Types::EvaluationFormQuestionTypeProperties
The properties of the type of question. Text questions do not have to define question type properties.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#ref_id ⇒ String
The identifier of the question. An identifier must be unique within the evaluation form.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#scoring_configuration ⇒ Types::EvaluationFormQuestionScoringConfiguration
The scoring configuration of the question.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the question.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Float
The scoring weight of the section.
14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 |
# File 'lib/aws-sdk-connect/types.rb', line 14237 class EvaluationFormQuestion < Struct.new( :title, :instructions, :ref_id, :not_applicable_enabled, :question_type, :question_type_properties, :enablement, :weight, :scoring_configuration, :metric_configuration) SENSITIVE = [] include Aws::Structure end |