Class: Aws::Connect::Types::EvaluationFormQuestionTypeProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluationFormQuestionTypeProperties is a union - when making an API calls you must set exactly one of the members.

Note:

EvaluationFormQuestionTypeProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormQuestionTypeProperties corresponding to the set member.

Information about properties for a question in an evaluation form. The question type properties must be either for a numeric question or a single select question.

Direct Known Subclasses

MultiSelect, Numeric, SingleSelect, Text, Unknown

Defined Under Namespace

Classes: MultiSelect, Numeric, SingleSelect, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#multi_selectTypes::EvaluationFormMultiSelectQuestionProperties

Properties for multi-select question types.



13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-connect/types.rb', line 13151

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#numericTypes::EvaluationFormNumericQuestionProperties

The properties of the numeric question.



13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-connect/types.rb', line 13151

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#single_selectTypes::EvaluationFormSingleSelectQuestionProperties

The properties of the numeric question.



13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-connect/types.rb', line 13151

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#textTypes::EvaluationFormTextQuestionProperties

The properties of the text question.



13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
# File 'lib/aws-sdk-connect/types.rb', line 13151

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



13151
13152
13153
# File 'lib/aws-sdk-connect/types.rb', line 13151

def unknown
  @unknown
end