Class: Aws::Connect::Types::EvaluationFormQuestionTypeProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluationFormQuestionTypeProperties is a union - when making an API calls you must set exactly one of the members.

Note:

EvaluationFormQuestionTypeProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormQuestionTypeProperties corresponding to the set member.

Information about properties for a question in an evaluation form. The question type properties must be either for a numeric question or a single select question.

Direct Known Subclasses

MultiSelect, Numeric, SingleSelect, Text, Unknown

Defined Under Namespace

Classes: MultiSelect, Numeric, SingleSelect, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#multi_selectTypes::EvaluationFormMultiSelectQuestionProperties

Properties for multi-select question types.



12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-connect/types.rb', line 12319

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#numericTypes::EvaluationFormNumericQuestionProperties

The properties of the numeric question.



12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-connect/types.rb', line 12319

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#single_selectTypes::EvaluationFormSingleSelectQuestionProperties

The properties of the numeric question.



12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-connect/types.rb', line 12319

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#textTypes::EvaluationFormTextQuestionProperties

The properties of the text question.



12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-connect/types.rb', line 12319

class EvaluationFormQuestionTypeProperties < Struct.new(
  :numeric,
  :single_select,
  :text,
  :multi_select,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Numeric < EvaluationFormQuestionTypeProperties; end
  class SingleSelect < EvaluationFormQuestionTypeProperties; end
  class Text < EvaluationFormQuestionTypeProperties; end
  class MultiSelect < EvaluationFormQuestionTypeProperties; end
  class Unknown < EvaluationFormQuestionTypeProperties; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



12319
12320
12321
# File 'lib/aws-sdk-connect/types.rb', line 12319

def unknown
  @unknown
end