Class: Aws::Connect::Types::EvaluationFormQuestionTypeProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormQuestionTypeProperties
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
EvaluationFormQuestionTypeProperties is a union - when making an API calls you must set exactly one of the members.
EvaluationFormQuestionTypeProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormQuestionTypeProperties corresponding to the set member.
Information about properties for a question in an evaluation form. The question type properties must be either for a numeric question or a single select question.
Direct Known Subclasses
Defined Under Namespace
Classes: MultiSelect, Numeric, SingleSelect, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#multi_select ⇒ Types::EvaluationFormMultiSelectQuestionProperties
Properties for multi-select question types.
-
#numeric ⇒ Types::EvaluationFormNumericQuestionProperties
The properties of the numeric question.
-
#single_select ⇒ Types::EvaluationFormSingleSelectQuestionProperties
The properties of the numeric question.
-
#text ⇒ Types::EvaluationFormTextQuestionProperties
The properties of the text question.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#multi_select ⇒ Types::EvaluationFormMultiSelectQuestionProperties
Properties for multi-select question types.
12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-connect/types.rb', line 12866 class EvaluationFormQuestionTypeProperties < Struct.new( :numeric, :single_select, :text, :multi_select, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Numeric < EvaluationFormQuestionTypeProperties; end class SingleSelect < EvaluationFormQuestionTypeProperties; end class Text < EvaluationFormQuestionTypeProperties; end class MultiSelect < EvaluationFormQuestionTypeProperties; end class Unknown < EvaluationFormQuestionTypeProperties; end end |
#numeric ⇒ Types::EvaluationFormNumericQuestionProperties
The properties of the numeric question.
12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-connect/types.rb', line 12866 class EvaluationFormQuestionTypeProperties < Struct.new( :numeric, :single_select, :text, :multi_select, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Numeric < EvaluationFormQuestionTypeProperties; end class SingleSelect < EvaluationFormQuestionTypeProperties; end class Text < EvaluationFormQuestionTypeProperties; end class MultiSelect < EvaluationFormQuestionTypeProperties; end class Unknown < EvaluationFormQuestionTypeProperties; end end |
#single_select ⇒ Types::EvaluationFormSingleSelectQuestionProperties
The properties of the numeric question.
12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-connect/types.rb', line 12866 class EvaluationFormQuestionTypeProperties < Struct.new( :numeric, :single_select, :text, :multi_select, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Numeric < EvaluationFormQuestionTypeProperties; end class SingleSelect < EvaluationFormQuestionTypeProperties; end class Text < EvaluationFormQuestionTypeProperties; end class MultiSelect < EvaluationFormQuestionTypeProperties; end class Unknown < EvaluationFormQuestionTypeProperties; end end |
#text ⇒ Types::EvaluationFormTextQuestionProperties
The properties of the text question.
12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 12877 12878 12879 12880 12881 |
# File 'lib/aws-sdk-connect/types.rb', line 12866 class EvaluationFormQuestionTypeProperties < Struct.new( :numeric, :single_select, :text, :multi_select, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Numeric < EvaluationFormQuestionTypeProperties; end class SingleSelect < EvaluationFormQuestionTypeProperties; end class Text < EvaluationFormQuestionTypeProperties; end class MultiSelect < EvaluationFormQuestionTypeProperties; end class Unknown < EvaluationFormQuestionTypeProperties; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12866 12867 12868 |
# File 'lib/aws-sdk-connect/types.rb', line 12866 def unknown @unknown end |