Class: Aws::Connect::Types::EvaluationFormSection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a section from an evaluation form. A section can contain sections and/or questions. Evaluation forms can only contain sections and subsections (two level nesting).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instructionsString

The instructions of the section.

Returns:

  • (String)


13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#is_excluded_from_scoringBoolean

The flag to exclude the section from scoring.

Returns:

  • (Boolean)


13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#itemsArray<Types::EvaluationFormItem>

The items of the section.

Returns:



13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#ref_idString

The identifier of the section. An identifier must be unique within the evaluation form.

Returns:

  • (String)


13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#score_thresholdsArray<Types::EvaluationFormScoreThreshold>

The score thresholds for performance categories.



13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the section.

Returns:

  • (String)


13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The scoring weight of the section.

Returns:

  • (Float)


13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
# File 'lib/aws-sdk-connect/types.rb', line 13664

class EvaluationFormSection < Struct.new(
  :title,
  :ref_id,
  :instructions,
  :items,
  :weight,
  :is_excluded_from_scoring,
  :score_thresholds)
  SENSITIVE = []
  include Aws::Structure
end