Class: Aws::Connect::Types::EvaluationFormSingleSelectQuestionAutomation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the automation configuration in single select questions. Automation options are evaluated in order, and the first matched option is applied. If no automation option matches, and there is a default option, then the default option is applied.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#answer_sourceTypes::EvaluationFormQuestionAutomationAnswerSource

Automation answer source.



13409
13410
13411
13412
13413
13414
13415
# File 'lib/aws-sdk-connect/types.rb', line 13409

class EvaluationFormSingleSelectQuestionAutomation < Struct.new(
  :options,
  :default_option_ref_id,
  :answer_source)
  SENSITIVE = []
  include Aws::Structure
end

#default_option_ref_idString

The identifier of the default answer option, when none of the automation options match the criteria.

Returns:

  • (String)


13409
13410
13411
13412
13413
13414
13415
# File 'lib/aws-sdk-connect/types.rb', line 13409

class EvaluationFormSingleSelectQuestionAutomation < Struct.new(
  :options,
  :default_option_ref_id,
  :answer_source)
  SENSITIVE = []
  include Aws::Structure
end

#optionsArray<Types::EvaluationFormSingleSelectQuestionAutomationOption>

The automation options of the single select question.



13409
13410
13411
13412
13413
13414
13415
# File 'lib/aws-sdk-connect/types.rb', line 13409

class EvaluationFormSingleSelectQuestionAutomation < Struct.new(
  :options,
  :default_option_ref_id,
  :answer_source)
  SENSITIVE = []
  include Aws::Structure
end