Class: Aws::Connect::Types::EvaluationFormSingleSelectQuestionAutomationOption

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluationFormSingleSelectQuestionAutomationOption is a union - when making an API calls you must set exactly one of the members.

Note:

EvaluationFormSingleSelectQuestionAutomationOption is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationFormSingleSelectQuestionAutomationOption corresponding to the set member.

Information about the automation option of a single select question.

Defined Under Namespace

Classes: RuleCategory, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rule_categoryTypes::SingleSelectQuestionRuleCategoryAutomation

The automation option based on a rule category for the single select question.



13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
# File 'lib/aws-sdk-connect/types.rb', line 13862

class EvaluationFormSingleSelectQuestionAutomationOption < Struct.new(
  :rule_category,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RuleCategory < EvaluationFormSingleSelectQuestionAutomationOption; end
  class Unknown < EvaluationFormSingleSelectQuestionAutomationOption; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



13862
13863
13864
# File 'lib/aws-sdk-connect/types.rb', line 13862

def unknown
  @unknown
end