Class: Aws::Connect::Types::EvaluationFormValidationFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationFormValidationFinding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a finding from the evaluation form validation process. Each finding identifies a structural issue or quality improvement opportunity for the evaluation form.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the validation issue.
-
#issue_code ⇒ String
A code that identifies the type of validation issue found.
-
#items ⇒ Array<Types::EvaluationFormValidationFindingItem>
A list of evaluation form items affected by this finding.
-
#severity ⇒ String
The severity of the finding.
-
#suggestion ⇒ String
A suggested fix for the validation issue.
Instance Attribute Details
#description ⇒ String
A description of the validation issue.
13930 13931 13932 13933 13934 13935 13936 13937 13938 |
# File 'lib/aws-sdk-connect/types.rb', line 13930 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#issue_code ⇒ String
A code that identifies the type of validation issue found.
13930 13931 13932 13933 13934 13935 13936 13937 13938 |
# File 'lib/aws-sdk-connect/types.rb', line 13930 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::EvaluationFormValidationFindingItem>
A list of evaluation form items affected by this finding.
13930 13931 13932 13933 13934 13935 13936 13937 13938 |
# File 'lib/aws-sdk-connect/types.rb', line 13930 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the finding. Valid values: ‘WARNING`, `ERROR`.
13930 13931 13932 13933 13934 13935 13936 13937 13938 |
# File 'lib/aws-sdk-connect/types.rb', line 13930 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |
#suggestion ⇒ String
A suggested fix for the validation issue.
13930 13931 13932 13933 13934 13935 13936 13937 13938 |
# File 'lib/aws-sdk-connect/types.rb', line 13930 class EvaluationFormValidationFinding < Struct.new( :issue_code, :items, :description, :suggestion, :severity) SENSITIVE = [] include Aws::Structure end |