Class: Aws::Connect::Types::EvaluationReviewRequestComment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationReviewRequestComment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A comment provided when requesting an evaluation review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ String
The text content of the review request comment.
-
#created_by ⇒ String
The user who created the evaluation review request comment.
-
#created_time ⇒ Time
The timestamp when the evaluation review request comment was created.
Instance Attribute Details
#comment ⇒ String
The text content of the review request comment.
13798 13799 13800 13801 13802 13803 13804 |
# File 'lib/aws-sdk-connect/types.rb', line 13798 class EvaluationReviewRequestComment < Struct.new( :comment, :created_time, :created_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the evaluation review request comment.
13798 13799 13800 13801 13802 13803 13804 |
# File 'lib/aws-sdk-connect/types.rb', line 13798 class EvaluationReviewRequestComment < Struct.new( :comment, :created_time, :created_by) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the evaluation review request comment was created.
13798 13799 13800 13801 13802 13803 13804 |
# File 'lib/aws-sdk-connect/types.rb', line 13798 class EvaluationReviewRequestComment < Struct.new( :comment, :created_time, :created_by) SENSITIVE = [] include Aws::Structure end |