Class: Aws::Connect::Types::EvaluationSearchMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationSearchMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Metadata information about an evaluation search.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
-
#acknowledged_time ⇒ Time
When the evaluation was acknowledged by the agent.
-
#acknowledger_comment ⇒ String
The comment from the agent when they acknowledged the evaluation.
-
#auto_evaluation_enabled ⇒ Boolean
Whether auto-evaluation is enabled.
-
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
-
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
-
#contact_agent_id ⇒ String
The unique ID of the agent who handled the contact.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#contact_participant_id ⇒ String
Identifier for a contact participant in the evaluation.
-
#contact_participant_role ⇒ String
Role of a contact participant in the evaluation.
-
#earned_points ⇒ Integer
The points earned for the evaluation.
-
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the person who evaluated the contact.
-
#max_base_point ⇒ Integer
The maximum base points possible for the evaluation.
-
#performance_category ⇒ String
The performance category for the evaluation score.
-
#review_id ⇒ String
Identifier for the review.
-
#sampling_job_id ⇒ String
Identifier of the sampling job.
-
#score_automatic_fail ⇒ Boolean
The flag that marks the item as automatic fail.
-
#score_not_applicable ⇒ Boolean
The flag to mark the item as not applicable for scoring.
-
#score_percentage ⇒ Float
The total evaluation score expressed as a percentage.
Instance Attribute Details
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#acknowledged_time ⇒ Time
When the evaluation was acknowledged by the agent.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#acknowledger_comment ⇒ String
The comment from the agent when they acknowledged the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_enabled ⇒ Boolean
Whether auto-evaluation is enabled.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_agent_id ⇒ String
The unique ID of the agent who handled the contact.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_participant_id ⇒ String
Identifier for a contact participant in the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_participant_role ⇒ String
Role of a contact participant in the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#earned_points ⇒ Integer
The points earned for the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the person who evaluated the contact.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#max_base_point ⇒ Integer
The maximum base points possible for the evaluation.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#performance_category ⇒ String
The performance category for the evaluation score.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#review_id ⇒ String
Identifier for the review.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#sampling_job_id ⇒ String
Identifier of the sampling job.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_automatic_fail ⇒ Boolean
The flag that marks the item as automatic fail. If the item or a child item gets an automatic fail answer, this flag is true.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_not_applicable ⇒ Boolean
The flag to mark the item as not applicable for scoring.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_percentage ⇒ Float
The total evaluation score expressed as a percentage.
15051 15052 15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 |
# File 'lib/aws-sdk-connect/types.rb', line 15051 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |