Class: Aws::Connect::Types::EvaluationSearchMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Metadata information about an evaluation search.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#acknowledged_byString

The agent who acknowledged the evaluation.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#acknowledged_timeTime

When the evaluation was acknowledged by the agent.

Returns:

  • (Time)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#acknowledger_commentString

The comment from the agent when they acknowledged the evaluation.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#auto_evaluation_enabledBoolean

Whether auto-evaluation is enabled.

Returns:

  • (Boolean)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#auto_evaluation_statusString

The status of the contact auto evaluation.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#calibration_session_idString

The calibration session ID that this evaluation belongs to.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_agent_idString

The unique ID of the agent who handled the contact.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_participant_idString

Identifier for a contact participant in the evaluation.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#contact_participant_roleString

Role of a contact participant in the evaluation.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#earned_pointsInteger

The points earned for the evaluation.

Returns:

  • (Integer)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#evaluator_arnString

The Amazon Resource Name (ARN) of the person who evaluated the contact.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#max_base_pointInteger

The maximum base points possible for the evaluation.

Returns:

  • (Integer)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#performance_categoryString

The performance category for the evaluation score.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#review_idString

Identifier for the review.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#sampling_job_idString

Identifier of the sampling job.

Returns:

  • (String)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_automatic_failBoolean

The flag that marks the item as automatic fail. If the item or a child item gets an automatic fail answer, this flag is true.

Returns:

  • (Boolean)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_not_applicableBoolean

The flag to mark the item as not applicable for scoring.

Returns:

  • (Boolean)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end

#score_percentageFloat

The total evaluation score expressed as a percentage.

Returns:

  • (Float)


14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-connect/types.rb', line 14481

class EvaluationSearchMetadata < Struct.new(
  :contact_id,
  :evaluator_arn,
  :contact_agent_id,
  :calibration_session_id,
  :score_percentage,
  :score_automatic_fail,
  :score_not_applicable,
  :auto_evaluation_enabled,
  :auto_evaluation_status,
  :acknowledged_time,
  :acknowledged_by,
  :acknowledger_comment,
  :sampling_job_id,
  :review_id,
  :contact_participant_role,
  :contact_participant_id,
  :earned_points,
  :max_base_point,
  :performance_category)
  SENSITIVE = []
  include Aws::Structure
end