Class: Aws::Connect::Types::EvaluationSearchMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationSearchMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Metadata information about an evaluation search.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
-
#acknowledged_time ⇒ Time
When the evaluation was acknowledged by the agent.
-
#acknowledger_comment ⇒ String
The comment from the agent when they acknowledged the evaluation.
-
#auto_evaluation_enabled ⇒ Boolean
Whether auto-evaluation is enabled.
-
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
-
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
-
#contact_agent_id ⇒ String
The unique ID of the agent who handled the contact.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#contact_participant_id ⇒ String
Identifier for a contact participant in the evaluation.
-
#contact_participant_role ⇒ String
Role of a contact participant in the evaluation.
-
#earned_points ⇒ Integer
The points earned for the evaluation.
-
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the person who evaluated the contact.
-
#max_base_point ⇒ Integer
The maximum base points possible for the evaluation.
-
#performance_category ⇒ String
The performance category for the evaluation score.
-
#review_id ⇒ String
Identifier for the review.
-
#sampling_job_id ⇒ String
Identifier of the sampling job.
-
#score_automatic_fail ⇒ Boolean
The flag that marks the item as automatic fail.
-
#score_not_applicable ⇒ Boolean
The flag to mark the item as not applicable for scoring.
-
#score_percentage ⇒ Float
The total evaluation score expressed as a percentage.
Instance Attribute Details
#acknowledged_by ⇒ String
The agent who acknowledged the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#acknowledged_time ⇒ Time
When the evaluation was acknowledged by the agent.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#acknowledger_comment ⇒ String
The comment from the agent when they acknowledged the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_enabled ⇒ Boolean
Whether auto-evaluation is enabled.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_agent_id ⇒ String
The unique ID of the agent who handled the contact.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_participant_id ⇒ String
Identifier for a contact participant in the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#contact_participant_role ⇒ String
Role of a contact participant in the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#earned_points ⇒ Integer
The points earned for the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the person who evaluated the contact.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#max_base_point ⇒ Integer
The maximum base points possible for the evaluation.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#performance_category ⇒ String
The performance category for the evaluation score.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#review_id ⇒ String
Identifier for the review.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#sampling_job_id ⇒ String
Identifier of the sampling job.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_automatic_fail ⇒ Boolean
The flag that marks the item as automatic fail. If the item or a child item gets an automatic fail answer, this flag is true.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_not_applicable ⇒ Boolean
The flag to mark the item as not applicable for scoring.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |
#score_percentage ⇒ Float
The total evaluation score expressed as a percentage.
14481 14482 14483 14484 14485 14486 14487 14488 14489 14490 14491 14492 14493 14494 14495 14496 14497 14498 14499 14500 14501 14502 14503 |
# File 'lib/aws-sdk-connect/types.rb', line 14481 class EvaluationSearchMetadata < Struct.new( :contact_id, :evaluator_arn, :contact_agent_id, :calibration_session_id, :score_percentage, :score_automatic_fail, :score_not_applicable, :auto_evaluation_enabled, :auto_evaluation_status, :acknowledged_time, :acknowledged_by, :acknowledger_comment, :sampling_job_id, :review_id, :contact_participant_role, :contact_participant_id, :earned_points, :max_base_point, :performance_category) SENSITIVE = [] include Aws::Structure end |