Class: Aws::Connect::Types::EvaluationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Summary information about a contact evaluation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#acknowledgement ⇒ Types::EvaluationAcknowledgementSummary
Information related to evaluation acknowledgement.
-
#auto_evaluation_enabled ⇒ Boolean
Whether automated evaluation is enabled.
-
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
-
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
-
#contact_participant ⇒ Types::EvaluationContactParticipant
Information about a contact participant in the evaluation.
-
#created_time ⇒ Time
The timestamp for when the evaluation was created.
-
#evaluation_arn ⇒ String
The Amazon Resource Name (ARN) for the contact evaluation resource.
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#evaluation_form_title ⇒ String
A title of the evaluation form.
-
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
-
#evaluation_type ⇒ String
Type of the evaluation.
-
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the evaluation.
-
#last_modified_time ⇒ Time
The timestamp for when the evaluation was last updated.
-
#score ⇒ Types::EvaluationScore
The overall score of the contact evaluation.
-
#status ⇒ String
The status of the contact evaluation.
Instance Attribute Details
#acknowledgement ⇒ Types::EvaluationAcknowledgementSummary
Information related to evaluation acknowledgement.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_enabled ⇒ Boolean
Whether automated evaluation is enabled.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_status ⇒ String
The status of the contact auto evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#calibration_session_id ⇒ String
The calibration session ID that this evaluation belongs to.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#contact_participant ⇒ Types::EvaluationContactParticipant
Information about a contact participant in the evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp for when the evaluation was created.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluation_arn ⇒ String
The Amazon Resource Name (ARN) for the contact evaluation resource.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_title ⇒ String
A title of the evaluation form.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluation_type ⇒ String
Type of the evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#evaluator_arn ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp for when the evaluation was last updated.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#score ⇒ Types::EvaluationScore
The overall score of the contact evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the contact evaluation.
13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 13362 13363 13364 13365 13366 13367 13368 13369 13370 |
# File 'lib/aws-sdk-connect/types.rb', line 13352 class EvaluationSummary < Struct.new( :evaluation_id, :evaluation_arn, :evaluation_form_title, :evaluation_form_id, :calibration_session_id, :status, :auto_evaluation_enabled, :auto_evaluation_status, :evaluator_arn, :score, :acknowledgement, :evaluation_type, :created_time, :last_modified_time, :contact_participant) SENSITIVE = [] include Aws::Structure end |