Class: Aws::Connect::Types::EvaluatorUserUnion

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluatorUserUnion is a union - when making an API calls you must set exactly one of the members.

Represents the entity that performed the action on the evaluation.

Defined Under Namespace

Classes: ConnectUserArn, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connect_user_arnString

Represents the Connect Customer ARN of the user.

Returns:

  • (String)


15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
# File 'lib/aws-sdk-connect/types.rb', line 15052

class EvaluatorUserUnion < Struct.new(
  :connect_user_arn,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ConnectUserArn < EvaluatorUserUnion; end
  class Unknown < EvaluatorUserUnion; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



15052
15053
15054
# File 'lib/aws-sdk-connect/types.rb', line 15052

def unknown
  @unknown
end