Class: Aws::Connect::Types::EvaluatorUserUnion

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluatorUserUnion is a union - when making an API calls you must set exactly one of the members.

Represents the entity that performed the action on the evaluation.

Defined Under Namespace

Classes: ConnectUserArn, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connect_user_arnString

Represents the Connect Customer ARN of the user.

Returns:

  • (String)


14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
# File 'lib/aws-sdk-connect/types.rb', line 14881

class EvaluatorUserUnion < Struct.new(
  :connect_user_arn,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ConnectUserArn < EvaluatorUserUnion; end
  class Unknown < EvaluatorUserUnion; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



14881
14882
14883
# File 'lib/aws-sdk-connect/types.rb', line 14881

def unknown
  @unknown
end