Class: Aws::Connect::Types::EvaluatorUserUnion

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

EvaluatorUserUnion is a union - when making an API calls you must set exactly one of the members.

Represents the entity that performed the action on the evaluation.

Direct Known Subclasses

ConnectUserArn, Unknown

Defined Under Namespace

Classes: ConnectUserArn, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connect_user_arnString

Represents the Connect Customer ARN of the user.

Returns:

  • (String)


14441
14442
14443
14444
14445
14446
14447
14448
14449
14450
# File 'lib/aws-sdk-connect/types.rb', line 14441

class EvaluatorUserUnion < Struct.new(
  :connect_user_arn,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ConnectUserArn < EvaluatorUserUnion; end
  class Unknown < EvaluatorUserUnion; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



14441
14442
14443
# File 'lib/aws-sdk-connect/types.rb', line 14441

def unknown
  @unknown
end