Class: Aws::Connect::Types::EvaluatorUserUnion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluatorUserUnion
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
EvaluatorUserUnion is a union - when making an API calls you must set exactly one of the members.
Represents the entity that performed the action on the evaluation.
Direct Known Subclasses
Defined Under Namespace
Classes: ConnectUserArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connect_user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#connect_user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
14073 14074 14075 14076 14077 14078 14079 14080 14081 14082 |
# File 'lib/aws-sdk-connect/types.rb', line 14073 class EvaluatorUserUnion < Struct.new( :connect_user_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < EvaluatorUserUnion; end class Unknown < EvaluatorUserUnion; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
14073 14074 14075 |
# File 'lib/aws-sdk-connect/types.rb', line 14073 def unknown @unknown end |