Class: Aws::Connect::Types::EvaluatorUserUnion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::EvaluatorUserUnion
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
EvaluatorUserUnion is a union - when making an API calls you must set exactly one of the members.
Represents the entity that performed the action on the evaluation.
Direct Known Subclasses
Defined Under Namespace
Classes: ConnectUserArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connect_user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#connect_user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
13402 13403 13404 13405 13406 13407 13408 13409 13410 13411 |
# File 'lib/aws-sdk-connect/types.rb', line 13402 class EvaluatorUserUnion < Struct.new( :connect_user_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ConnectUserArn < EvaluatorUserUnion; end class Unknown < EvaluatorUserUnion; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
13402 13403 13404 |
# File 'lib/aws-sdk-connect/types.rb', line 13402 def unknown @unknown end |