Class: Aws::Connect::Types::Expiry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Expiry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An object to specify the expiration of a routing step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_in_seconds ⇒ Integer
The number of seconds to wait before expiring the routing step.
-
#expiry_timestamp ⇒ Time
The timestamp indicating when the routing step expires.
Instance Attribute Details
#duration_in_seconds ⇒ Integer
The number of seconds to wait before expiring the routing step.
14299 14300 14301 14302 14303 14304 |
# File 'lib/aws-sdk-connect/types.rb', line 14299 class Expiry < Struct.new( :duration_in_seconds, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#expiry_timestamp ⇒ Time
The timestamp indicating when the routing step expires.
14299 14300 14301 14302 14303 14304 |
# File 'lib/aws-sdk-connect/types.rb', line 14299 class Expiry < Struct.new( :duration_in_seconds, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |