Class: Aws::Connect::Types::ExtractionDefinitionNotFoundBehavior
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ExtractionDefinitionNotFoundBehavior
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The behavior configuration when an extraction definition cannot find the target value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#behavior ⇒ String
The behavior type.
-
#default_value ⇒ String
The default value to use when the behavior is
USE_DEFAULT_VALUE.
Instance Attribute Details
#behavior ⇒ String
The behavior type. USE_DEFAULT_VALUE returns the specified default
value. OMIT excludes the field from the output.
15688 15689 15690 15691 15692 15693 |
# File 'lib/aws-sdk-connect/types.rb', line 15688 class ExtractionDefinitionNotFoundBehavior < Struct.new( :behavior, :default_value) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ String
The default value to use when the behavior is USE_DEFAULT_VALUE.
15688 15689 15690 15691 15692 15693 |
# File 'lib/aws-sdk-connect/types.rb', line 15688 class ExtractionDefinitionNotFoundBehavior < Struct.new( :behavior, :default_value) SENSITIVE = [] include Aws::Structure end |