Class: Aws::Connect::Types::GetAttachedFileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetAttachedFileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Response from GetAttachedFile API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_arn ⇒ String
The resource to which the attached file is (being) uploaded to.
-
#created_by ⇒ Types::CreatedByInfo
Represents the identity that created the file.
-
#creation_time ⇒ String
The time of Creation of the file resource as an ISO timestamp.
-
#download_url_metadata ⇒ Types::DownloadUrlMetadata
URL and expiry to be used when downloading the attached file.
-
#file_arn ⇒ String
The unique identifier of the attached file resource (ARN).
-
#file_id ⇒ String
The unique identifier of the attached file resource.
-
#file_name ⇒ String
A case-sensitive name of the attached file being uploaded.
-
#file_size_in_bytes ⇒ Integer
The size of the attached file in bytes.
-
#file_status ⇒ String
The current status of the attached file.
-
#file_use_case_type ⇒ String
The use case for the file.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#associated_resource_arn ⇒ String
The resource to which the attached file is (being) uploaded to. Cases are the only current supported resource.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::CreatedByInfo
Represents the identity that created the file.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ String
The time of Creation of the file resource as an ISO timestamp. It's
specified in ISO 8601 format: yyyy-MM-ddThh:mm:ss.SSSZ. For
example, 2024-05-03T02:41:28.172Z.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#download_url_metadata ⇒ Types::DownloadUrlMetadata
URL and expiry to be used when downloading the attached file.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_arn ⇒ String
The unique identifier of the attached file resource (ARN).
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_id ⇒ String
The unique identifier of the attached file resource.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
A case-sensitive name of the attached file being uploaded.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_size_in_bytes ⇒ Integer
The size of the attached file in bytes.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_status ⇒ String
The current status of the attached file.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#file_use_case_type ⇒ String
The use case for the file.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this
resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.
15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 15569 15570 15571 15572 15573 |
# File 'lib/aws-sdk-connect/types.rb', line 15559 class GetAttachedFileResponse < Struct.new( :file_arn, :file_id, :creation_time, :file_status, :file_name, :file_size_in_bytes, :associated_resource_arn, :file_use_case_type, :created_by, :download_url_metadata, :tags) SENSITIVE = [] include Aws::Structure end |