Class: Aws::Connect::Types::GetContactMetricsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetContactMetricsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#metrics ⇒ Array<Types::ContactMetricInfo>
A list of contact level metrics to retrieve.Supported metrics include POSITION_IN_QUEUE (the contact’s current position in the queue) and ESTIMATED_WAIT_TIME (the predicted time in seconds until the contact is connected to an agent).
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-connect/types.rb', line 14933 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-connect/types.rb', line 14933 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<Types::ContactMetricInfo>
A list of contact level metrics to retrieve.Supported metrics include POSITION_IN_QUEUE (the contact’s current position in the queue) and ESTIMATED_WAIT_TIME (the predicted time in seconds until the contact is connected to an agent)
14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-connect/types.rb', line 14933 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |