Class: Aws::Connect::Types::GetContactMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact in this instance of Amazon Connect.

Returns:

  • (String)


14630
14631
14632
14633
14634
14635
14636
# File 'lib/aws-sdk-connect/types.rb', line 14630

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


14630
14631
14632
14633
14634
14635
14636
# File 'lib/aws-sdk-connect/types.rb', line 14630

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<Types::ContactMetricInfo>

A list of contact level metrics to retrieve.Supported metrics include POSITION_IN_QUEUE (the contact’s current position in the queue) and ESTIMATED_WAIT_TIME (the predicted time in seconds until the contact is connected to an agent)

Returns:



14630
14631
14632
14633
14634
14635
14636
# File 'lib/aws-sdk-connect/types.rb', line 14630

class GetContactMetricsRequest < Struct.new(
  :instance_id,
  :contact_id,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end