Class: Aws::Connect::Types::GetContactMetricsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetContactMetricsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#metrics ⇒ Array<Types::ContactMetricInfo>
A list of contact-level metrics to retrieve.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Amazon Connect.
13927 13928 13929 13930 13931 13932 13933 |
# File 'lib/aws-sdk-connect/types.rb', line 13927 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
13927 13928 13929 13930 13931 13932 13933 |
# File 'lib/aws-sdk-connect/types.rb', line 13927 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<Types::ContactMetricInfo>
A list of contact-level metrics to retrieve.
13927 13928 13929 13930 13931 13932 13933 |
# File 'lib/aws-sdk-connect/types.rb', line 13927 class GetContactMetricsRequest < Struct.new( :instance_id, :contact_id, :metrics) SENSITIVE = [] include Aws::Structure end |