Class: Aws::Connect::Types::GetContactMetricsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the contact for which metrics were retrieved.

Returns:

  • (String)


13952
13953
13954
13955
13956
13957
13958
# File 'lib/aws-sdk-connect/types.rb', line 13952

class GetContactMetricsResponse < Struct.new(
  :metric_results,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the contact for which metrics were retrieved.

Returns:

  • (String)


13952
13953
13954
13955
13956
13957
13958
# File 'lib/aws-sdk-connect/types.rb', line 13952

class GetContactMetricsResponse < Struct.new(
  :metric_results,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#metric_resultsArray<Types::ContactMetricResult>

A list of metric results containing the calculated values for each requested metric. Each result includes the metric name and its corresponding calculated value.

Returns:



13952
13953
13954
13955
13956
13957
13958
# File 'lib/aws-sdk-connect/types.rb', line 13952

class GetContactMetricsResponse < Struct.new(
  :metric_results,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end