Class: Aws::Connect::Types::GetContactMetricsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetContactMetricsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the contact for which metrics were retrieved.
-
#id ⇒ String
The unique identifier of the contact for which metrics were retrieved.
-
#metric_results ⇒ Array<Types::ContactMetricResult>
A list of metric results containing the calculated values for each requested metric.
Instance Attribute Details
#arn ⇒ String
The ARN of the contact for which metrics were retrieved.
13952 13953 13954 13955 13956 13957 13958 |
# File 'lib/aws-sdk-connect/types.rb', line 13952 class GetContactMetricsResponse < Struct.new( :metric_results, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the contact for which metrics were retrieved.
13952 13953 13954 13955 13956 13957 13958 |
# File 'lib/aws-sdk-connect/types.rb', line 13952 class GetContactMetricsResponse < Struct.new( :metric_results, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#metric_results ⇒ Array<Types::ContactMetricResult>
A list of metric results containing the calculated values for each requested metric. Each result includes the metric name and its corresponding calculated value.
13952 13953 13954 13955 13956 13957 13958 |
# File 'lib/aws-sdk-connect/types.rb', line 13952 class GetContactMetricsResponse < Struct.new( :metric_results, :id, :arn) SENSITIVE = [] include Aws::Structure end |