Class: Aws::Connect::Types::GetCrossRegionRoutingResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetCrossRegionRoutingResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#isolated_regions ⇒ Array<String>
The list of Regions for which cross-region routing is currently disabled (isolated).
Instance Attribute Details
#isolated_regions ⇒ Array<String>
The list of Regions for which cross-region routing is currently disabled (isolated). When a Region appears in this list, contacts originating in that Region will not be routed to agents in other Regions, and agents in that Region will not receive contacts from other Regions.
16470 16471 16472 16473 16474 |
# File 'lib/aws-sdk-connect/types.rb', line 16470 class GetCrossRegionRoutingResponse < Struct.new( :isolated_regions) SENSITIVE = [] include Aws::Structure end |