Class: Aws::Connect::Types::GetCurrentMetricDataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetCurrentMetricDataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total count of the result, regardless of the current page size.
-
#data_snapshot_time ⇒ Time
The time at which the metrics were retrieved and cached for pagination.
-
#metric_results ⇒ Array<Types::CurrentMetricResult>
Information about the real-time metrics.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total count of the result, regardless of the current page size.
15119 15120 15121 15122 15123 15124 15125 15126 |
# File 'lib/aws-sdk-connect/types.rb', line 15119 class GetCurrentMetricDataResponse < Struct.new( :next_token, :metric_results, :data_snapshot_time, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#data_snapshot_time ⇒ Time
The time at which the metrics were retrieved and cached for pagination.
15119 15120 15121 15122 15123 15124 15125 15126 |
# File 'lib/aws-sdk-connect/types.rb', line 15119 class GetCurrentMetricDataResponse < Struct.new( :next_token, :metric_results, :data_snapshot_time, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#metric_results ⇒ Array<Types::CurrentMetricResult>
Information about the real-time metrics.
15119 15120 15121 15122 15123 15124 15125 15126 |
# File 'lib/aws-sdk-connect/types.rb', line 15119 class GetCurrentMetricDataResponse < Struct.new( :next_token, :metric_results, :data_snapshot_time, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
The token expires after 5 minutes from the time it is created. Subsequent requests that use the token must use the same request parameters as the request that generated the token.
15119 15120 15121 15122 15123 15124 15125 15126 |
# File 'lib/aws-sdk-connect/types.rb', line 15119 class GetCurrentMetricDataResponse < Struct.new( :next_token, :metric_results, :data_snapshot_time, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |