Class: Aws::Connect::Types::GetCurrentUserDataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersTypes::UserDataFilters

The filters to apply to returned user data. You can filter up to the following limits:

  • Queues: 100

  • Routing profiles: 100

  • Agents: 100

  • Contact states: 9

  • User hierarchy groups: 1

The user data is retrieved for only the specified values/resources in the filter. A maximum of one filter can be passed from queues, routing profiles, agents, and user hierarchy groups.

Currently tagging is only supported on the resources that are passed in the filter.



16017
16018
16019
16020
16021
16022
16023
16024
# File 'lib/aws-sdk-connect/types.rb', line 16017

class GetCurrentUserDataRequest < Struct.new(
  :instance_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


16017
16018
16019
16020
16021
16022
16023
16024
# File 'lib/aws-sdk-connect/types.rb', line 16017

class GetCurrentUserDataRequest < Struct.new(
  :instance_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


16017
16018
16019
16020
16021
16022
16023
16024
# File 'lib/aws-sdk-connect/types.rb', line 16017

class GetCurrentUserDataRequest < Struct.new(
  :instance_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


16017
16018
16019
16020
16021
16022
16023
16024
# File 'lib/aws-sdk-connect/types.rb', line 16017

class GetCurrentUserDataRequest < Struct.new(
  :instance_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end