Class: Aws::Connect::Types::GetCurrentUserDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetCurrentUserDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::UserDataFilters
The filters to apply to returned user data.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#filters ⇒ Types::UserDataFilters
The filters to apply to returned user data. You can filter up to the following limits:
-
Queues: 100
-
Routing profiles: 100
-
Agents: 100
-
Contact states: 9
-
User hierarchy groups: 1
The user data is retrieved for only the specified values/resources in the filter. A maximum of one filter can be passed from queues, routing profiles, agents, and user hierarchy groups.
Currently tagging is only supported on the resources that are passed in the filter.
15385 15386 15387 15388 15389 15390 15391 15392 |
# File 'lib/aws-sdk-connect/types.rb', line 15385 class GetCurrentUserDataRequest < Struct.new( :instance_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
15385 15386 15387 15388 15389 15390 15391 15392 |
# File 'lib/aws-sdk-connect/types.rb', line 15385 class GetCurrentUserDataRequest < Struct.new( :instance_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
15385 15386 15387 15388 15389 15390 15391 15392 |
# File 'lib/aws-sdk-connect/types.rb', line 15385 class GetCurrentUserDataRequest < Struct.new( :instance_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
15385 15386 15387 15388 15389 15390 15391 15392 |
# File 'lib/aws-sdk-connect/types.rb', line 15385 class GetCurrentUserDataRequest < Struct.new( :instance_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |