Class: Aws::Connect::Types::GetEffectiveHoursOfOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#effective_hours_of_operation_listArray<Types::EffectiveHoursOfOperations>

Information about the effective hours of operations.



16338
16339
16340
16341
16342
16343
16344
# File 'lib/aws-sdk-connect/types.rb', line 16338

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#effective_override_hours_listArray<Types::EffectiveOverrideHours>

Information about override configurations applied to the base hours of operation to calculate the effective hours.

For more information about how override types are applied, see Build your list of overrides in the Administrator Guide.

Returns:



16338
16339
16340
16341
16342
16343
16344
# File 'lib/aws-sdk-connect/types.rb', line 16338

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The time zone for the hours of operation.

Returns:

  • (String)


16338
16339
16340
16341
16342
16343
16344
# File 'lib/aws-sdk-connect/types.rb', line 16338

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end