Class: Aws::Connect::Types::GetEffectiveHoursOfOperationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetEffectiveHoursOfOperationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#effective_hours_of_operation_list ⇒ Array<Types::EffectiveHoursOfOperations>
Information about the effective hours of operations.
-
#effective_override_hours_list ⇒ Array<Types::EffectiveOverrideHours>
Information about override configurations applied to the base hours of operation to calculate the effective hours.
-
#time_zone ⇒ String
The time zone for the hours of operation.
Instance Attribute Details
#effective_hours_of_operation_list ⇒ Array<Types::EffectiveHoursOfOperations>
Information about the effective hours of operations.
16323 16324 16325 16326 16327 16328 16329 |
# File 'lib/aws-sdk-connect/types.rb', line 16323 class GetEffectiveHoursOfOperationsResponse < Struct.new( :effective_hours_of_operation_list, :effective_override_hours_list, :time_zone) SENSITIVE = [] include Aws::Structure end |
#effective_override_hours_list ⇒ Array<Types::EffectiveOverrideHours>
Information about override configurations applied to the base hours of operation to calculate the effective hours.
For more information about how override types are applied, see Build your list of overrides in the Administrator Guide.
16323 16324 16325 16326 16327 16328 16329 |
# File 'lib/aws-sdk-connect/types.rb', line 16323 class GetEffectiveHoursOfOperationsResponse < Struct.new( :effective_hours_of_operation_list, :effective_override_hours_list, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone for the hours of operation.
16323 16324 16325 16326 16327 16328 16329 |
# File 'lib/aws-sdk-connect/types.rb', line 16323 class GetEffectiveHoursOfOperationsResponse < Struct.new( :effective_hours_of_operation_list, :effective_override_hours_list, :time_zone) SENSITIVE = [] include Aws::Structure end |