Class: Aws::Connect::Types::GetEffectiveHoursOfOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#effective_hours_of_operation_listArray<Types::EffectiveHoursOfOperations>

Information about the effective hours of operations.



15085
15086
15087
15088
15089
15090
15091
# File 'lib/aws-sdk-connect/types.rb', line 15085

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#effective_override_hours_listArray<Types::EffectiveOverrideHours>

Information about override configurations applied to the base hours of operation to calculate the effective hours.

For more information about how override types are applied, see

Build your list of overrides][1

in the <i> Administrator

Guide</i>.

[1]: docs.aws.amazon.com/https:/docs.aws.amazon.com/connect/latest/adminguide/hours-of-operation-overrides.html

Returns:



15085
15086
15087
15088
15089
15090
15091
# File 'lib/aws-sdk-connect/types.rb', line 15085

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The time zone for the hours of operation.

Returns:

  • (String)


15085
15086
15087
15088
15089
15090
15091
# File 'lib/aws-sdk-connect/types.rb', line 15085

class GetEffectiveHoursOfOperationsResponse < Struct.new(
  :effective_hours_of_operation_list,
  :effective_override_hours_list,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end