Class: Aws::Connect::Types::GetEvaluationFormValidationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetEvaluationFormValidationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#evaluation_form_version ⇒ Integer
The version of the evaluation form to retrieve validation results for.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
15938 15939 15940 15941 15942 15943 15944 |
# File 'lib/aws-sdk-connect/types.rb', line 15938 class GetEvaluationFormValidationRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_version ⇒ Integer
The version of the evaluation form to retrieve validation results for.
15938 15939 15940 15941 15942 15943 15944 |
# File 'lib/aws-sdk-connect/types.rb', line 15938 class GetEvaluationFormValidationRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
15938 15939 15940 15941 15942 15943 15944 |
# File 'lib/aws-sdk-connect/types.rb', line 15938 class GetEvaluationFormValidationRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version) SENSITIVE = [] include Aws::Structure end |