Class: Aws::Connect::Types::GetEvaluationFormValidationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_form_idString

The unique identifier for the evaluation form.

Returns:

  • (String)


15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_form_versionInteger

A version of the evaluation form.

Returns:

  • (Integer)


15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason the validation failed. This field is populated only when the status is ‘FAILED`.

Returns:

  • (String)


15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end

#findingsArray<Types::EvaluationFormValidationFinding>

A list of findings from the validation process. Each finding identifies a structural issue or quality improvement for the evaluation form, and may include a suggested fix. This field is populated when the status is ‘COMPLETED`.



15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end

#started_timeTime

The timestamp when the validation process was started.

Returns:

  • (Time)


15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the validation process. Valid values: ‘IN_PROGRESS`, `COMPLETED`, `FAILED`.

Returns:

  • (String)


15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
# File 'lib/aws-sdk-connect/types.rb', line 15832

class GetEvaluationFormValidationResponse < Struct.new(
  :status,
  :failure_reason,
  :evaluation_form_id,
  :evaluation_form_version,
  :started_time,
  :findings)
  SENSITIVE = []
  include Aws::Structure
end