Class: Aws::Connect::Types::GetEvaluationFormValidationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetEvaluationFormValidationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#evaluation_form_version ⇒ Integer
A version of the evaluation form.
-
#failure_reason ⇒ String
The reason the validation failed.
-
#findings ⇒ Array<Types::EvaluationFormValidationFinding>
A list of findings from the validation process.
-
#started_time ⇒ Time
The timestamp when the validation process was started.
-
#status ⇒ String
The current status of the validation process.
Instance Attribute Details
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_version ⇒ Integer
A version of the evaluation form.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason the validation failed. This field is populated only when the status is ‘FAILED`.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |
#findings ⇒ Array<Types::EvaluationFormValidationFinding>
A list of findings from the validation process. Each finding identifies a structural issue or quality improvement for the evaluation form, and may include a suggested fix. This field is populated when the status is ‘COMPLETED`.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |
#started_time ⇒ Time
The timestamp when the validation process was started.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the validation process. Valid values: ‘IN_PROGRESS`, `COMPLETED`, `FAILED`.
15832 15833 15834 15835 15836 15837 15838 15839 15840 15841 |
# File 'lib/aws-sdk-connect/types.rb', line 15832 class GetEvaluationFormValidationResponse < Struct.new( :status, :failure_reason, :evaluation_form_id, :evaluation_form_version, :started_time, :findings) SENSITIVE = [] include Aws::Structure end |