Class: Aws::Connect::Types::GetMetricDataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetMetricDataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_results ⇒ Array<Types::HistoricalMetricResult>
Information about the historical metrics.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#metric_results ⇒ Array<Types::HistoricalMetricResult>
Information about the historical metrics.
If no grouping is specified, a summary of metric data is returned.
16623 16624 16625 16626 16627 16628 |
# File 'lib/aws-sdk-connect/types.rb', line 16623 class GetMetricDataResponse < Struct.new( :next_token, :metric_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
The token expires after 5 minutes from the time it is created. Subsequent requests that use the token must use the same request parameters as the request that generated the token.
16623 16624 16625 16626 16627 16628 |
# File 'lib/aws-sdk-connect/types.rb', line 16623 class GetMetricDataResponse < Struct.new( :next_token, :metric_results) SENSITIVE = [] include Aws::Structure end |