Class: Aws::Connect::Types::GetMetricDataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetMetricDataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_results ⇒ Array<Types::HistoricalMetricResult>
Information about the historical metrics.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#metric_results ⇒ Array<Types::HistoricalMetricResult>
Information about the historical metrics.
If no grouping is specified, a summary of metric data is returned.
15838 15839 15840 15841 15842 15843 |
# File 'lib/aws-sdk-connect/types.rb', line 15838 class GetMetricDataResponse < Struct.new( :next_token, :metric_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
The token expires after 5 minutes from the time it is created. Subsequent requests that use the token must use the same request parameters as the request that generated the token.
15838 15839 15840 15841 15842 15843 |
# File 'lib/aws-sdk-connect/types.rb', line 15838 class GetMetricDataResponse < Struct.new( :next_token, :metric_results) SENSITIVE = [] include Aws::Structure end |