Class: Aws::Connect::Types::GetTaskTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetTaskTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN).
-
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
-
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
-
#created_time ⇒ Time
The timestamp when the task template was created.
-
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
-
#description ⇒ String
The description of the task template.
-
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
-
#id ⇒ String
A unique identifier for the task template.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#last_modified_time ⇒ Time
The timestamp when the task template was last modified.
-
#name ⇒ String
The name of the task template.
-
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it. -
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN).
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the task template was created.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the task template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the task template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the task template was last modified.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to
it. Tasks can only be created from ACTIVE templates. If a template
is marked as INACTIVE, then a task that refers to this template
cannot be created.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 |
# File 'lib/aws-sdk-connect/types.rb', line 19027 class GetTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time, :tags) SENSITIVE = [] include Aws::Structure end |