Class: Aws::Connect::Types::GetTrafficDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GetTrafficDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the traffic distribution group.
Instance Attribute Details
#id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
19149 19150 19151 19152 19153 |
# File 'lib/aws-sdk-connect/types.rb', line 19149 class GetTrafficDistributionRequest < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |