Class: Aws::Connect::Types::GetTrafficDistributionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


17093
17094
17095
17096
17097
# File 'lib/aws-sdk-connect/types.rb', line 17093

class GetTrafficDistributionRequest < Struct.new(
  :id)
  SENSITIVE = []
  include Aws::Structure
end