Class: Aws::Connect::Types::GetTrafficDistributionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_configTypes::AgentConfig

The distribution of agents between the instance and its replica(s).

Returns:



18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/aws-sdk-connect/types.rb', line 18453

class GetTrafficDistributionResponse < Struct.new(
  :telephony_config,
  :id,
  :arn,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/aws-sdk-connect/types.rb', line 18453

class GetTrafficDistributionResponse < Struct.new(
  :telephony_config,
  :id,
  :arn,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/aws-sdk-connect/types.rb', line 18453

class GetTrafficDistributionResponse < Struct.new(
  :telephony_config,
  :id,
  :arn,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#sign_in_configTypes::SignInConfig

The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).

Returns:



18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/aws-sdk-connect/types.rb', line 18453

class GetTrafficDistributionResponse < Struct.new(
  :telephony_config,
  :id,
  :arn,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end

#telephony_configTypes::TelephonyConfig

The distribution of traffic between the instance and its replicas.



18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/aws-sdk-connect/types.rb', line 18453

class GetTrafficDistributionResponse < Struct.new(
  :telephony_config,
  :id,
  :arn,
  :sign_in_config,
  :agent_config)
  SENSITIVE = []
  include Aws::Structure
end