Class: Aws::Connect::Types::GlobalResiliencyMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::GlobalResiliencyMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the global resiliency configuration for the contact, including traffic distribution details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_region ⇒ String
The current AWS region in which the contact is active.
-
#origin_region ⇒ String
The AWS region where the contact was originally created and initiated.
-
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group.
Instance Attribute Details
#active_region ⇒ String
The current AWS region in which the contact is active. This indicates where the contact is being processed in real-time.
19212 19213 19214 19215 19216 19217 19218 |
# File 'lib/aws-sdk-connect/types.rb', line 19212 class GlobalResiliencyMetadata < Struct.new( :active_region, :origin_region, :traffic_distribution_group_id) SENSITIVE = [] include Aws::Structure end |
#origin_region ⇒ String
The AWS region where the contact was originally created and initiated. This may differ from the ActiveRegion if the contact has been transferred across regions.
19212 19213 19214 19215 19216 19217 19218 |
# File 'lib/aws-sdk-connect/types.rb', line 19212 class GlobalResiliencyMetadata < Struct.new( :active_region, :origin_region, :traffic_distribution_group_id) SENSITIVE = [] include Aws::Structure end |
#traffic_distribution_group_id ⇒ String
The identifier of the traffic distribution group.
19212 19213 19214 19215 19216 19217 19218 |
# File 'lib/aws-sdk-connect/types.rb', line 19212 class GlobalResiliencyMetadata < Struct.new( :active_region, :origin_region, :traffic_distribution_group_id) SENSITIVE = [] include Aws::Structure end |