Class: Aws::Connect::Types::GlobalResiliencyMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the global resiliency configuration for the contact, including traffic distribution details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_regionString

The current AWS region in which the contact is active. This indicates where the contact is being processed in real-time.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
# File 'lib/aws-sdk-connect/types.rb', line 17673

class  < Struct.new(
  :active_region,
  :origin_region,
  :traffic_distribution_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#origin_regionString

The AWS region where the contact was originally created and initiated. This may differ from the ActiveRegion if the contact has been transferred across regions.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
# File 'lib/aws-sdk-connect/types.rb', line 17673

class  < Struct.new(
  :active_region,
  :origin_region,
  :traffic_distribution_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_distribution_group_idString

The identifier of the traffic distribution group.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
# File 'lib/aws-sdk-connect/types.rb', line 17673

class  < Struct.new(
  :active_region,
  :origin_region,
  :traffic_distribution_group_id)
  SENSITIVE = []
  include Aws::Structure
end