Class: Aws::Connect::Types::HistoricalMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::HistoricalMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a historical metric.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the metric.
-
#statistic ⇒ String
The statistic for the metric.
-
#threshold ⇒ Types::Threshold
The threshold for the metric, used with service level metrics.
-
#unit ⇒ String
The unit for the metric.
Instance Attribute Details
#name ⇒ String
The name of the metric. Following is a list of each supported metric mapped to the UI name, linked to a detailed description in the *Amazon Connect Administrator Guide*.
ABANDON_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average queue abandon time][1]
AFTER_CONTACT_WORK_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [After contact work time][2]
API_CONTACTS_HANDLED
: Unit: COUNT
Statistic: SUM
UI name: [API contacts handled][3]
AVG_HOLD_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average customer hold time][4]
CALLBACK_CONTACTS_HANDLED
: Unit: COUNT
Statistic: SUM
UI name: [Callback contacts handled][5]
CONTACTS_ABANDONED
: Unit: COUNT
Statistic: SUM
UI name: [Contacts abandoned][6]
CONTACTS_AGENT_HUNG_UP_FIRST
: Unit: COUNT
Statistic: SUM
UI name: [Contacts agent hung up first][7]
CONTACTS_CONSULTED
: Unit: COUNT
Statistic: SUM
UI name: [Contacts consulted][8]
CONTACTS_HANDLED
: Unit: COUNT
Statistic: SUM
UI name: [Contacts handled][9]
CONTACTS_HANDLED_INCOMING
: Unit: COUNT
Statistic: SUM
UI name: [Contacts handled incoming][10]
CONTACTS_HANDLED_OUTBOUND
: Unit: COUNT
Statistic: SUM
UI name: [Contacts handled outbound][11]
CONTACTS_HOLD_ABANDONS
: Unit: COUNT
Statistic: SUM
UI name: [Contacts hold disconnect][12]
CONTACTS_MISSED
: Unit: COUNT
Statistic: SUM
UI name: [AGENT\_NON\_RESPONSE][13]
CONTACTS_QUEUED
: Unit: COUNT
Statistic: SUM
UI name: [Contacts queued][14]
CONTACTS_TRANSFERRED_IN
: Unit: COUNT
Statistic: SUM
UI name: [Contacts transferred in][15]
CONTACTS_TRANSFERRED_IN_FROM_QUEUE
: Unit: COUNT
Statistic: SUM
UI name: [Contacts transferred out queue][16]
CONTACTS_TRANSFERRED_OUT
: Unit: COUNT
Statistic: SUM
UI name: [Contacts transferred out][17]
CONTACTS_TRANSFERRED_OUT_FROM_QUEUE
: Unit: COUNT
Statistic: SUM
UI name: [Contacts transferred out queue][16]
HANDLE_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average handle time][18]
INTERACTION_AND_HOLD_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average agent interaction and customer hold time][19]
INTERACTION_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average agent interaction time][20]
OCCUPANCY
: Unit: PERCENT
Statistic: AVG
UI name: [Occupancy][21]
QUEUE_ANSWER_TIME
: Unit: SECONDS
Statistic: AVG
UI name: [Average queue answer time][22]
QUEUED_TIME
: Unit: SECONDS
Statistic: MAX
UI name: [Minimum flow time][23]
SERVICE_LEVEL
: You can include up to 20 SERVICE_LEVEL metrics in a request.
Unit: PERCENT
Statistic: AVG
Threshold: For `ThresholdValue`, enter any whole number from 1 to
604800 (inclusive), in seconds. For `Comparison`, you must enter
`LT` (for "Less than").
UI name: [Service level X][24]
[1]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#average-queue-abandon-time [2]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#after-contact-work-time [3]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#api-contacts-handled [4]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#average-customer-hold-time [5]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#callback-contacts-handled [6]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-abandoned [7]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-agent-hung-up-first [8]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-consulted [9]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-handled [10]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-handled-incoming [11]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-handled-outbound [12]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-hold-disconnect [13]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#agent-non-response [14]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-queued [15]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-transferred-in [16]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-transferred-out-queue [17]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#contacts-transferred-out [18]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#average-handle-time [19]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#average-agent-interaction-and-customer-hold-time [20]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#aaverage-agent-interaction-time [21]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#occupancy [22]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html##average-queue-answer-time [23]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#minimum-flow-time [24]: docs.aws.amazon.com/connect/latest/adminguide/metrics-definitions.html#service-level
17781 17782 17783 17784 17785 17786 17787 17788 |
# File 'lib/aws-sdk-connect/types.rb', line 17781 class HistoricalMetric < Struct.new( :name, :threshold, :statistic, :unit) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic for the metric.
17781 17782 17783 17784 17785 17786 17787 17788 |
# File 'lib/aws-sdk-connect/types.rb', line 17781 class HistoricalMetric < Struct.new( :name, :threshold, :statistic, :unit) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Types::Threshold
The threshold for the metric, used with service level metrics.
17781 17782 17783 17784 17785 17786 17787 17788 |
# File 'lib/aws-sdk-connect/types.rb', line 17781 class HistoricalMetric < Struct.new( :name, :threshold, :statistic, :unit) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit for the metric.
17781 17782 17783 17784 17785 17786 17787 17788 |
# File 'lib/aws-sdk-connect/types.rb', line 17781 class HistoricalMetric < Struct.new( :name, :threshold, :statistic, :unit) SENSITIVE = [] include Aws::Structure end |