Class: Aws::Connect::Types::ImportPhoneNumberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


20084
20085
20086
20087
20088
20089
20090
20091
20092
# File 'lib/aws-sdk-connect/types.rb', line 20084

class ImportPhoneNumberRequest < Struct.new(
  :instance_id,
  :source_phone_number_arn,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


20084
20085
20086
20087
20088
20089
20090
20091
20092
# File 'lib/aws-sdk-connect/types.rb', line 20084

class ImportPhoneNumberRequest < Struct.new(
  :instance_id,
  :source_phone_number_arn,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_descriptionString

The description of the phone number.

Returns:

  • (String)


20084
20085
20086
20087
20088
20089
20090
20091
20092
# File 'lib/aws-sdk-connect/types.rb', line 20084

class ImportPhoneNumberRequest < Struct.new(
  :instance_id,
  :source_phone_number_arn,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_phone_number_arnString

The claimed phone number ARN being imported from the external service, such as Amazon Web Services End User Messaging. If it is from Amazon Web Services End User Messaging, it looks like the ARN of the phone number to import from Amazon Web Services End User Messaging.

Returns:

  • (String)


20084
20085
20086
20087
20088
20089
20090
20091
20092
# File 'lib/aws-sdk-connect/types.rb', line 20084

class ImportPhoneNumberRequest < Struct.new(
  :instance_id,
  :source_phone_number_arn,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


20084
20085
20086
20087
20088
20089
20090
20091
20092
# File 'lib/aws-sdk-connect/types.rb', line 20084

class ImportPhoneNumberRequest < Struct.new(
  :instance_id,
  :source_phone_number_arn,
  :phone_number_description,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end