Class: Aws::Connect::Types::ImportPhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ImportPhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#phone_number_description ⇒ String
The description of the phone number.
-
#source_phone_number_arn ⇒ String
The claimed phone number ARN being imported from the external service, such as Amazon Web Services End User Messaging.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
19237 19238 19239 19240 19241 19242 19243 19244 19245 |
# File 'lib/aws-sdk-connect/types.rb', line 19237 class ImportPhoneNumberRequest < Struct.new( :instance_id, :source_phone_number_arn, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19237 19238 19239 19240 19241 19242 19243 19244 19245 |
# File 'lib/aws-sdk-connect/types.rb', line 19237 class ImportPhoneNumberRequest < Struct.new( :instance_id, :source_phone_number_arn, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_description ⇒ String
The description of the phone number.
19237 19238 19239 19240 19241 19242 19243 19244 19245 |
# File 'lib/aws-sdk-connect/types.rb', line 19237 class ImportPhoneNumberRequest < Struct.new( :instance_id, :source_phone_number_arn, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_phone_number_arn ⇒ String
The claimed phone number ARN being imported from the external service, such as Amazon Web Services End User Messaging. If it is from Amazon Web Services End User Messaging, it looks like the ARN of the phone number to import from Amazon Web Services End User Messaging.
19237 19238 19239 19240 19241 19242 19243 19244 19245 |
# File 'lib/aws-sdk-connect/types.rb', line 19237 class ImportPhoneNumberRequest < Struct.new( :instance_id, :source_phone_number_arn, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
19237 19238 19239 19240 19241 19242 19243 19244 19245 |
# File 'lib/aws-sdk-connect/types.rb', line 19237 class ImportPhoneNumberRequest < Struct.new( :instance_id, :source_phone_number_arn, :phone_number_description, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |