Class: Aws::Connect::Types::ListBotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListBotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#lex_version ⇒ String
The version of Amazon Lex or Amazon Lex V2.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
22194 22195 22196 22197 22198 22199 22200 22201 |
# File 'lib/aws-sdk-connect/types.rb', line 22194 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#lex_version ⇒ String
The version of Amazon Lex or Amazon Lex V2.
22194 22195 22196 22197 22198 22199 22200 22201 |
# File 'lib/aws-sdk-connect/types.rb', line 22194 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22194 22195 22196 22197 22198 22199 22200 22201 |
# File 'lib/aws-sdk-connect/types.rb', line 22194 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22194 22195 22196 22197 22198 22199 22200 22201 |
# File 'lib/aws-sdk-connect/types.rb', line 22194 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |