Class: Aws::Connect::Types::ListBotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListBotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#lex_version ⇒ String
The version of Amazon Lex or Amazon Lex V2.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19540 19541 19542 19543 19544 19545 19546 19547 |
# File 'lib/aws-sdk-connect/types.rb', line 19540 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#lex_version ⇒ String
The version of Amazon Lex or Amazon Lex V2.
19540 19541 19542 19543 19544 19545 19546 19547 |
# File 'lib/aws-sdk-connect/types.rb', line 19540 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
19540 19541 19542 19543 19544 19545 19546 19547 |
# File 'lib/aws-sdk-connect/types.rb', line 19540 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19540 19541 19542 19543 19544 19545 19546 19547 |
# File 'lib/aws-sdk-connect/types.rb', line 19540 class ListBotsRequest < Struct.new( :instance_id, :next_token, :max_results, :lex_version) SENSITIVE = [] include Aws::Structure end |