Class: Aws::Connect::Types::ListContactEvaluationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactEvaluationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
22331 22332 22333 22334 22335 22336 22337 |
# File 'lib/aws-sdk-connect/types.rb', line 22331 class ListContactEvaluationsRequest < Struct.new( :instance_id, :contact_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
22331 22332 22333 22334 22335 22336 22337 |
# File 'lib/aws-sdk-connect/types.rb', line 22331 class ListContactEvaluationsRequest < Struct.new( :instance_id, :contact_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
This is not expected to be set because the value returned in the previous response is always null.
22331 22332 22333 22334 22335 22336 22337 |
# File 'lib/aws-sdk-connect/types.rb', line 22331 class ListContactEvaluationsRequest < Struct.new( :instance_id, :contact_id, :next_token) SENSITIVE = [] include Aws::Structure end |