Class: Aws::Connect::Types::ListContactEvaluationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactEvaluationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_summary_list ⇒ Array<Types::EvaluationSummary>
Provides details about a list of contact evaluations belonging to an instance.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#evaluation_summary_list ⇒ Array<Types::EvaluationSummary>
Provides details about a list of contact evaluations belonging to an instance.
19699 19700 19701 19702 19703 19704 |
# File 'lib/aws-sdk-connect/types.rb', line 19699 class ListContactEvaluationsResponse < Struct.new( :evaluation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
This is always returned as null in the response.
19699 19700 19701 19702 19703 19704 |
# File 'lib/aws-sdk-connect/types.rb', line 19699 class ListContactEvaluationsResponse < Struct.new( :evaluation_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |