Class: Aws::Connect::Types::ListContactFlowModuleVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactFlowModuleVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_module_id ⇒ String
The identifier of the flow module.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_flow_module_id ⇒ String
The identifier of the flow module.
20479 20480 20481 20482 20483 20484 20485 20486 |
# File 'lib/aws-sdk-connect/types.rb', line 20479 class ListContactFlowModuleVersionsRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
20479 20480 20481 20482 20483 20484 20485 20486 |
# File 'lib/aws-sdk-connect/types.rb', line 20479 class ListContactFlowModuleVersionsRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
20479 20480 20481 20482 20483 20484 20485 20486 |
# File 'lib/aws-sdk-connect/types.rb', line 20479 class ListContactFlowModuleVersionsRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20479 20480 20481 20482 20483 20484 20485 20486 |
# File 'lib/aws-sdk-connect/types.rb', line 20479 class ListContactFlowModuleVersionsRequest < Struct.new( :instance_id, :contact_flow_module_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |