Class: Aws::Connect::Types::ListContactFlowVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactFlowVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_id ⇒ String
The identifier of the flow.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_flow_id ⇒ String
The identifier of the flow.
20579 20580 20581 20582 20583 20584 20585 20586 |
# File 'lib/aws-sdk-connect/types.rb', line 20579 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
20579 20580 20581 20582 20583 20584 20585 20586 |
# File 'lib/aws-sdk-connect/types.rb', line 20579 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
20579 20580 20581 20582 20583 20584 20585 20586 |
# File 'lib/aws-sdk-connect/types.rb', line 20579 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20579 20580 20581 20582 20583 20584 20585 20586 |
# File 'lib/aws-sdk-connect/types.rb', line 20579 class ListContactFlowVersionsRequest < Struct.new( :instance_id, :contact_flow_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |