Class: Aws::Connect::Types::ListContactFlowsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactFlowsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_types ⇒ Array<String>
The type of flow.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#contact_flow_types ⇒ Array<String>
The type of flow.
19936 19937 19938 19939 19940 19941 19942 19943 |
# File 'lib/aws-sdk-connect/types.rb', line 19936 class ListContactFlowsRequest < Struct.new( :instance_id, :contact_flow_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19936 19937 19938 19939 19940 19941 19942 19943 |
# File 'lib/aws-sdk-connect/types.rb', line 19936 class ListContactFlowsRequest < Struct.new( :instance_id, :contact_flow_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
19936 19937 19938 19939 19940 19941 19942 19943 |
# File 'lib/aws-sdk-connect/types.rb', line 19936 class ListContactFlowsRequest < Struct.new( :instance_id, :contact_flow_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
19936 19937 19938 19939 19940 19941 19942 19943 |
# File 'lib/aws-sdk-connect/types.rb', line 19936 class ListContactFlowsRequest < Struct.new( :instance_id, :contact_flow_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |