Class: Aws::Connect::Types::ListContactReferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListContactReferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the initial contact.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#next_token ⇒ String
The token for the next set of results.
-
#reference_types ⇒ Array<String>
The type of reference.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the initial contact.
19991 19992 19993 19994 19995 19996 19997 19998 |
# File 'lib/aws-sdk-connect/types.rb', line 19991 class ListContactReferencesRequest < Struct.new( :instance_id, :contact_id, :reference_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
19991 19992 19993 19994 19995 19996 19997 19998 |
# File 'lib/aws-sdk-connect/types.rb', line 19991 class ListContactReferencesRequest < Struct.new( :instance_id, :contact_id, :reference_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
This is not expected to be set, because the value returned in the previous response is always null.
19991 19992 19993 19994 19995 19996 19997 19998 |
# File 'lib/aws-sdk-connect/types.rb', line 19991 class ListContactReferencesRequest < Struct.new( :instance_id, :contact_id, :reference_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#reference_types ⇒ Array<String>
The type of reference.
19991 19992 19993 19994 19995 19996 19997 19998 |
# File 'lib/aws-sdk-connect/types.rb', line 19991 class ListContactReferencesRequest < Struct.new( :instance_id, :contact_id, :reference_types, :next_token) SENSITIVE = [] include Aws::Structure end |