Class: Aws::Connect::Types::ListContactReferencesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the initial contact.

Returns:

  • (String)


20687
20688
20689
20690
20691
20692
20693
20694
# File 'lib/aws-sdk-connect/types.rb', line 20687

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


20687
20688
20689
20690
20691
20692
20693
20694
# File 'lib/aws-sdk-connect/types.rb', line 20687

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

This is not expected to be set, because the value returned in the previous response is always null.

Returns:

  • (String)


20687
20688
20689
20690
20691
20692
20693
20694
# File 'lib/aws-sdk-connect/types.rb', line 20687

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reference_typesArray<String>

The type of reference.

Returns:

  • (Array<String>)


20687
20688
20689
20690
20691
20692
20693
20694
# File 'lib/aws-sdk-connect/types.rb', line 20687

class ListContactReferencesRequest < Struct.new(
  :instance_id,
  :contact_id,
  :reference_types,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end