Class: Aws::Connect::Types::ListDataTableAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_idsArray<String>

Optional list of specific attribute IDs to retrieve. Used for CloudFormation to effectively describe attributes by ID. If NextToken is provided, this parameter is ignored.

Returns:



20743
20744
20745
20746
20747
20748
20749
20750
20751
# File 'lib/aws-sdk-connect/types.rb', line 20743

class ListDataTableAttributesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :attribute_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#data_table_idString

The unique identifier for the data table whose attributes should be listed.

Returns:



20743
20744
20745
20746
20747
20748
20749
20750
20751
# File 'lib/aws-sdk-connect/types.rb', line 20743

class ListDataTableAttributesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :attribute_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The unique identifier for the Amazon Connect instance.

Returns:



20743
20744
20745
20746
20747
20748
20749
20750
20751
# File 'lib/aws-sdk-connect/types.rb', line 20743

class ListDataTableAttributesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :attribute_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of data table attributes to return in one page of results.

Returns:



20743
20744
20745
20746
20747
20748
20749
20750
20751
# File 'lib/aws-sdk-connect/types.rb', line 20743

class ListDataTableAttributesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :attribute_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token from a previous request to retrieve the next page of results.

Returns:



20743
20744
20745
20746
20747
20748
20749
20750
20751
# File 'lib/aws-sdk-connect/types.rb', line 20743

class ListDataTableAttributesRequest < Struct.new(
  :instance_id,
  :data_table_id,
  :attribute_ids,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end