Class: Aws::Connect::Types::ListDataTableAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListDataTableAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_ids ⇒ Array<String>
Optional list of specific attribute IDs to retrieve.
-
#data_table_id ⇒ String
The unique identifier for the data table whose attributes should be listed.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of data table attributes to return in one page of results.
-
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
Instance Attribute Details
#attribute_ids ⇒ Array<String>
Optional list of specific attribute IDs to retrieve. Used for CloudFormation to effectively describe attributes by ID. If NextToken is provided, this parameter is ignored.
20743 20744 20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-connect/types.rb', line 20743 class ListDataTableAttributesRequest < Struct.new( :instance_id, :data_table_id, :attribute_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#data_table_id ⇒ String
The unique identifier for the data table whose attributes should be listed.
20743 20744 20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-connect/types.rb', line 20743 class ListDataTableAttributesRequest < Struct.new( :instance_id, :data_table_id, :attribute_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
20743 20744 20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-connect/types.rb', line 20743 class ListDataTableAttributesRequest < Struct.new( :instance_id, :data_table_id, :attribute_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data table attributes to return in one page of results.
20743 20744 20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-connect/types.rb', line 20743 class ListDataTableAttributesRequest < Struct.new( :instance_id, :data_table_id, :attribute_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specify the pagination token from a previous request to retrieve the next page of results.
20743 20744 20745 20746 20747 20748 20749 20750 20751 |
# File 'lib/aws-sdk-connect/types.rb', line 20743 class ListDataTableAttributesRequest < Struct.new( :instance_id, :data_table_id, :attribute_ids, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |