Class: Aws::Connect::Types::ListHoursOfOperationOverridesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListHoursOfOperationOverridesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
20527 20528 20529 20530 20531 20532 20533 20534 |
# File 'lib/aws-sdk-connect/types.rb', line 20527 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
20527 20528 20529 20530 20531 20532 20533 20534 |
# File 'lib/aws-sdk-connect/types.rb', line 20527 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
20527 20528 20529 20530 20531 20532 20533 20534 |
# File 'lib/aws-sdk-connect/types.rb', line 20527 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20527 20528 20529 20530 20531 20532 20533 20534 |
# File 'lib/aws-sdk-connect/types.rb', line 20527 class ListHoursOfOperationOverridesRequest < Struct.new( :instance_id, :hours_of_operation_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |