Class: Aws::Connect::Types::ListHoursOfOperationOverridesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListHoursOfOperationOverridesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hours_of_operation_override_list ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operation override.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#hours_of_operation_override_list ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operation override.
20193 20194 20195 20196 20197 20198 20199 20200 |
# File 'lib/aws-sdk-connect/types.rb', line 20193 class ListHoursOfOperationOverridesResponse < Struct.new( :next_token, :hours_of_operation_override_list, :last_modified_region, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
20193 20194 20195 20196 20197 20198 20199 20200 |
# File 'lib/aws-sdk-connect/types.rb', line 20193 class ListHoursOfOperationOverridesResponse < Struct.new( :next_token, :hours_of_operation_override_list, :last_modified_region, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
20193 20194 20195 20196 20197 20198 20199 20200 |
# File 'lib/aws-sdk-connect/types.rb', line 20193 class ListHoursOfOperationOverridesResponse < Struct.new( :next_token, :hours_of_operation_override_list, :last_modified_region, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
20193 20194 20195 20196 20197 20198 20199 20200 |
# File 'lib/aws-sdk-connect/types.rb', line 20193 class ListHoursOfOperationOverridesResponse < Struct.new( :next_token, :hours_of_operation_override_list, :last_modified_region, :last_modified_time) SENSITIVE = [] include Aws::Structure end |