Class: Aws::Connect::Types::ListIntegrationAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListIntegrationAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
-
#integration_type ⇒ String
The integration type.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21050 21051 21052 21053 21054 21055 21056 21057 21058 |
# File 'lib/aws-sdk-connect/types.rb', line 21050 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the integration.
21050 21051 21052 21053 21054 21055 21056 21057 21058 |
# File 'lib/aws-sdk-connect/types.rb', line 21050 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#integration_type ⇒ String
The integration type.
21050 21051 21052 21053 21054 21055 21056 21057 21058 |
# File 'lib/aws-sdk-connect/types.rb', line 21050 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
21050 21051 21052 21053 21054 21055 21056 21057 21058 |
# File 'lib/aws-sdk-connect/types.rb', line 21050 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21050 21051 21052 21053 21054 21055 21056 21057 21058 |
# File 'lib/aws-sdk-connect/types.rb', line 21050 class ListIntegrationAssociationsRequest < Struct.new( :instance_id, :integration_type, :next_token, :max_results, :integration_arn) SENSITIVE = [] include Aws::Structure end |