Class: Aws::Connect::Types::ListLambdaFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListLambdaFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21524 21525 21526 21527 21528 21529 21530 |
# File 'lib/aws-sdk-connect/types.rb', line 21524 class ListLambdaFunctionsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
21524 21525 21526 21527 21528 21529 21530 |
# File 'lib/aws-sdk-connect/types.rb', line 21524 class ListLambdaFunctionsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21524 21525 21526 21527 21528 21529 21530 |
# File 'lib/aws-sdk-connect/types.rb', line 21524 class ListLambdaFunctionsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |