Class: Aws::Connect::Types::ListLexBotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListLexBotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21572 21573 21574 21575 21576 21577 21578 |
# File 'lib/aws-sdk-connect/types.rb', line 21572 class ListLexBotsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. If no value is specified, the default is 10.
21572 21573 21574 21575 21576 21577 21578 |
# File 'lib/aws-sdk-connect/types.rb', line 21572 class ListLexBotsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21572 21573 21574 21575 21576 21577 21578 |
# File 'lib/aws-sdk-connect/types.rb', line 21572 class ListLexBotsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |