Class: Aws::Connect::Types::ListPhoneNumbersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPhoneNumbersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
-
#phone_number_types ⇒ Array<String>
The type of phone number.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21673 21674 21675 21676 21677 21678 21679 21680 21681 |
# File 'lib/aws-sdk-connect/types.rb', line 21673 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
21673 21674 21675 21676 21677 21678 21679 21680 21681 |
# File 'lib/aws-sdk-connect/types.rb', line 21673 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21673 21674 21675 21676 21677 21678 21679 21680 21681 |
# File 'lib/aws-sdk-connect/types.rb', line 21673 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
21673 21674 21675 21676 21677 21678 21679 21680 21681 |
# File 'lib/aws-sdk-connect/types.rb', line 21673 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#phone_number_types ⇒ Array<String>
The type of phone number.
<note markdown=“1”> We recommend using [ListPhoneNumbersV2] to return phone number types. While ListPhoneNumbers returns number types UIFN, SHARED, THIRD_PARTY_TF, and THIRD_PARTY_DID, it incorrectly lists them as TOLL_FREE or DID.
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html
21673 21674 21675 21676 21677 21678 21679 21680 21681 |
# File 'lib/aws-sdk-connect/types.rb', line 21673 class ListPhoneNumbersRequest < Struct.new( :instance_id, :phone_number_types, :phone_number_country_codes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |