Class: Aws::Connect::Types::ListPhoneNumbersSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPhoneNumbersSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about phone numbers that have been claimed to your Connect Customer instance or traffic distribution group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to.
-
#phone_number ⇒ String
The phone number.
-
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the phone number.
-
#phone_number_country_code ⇒ String
The ISO country code.
-
#phone_number_description ⇒ String
The description of the phone number.
-
#phone_number_id ⇒ String
A unique identifier for the phone number.
-
#phone_number_type ⇒ String
The type of phone number.
-
#source_phone_number_arn ⇒ String
The claimed phone number ARN that was previously imported from the external service, such as Amazon Web Services End User Messaging.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
The phone number. Phone numbers are formatted [+] [country code] [subscriber number including area code].
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the phone number.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_code ⇒ String
The ISO country code.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_description ⇒ String
The description of the phone number.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
A unique identifier for the phone number.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#phone_number_type ⇒ String
The type of phone number.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#source_phone_number_arn ⇒ String
The claimed phone number ARN that was previously imported from the external service, such as Amazon Web Services End User Messaging. If it is from Amazon Web Services End User Messaging, it looks like the ARN of the phone number that was imported from Amazon Web Services End User Messaging.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 |
# File 'lib/aws-sdk-connect/types.rb', line 23880 class ListPhoneNumbersSummary < Struct.new( :phone_number_id, :phone_number_arn, :phone_number, :phone_number_country_code, :phone_number_type, :target_arn, :instance_id, :phone_number_description, :source_phone_number_arn) SENSITIVE = [] include Aws::Structure end |