Class: Aws::Connect::Types::ListPhoneNumbersV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPhoneNumbersV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
-
#phone_number_prefix ⇒ String
The prefix of the phone number.
-
#phone_number_types ⇒ Array<String>
The type of phone number.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers
are claimed to. You can find the instance ID in the Amazon
Resource Name (ARN) of the instance. If both TargetArn and
InstanceId are not provided, this API lists numbers claimed to all
the Connect Customer instances belonging to your account in the same
Amazon Web Services Region as the request.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_codes ⇒ Array<String>
The ISO country code.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#phone_number_prefix ⇒ String
The prefix of the phone number. If provided, it must contain + as
part of the country code.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#phone_number_types ⇒ Array<String>
The type of phone number.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or
traffic distribution groups that phone number inbound traffic is
routed through. If both TargetArn and InstanceId input are not
provided, this API lists numbers claimed to all the Connect Customer
instances belonging to your account in the same Amazon Web Services
Region as the request.
23941 23942 23943 23944 23945 23946 23947 23948 23949 23950 23951 |
# File 'lib/aws-sdk-connect/types.rb', line 23941 class ListPhoneNumbersV2Request < Struct.new( :target_arn, :instance_id, :max_results, :next_token, :phone_number_country_codes, :phone_number_types, :phone_number_prefix) SENSITIVE = [] include Aws::Structure end |