Class: Aws::Connect::Types::ListPhoneNumbersV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Amazon Connect instance that phone numbers are claimed to. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance. If both TargetArn and InstanceId are not provided, this API lists numbers claimed to all the Amazon Connect instances belonging to your account in the same Amazon Web Services Region as the request.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_country_codesArray<String>

The ISO country code.

Returns:

  • (Array<String>)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_prefixString

The prefix of the phone number. If provided, it must contain ‘+` as part of the country code.

Returns:

  • (String)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_typesArray<String>

The type of phone number.

Returns:

  • (Array<String>)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) for Amazon Connect instances or traffic distribution groups that phone number inbound traffic is routed through. If both TargetArn and InstanceId input are not provided, this API lists numbers claimed to all the Amazon Connect instances belonging to your account in the same Amazon Web Services Region as the request.

Returns:

  • (String)


21830
21831
21832
21833
21834
21835
21836
21837
21838
21839
21840
# File 'lib/aws-sdk-connect/types.rb', line 21830

class ListPhoneNumbersV2Request < Struct.new(
  :target_arn,
  :instance_id,
  :max_results,
  :next_token,
  :phone_number_country_codes,
  :phone_number_types,
  :phone_number_prefix)
  SENSITIVE = []
  include Aws::Structure
end