Class: Aws::Connect::Types::ListPromptsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListPromptsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
21921 21922 21923 21924 21925 21926 21927 |
# File 'lib/aws-sdk-connect/types.rb', line 21921 class ListPromptsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
21921 21922 21923 21924 21925 21926 21927 |
# File 'lib/aws-sdk-connect/types.rb', line 21921 class ListPromptsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21921 21922 21923 21924 21925 21926 21927 |
# File 'lib/aws-sdk-connect/types.rb', line 21921 class ListPromptsRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |