Class: Aws::Connect::Types::ListQueueEmailAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQueueEmailAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#queue_id ⇒ String
The identifier for the queue.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21972 21973 21974 21975 21976 21977 21978 21979 |
# File 'lib/aws-sdk-connect/types.rb', line 21972 class ListQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
21972 21973 21974 21975 21976 21977 21978 21979 |
# File 'lib/aws-sdk-connect/types.rb', line 21972 class ListQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21972 21973 21974 21975 21976 21977 21978 21979 |
# File 'lib/aws-sdk-connect/types.rb', line 21972 class ListQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
21972 21973 21974 21975 21976 21977 21978 21979 |
# File 'lib/aws-sdk-connect/types.rb', line 21972 class ListQueueEmailAddressesRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |