Class: Aws::Connect::Types::ListQueueEmailAddressesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQueueEmailAddressesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_address_metadata_list ⇒ Array<Types::EmailAddressSummary>
List of email address summary information for all email addresses associated with the queue.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#email_address_metadata_list ⇒ Array<Types::EmailAddressSummary>
List of email address summary information for all email addresses associated with the queue. Each item contains the email address identifier, ARN, and configuration details.
22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-connect/types.rb', line 22003 class ListQueueEmailAddressesResponse < Struct.new( :next_token, :email_address_metadata_list, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-connect/types.rb', line 22003 class ListQueueEmailAddressesResponse < Struct.new( :next_token, :email_address_metadata_list, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-connect/types.rb', line 22003 class ListQueueEmailAddressesResponse < Struct.new( :next_token, :email_address_metadata_list, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-connect/types.rb', line 22003 class ListQueueEmailAddressesResponse < Struct.new( :next_token, :email_address_metadata_list, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |