Class: Aws::Connect::Types::ListQueueQuickConnectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQueueQuickConnectsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#queue_id ⇒ String
The identifier for the queue.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
21802 21803 21804 21805 21806 21807 21808 21809 |
# File 'lib/aws-sdk-connect/types.rb', line 21802 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
21802 21803 21804 21805 21806 21807 21808 21809 |
# File 'lib/aws-sdk-connect/types.rb', line 21802 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
21802 21803 21804 21805 21806 21807 21808 21809 |
# File 'lib/aws-sdk-connect/types.rb', line 21802 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
21802 21803 21804 21805 21806 21807 21808 21809 |
# File 'lib/aws-sdk-connect/types.rb', line 21802 class ListQueueQuickConnectsRequest < Struct.new( :instance_id, :queue_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |