Class: Aws::Connect::Types::ListQueuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


24213
24214
24215
24216
24217
24218
24219
24220
# File 'lib/aws-sdk-connect/types.rb', line 24213

class ListQueuesRequest < Struct.new(
  :instance_id,
  :queue_types,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. The default MaxResult size is 100.

Returns:

  • (Integer)


24213
24214
24215
24216
24217
24218
24219
24220
# File 'lib/aws-sdk-connect/types.rb', line 24213

class ListQueuesRequest < Struct.new(
  :instance_id,
  :queue_types,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


24213
24214
24215
24216
24217
24218
24219
24220
# File 'lib/aws-sdk-connect/types.rb', line 24213

class ListQueuesRequest < Struct.new(
  :instance_id,
  :queue_types,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_typesArray<String>

The type of queue.

Returns:

  • (Array<String>)


24213
24214
24215
24216
24217
24218
24219
24220
# File 'lib/aws-sdk-connect/types.rb', line 24213

class ListQueuesRequest < Struct.new(
  :instance_id,
  :queue_types,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end