Class: Aws::Connect::Types::ListQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#queue_types ⇒ Array<String>
The type of queue.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24213 24214 24215 24216 24217 24218 24219 24220 |
# File 'lib/aws-sdk-connect/types.rb', line 24213 class ListQueuesRequest < Struct.new( :instance_id, :queue_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24213 24214 24215 24216 24217 24218 24219 24220 |
# File 'lib/aws-sdk-connect/types.rb', line 24213 class ListQueuesRequest < Struct.new( :instance_id, :queue_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24213 24214 24215 24216 24217 24218 24219 24220 |
# File 'lib/aws-sdk-connect/types.rb', line 24213 class ListQueuesRequest < Struct.new( :instance_id, :queue_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#queue_types ⇒ Array<String>
The type of queue.
24213 24214 24215 24216 24217 24218 24219 24220 |
# File 'lib/aws-sdk-connect/types.rb', line 24213 class ListQueuesRequest < Struct.new( :instance_id, :queue_types, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |