Class: Aws::Connect::Types::ListQuickConnectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListQuickConnectsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#quick_connect_types ⇒ Array<String>
The type of quick connect.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. Both Instance ID and Instance ARN are supported input formats.
24270 24271 24272 24273 24274 24275 24276 24277 |
# File 'lib/aws-sdk-connect/types.rb', line 24270 class ListQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :quick_connect_types) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
24270 24271 24272 24273 24274 24275 24276 24277 |
# File 'lib/aws-sdk-connect/types.rb', line 24270 class ListQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :quick_connect_types) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24270 24271 24272 24273 24274 24275 24276 24277 |
# File 'lib/aws-sdk-connect/types.rb', line 24270 class ListQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :quick_connect_types) SENSITIVE = [] include Aws::Structure end |
#quick_connect_types ⇒ Array<String>
The type of quick connect. In the Connect Customer admin website, when you create a quick connect, you are prompted to assign one of the following types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE).
24270 24271 24272 24273 24274 24275 24276 24277 |
# File 'lib/aws-sdk-connect/types.rb', line 24270 class ListQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :quick_connect_types) SENSITIVE = [] include Aws::Structure end |