Class: Aws::Connect::Types::ListRoutingProfileQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRoutingProfileQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID][1] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22355 22356 22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-connect/types.rb', line 22355 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
22355 22356 22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-connect/types.rb', line 22355 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22355 22356 22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-connect/types.rb', line 22355 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
22355 22356 22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-connect/types.rb', line 22355 class ListRoutingProfileQueuesRequest < Struct.new( :instance_id, :routing_profile_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |