Class: Aws::Connect::Types::ListRoutingProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListRoutingProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22401 22402 22403 22404 22405 22406 22407 |
# File 'lib/aws-sdk-connect/types.rb', line 22401 class ListRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
22401 22402 22403 22404 22405 22406 22407 |
# File 'lib/aws-sdk-connect/types.rb', line 22401 class ListRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22401 22402 22403 22404 22405 22406 22407 |
# File 'lib/aws-sdk-connect/types.rb', line 22401 class ListRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |