Class: Aws::Connect::Types::ListSecurityProfileAIAgentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfileAIAgentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#security_profile_id ⇒ String
The identifier for the security profle.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24681 24682 24683 24684 24685 24686 24687 24688 |
# File 'lib/aws-sdk-connect/types.rb', line 24681 class ListSecurityProfileAIAgentsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
24681 24682 24683 24684 24685 24686 24687 24688 |
# File 'lib/aws-sdk-connect/types.rb', line 24681 class ListSecurityProfileAIAgentsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24681 24682 24683 24684 24685 24686 24687 24688 |
# File 'lib/aws-sdk-connect/types.rb', line 24681 class ListSecurityProfileAIAgentsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#security_profile_id ⇒ String
The identifier for the security profle.
24681 24682 24683 24684 24685 24686 24687 24688 |
# File 'lib/aws-sdk-connect/types.rb', line 24681 class ListSecurityProfileAIAgentsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |