Class: Aws::Connect::Types::ListSecurityProfileAIAgentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfileAIAgentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_ai_agents ⇒ Array<Types::AIAgent>
A list of the allowed AI agents and their types.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#allowed_ai_agents ⇒ Array<Types::AIAgent>
A list of the allowed AI agents and their types.
24710 24711 24712 24713 24714 24715 24716 24717 |
# File 'lib/aws-sdk-connect/types.rb', line 24710 class ListSecurityProfileAIAgentsResponse < Struct.new( :allowed_ai_agents, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
24710 24711 24712 24713 24714 24715 24716 24717 |
# File 'lib/aws-sdk-connect/types.rb', line 24710 class ListSecurityProfileAIAgentsResponse < Struct.new( :allowed_ai_agents, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
24710 24711 24712 24713 24714 24715 24716 24717 |
# File 'lib/aws-sdk-connect/types.rb', line 24710 class ListSecurityProfileAIAgentsResponse < Struct.new( :allowed_ai_agents, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
24710 24711 24712 24713 24714 24715 24716 24717 |
# File 'lib/aws-sdk-connect/types.rb', line 24710 class ListSecurityProfileAIAgentsResponse < Struct.new( :allowed_ai_agents, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |