Class: Aws::Connect::Types::ListSecurityProfileFlowModulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfileFlowModulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool.
-
#last_modified_region ⇒ String
The Region that flow module was last modified in.
-
#last_modified_time ⇒ Time
The time the flow module was last modified.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#allowed_flow_modules ⇒ Array<Types::FlowModule>
A list of Flow Modules an AI Agent can invoke as a tool.
22663 22664 22665 22666 22667 22668 22669 22670 |
# File 'lib/aws-sdk-connect/types.rb', line 22663 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Region that flow module was last modified in.
22663 22664 22665 22666 22667 22668 22669 22670 |
# File 'lib/aws-sdk-connect/types.rb', line 22663 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the flow module was last modified.
22663 22664 22665 22666 22667 22668 22669 22670 |
# File 'lib/aws-sdk-connect/types.rb', line 22663 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22663 22664 22665 22666 22667 22668 22669 22670 |
# File 'lib/aws-sdk-connect/types.rb', line 22663 class ListSecurityProfileFlowModulesResponse < Struct.new( :allowed_flow_modules, :next_token, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |