Class: Aws::Connect::Types::ListSecurityProfilePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListSecurityProfilePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#security_profile_id ⇒ String
The identifier for the security profle.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
24871 24872 24873 24874 24875 24876 24877 24878 |
# File 'lib/aws-sdk-connect/types.rb', line 24871 class ListSecurityProfilePermissionsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
24871 24872 24873 24874 24875 24876 24877 24878 |
# File 'lib/aws-sdk-connect/types.rb', line 24871 class ListSecurityProfilePermissionsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
24871 24872 24873 24874 24875 24876 24877 24878 |
# File 'lib/aws-sdk-connect/types.rb', line 24871 class ListSecurityProfilePermissionsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#security_profile_id ⇒ String
The identifier for the security profle.
24871 24872 24873 24874 24875 24876 24877 24878 |
# File 'lib/aws-sdk-connect/types.rb', line 24871 class ListSecurityProfilePermissionsRequest < Struct.new( :security_profile_id, :instance_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |