Class: Aws::Connect::Types::ListTaskTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTaskTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#name ⇒ String
The name of the task template.
-
#next_token ⇒ String
The token for the next set of results.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
25030 25031 25032 25033 25034 25035 25036 25037 25038 |
# File 'lib/aws-sdk-connect/types.rb', line 25030 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
It is not expected that you set this.
25030 25031 25032 25033 25034 25035 25036 25037 25038 |
# File 'lib/aws-sdk-connect/types.rb', line 25030 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
25030 25031 25032 25033 25034 25035 25036 25037 25038 |
# File 'lib/aws-sdk-connect/types.rb', line 25030 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
It is not expected that you set this because the value returned in the previous response is always null.
25030 25031 25032 25033 25034 25035 25036 25037 25038 |
# File 'lib/aws-sdk-connect/types.rb', line 25030 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to
it. Tasks can only be created from ACTIVE templates. If a template
is marked as INACTIVE, then a task that refers to this template
cannot be created.
25030 25031 25032 25033 25034 25035 25036 25037 25038 |
# File 'lib/aws-sdk-connect/types.rb', line 25030 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |