Class: Aws::Connect::Types::ListTaskTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTaskTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#name ⇒ String
The name of the task template.
-
#next_token ⇒ String
The token for the next set of results.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
22620 22621 22622 22623 22624 22625 22626 22627 22628 |
# File 'lib/aws-sdk-connect/types.rb', line 22620 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
It is not expected that you set this.
22620 22621 22622 22623 22624 22625 22626 22627 22628 |
# File 'lib/aws-sdk-connect/types.rb', line 22620 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
22620 22621 22622 22623 22624 22625 22626 22627 22628 |
# File 'lib/aws-sdk-connect/types.rb', line 22620 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
It is not expected that you set this because the value returned in the previous response is always null.
22620 22621 22622 22623 22624 22625 22626 22627 22628 |
# File 'lib/aws-sdk-connect/types.rb', line 22620 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to it. Tasks can only be created from ACTIVE templates. If a template is marked as INACTIVE, then a task that refers to this template cannot be created.
22620 22621 22622 22623 22624 22625 22626 22627 22628 |
# File 'lib/aws-sdk-connect/types.rb', line 22620 class ListTaskTemplatesRequest < Struct.new( :instance_id, :next_token, :max_results, :status, :name) SENSITIVE = [] include Aws::Structure end |