Class: Aws::Connect::Types::ListTestCaseExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTestCaseExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
Filter executions that started before this time.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#start_time ⇒ Integer
Filter executions that started after this time.
-
#status ⇒ String
Filter executions by status.
-
#test_case_id ⇒ String
Filter executions by test case identifier.
-
#test_case_name ⇒ String
Filter executions by test case name.
Instance Attribute Details
#end_time ⇒ Integer
Filter executions that started before this time.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
Filter executions that started after this time.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter executions by status.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
Filter executions by test case identifier.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#test_case_name ⇒ String
Filter executions by test case name.
25154 25155 25156 25157 25158 25159 25160 25161 25162 25163 25164 25165 |
# File 'lib/aws-sdk-connect/types.rb', line 25154 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |