Class: Aws::Connect::Types::ListTestCaseExecutionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

Filter executions that started before this time.

Returns:

  • (Time)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance.

Returns:

  • (String)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

Filter executions that started after this time.

Returns:

  • (Time)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter executions by status.

Returns:

  • (String)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_idString

Filter executions by test case identifier.

Returns:

  • (String)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_nameString

Filter executions by test case name.

Returns:

  • (String)


22980
22981
22982
22983
22984
22985
22986
22987
22988
22989
22990
22991
# File 'lib/aws-sdk-connect/types.rb', line 22980

class ListTestCaseExecutionsRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :test_case_name,
  :start_time,
  :end_time,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end