Class: Aws::Connect::Types::ListTestCaseExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListTestCaseExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
Filter executions that started before this time.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#start_time ⇒ Time
Filter executions that started after this time.
-
#status ⇒ String
Filter executions by status.
-
#test_case_id ⇒ String
Filter executions by test case identifier.
-
#test_case_name ⇒ String
Filter executions by test case name.
Instance Attribute Details
#end_time ⇒ Time
Filter executions that started before this time.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Filter executions that started after this time.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter executions by status.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
Filter executions by test case identifier.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#test_case_name ⇒ String
Filter executions by test case name.
22980 22981 22982 22983 22984 22985 22986 22987 22988 22989 22990 22991 |
# File 'lib/aws-sdk-connect/types.rb', line 22980 class ListTestCaseExecutionsRequest < Struct.new( :instance_id, :test_case_id, :test_case_name, :start_time, :end_time, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |