Class: Aws::Connect::Types::ListUseCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUseCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Provides summary information about the use cases for the specified integration association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#integration_association_id ⇒ String
The identifier for the integration association.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
23173 23174 23175 23176 23177 23178 23179 23180 |
# File 'lib/aws-sdk-connect/types.rb', line 23173 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#integration_association_id ⇒ String
The identifier for the integration association.
23173 23174 23175 23176 23177 23178 23179 23180 |
# File 'lib/aws-sdk-connect/types.rb', line 23173 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23173 23174 23175 23176 23177 23178 23179 23180 |
# File 'lib/aws-sdk-connect/types.rb', line 23173 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23173 23174 23175 23176 23177 23178 23179 23180 |
# File 'lib/aws-sdk-connect/types.rb', line 23173 class ListUseCasesRequest < Struct.new( :instance_id, :integration_association_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |