Class: Aws::Connect::Types::ListUserNotificationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:



23273
23274
23275
23276
23277
23278
23279
23280
# File 'lib/aws-sdk-connect/types.rb', line 23273

class ListUserNotificationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page. Valid range is 1-1000.

Returns:



23273
23274
23275
23276
23277
23278
23279
23280
# File 'lib/aws-sdk-connect/types.rb', line 23273

class ListUserNotificationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.

Returns:



23273
23274
23275
23276
23277
23278
23279
23280
# File 'lib/aws-sdk-connect/types.rb', line 23273

class ListUserNotificationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier of the user.

Returns:



23273
23274
23275
23276
23277
23278
23279
23280
# File 'lib/aws-sdk-connect/types.rb', line 23273

class ListUserNotificationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end