Class: Aws::Connect::Types::ListUserNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUserNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#user_id ⇒ String
The identifier of the user.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
23273 23274 23275 23276 23277 23278 23279 23280 |
# File 'lib/aws-sdk-connect/types.rb', line 23273 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. Valid range is 1-1000.
23273 23274 23275 23276 23277 23278 23279 23280 |
# File 'lib/aws-sdk-connect/types.rb', line 23273 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.
23273 23274 23275 23276 23277 23278 23279 23280 |
# File 'lib/aws-sdk-connect/types.rb', line 23273 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user.
23273 23274 23275 23276 23277 23278 23279 23280 |
# File 'lib/aws-sdk-connect/types.rb', line 23273 class ListUserNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :user_id) SENSITIVE = [] include Aws::Structure end |