Class: Aws::Connect::Types::ListUserProficienciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListUserProficienciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#user_id ⇒ String
The identifier of the user account.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-connect/types.rb', line 23307 class ListUserProficienciesRequest < Struct.new( :instance_id, :user_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-connect/types.rb', line 23307 class ListUserProficienciesRequest < Struct.new( :instance_id, :user_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-connect/types.rb', line 23307 class ListUserProficienciesRequest < Struct.new( :instance_id, :user_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
23307 23308 23309 23310 23311 23312 23313 23314 |
# File 'lib/aws-sdk-connect/types.rb', line 23307 class ListUserProficienciesRequest < Struct.new( :instance_id, :user_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |