Class: Aws::Connect::Types::ListViewsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ListViewsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#type ⇒ String
The type of the view.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
23478 23479 23480 23481 23482 23483 23484 23485 |
# File 'lib/aws-sdk-connect/types.rb', line 23478 class ListViewsRequest < Struct.new( :instance_id, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. The default MaxResult size is 100.
23478 23479 23480 23481 23482 23483 23484 23485 |
# File 'lib/aws-sdk-connect/types.rb', line 23478 class ListViewsRequest < Struct.new( :instance_id, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
23478 23479 23480 23481 23482 23483 23484 23485 |
# File 'lib/aws-sdk-connect/types.rb', line 23478 class ListViewsRequest < Struct.new( :instance_id, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the view.
23478 23479 23480 23481 23482 23483 23484 23485 |
# File 'lib/aws-sdk-connect/types.rb', line 23478 class ListViewsRequest < Struct.new( :instance_id, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |