Class: Aws::Connect::Types::MetricDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::MetricDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains the full definition of a metric, including its calculation, unit, status, and trend indicator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the metric.
-
#category ⇒ String
The category of the metric.
-
#created_time ⇒ Time
The timestamp of when the metric was created.
-
#created_user ⇒ Types::CreatedByInfo
The user that created the metric.
-
#creation_method ⇒ String
The method used to create the metric.
-
#default_stat ⇒ String
The default stat aggregation for the metric.
-
#description ⇒ String
The description of the metric.
-
#effective_time ⇒ Time
The earliest time that can be queried for this metric.
-
#filters ⇒ Array<Types::AvailableFilter>
The filters applied to the metric.
-
#groupings ⇒ Array<String>
The groupings available for this metric.
-
#id ⇒ String
The identifier of the metric.
-
#last_modified_region ⇒ String
The region where the metric was last modified.
-
#last_modified_time ⇒ Time
The timestamp of when the metric was last modified.
-
#last_modified_user ⇒ Types::CreatedByInfo
The user that last modified the metric.
-
#metric_calculation ⇒ Types::MetricCalculation
The calculation definition for the metric.
-
#name ⇒ String
The name of the metric.
-
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted.
-
#primary_event_source ⇒ String
The primary event source for the metric data.
-
#primary_event_source_effective_timestamp_type ⇒ String
The timestamp type that determines where the metric appears on a time series.
-
#refresh_rate ⇒ Integer
The minimum interval, in seconds, between data refreshes for this metric.
-
#status ⇒ String
The publish status of the metric.
-
#supported_stats ⇒ Array<String>
The stat aggregations available for this metric.
-
#supports_custom_calculation ⇒ Boolean
Specifies whether the metric can be used as a component of custom metrics.
-
#supports_preaggregate_calculation ⇒ Boolean
Specifies whether the metric can be used inside aggregating statistical functions (SUM, AVG, etc.) in custom metric calculations.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#type ⇒ String
The type of the metric.
-
#unit ⇒ String
The display unit for the metric's data.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the metric. May be qualified with
$SAVED or $LATEST.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp of when the metric was created.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#created_user ⇒ Types::CreatedByInfo
The user that created the metric. The creator for metrics created
through the CreateMetric API will be Amazon Connect API.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_method ⇒ String
The method used to create the metric. Valid values:
SERVICE_LEVEL_BUILDER (created with the guided service-level
experience) | METRIC_BUILDER (created with the free-form metric
builder).
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#default_stat ⇒ String
The default stat aggregation for the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#effective_time ⇒ Time
The earliest time that can be queried for this metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::AvailableFilter>
The filters applied to the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#groupings ⇒ Array<String>
The groupings available for this metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The region where the metric was last modified.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the metric was last modified.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_user ⇒ Types::CreatedByInfo
The user that last modified the metric. For modifications made
through the API, this will be Amazon Connect API.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#metric_calculation ⇒ Types::MetricCalculation
The calculation definition for the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted. Valid
values: POSITIVE, NEUTRAL, NEGATIVE.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#primary_event_source ⇒ String
The primary event source for the metric data.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#primary_event_source_effective_timestamp_type ⇒ String
The timestamp type that determines where the metric appears on a time series.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#refresh_rate ⇒ Integer
The minimum interval, in seconds, between data refreshes for this metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The publish status of the metric. Valid values: PUBLISHED |
SAVED.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#supported_stats ⇒ Array<String>
The stat aggregations available for this metric.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#supports_custom_calculation ⇒ Boolean
Specifies whether the metric can be used as a component of custom metrics.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#supports_preaggregate_calculation ⇒ Boolean
Specifies whether the metric can be used inside aggregating statistical functions (SUM, AVG, etc.) in custom metric calculations.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the metric. Valid values: AWS_MANAGED |
CUSTOMER_MANAGED.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The display unit for the metric's data.
25814 25815 25816 25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 25829 25830 25831 25832 25833 25834 25835 25836 25837 25838 25839 25840 25841 25842 25843 25844 |
# File 'lib/aws-sdk-connect/types.rb', line 25814 class MetricDefinition < Struct.new( :arn, :id, :name, :description, :metric_calculation, :creation_method, :status, :type, :unit, :positive_trend_indicator, :groupings, :filters, :effective_time, :refresh_rate, :category, :supported_stats, :default_stat, :supports_preaggregate_calculation, :supports_custom_calculation, :primary_event_source, :primary_event_source_effective_timestamp_type, :created_time, :created_user, :last_modified_region, :last_modified_time, :last_modified_user, :tags) SENSITIVE = [] include Aws::Structure end |