Class: Aws::Connect::Types::MetricDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains the full definition of a metric, including its calculation, unit, status, and trend indicator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the metric. May be qualified with $SAVED or $LATEST.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#categoryString

The category of the metric.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp of when the metric was created.

Returns:

  • (Time)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_userTypes::CreatedByInfo

The user that created the metric. The creator for metrics created through the CreateMetric API will be Amazon Connect API.



25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_methodString

The method used to create the metric. Valid values: SERVICE_LEVEL_BUILDER (created with the guided service-level experience) | METRIC_BUILDER (created with the free-form metric builder).

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_statString

The default stat aggregation for the metric.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the metric.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#effective_timeTime

The earliest time that can be queried for this metric.

Returns:

  • (Time)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::AvailableFilter>

The filters applied to the metric.

Returns:



25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#groupingsArray<String>

The groupings available for this metric.

Returns:

  • (Array<String>)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the metric.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The region where the metric was last modified.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp of when the metric was last modified.

Returns:

  • (Time)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_userTypes::CreatedByInfo

The user that last modified the metric. For modifications made through the API, this will be Amazon Connect API.



25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#metric_calculationTypes::MetricCalculation

The calculation definition for the metric.



25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the metric.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#positive_trend_indicatorString

How an increase in the metric value should be interpreted. Valid values: POSITIVE, NEUTRAL, NEGATIVE.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#primary_event_sourceString

The primary event source for the metric data.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#primary_event_source_effective_timestamp_typeString

The timestamp type that determines where the metric appears on a time series.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_rateInteger

The minimum interval, in seconds, between data refreshes for this metric.

Returns:

  • (Integer)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The publish status of the metric. Valid values: PUBLISHED | SAVED.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#supported_statsArray<String>

The stat aggregations available for this metric.

Returns:

  • (Array<String>)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#supports_custom_calculationBoolean

Specifies whether the metric can be used as a component of custom metrics.

Returns:

  • (Boolean)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#supports_preaggregate_calculationBoolean

Specifies whether the metric can be used inside aggregating statistical functions (SUM, AVG, etc.) in custom metric calculations.

Returns:

  • (Boolean)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the metric. Valid values: AWS_MANAGED | CUSTOMER_MANAGED.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

The display unit for the metric's data.

Returns:

  • (String)


25773
25774
25775
25776
25777
25778
25779
25780
25781
25782
25783
25784
25785
25786
25787
25788
25789
25790
25791
25792
25793
25794
25795
25796
25797
25798
25799
25800
25801
25802
25803
# File 'lib/aws-sdk-connect/types.rb', line 25773

class MetricDefinition < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :metric_calculation,
  :creation_method,
  :status,
  :type,
  :unit,
  :positive_trend_indicator,
  :groupings,
  :filters,
  :effective_time,
  :refresh_rate,
  :category,
  :supported_stats,
  :default_stat,
  :supports_preaggregate_calculation,
  :supports_custom_calculation,
  :primary_event_source,
  :primary_event_source_effective_timestamp_type,
  :created_time,
  :created_user,
  :last_modified_region,
  :last_modified_time,
  :last_modified_user,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end