Class: Aws::Connect::Types::MonitorContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_monitor_capabilitiesArray<String>

Specify which monitoring actions the user is allowed to take. For example, whether the user is allowed to escalate from silent monitoring to barge. AllowedMonitorCapabilities is required if barge is enabled.

Returns:

  • (Array<String>)


26191
26192
26193
26194
26195
26196
26197
26198
26199
# File 'lib/aws-sdk-connect/types.rb', line 26191

class MonitorContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :user_id,
  :allowed_monitor_capabilities,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


26191
26192
26193
26194
26195
26196
26197
26198
26199
# File 'lib/aws-sdk-connect/types.rb', line 26191

class MonitorContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :user_id,
  :allowed_monitor_capabilities,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact.

Returns:

  • (String)


26191
26192
26193
26194
26195
26196
26197
26198
26199
# File 'lib/aws-sdk-connect/types.rb', line 26191

class MonitorContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :user_id,
  :allowed_monitor_capabilities,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.

Returns:

  • (String)


26191
26192
26193
26194
26195
26196
26197
26198
26199
# File 'lib/aws-sdk-connect/types.rb', line 26191

class MonitorContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :user_id,
  :allowed_monitor_capabilities,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier of the user account.

Returns:

  • (String)


26191
26192
26193
26194
26195
26196
26197
26198
26199
# File 'lib/aws-sdk-connect/types.rb', line 26191

class MonitorContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :user_id,
  :allowed_monitor_capabilities,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end