Class: Aws::Connect::Types::MonitorContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::MonitorContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_monitor_capabilities ⇒ Array<String>
Specify which monitoring actions the user is allowed to take.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#user_id ⇒ String
The identifier of the user account.
Instance Attribute Details
#allowed_monitor_capabilities ⇒ Array<String>
Specify which monitoring actions the user is allowed to take. For example, whether the user is allowed to escalate from silent monitoring to barge. AllowedMonitorCapabilities is required if barge is enabled.
24252 24253 24254 24255 24256 24257 24258 24259 24260 |
# File 'lib/aws-sdk-connect/types.rb', line 24252 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
24252 24253 24254 24255 24256 24257 24258 24259 24260 |
# File 'lib/aws-sdk-connect/types.rb', line 24252 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact.
24252 24253 24254 24255 24256 24257 24258 24259 24260 |
# File 'lib/aws-sdk-connect/types.rb', line 24252 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
24252 24253 24254 24255 24256 24257 24258 24259 24260 |
# File 'lib/aws-sdk-connect/types.rb', line 24252 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
24252 24253 24254 24255 24256 24257 24258 24259 24260 |
# File 'lib/aws-sdk-connect/types.rb', line 24252 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |