Class: Aws::Connect::Types::MonitorContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::MonitorContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_monitor_capabilities ⇒ Array<String>
Specify which monitoring actions the user is allowed to take.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#user_id ⇒ String
The identifier of the user account.
Instance Attribute Details
#allowed_monitor_capabilities ⇒ Array<String>
Specify which monitoring actions the user is allowed to take. For example, whether the user is allowed to escalate from silent monitoring to barge. AllowedMonitorCapabilities is required if barge is enabled.
26572 26573 26574 26575 26576 26577 26578 26579 26580 |
# File 'lib/aws-sdk-connect/types.rb', line 26572 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
26572 26573 26574 26575 26576 26577 26578 26579 26580 |
# File 'lib/aws-sdk-connect/types.rb', line 26572 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact.
26572 26573 26574 26575 26576 26577 26578 26579 26580 |
# File 'lib/aws-sdk-connect/types.rb', line 26572 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
26572 26573 26574 26575 26576 26577 26578 26579 26580 |
# File 'lib/aws-sdk-connect/types.rb', line 26572 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
26572 26573 26574 26575 26576 26577 26578 26579 26580 |
# File 'lib/aws-sdk-connect/types.rb', line 26572 class MonitorContactRequest < Struct.new( :instance_id, :contact_id, :user_id, :allowed_monitor_capabilities, :client_token) SENSITIVE = [] include Aws::Structure end |