Class: Aws::Connect::Types::NewSessionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::NewSessionDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Payload of chat properties to apply when starting a new contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#participant_details ⇒ Types::ParticipantDetails
The customer's details.
-
#streaming_configuration ⇒ Types::ChatStreamingConfiguration
The streaming configuration, such as the Amazon SNS streaming endpoint.
-
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes. They can be accessed in flows just like any other contact attributes.
There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.
25207 25208 25209 25210 25211 25212 25213 25214 |
# File 'lib/aws-sdk-connect/types.rb', line 25207 class NewSessionDetails < Struct.new( :supported_messaging_content_types, :participant_details, :attributes, :streaming_configuration) SENSITIVE = [] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
The customer's details.
25207 25208 25209 25210 25211 25212 25213 25214 |
# File 'lib/aws-sdk-connect/types.rb', line 25207 class NewSessionDetails < Struct.new( :supported_messaging_content_types, :participant_details, :attributes, :streaming_configuration) SENSITIVE = [] include Aws::Structure end |
#streaming_configuration ⇒ Types::ChatStreamingConfiguration
The streaming configuration, such as the Amazon SNS streaming endpoint.
25207 25208 25209 25210 25211 25212 25213 25214 |
# File 'lib/aws-sdk-connect/types.rb', line 25207 class NewSessionDetails < Struct.new( :supported_messaging_content_types, :participant_details, :attributes, :streaming_configuration) SENSITIVE = [] include Aws::Structure end |
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types. Supported types are
text/plain, text/markdown, application/json,
application/vnd.amazonaws.connect.message.interactive, and
application/vnd.amazonaws.connect.message.interactive.response.
Content types must always contain text/plain. You can then put
any other supported type in the list. For example, all the following
lists are valid because they contain text/plain: [text/plain, text/markdown, application/json], [text/markdown, text/plain],
[text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response].
25207 25208 25209 25210 25211 25212 25213 25214 |
# File 'lib/aws-sdk-connect/types.rb', line 25207 class NewSessionDetails < Struct.new( :supported_messaging_content_types, :participant_details, :attributes, :streaming_configuration) SENSITIVE = [] include Aws::Structure end |