Class: Aws::Connect::Types::NewSessionDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Payload of chat properties to apply when starting a new contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes. They can be accessed in flows just like any other contact attributes.

There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.

Returns:

  • (Hash<String,String>)


24559
24560
24561
24562
24563
24564
24565
24566
# File 'lib/aws-sdk-connect/types.rb', line 24559

class NewSessionDetails < Struct.new(
  :supported_messaging_content_types,
  :participant_details,
  :attributes,
  :streaming_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#participant_detailsTypes::ParticipantDetails

The customer’s details.



24559
24560
24561
24562
24563
24564
24565
24566
# File 'lib/aws-sdk-connect/types.rb', line 24559

class NewSessionDetails < Struct.new(
  :supported_messaging_content_types,
  :participant_details,
  :attributes,
  :streaming_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_configurationTypes::ChatStreamingConfiguration

The streaming configuration, such as the Amazon SNS streaming endpoint.



24559
24560
24561
24562
24563
24564
24565
24566
# File 'lib/aws-sdk-connect/types.rb', line 24559

class NewSessionDetails < Struct.new(
  :supported_messaging_content_types,
  :participant_details,
  :attributes,
  :streaming_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#supported_messaging_content_typesArray<String>

The supported chat message content types. Supported types are ‘text/plain`, `text/markdown`, `application/json`, `application/vnd.amazonaws.connect.message.interactive`, and `application/vnd.amazonaws.connect.message.interactive.response`.

Content types must always contain ‘ text/plain`. You can then put any other supported type in the list. For example, all the following lists are valid because they contain `text/plain`: `[text/plain, text/markdown, application/json]`, ` [text/markdown, text/plain]`, `[text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response]`.

Returns:

  • (Array<String>)


24559
24560
24561
24562
24563
24564
24565
24566
# File 'lib/aws-sdk-connect/types.rb', line 24559

class NewSessionDetails < Struct.new(
  :supported_messaging_content_types,
  :participant_details,
  :attributes,
  :streaming_configuration)
  SENSITIVE = []
  include Aws::Structure
end