Class: Aws::Connect::Types::Notification
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Notification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a notification, including its content, priority, recipients, and metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the notification.
-
#content ⇒ Hash<String,String>
The localized content of the notification.
-
#created_at ⇒ Time
The timestamp when the notification was created.
-
#expires_at ⇒ Time
The timestamp when the notification expires and is no longer displayed to users.
-
#id ⇒ String
The unique identifier for the notification.
-
#last_modified_region ⇒ String
The AWS Region where the notification was last modified.
-
#last_modified_time ⇒ Time
The timestamp when the notification was last modified.
-
#priority ⇒ String
The priority level of the notification.
-
#recipients ⇒ Array<String>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the notification.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Hash<String,String>
The localized content of the notification. A map where keys are locale codes and values are the notification text in that locale.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the notification was created.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
The timestamp when the notification expires and is no longer displayed to users.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the notification.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The AWS Region where the notification was last modified.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the notification was last modified.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The priority level of the notification. Valid values are URGENT, HIGH, and LOW.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#recipients ⇒ Array<String>
A list of Amazon Resource Names (ARNs) identifying the recipients of the notification. Maximum of 200 recipients.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, ‘{ “Tags”: “key2”:“value2” }`.
24225 24226 24227 24228 24229 24230 24231 24232 24233 24234 24235 24236 24237 24238 |
# File 'lib/aws-sdk-connect/types.rb', line 24225 class Notification < Struct.new( :content, :id, :arn, :priority, :recipients, :last_modified_time, :created_at, :expires_at, :last_modified_region, :tags) SENSITIVE = [] include Aws::Structure end |