Class: Aws::Connect::Types::NotificationSearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::NotificationSearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The search criteria to be used to return notifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#and_conditions ⇒ Array<Types::NotificationSearchCriteria>
A list of conditions that must all be satisfied.
-
#or_conditions ⇒ Array<Types::NotificationSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
-
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
Instance Attribute Details
#and_conditions ⇒ Array<Types::NotificationSearchCriteria>
A list of conditions that must all be satisfied.
24057 24058 24059 24060 24061 24062 24063 |
# File 'lib/aws-sdk-connect/types.rb', line 24057 class NotificationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#or_conditions ⇒ Array<Types::NotificationSearchCriteria>
A list of conditions to be met, where at least one condition must be satisfied.
24057 24058 24059 24060 24061 24062 24063 |
# File 'lib/aws-sdk-connect/types.rb', line 24057 class NotificationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |
#string_condition ⇒ Types::StringCondition
A leaf node condition which can be used to specify a string condition.
24057 24058 24059 24060 24061 24062 24063 |
# File 'lib/aws-sdk-connect/types.rb', line 24057 class NotificationSearchCriteria < Struct.new( :or_conditions, :and_conditions, :string_condition) SENSITIVE = [] include Aws::Structure end |