Class: Aws::Connect::Types::ParticipantTimerValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

ParticipantTimerValue is a union - when making an API calls you must set exactly one of the members.

The value of the timer. Either the timer action (Unset to delete the timer), or the duration of the timer in minutes. Only one value can be set.

For more information about how chat timeouts work, see Set up chat timeouts for human participants.

Defined Under Namespace

Classes: ParticipantTimerAction, ParticipantTimerDurationInMinutes, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#participant_timer_actionString

The timer action. Currently only one value is allowed: Unset. It deletes a timer.

Returns:

  • (String)


27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
# File 'lib/aws-sdk-connect/types.rb', line 27275

class ParticipantTimerValue < Struct.new(
  :participant_timer_action,
  :participant_timer_duration_in_minutes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParticipantTimerAction < ParticipantTimerValue; end
  class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end
  class Unknown < ParticipantTimerValue; end
end

#participant_timer_duration_in_minutesInteger

The duration of a timer, in minutes.

Returns:

  • (Integer)


27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
# File 'lib/aws-sdk-connect/types.rb', line 27275

class ParticipantTimerValue < Struct.new(
  :participant_timer_action,
  :participant_timer_duration_in_minutes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParticipantTimerAction < ParticipantTimerValue; end
  class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end
  class Unknown < ParticipantTimerValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



27275
27276
27277
# File 'lib/aws-sdk-connect/types.rb', line 27275

def unknown
  @unknown
end