Class: Aws::Connect::Types::ParticipantTimerValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ParticipantTimerValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Note:
ParticipantTimerValue is a union - when making an API calls you must set exactly one of the members.
The value of the timer. Either the timer action (Unset to delete the
timer), or the duration of the timer in minutes. Only one value can be
set.
For more information about how chat timeouts work, see Set up chat timeouts for human participants.
Defined Under Namespace
Classes: ParticipantTimerAction, ParticipantTimerDurationInMinutes, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#participant_timer_action ⇒ String
The timer action.
-
#participant_timer_duration_in_minutes ⇒ Integer
The duration of a timer, in minutes.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#participant_timer_action ⇒ String
The timer action. Currently only one value is allowed: Unset. It
deletes a timer.
26872 26873 26874 26875 26876 26877 26878 26879 26880 26881 26882 26883 |
# File 'lib/aws-sdk-connect/types.rb', line 26872 class ParticipantTimerValue < Struct.new( :participant_timer_action, :participant_timer_duration_in_minutes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParticipantTimerAction < ParticipantTimerValue; end class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end class Unknown < ParticipantTimerValue; end end |
#participant_timer_duration_in_minutes ⇒ Integer
The duration of a timer, in minutes.
26872 26873 26874 26875 26876 26877 26878 26879 26880 26881 26882 26883 |
# File 'lib/aws-sdk-connect/types.rb', line 26872 class ParticipantTimerValue < Struct.new( :participant_timer_action, :participant_timer_duration_in_minutes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ParticipantTimerAction < ParticipantTimerValue; end class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end class Unknown < ParticipantTimerValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
26872 26873 26874 |
# File 'lib/aws-sdk-connect/types.rb', line 26872 def unknown @unknown end |