Class: Aws::Connect::Types::ParticipantTimerValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Note:

ParticipantTimerValue is a union - when making an API calls you must set exactly one of the members.

The value of the timer. Either the timer action (Unset to delete the timer), or the duration of the timer in minutes. Only one value can be set.

For more information about how chat timeouts work, see [Set up chat timeouts for human participants].

[1]: docs.aws.amazon.com/connect/latest/adminguide/setup-chat-timeouts.html

Defined Under Namespace

Classes: ParticipantTimerAction, ParticipantTimerDurationInMinutes, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#participant_timer_actionString

The timer action. Currently only one value is allowed: Unset. It deletes a timer.

Returns:

  • (String)


25059
25060
25061
25062
25063
25064
25065
25066
25067
25068
25069
25070
# File 'lib/aws-sdk-connect/types.rb', line 25059

class ParticipantTimerValue < Struct.new(
  :participant_timer_action,
  :participant_timer_duration_in_minutes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParticipantTimerAction < ParticipantTimerValue; end
  class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end
  class Unknown < ParticipantTimerValue; end
end

#participant_timer_duration_in_minutesInteger

The duration of a timer, in minutes.

Returns:

  • (Integer)


25059
25060
25061
25062
25063
25064
25065
25066
25067
25068
25069
25070
# File 'lib/aws-sdk-connect/types.rb', line 25059

class ParticipantTimerValue < Struct.new(
  :participant_timer_action,
  :participant_timer_duration_in_minutes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ParticipantTimerAction < ParticipantTimerValue; end
  class ParticipantTimerDurationInMinutes < ParticipantTimerValue; end
  class Unknown < ParticipantTimerValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



25059
25060
25061
# File 'lib/aws-sdk-connect/types.rb', line 25059

def unknown
  @unknown
end