Class: Aws::Connect::Types::PredefinedAttribute

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a predefined attribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_configurationTypes::PredefinedAttributeConfiguration

Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.



25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

Last modified region.

Returns:

  • (String)


25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Last modified time.

Returns:

  • (Time)


25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the predefined attribute.

Returns:

  • (String)


25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#purposesArray<String>

Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Connect Customer admin website.

Returns:

  • (Array<String>)


25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end

#valuesTypes::PredefinedAttributeValues

The values of the predefined attribute.



25590
25591
25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/aws-sdk-connect/types.rb', line 25590

class PredefinedAttribute < Struct.new(
  :name,
  :values,
  :purposes,
  :attribute_configuration,
  :last_modified_time,
  :last_modified_region)
  SENSITIVE = []
  include Aws::Structure
end