Class: Aws::Connect::Types::PredefinedAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::PredefinedAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a predefined attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_configuration ⇒ Types::PredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Amazon Connect admin website.
-
#last_modified_region ⇒ String
Last modified region.
-
#last_modified_time ⇒ Time
Last modified time.
-
#name ⇒ String
The name of the predefined attribute.
-
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes.
-
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
Instance Attribute Details
#attribute_configuration ⇒ Types::PredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Amazon Connect admin website.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
Last modified region.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Last modified time.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the predefined attribute.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Amazon Connect admin website.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
25584 25585 25586 25587 25588 25589 25590 25591 25592 25593 |
# File 'lib/aws-sdk-connect/types.rb', line 25584 class PredefinedAttribute < Struct.new( :name, :values, :purposes, :attribute_configuration, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |