Class: Aws::Connect::Types::QuestionOptionPointsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::QuestionOptionPointsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the points configuration for an answer option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_bonus ⇒ Boolean
The flag to mark the option as a bonus option.
-
#point_value ⇒ Integer
The point value assigned to the answer option.
Instance Attribute Details
#is_bonus ⇒ Boolean
The flag to mark the option as a bonus option.
26646 26647 26648 26649 26650 26651 |
# File 'lib/aws-sdk-connect/types.rb', line 26646 class QuestionOptionPointsConfiguration < Struct.new( :point_value, :is_bonus) SENSITIVE = [] include Aws::Structure end |
#point_value ⇒ Integer
The point value assigned to the answer option.
26646 26647 26648 26649 26650 26651 |
# File 'lib/aws-sdk-connect/types.rb', line 26646 class QuestionOptionPointsConfiguration < Struct.new( :point_value, :is_bonus) SENSITIVE = [] include Aws::Structure end |