Class: Aws::Connect::Types::Queue
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Queue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a queue.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the queue.
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#max_contacts ⇒ Integer
The maximum number of contacts that can be in the queue before it is considered full.
-
#name ⇒ String
The name of the queue.
-
#outbound_caller_config ⇒ Types::OutboundCallerConfig
The outbound caller ID name, number, and outbound whisper flow.
-
#outbound_email_config ⇒ Types::OutboundEmailConfig
The outbound email address ID for a specified queue.
-
#queue_arn ⇒ String
The Amazon Resource Name (ARN) for the queue.
-
#queue_id ⇒ String
The identifier for the queue.
-
#status ⇒ String
The status of the queue.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#description ⇒ String
The description of the queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#max_contacts ⇒ Integer
The maximum number of contacts that can be in the queue before it is considered full.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#outbound_caller_config ⇒ Types::OutboundCallerConfig
The outbound caller ID name, number, and outbound whisper flow.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#outbound_email_config ⇒ Types::OutboundEmailConfig
The outbound email address ID for a specified queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#queue_arn ⇒ String
The Amazon Resource Name (ARN) for the queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the queue.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
26123 26124 26125 26126 26127 26128 26129 26130 26131 26132 26133 26134 26135 26136 26137 26138 |
# File 'lib/aws-sdk-connect/types.rb', line 26123 class Queue < Struct.new( :name, :queue_arn, :queue_id, :description, :outbound_caller_config, :outbound_email_config, :hours_of_operation_id, :max_contacts, :status, :tags, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |