Class: Aws::Connect::Types::RealTimeContactAnalysisExtractedInformationValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

An individual value extracted from the conversation, including its content and the locations where it was found.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The text content of the extracted value.

Returns:

  • (String)


28641
28642
28643
28644
28645
28646
# File 'lib/aws-sdk-connect/types.rb', line 28641

class RealTimeContactAnalysisExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end

#points_of_interestArray<Types::RealTimeContactAnalysisTranscriptItemWithCharacterOffsets>

The sections in the conversation that indicate where the extracted value was found.



28641
28642
28643
28644
28645
28646
# File 'lib/aws-sdk-connect/types.rb', line 28641

class RealTimeContactAnalysisExtractedInformationValue < Struct.new(
  :content,
  :points_of_interest)
  SENSITIVE = []
  include Aws::Structure
end