Class: Aws::Connect::Types::RealTimeContactAnalysisExtractedInformationValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisExtractedInformationValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
An individual value extracted from the conversation, including its content and the locations where it was found.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The text content of the extracted value.
-
#points_of_interest ⇒ Array<Types::RealTimeContactAnalysisTranscriptItemWithCharacterOffsets>
The sections in the conversation that indicate where the extracted value was found.
Instance Attribute Details
#content ⇒ String
The text content of the extracted value.
28641 28642 28643 28644 28645 28646 |
# File 'lib/aws-sdk-connect/types.rb', line 28641 class RealTimeContactAnalysisExtractedInformationValue < Struct.new( :content, :points_of_interest) SENSITIVE = [] include Aws::Structure end |
#points_of_interest ⇒ Array<Types::RealTimeContactAnalysisTranscriptItemWithCharacterOffsets>
The sections in the conversation that indicate where the extracted value was found.
28641 28642 28643 28644 28645 28646 |
# File 'lib/aws-sdk-connect/types.rb', line 28641 class RealTimeContactAnalysisExtractedInformationValue < Struct.new( :content, :points_of_interest) SENSITIVE = [] include Aws::Structure end |