Class: Aws::Connect::Types::RealTimeContactAnalysisSegmentExtractedInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisSegmentExtractedInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Segment containing information extracted from the conversation. Each segment represents the results for a single extraction definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#extracted_values ⇒ Array<Types::RealTimeContactAnalysisExtractedInformationValue>
The list of values extracted from the conversation for this extraction definition.
-
#extraction_definition_display_label ⇒ String
The display label of the extraction definition that produced this result.
-
#extraction_definition_id ⇒ String
The identifier of the extraction definition that produced this result.
-
#extraction_definition_name ⇒ String
The name of the extraction definition that produced this result.
-
#failure_code ⇒ String
If the information failed to be extracted, one of the following failure codes occurs:.
Instance Attribute Details
#extracted_values ⇒ Array<Types::RealTimeContactAnalysisExtractedInformationValue>
The list of values extracted from the conversation for this
extraction definition. This field is empty when a FailureCode is
present.
28823 28824 28825 28826 28827 28828 28829 28830 28831 |
# File 'lib/aws-sdk-connect/types.rb', line 28823 class RealTimeContactAnalysisSegmentExtractedInformation < Struct.new( :extraction_definition_id, :extraction_definition_name, :extraction_definition_display_label, :extracted_values, :failure_code) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_display_label ⇒ String
The display label of the extraction definition that produced this result.
28823 28824 28825 28826 28827 28828 28829 28830 28831 |
# File 'lib/aws-sdk-connect/types.rb', line 28823 class RealTimeContactAnalysisSegmentExtractedInformation < Struct.new( :extraction_definition_id, :extraction_definition_name, :extraction_definition_display_label, :extracted_values, :failure_code) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_id ⇒ String
The identifier of the extraction definition that produced this result.
28823 28824 28825 28826 28827 28828 28829 28830 28831 |
# File 'lib/aws-sdk-connect/types.rb', line 28823 class RealTimeContactAnalysisSegmentExtractedInformation < Struct.new( :extraction_definition_id, :extraction_definition_name, :extraction_definition_display_label, :extracted_values, :failure_code) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_name ⇒ String
The name of the extraction definition that produced this result.
28823 28824 28825 28826 28827 28828 28829 28830 28831 |
# File 'lib/aws-sdk-connect/types.rb', line 28823 class RealTimeContactAnalysisSegmentExtractedInformation < Struct.new( :extraction_definition_id, :extraction_definition_name, :extraction_definition_display_label, :extracted_values, :failure_code) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
If the information failed to be extracted, one of the following failure codes occurs:
-
QUOTA_EXCEEDED: The number of concurrent analytics jobs reached your service quota. -
INSUFFICIENT_CONVERSATION_CONTENT: Information extraction requires a conversation with at least one turn from each participant. -
FAILED_SAFETY_GUIDELINES: The extracted information cannot be provided because it failed to meet system safety guidelines. -
INTERNAL_ERROR: Internal system error. -
MAX_PACKAGE_FEATURE_ONLY: Information extraction is only available in Amazon Connect Customer instances.
28823 28824 28825 28826 28827 28828 28829 28830 28831 |
# File 'lib/aws-sdk-connect/types.rb', line 28823 class RealTimeContactAnalysisSegmentExtractedInformation < Struct.new( :extraction_definition_id, :extraction_definition_name, :extraction_definition_display_label, :extracted_values, :failure_code) SENSITIVE = [] include Aws::Structure end |