Class: Aws::Connect::Types::RealTimeContactAnalysisSegmentTranscript

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The analyzed transcript segment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The content of the transcript. Can be redacted.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

The type of content of the item. For example, text/plain.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the participant.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the transcript.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#participant_idString

The identifier of the participant.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#participant_roleString

The role of the participant. For example, is it a customer, agent, or system.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#redactionTypes::RealTimeContactAnalysisTranscriptItemRedaction

Object describing redaction that was applied to the transcript. If transcript has the field it means part of the transcript was redacted.



28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#sentimentString

The sentiment detected for this piece of transcript.

Returns:

  • (String)


28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end

#timeTypes::RealTimeContactAnalysisTimeData

Field describing the time of the event. It can have different representations of time.



28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
# File 'lib/aws-sdk-connect/types.rb', line 28938

class RealTimeContactAnalysisSegmentTranscript < Struct.new(
  :id,
  :participant_id,
  :participant_role,
  :display_name,
  :content,
  :content_type,
  :time,
  :redaction,
  :sentiment)
  SENSITIVE = []
  include Aws::Structure
end