Class: Aws::Connect::Types::RealTimeContactAnalysisSegmentTranscript
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisSegmentTranscript
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
The analyzed transcript segment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the transcript.
-
#content_type ⇒ String
The type of content of the item.
-
#display_name ⇒ String
The display name of the participant.
-
#id ⇒ String
The identifier of the transcript.
-
#participant_id ⇒ String
The identifier of the participant.
-
#participant_role ⇒ String
The role of the participant.
-
#redaction ⇒ Types::RealTimeContactAnalysisTranscriptItemRedaction
Object describing redaction that was applied to the transcript.
-
#sentiment ⇒ String
The sentiment detected for this piece of transcript.
-
#time ⇒ Types::RealTimeContactAnalysisTimeData
Field describing the time of the event.
Instance Attribute Details
#content ⇒ String
The content of the transcript. Can be redacted.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The type of content of the item. For example, ‘text/plain`.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the participant.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the transcript.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#participant_id ⇒ String
The identifier of the participant.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#participant_role ⇒ String
The role of the participant. For example, is it a customer, agent, or system.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#redaction ⇒ Types::RealTimeContactAnalysisTranscriptItemRedaction
Object describing redaction that was applied to the transcript. If transcript has the field it means part of the transcript was redacted.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#sentiment ⇒ String
The sentiment detected for this piece of transcript.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Types::RealTimeContactAnalysisTimeData
Field describing the time of the event. It can have different representations of time.
26419 26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 |
# File 'lib/aws-sdk-connect/types.rb', line 26419 class RealTimeContactAnalysisSegmentTranscript < Struct.new( :id, :participant_id, :participant_role, :display_name, :content, :content_type, :time, :redaction, :sentiment) SENSITIVE = [] include Aws::Structure end |