Class: Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemRedaction
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemRedaction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Object describing redaction applied to the segment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#character_offsets ⇒ Array<Types::RealTimeContactAnalysisCharacterInterval>
List of character intervals each describing a part of the text that was redacted.
Instance Attribute Details
#character_offsets ⇒ Array<Types::RealTimeContactAnalysisCharacterInterval>
List of character intervals each describing a part of the text that
was redacted. For OutputType.Raw, part of the original text that
contains data that can be redacted. For OutputType.Redacted, part
of the string with redaction tag.
28987 28988 28989 28990 28991 |
# File 'lib/aws-sdk-connect/types.rb', line 28987 class RealTimeContactAnalysisTranscriptItemRedaction < Struct.new( :character_offsets) SENSITIVE = [] include Aws::Structure end |