Class: Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemWithContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Transcript representation containing Id, Content and list of character intervals that are associated with analysis data. For example, this object within an issue detected would describe both content that contains identified issue and intervals where that content is taken from.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#character_offsetsTypes::RealTimeContactAnalysisCharacterInterval

Begin and end offsets for a part of text.



27871
27872
27873
27874
27875
27876
27877
# File 'lib/aws-sdk-connect/types.rb', line 27871

class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new(
  :content,
  :id,
  :character_offsets)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

Part of the transcript content that contains identified issue. Can be redacted

Returns:

  • (String)


27871
27872
27873
27874
27875
27876
27877
# File 'lib/aws-sdk-connect/types.rb', line 27871

class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new(
  :content,
  :id,
  :character_offsets)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Transcript identifier. Matches the identifier from one of the TranscriptSegments.

Returns:

  • (String)


27871
27872
27873
27874
27875
27876
27877
# File 'lib/aws-sdk-connect/types.rb', line 27871

class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new(
  :content,
  :id,
  :character_offsets)
  SENSITIVE = []
  include Aws::Structure
end