Class: Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemWithContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RealTimeContactAnalysisTranscriptItemWithContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Transcript representation containing Id, Content and list of character intervals that are associated with analysis data. For example, this object within an issue detected would describe both content that contains identified issue and intervals where that content is taken from.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#character_offsets ⇒ Types::RealTimeContactAnalysisCharacterInterval
Begin and end offsets for a part of text.
-
#content ⇒ String
Part of the transcript content that contains identified issue.
-
#id ⇒ String
Transcript identifier.
Instance Attribute Details
#character_offsets ⇒ Types::RealTimeContactAnalysisCharacterInterval
Begin and end offsets for a part of text.
26975 26976 26977 26978 26979 26980 26981 |
# File 'lib/aws-sdk-connect/types.rb', line 26975 class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new( :content, :id, :character_offsets) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
Part of the transcript content that contains identified issue. Can be redacted
26975 26976 26977 26978 26979 26980 26981 |
# File 'lib/aws-sdk-connect/types.rb', line 26975 class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new( :content, :id, :character_offsets) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Transcript identifier. Matches the identifier from one of the TranscriptSegments.
26975 26976 26977 26978 26979 26980 26981 |
# File 'lib/aws-sdk-connect/types.rb', line 26975 class RealTimeContactAnalysisTranscriptItemWithContent < Struct.new( :content, :id, :character_offsets) SENSITIVE = [] include Aws::Structure end |