Class: Aws::Connect::Types::ReleasePhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ReleasePhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#phone_number_id ⇒ String
A unique identifier for the phone number.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
29428 29429 29430 29431 29432 29433 |
# File 'lib/aws-sdk-connect/types.rb', line 29428 class ReleasePhoneNumberRequest < Struct.new( :phone_number_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
A unique identifier for the phone number.
29428 29429 29430 29431 29432 29433 |
# File 'lib/aws-sdk-connect/types.rb', line 29428 class ReleasePhoneNumberRequest < Struct.new( :phone_number_id, :client_token) SENSITIVE = [] include Aws::Structure end |