Class: Aws::Connect::Types::ReleasePhoneNumberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


28336
28337
28338
28339
28340
28341
# File 'lib/aws-sdk-connect/types.rb', line 28336

class ReleasePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

A unique identifier for the phone number.

Returns:

  • (String)


28336
28337
28338
28339
28340
28341
# File 'lib/aws-sdk-connect/types.rb', line 28336

class ReleasePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end