Class: Aws::Connect::Types::ReplicateInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ReplicateInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:replica_alias]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#replica_alias ⇒ String
The alias for the replicated instance.
-
#replica_region ⇒ String
The Amazon Web Services Region where to replicate the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
28474 28475 28476 28477 28478 28479 28480 28481 |
# File 'lib/aws-sdk-connect/types.rb', line 28474 class ReplicateInstanceRequest < Struct.new( :instance_id, :replica_region, :client_token, :replica_alias) SENSITIVE = [:replica_alias] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the
instance ID in the Amazon Resource Name (ARN) of the instance.
You can provide the InstanceId, or the entire ARN.
28474 28475 28476 28477 28478 28479 28480 28481 |
# File 'lib/aws-sdk-connect/types.rb', line 28474 class ReplicateInstanceRequest < Struct.new( :instance_id, :replica_region, :client_token, :replica_alias) SENSITIVE = [:replica_alias] include Aws::Structure end |
#replica_alias ⇒ String
The alias for the replicated instance. The ReplicaAlias must be
unique.
28474 28475 28476 28477 28478 28479 28480 28481 |
# File 'lib/aws-sdk-connect/types.rb', line 28474 class ReplicateInstanceRequest < Struct.new( :instance_id, :replica_region, :client_token, :replica_alias) SENSITIVE = [:replica_alias] include Aws::Structure end |
#replica_region ⇒ String
The Amazon Web Services Region where to replicate the Connect Customer instance.
28474 28475 28476 28477 28478 28479 28480 28481 |
# File 'lib/aws-sdk-connect/types.rb', line 28474 class ReplicateInstanceRequest < Struct.new( :instance_id, :replica_region, :client_token, :replica_alias) SENSITIVE = [:replica_alias] include Aws::Structure end |