Class: Aws::Connect::Types::ReplicateInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:replica_alias]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


28214
28215
28216
28217
28218
28219
28220
28221
# File 'lib/aws-sdk-connect/types.rb', line 28214

class ReplicateInstanceRequest < Struct.new(
  :instance_id,
  :replica_region,
  :client_token,
  :replica_alias)
  SENSITIVE = [:replica_alias]
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. You can provide the InstanceId, or the entire ARN.

Returns:

  • (String)


28214
28215
28216
28217
28218
28219
28220
28221
# File 'lib/aws-sdk-connect/types.rb', line 28214

class ReplicateInstanceRequest < Struct.new(
  :instance_id,
  :replica_region,
  :client_token,
  :replica_alias)
  SENSITIVE = [:replica_alias]
  include Aws::Structure
end

#replica_aliasString

The alias for the replicated instance. The ReplicaAlias must be unique.

Returns:

  • (String)


28214
28215
28216
28217
28218
28219
28220
28221
# File 'lib/aws-sdk-connect/types.rb', line 28214

class ReplicateInstanceRequest < Struct.new(
  :instance_id,
  :replica_region,
  :client_token,
  :replica_alias)
  SENSITIVE = [:replica_alias]
  include Aws::Structure
end

#replica_regionString

The Amazon Web Services Region where to replicate the Connect Customer instance.

Returns:

  • (String)


28214
28215
28216
28217
28218
28219
28220
28221
# File 'lib/aws-sdk-connect/types.rb', line 28214

class ReplicateInstanceRequest < Struct.new(
  :instance_id,
  :replica_region,
  :client_token,
  :replica_alias)
  SENSITIVE = [:replica_alias]
  include Aws::Structure
end