Class: Aws::Connect::Types::ReplicationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ReplicationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Details about the status of the replication of a source Connect Customer instance across Amazon Web Services Regions. Use these details to understand the general status of a given replication. For information about why a replication process may fail, see [Why a ReplicateInstance call fails] in the *Create a replica of your existing Connect Customer instance* topic in the *Connect Customer Administrator Guide*.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_sign_in_endpoint ⇒ String
The URL that is used to sign-in to your Connect Customer instance according to your traffic distribution group configuration.
-
#replication_status_summary_list ⇒ Array<Types::ReplicationStatusSummary>
A list of replication status summaries.
-
#source_region ⇒ String
The Amazon Web Services Region where the source Connect Customer instance was created.
Instance Attribute Details
#global_sign_in_endpoint ⇒ String
The URL that is used to sign-in to your Connect Customer instance according to your traffic distribution group configuration. For more information about sign-in and traffic distribution groups, see
- Important things to know][1
-
in the *Create traffic distribution
groups* topic in the *Connect Customer Administrator Guide*.
[1]: docs.aws.amazon.com/connect/latest/adminguide/setup-traffic-distribution-groups.html
27497 27498 27499 27500 27501 27502 27503 |
# File 'lib/aws-sdk-connect/types.rb', line 27497 class ReplicationConfiguration < Struct.new( :replication_status_summary_list, :source_region, :global_sign_in_endpoint) SENSITIVE = [] include Aws::Structure end |
#replication_status_summary_list ⇒ Array<Types::ReplicationStatusSummary>
A list of replication status summaries. The summaries contain details about the replication of configuration information for Connect Customer resources, for each Amazon Web Services Region.
27497 27498 27499 27500 27501 27502 27503 |
# File 'lib/aws-sdk-connect/types.rb', line 27497 class ReplicationConfiguration < Struct.new( :replication_status_summary_list, :source_region, :global_sign_in_endpoint) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The Amazon Web Services Region where the source Connect Customer instance was created. This is the Region where the
- ReplicateInstance][1
-
API was called to start the replication
process.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_ReplicateInstance.html
27497 27498 27499 27500 27501 27502 27503 |
# File 'lib/aws-sdk-connect/types.rb', line 27497 class ReplicationConfiguration < Struct.new( :replication_status_summary_list, :source_region, :global_sign_in_endpoint) SENSITIVE = [] include Aws::Structure end |