Class: Aws::Connect::Types::ReplicationStatusSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ReplicationStatusSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Status information about the replication process, where you use the ReplicateInstance API to create a replica of your Connect Customer instance in another Amazon Web Services Region. For more information, see Set up Connect Customer Global Resiliency in the Connect Customer Administrator Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#region ⇒ String
The Amazon Web Services Region.
-
#replication_status ⇒ String
The state of the replication.
-
#replication_status_reason ⇒ String
A description of the replication status.
Instance Attribute Details
#region ⇒ String
The Amazon Web Services Region. This can be either the source or the replica Region, depending where it appears in the summary list.
29578 29579 29580 29581 29582 29583 29584 |
# File 'lib/aws-sdk-connect/types.rb', line 29578 class ReplicationStatusSummary < Struct.new( :region, :replication_status, :replication_status_reason) SENSITIVE = [] include Aws::Structure end |
#replication_status ⇒ String
The state of the replication.
29578 29579 29580 29581 29582 29583 29584 |
# File 'lib/aws-sdk-connect/types.rb', line 29578 class ReplicationStatusSummary < Struct.new( :region, :replication_status, :replication_status_reason) SENSITIVE = [] include Aws::Structure end |
#replication_status_reason ⇒ String
A description of the replication status. Use this information to resolve any issues that are preventing the successful replication of your Connect Customer instance to another Region.
29578 29579 29580 29581 29582 29583 29584 |
# File 'lib/aws-sdk-connect/types.rb', line 29578 class ReplicationStatusSummary < Struct.new( :region, :replication_status, :replication_status_reason) SENSITIVE = [] include Aws::Structure end |