Class: Aws::Connect::Types::RoutingCriteriaInputStepExpiry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RoutingCriteriaInputStepExpiry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Specify whether this routing criteria step should apply for only a limited amount of time, or if it should never expire.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_in_seconds ⇒ Integer
The number of seconds that the contact will be routed only to agents matching this routing step, if expiry was configured for this routing step.
Instance Attribute Details
#duration_in_seconds ⇒ Integer
The number of seconds that the contact will be routed only to agents matching this routing step, if expiry was configured for this routing step.
27596 27597 27598 27599 27600 |
# File 'lib/aws-sdk-connect/types.rb', line 27596 class RoutingCriteriaInputStepExpiry < Struct.new( :duration_in_seconds) SENSITIVE = [] include Aws::Structure end |