Class: Aws::Connect::Types::RoutingProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RoutingProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a routing profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_availability_timer ⇒ String
Whether agents with this routing profile will have their routing order calculated based on *time since their last inbound contact* or *longest idle time*.
-
#associated_manual_assignment_queue_ids ⇒ Array<String>
The IDs of the associated manual assignment queues.
-
#associated_queue_ids ⇒ Array<String>
The IDs of the associated queue.
-
#default_outbound_queue_id ⇒ String
The identifier of the default outbound queue for this routing profile.
-
#description ⇒ String
The description of the routing profile.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#is_default ⇒ Boolean
Whether this a default routing profile.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#media_concurrencies ⇒ Array<Types::MediaConcurrency>
The channels agents can handle in the Contact Control Panel (CCP) for this routing profile.
-
#name ⇒ String
The name of the routing profile.
-
#number_of_associated_manual_assignment_queues ⇒ Integer
The number of associated manual assignment queues in routing profile.
-
#number_of_associated_queues ⇒ Integer
The number of associated queues in routing profile.
-
#number_of_associated_users ⇒ Integer
The number of associated users in routing profile.
-
#routing_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the routing profile.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#agent_availability_timer ⇒ String
Whether agents with this routing profile will have their routing order calculated based on *time since their last inbound contact* or *longest idle time*.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#associated_manual_assignment_queue_ids ⇒ Array<String>
The IDs of the associated manual assignment queues.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#associated_queue_ids ⇒ Array<String>
The IDs of the associated queue.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#default_outbound_queue_id ⇒ String
The identifier of the default outbound queue for this routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Whether this a default routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#media_concurrencies ⇒ Array<Types::MediaConcurrency>
The channels agents can handle in the Contact Control Panel (CCP) for this routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#number_of_associated_manual_assignment_queues ⇒ Integer
The number of associated manual assignment queues in routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#number_of_associated_queues ⇒ Integer
The number of associated queues in routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#number_of_associated_users ⇒ Integer
The number of associated users in routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#routing_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 |
# File 'lib/aws-sdk-connect/types.rb', line 28072 class RoutingProfile < Struct.new( :instance_id, :name, :routing_profile_arn, :routing_profile_id, :description, :media_concurrencies, :default_outbound_queue_id, :tags, :number_of_associated_queues, :number_of_associated_manual_assignment_queues, :number_of_associated_users, :agent_availability_timer, :last_modified_time, :last_modified_region, :is_default, :associated_queue_ids, :associated_manual_assignment_queue_ids) SENSITIVE = [] include Aws::Structure end |