Class: Aws::Connect::Types::Rule
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::Rule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
-
#created_time ⇒ Time
The timestamp for when the rule was created.
-
#function ⇒ String
The conditions of the rule.
-
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the rule.
-
#last_updated_time ⇒ Time
The timestamp for the when the rule was last updated.
-
#name ⇒ String
The name of the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
-
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
Instance Attribute Details
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp for when the rule was created.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The conditions of the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp for the when the rule was last updated.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule. Used for
categorizing rules by capability (for example, GenerativeAI).
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
29233 29234 29235 29236 29237 29238 29239 29240 29241 29242 29243 29244 29245 29246 29247 29248 |
# File 'lib/aws-sdk-connect/types.rb', line 29233 class Rule < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :rule_capability_tiers, :function, :actions, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |