Class: Aws::Connect::Types::RuleAttributeAndCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RuleAttributeAndCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A list of conditions which would be applied together with an AND
condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tag_conditions ⇒ Array<Types::TagCondition>
A list of tag conditions that need to be applied with
ANDcondition.
Instance Attribute Details
#tag_conditions ⇒ Array<Types::TagCondition>
A list of tag conditions that need to be applied with AND
condition.
29348 29349 29350 29351 29352 |
# File 'lib/aws-sdk-connect/types.rb', line 29348 class RuleAttributeAndCondition < Struct.new( :tag_conditions) SENSITIVE = [] include Aws::Structure end |