Class: Aws::Connect::Types::RuleSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RuleSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A summary of information about a rule, returned as part of the
response to a SearchRules operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_summaries ⇒ Array<Types::ActionSummary>
A list of
ActionTypesassociated with a rule. -
#created_time ⇒ Time
The timestamp for when the rule was created.
-
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the rule.
-
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
-
#name ⇒ String
The name of the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
-
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
Instance Attribute Details
#action_summaries ⇒ Array<Types::ActionSummary>
A list of ActionTypes associated with a rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp for when the rule was created.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule. Used for
categorizing rules by capability (for example, GenerativeAI).
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |
#trigger_event_source ⇒ Types::RuleTriggerEventSource
The event source to trigger the rule.
30115 30116 30117 30118 30119 30120 30121 30122 30123 30124 30125 30126 30127 30128 30129 |
# File 'lib/aws-sdk-connect/types.rb', line 30115 class RuleSearchSummary < Struct.new( :name, :rule_id, :rule_arn, :trigger_event_source, :action_summaries, :rule_capability_tiers, :publish_status, :created_time, :last_updated_time, :last_updated_by, :tags) SENSITIVE = [] include Aws::Structure end |