Class: Aws::Connect::Types::RuleSearchSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

A summary of information about a rule, returned as part of the response to a SearchRules operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_summariesArray<Types::ActionSummary>

A list of ActionTypes associated with a rule.

Returns:



29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp for when the rule was created.

Returns:

  • (Time)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_byString

The Amazon Resource Name (ARN) of the user who last updated the rule.

Returns:

  • (String)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The timestamp for when the rule was last updated.

Returns:

  • (Time)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the rule.

Returns:

  • (String)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#publish_statusString

The publish status of the rule.

Returns:

  • (String)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_arnString

The Amazon Resource Name (ARN) of the rule.

Returns:

  • (String)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_capability_tiersArray<String>

The list of capability tiers associated with the rule. Used for categorizing rules by capability (for example, GenerativeAI).

Returns:

  • (Array<String>)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_idString

A unique identifier for the rule.

Returns:

  • (String)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_event_sourceTypes::RuleTriggerEventSource

The event source to trigger the rule.



29442
29443
29444
29445
29446
29447
29448
29449
29450
29451
29452
29453
29454
29455
29456
# File 'lib/aws-sdk-connect/types.rb', line 29442

class RuleSearchSummary < Struct.new(
  :name,
  :rule_id,
  :rule_arn,
  :trigger_event_source,
  :action_summaries,
  :rule_capability_tiers,
  :publish_status,
  :created_time,
  :last_updated_time,
  :last_updated_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end