Class: Aws::Connect::Types::RuleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RuleSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A list of ActionTypes associated with a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_summaries ⇒ Array<Types::ActionSummary>
A list of ActionTypes associated with a rule.
-
#created_time ⇒ Time
The timestamp for when the rule was created.
-
#event_source_name ⇒ String
The name of the event source.
-
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
-
#name ⇒ String
The name of the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
-
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
Instance Attribute Details
#action_summaries ⇒ Array<Types::ActionSummary>
A list of ActionTypes associated with a rule.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp for when the rule was created.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#event_source_name ⇒ String
The name of the event source.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule. Used for
categorizing rules by capability (for example, GenerativeAI).
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
30172 30173 30174 30175 30176 30177 30178 30179 30180 30181 30182 30183 30184 |
# File 'lib/aws-sdk-connect/types.rb', line 30172 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |