Class: Aws::Connect::Types::RuleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::RuleSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A list of ActionTypes associated with a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_summaries ⇒ Array<Types::ActionSummary>
A list of ActionTypes associated with a rule.
-
#created_time ⇒ Time
The timestamp for when the rule was created.
-
#event_source_name ⇒ String
The name of the event source.
-
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
-
#name ⇒ String
The name of the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
-
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
Instance Attribute Details
#action_summaries ⇒ Array<Types::ActionSummary>
A list of ActionTypes associated with a rule.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp for when the rule was created.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#event_source_name ⇒ String
The name of the event source.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp for when the rule was last updated.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_capability_tiers ⇒ Array<String>
The list of capability tiers associated with the rule. Used for
categorizing rules by capability (for example, GenerativeAI).
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
29522 29523 29524 29525 29526 29527 29528 29529 29530 29531 29532 29533 29534 |
# File 'lib/aws-sdk-connect/types.rb', line 29522 class RuleSummary < Struct.new( :name, :rule_id, :rule_arn, :event_source_name, :publish_status, :rule_capability_tiers, :action_summaries, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |