Class: Aws::Connect::Types::RulesSearchCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

The search criteria to be used to return rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#and_conditionsArray<Types::RulesSearchCriteria>

A list of conditions which would be applied together with an AND condition.

Returns:



29601
29602
29603
29604
29605
29606
29607
# File 'lib/aws-sdk-connect/types.rb', line 29601

class RulesSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#or_conditionsArray<Types::RulesSearchCriteria>

A list of conditions which would be applied together with an OR condition.

Returns:



29601
29602
29603
29604
29605
29606
29607
# File 'lib/aws-sdk-connect/types.rb', line 29601

class RulesSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end

#string_conditionTypes::StringCondition

A leaf node condition which can be used to specify a string condition.

The currently supported values for FieldName are Name, PublishStatus, EventSourceName, RuleId, IntegrationAssociationId, ActionSummaries, and RuleCapabilityTiers.



29601
29602
29603
29604
29605
29606
29607
# File 'lib/aws-sdk-connect/types.rb', line 29601

class RulesSearchCriteria < Struct.new(
  :or_conditions,
  :and_conditions,
  :string_condition)
  SENSITIVE = []
  include Aws::Structure
end