Class: Aws::Connect::Types::SearchAgentStatusesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.

Returns:

  • (String)


30828
30829
30830
30831
30832
30833
30834
30835
30836
# File 'lib/aws-sdk-connect/types.rb', line 30828

class SearchAgentStatusesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


30828
30829
30830
30831
30832
30833
30834
30835
30836
# File 'lib/aws-sdk-connect/types.rb', line 30828

class SearchAgentStatusesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


30828
30829
30830
30831
30832
30833
30834
30835
30836
# File 'lib/aws-sdk-connect/types.rb', line 30828

class SearchAgentStatusesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::AgentStatusSearchCriteria

The search criteria to be used to return agent statuses.



30828
30829
30830
30831
30832
30833
30834
30835
30836
# File 'lib/aws-sdk-connect/types.rb', line 30828

class SearchAgentStatusesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::AgentStatusSearchFilter

Filters to be applied to search results.



30828
30829
30830
30831
30832
30833
30834
30835
30836
# File 'lib/aws-sdk-connect/types.rb', line 30828

class SearchAgentStatusesRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_filter,
  :search_criteria)
  SENSITIVE = []
  include Aws::Structure
end