Class: Aws::Connect::Types::SearchAgentStatusesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchAgentStatusesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::AgentStatusSearchCriteria
The search criteria to be used to return agent statuses.
-
#search_filter ⇒ Types::AgentStatusSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
29674 29675 29676 29677 29678 29679 29680 29681 29682 |
# File 'lib/aws-sdk-connect/types.rb', line 29674 class SearchAgentStatusesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29674 29675 29676 29677 29678 29679 29680 29681 29682 |
# File 'lib/aws-sdk-connect/types.rb', line 29674 class SearchAgentStatusesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29674 29675 29676 29677 29678 29679 29680 29681 29682 |
# File 'lib/aws-sdk-connect/types.rb', line 29674 class SearchAgentStatusesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::AgentStatusSearchCriteria
The search criteria to be used to return agent statuses.
29674 29675 29676 29677 29678 29679 29680 29681 29682 |
# File 'lib/aws-sdk-connect/types.rb', line 29674 class SearchAgentStatusesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::AgentStatusSearchFilter
Filters to be applied to search results.
29674 29675 29676 29677 29678 29679 29680 29681 29682 |
# File 'lib/aws-sdk-connect/types.rb', line 29674 class SearchAgentStatusesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |