Class: Aws::Connect::Types::SearchAvailablePhoneNumbersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance that phone numbers are claimed to. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. You must enter InstanceId or TargetArn.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_country_codeString

The ISO country code.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_prefixString

The prefix of the phone number. If provided, it must contain + as part of the country code.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_typeString

The type of phone number.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through. You must enter InstanceId or TargetArn.

Returns:

  • (String)


29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
# File 'lib/aws-sdk-connect/types.rb', line 29726

class SearchAvailablePhoneNumbersRequest < Struct.new(
  :target_arn,
  :instance_id,
  :phone_number_country_code,
  :phone_number_type,
  :phone_number_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end