Class: Aws::Connect::Types::SearchAvailablePhoneNumbersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchAvailablePhoneNumbersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#phone_number_country_code ⇒ String
The ISO country code.
-
#phone_number_prefix ⇒ String
The prefix of the phone number.
-
#phone_number_type ⇒ String
The type of phone number.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance that phone numbers are claimed to. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance. You must enter ‘InstanceId` or `TargetArn`.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_country_code ⇒ String
The ISO country code.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_prefix ⇒ String
The prefix of the phone number. If provided, it must contain ‘+` as part of the country code.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_type ⇒ String
The type of phone number.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through. You must enter ‘InstanceId` or `TargetArn`.
28519 28520 28521 28522 28523 28524 28525 28526 28527 28528 28529 |
# File 'lib/aws-sdk-connect/types.rb', line 28519 class SearchAvailablePhoneNumbersRequest < Struct.new( :target_arn, :instance_id, :phone_number_country_code, :phone_number_type, :phone_number_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |