Class: Aws::Connect::Types::SearchContactEvaluationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


30474
30475
30476
30477
30478
30479
30480
30481
30482
# File 'lib/aws-sdk-connect/types.rb', line 30474

class SearchContactEvaluationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


30474
30475
30476
30477
30478
30479
30480
30481
30482
# File 'lib/aws-sdk-connect/types.rb', line 30474

class SearchContactEvaluationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


30474
30475
30476
30477
30478
30479
30480
30481
30482
# File 'lib/aws-sdk-connect/types.rb', line 30474

class SearchContactEvaluationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::EvaluationSearchCriteria

The search criteria to be used to return contact evaluations.



30474
30475
30476
30477
30478
30479
30480
30481
30482
# File 'lib/aws-sdk-connect/types.rb', line 30474

class SearchContactEvaluationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::EvaluationSearchFilter

Filters to be applied to search results.



30474
30475
30476
30477
30478
30479
30480
30481
30482
# File 'lib/aws-sdk-connect/types.rb', line 30474

class SearchContactEvaluationsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end