Class: Aws::Connect::Types::SearchContactEvaluationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactEvaluationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::EvaluationSearchCriteria
The search criteria to be used to return contact evaluations.
-
#search_filter ⇒ Types::EvaluationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-connect/types.rb', line 29383 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-connect/types.rb', line 29383 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-connect/types.rb', line 29383 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::EvaluationSearchCriteria
The search criteria to be used to return contact evaluations.
29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-connect/types.rb', line 29383 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::EvaluationSearchFilter
Filters to be applied to search results.
29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-connect/types.rb', line 29383 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |