Class: Aws::Connect::Types::SearchContactEvaluationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactEvaluationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::EvaluationSearchCriteria
The search criteria to be used to return contact evaluations.
-
#search_filter ⇒ Types::EvaluationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
26564 26565 26566 26567 26568 26569 26570 26571 26572 |
# File 'lib/aws-sdk-connect/types.rb', line 26564 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
26564 26565 26566 26567 26568 26569 26570 26571 26572 |
# File 'lib/aws-sdk-connect/types.rb', line 26564 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
26564 26565 26566 26567 26568 26569 26570 26571 26572 |
# File 'lib/aws-sdk-connect/types.rb', line 26564 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::EvaluationSearchCriteria
The search criteria to be used to return contact evaluations.
26564 26565 26566 26567 26568 26569 26570 26571 26572 |
# File 'lib/aws-sdk-connect/types.rb', line 26564 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::EvaluationSearchFilter
Filters to be applied to search results.
26564 26565 26566 26567 26568 26569 26570 26571 26572 |
# File 'lib/aws-sdk-connect/types.rb', line 26564 class SearchContactEvaluationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |