Class: Aws::Connect::Types::SearchContactFlowModulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactFlowModulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::ContactFlowModuleSearchCriteria
The search criteria to be used to return flow modules.
-
#search_filter ⇒ Types::ContactFlowModuleSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
29852 29853 29854 29855 29856 29857 29858 29859 29860 |
# File 'lib/aws-sdk-connect/types.rb', line 29852 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29852 29853 29854 29855 29856 29857 29858 29859 29860 |
# File 'lib/aws-sdk-connect/types.rb', line 29852 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29852 29853 29854 29855 29856 29857 29858 29859 29860 |
# File 'lib/aws-sdk-connect/types.rb', line 29852 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::ContactFlowModuleSearchCriteria
The search criteria to be used to return flow modules.
name and description fields support "contains" queries
with a minimum of 2 characters and a maximum of 25 characters. Any
queries with character lengths outside of this range will result in
invalid results.
29852 29853 29854 29855 29856 29857 29858 29859 29860 |
# File 'lib/aws-sdk-connect/types.rb', line 29852 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::ContactFlowModuleSearchFilter
Filters to be applied to search results.
29852 29853 29854 29855 29856 29857 29858 29859 29860 |
# File 'lib/aws-sdk-connect/types.rb', line 29852 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |