Class: Aws::Connect::Types::SearchContactFlowModulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactFlowModulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::ContactFlowModuleSearchCriteria
The search criteria to be used to return flow modules.
-
#search_filter ⇒ Types::ContactFlowModuleSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-connect/types.rb', line 29255 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-connect/types.rb', line 29255 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-connect/types.rb', line 29255 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::ContactFlowModuleSearchCriteria
The search criteria to be used to return flow modules.
<note markdown=“1”> The ‘name` and `description` fields support “contains” queries with a minimum of 2 characters and a maximum of 25 characters. Any queries with character lengths outside of this range will result in invalid results.
</note>
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-connect/types.rb', line 29255 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::ContactFlowModuleSearchFilter
Filters to be applied to search results.
29255 29256 29257 29258 29259 29260 29261 29262 29263 |
# File 'lib/aws-sdk-connect/types.rb', line 29255 class SearchContactFlowModulesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |