Class: Aws::Connect::Types::SearchContactFlowsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactFlowsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::ContactFlowSearchCriteria
The search criteria to be used to return flows.
-
#search_filter ⇒ Types::ContactFlowSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
26695 26696 26697 26698 26699 26700 26701 26702 26703 |
# File 'lib/aws-sdk-connect/types.rb', line 26695 class SearchContactFlowsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
26695 26696 26697 26698 26699 26700 26701 26702 26703 |
# File 'lib/aws-sdk-connect/types.rb', line 26695 class SearchContactFlowsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
26695 26696 26697 26698 26699 26700 26701 26702 26703 |
# File 'lib/aws-sdk-connect/types.rb', line 26695 class SearchContactFlowsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::ContactFlowSearchCriteria
The search criteria to be used to return flows.
<note markdown=“1”> The ‘name` and `description` fields support “contains” queries with a minimum of 2 characters and a maximum of 25 characters. Any queries with character lengths outside of this range will result in invalid results.
</note>
26695 26696 26697 26698 26699 26700 26701 26702 26703 |
# File 'lib/aws-sdk-connect/types.rb', line 26695 class SearchContactFlowsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::ContactFlowSearchFilter
Filters to be applied to search results.
26695 26696 26697 26698 26699 26700 26701 26702 26703 |
# File 'lib/aws-sdk-connect/types.rb', line 26695 class SearchContactFlowsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |