Class: Aws::Connect::Types::SearchContactsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchContactsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::SearchCriteria
The search criteria to be used to return contacts.
-
#sort ⇒ Types::Sort
Specifies a field to sort by and a sort order.
-
#time_range ⇒ Types::SearchContactsTimeRange
Time range that you want to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::SearchCriteria
The search criteria to be used to return contacts.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ Types::Sort
Specifies a field to sort by and a sort order.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |
#time_range ⇒ Types::SearchContactsTimeRange
Time range that you want to search results.
30713 30714 30715 30716 30717 30718 30719 30720 30721 30722 |
# File 'lib/aws-sdk-connect/types.rb', line 30713 class SearchContactsRequest < Struct.new( :instance_id, :time_range, :search_criteria, :max_results, :next_token, :sort) SENSITIVE = [] include Aws::Structure end |