Class: Aws::Connect::Types::SearchCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A structure of search criteria to be used to return contacts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_regions ⇒ Array<String>
The list of active regions for contacts in ACGR instances.
-
#additional_time_range ⇒ Types::SearchContactsAdditionalTimeRange
Additional TimeRange used to filter contacts.
-
#agent_hierarchy_groups ⇒ Types::AgentHierarchyGroups
The agent hierarchy groups of the agent at the time of handling the contact.
-
#agent_ids ⇒ Array<String>
The identifiers of agents who handled the contacts.
-
#channels ⇒ Array<String>
The list of channels associated with contacts.
-
#contact_analysis ⇒ Types::ContactAnalysis
Search criteria based on analysis outputs from Connect Customer Contact Lens.
-
#contact_tags ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the ‘SearchFilter`.
-
#initiation_methods ⇒ Array<String>
The list of initiation methods associated with contacts.
-
#name ⇒ Types::NameCriteria
Name of the contact.
-
#queue_ids ⇒ Array<String>
The list of queue IDs associated with contacts.
-
#routing_criteria ⇒ Types::SearchableRoutingCriteria
Routing criteria for the contact.
-
#searchable_contact_attributes ⇒ Types::SearchableContactAttributes
The search criteria based on user-defined contact attributes that have been configured for contact search.
-
#searchable_segment_attributes ⇒ Types::SearchableSegmentAttributes
The search criteria based on searchable segment attributes of a contact.
Instance Attribute Details
#active_regions ⇒ Array<String>
The list of active regions for contacts in ACGR instances.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#additional_time_range ⇒ Types::SearchContactsAdditionalTimeRange
Additional TimeRange used to filter contacts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#agent_hierarchy_groups ⇒ Types::AgentHierarchyGroups
The agent hierarchy groups of the agent at the time of handling the contact.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#agent_ids ⇒ Array<String>
The identifiers of agents who handled the contacts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Array<String>
The list of channels associated with contacts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#contact_analysis ⇒ Types::ContactAnalysis
Search criteria based on analysis outputs from Connect Customer Contact Lens.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#contact_tags ⇒ Types::ControlPlaneTagFilter
An object that can be used to specify Tag conditions inside the ‘SearchFilter`. This accepts an `OR` of `AND` (List of List) input where:
-
Top level list specifies conditions that need to be applied with ‘OR` operator
-
Inner list specifies conditions that need to be applied with ‘AND` operator.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#initiation_methods ⇒ Array<String>
The list of initiation methods associated with contacts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ Types::NameCriteria
Name of the contact.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#queue_ids ⇒ Array<String>
The list of queue IDs associated with contacts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#routing_criteria ⇒ Types::SearchableRoutingCriteria
Routing criteria for the contact.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#searchable_contact_attributes ⇒ Types::SearchableContactAttributes
The search criteria based on user-defined contact attributes that have been configured for contact search. For more information, see
- Search by custom contact attributes][1
-
in the *Connect Customer
Administrator Guide*.
To use ‘SearchableContactAttributes` in a search request, the `GetContactAttributes` action is required to perform an API request. For more information, see [docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnect.html#amazonconnect-actions-as-permissions][2]Actions defined by Connect Customer.
[1]: docs.aws.amazon.com/connect/latest/adminguide/search-custom-attributes.html [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnect.html#amazonconnect-actions-as-permissions
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |
#searchable_segment_attributes ⇒ Types::SearchableSegmentAttributes
The search criteria based on searchable segment attributes of a contact.
28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 28988 28989 28990 28991 28992 28993 28994 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchCriteria < Struct.new( :name, :agent_ids, :agent_hierarchy_groups, :channels, :contact_analysis, :initiation_methods, :queue_ids, :routing_criteria, :additional_time_range, :searchable_contact_attributes, :searchable_segment_attributes, :active_regions, :contact_tags) SENSITIVE = [] include Aws::Structure end |