Class: Aws::Connect::Types::SearchEmailAddressesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


30062
30063
30064
30065
30066
30067
30068
30069
30070
# File 'lib/aws-sdk-connect/types.rb', line 30062

class SearchEmailAddressesRequest < Struct.new(
  :instance_id,
  :max_results,
  :next_token,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


30062
30063
30064
30065
30066
30067
30068
30069
30070
# File 'lib/aws-sdk-connect/types.rb', line 30062

class SearchEmailAddressesRequest < Struct.new(
  :instance_id,
  :max_results,
  :next_token,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


30062
30063
30064
30065
30066
30067
30068
30069
30070
# File 'lib/aws-sdk-connect/types.rb', line 30062

class SearchEmailAddressesRequest < Struct.new(
  :instance_id,
  :max_results,
  :next_token,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::EmailAddressSearchCriteria

The search criteria to be used to return email addresses.



30062
30063
30064
30065
30066
30067
30068
30069
30070
# File 'lib/aws-sdk-connect/types.rb', line 30062

class SearchEmailAddressesRequest < Struct.new(
  :instance_id,
  :max_results,
  :next_token,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::EmailAddressSearchFilter

Filters to be applied to search results.



30062
30063
30064
30065
30066
30067
30068
30069
30070
# File 'lib/aws-sdk-connect/types.rb', line 30062

class SearchEmailAddressesRequest < Struct.new(
  :instance_id,
  :max_results,
  :next_token,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end