Class: Aws::Connect::Types::SearchEmailAddressesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchEmailAddressesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::EmailAddressSearchCriteria
The search criteria to be used to return email addresses.
-
#search_filter ⇒ Types::EmailAddressSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
28611 28612 28613 28614 28615 28616 28617 28618 28619 |
# File 'lib/aws-sdk-connect/types.rb', line 28611 class SearchEmailAddressesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
28611 28612 28613 28614 28615 28616 28617 28618 28619 |
# File 'lib/aws-sdk-connect/types.rb', line 28611 class SearchEmailAddressesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
28611 28612 28613 28614 28615 28616 28617 28618 28619 |
# File 'lib/aws-sdk-connect/types.rb', line 28611 class SearchEmailAddressesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::EmailAddressSearchCriteria
The search criteria to be used to return email addresses.
28611 28612 28613 28614 28615 28616 28617 28618 28619 |
# File 'lib/aws-sdk-connect/types.rb', line 28611 class SearchEmailAddressesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::EmailAddressSearchFilter
Filters to be applied to search results.
28611 28612 28613 28614 28615 28616 28617 28618 28619 |
# File 'lib/aws-sdk-connect/types.rb', line 28611 class SearchEmailAddressesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |