Class: Aws::Connect::Types::SearchEvaluationFormsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchEvaluationFormsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::EvaluationFormSearchCriteria
The search criteria to be used to return evaluation forms.
-
#search_filter ⇒ Types::EvaluationFormSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31539 31540 31541 31542 31543 31544 31545 31546 31547 |
# File 'lib/aws-sdk-connect/types.rb', line 31539 class SearchEvaluationFormsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31539 31540 31541 31542 31543 31544 31545 31546 31547 |
# File 'lib/aws-sdk-connect/types.rb', line 31539 class SearchEvaluationFormsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31539 31540 31541 31542 31543 31544 31545 31546 31547 |
# File 'lib/aws-sdk-connect/types.rb', line 31539 class SearchEvaluationFormsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::EvaluationFormSearchCriteria
The search criteria to be used to return evaluation forms.
31539 31540 31541 31542 31543 31544 31545 31546 31547 |
# File 'lib/aws-sdk-connect/types.rb', line 31539 class SearchEvaluationFormsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::EvaluationFormSearchFilter
Filters to be applied to search results.
31539 31540 31541 31542 31543 31544 31545 31546 31547 |
# File 'lib/aws-sdk-connect/types.rb', line 31539 class SearchEvaluationFormsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |