Class: Aws::Connect::Types::SearchEvaluationFormsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


30003
30004
30005
30006
30007
30008
30009
30010
30011
# File 'lib/aws-sdk-connect/types.rb', line 30003

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


30003
30004
30005
30006
30007
30008
30009
30010
30011
# File 'lib/aws-sdk-connect/types.rb', line 30003

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


30003
30004
30005
30006
30007
30008
30009
30010
30011
# File 'lib/aws-sdk-connect/types.rb', line 30003

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_criteriaTypes::EvaluationFormSearchCriteria

The search criteria to be used to return evaluation forms.



30003
30004
30005
30006
30007
30008
30009
30010
30011
# File 'lib/aws-sdk-connect/types.rb', line 30003

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end

#search_filterTypes::EvaluationFormSearchFilter

Filters to be applied to search results.



30003
30004
30005
30006
30007
30008
30009
30010
30011
# File 'lib/aws-sdk-connect/types.rb', line 30003

class SearchEvaluationFormsRequest < Struct.new(
  :instance_id,
  :next_token,
  :max_results,
  :search_criteria,
  :search_filter)
  SENSITIVE = []
  include Aws::Structure
end