Class: Aws::Connect::Types::SearchHoursOfOperationOverridesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationOverridesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::HoursOfOperationOverrideSearchCriteria
The search criteria to be used to return hours of operations overrides.
-
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance.
31108 31109 31110 31111 31112 31113 31114 31115 31116 |
# File 'lib/aws-sdk-connect/types.rb', line 31108 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31108 31109 31110 31111 31112 31113 31114 31115 31116 |
# File 'lib/aws-sdk-connect/types.rb', line 31108 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31108 31109 31110 31111 31112 31113 31114 31115 31116 |
# File 'lib/aws-sdk-connect/types.rb', line 31108 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::HoursOfOperationOverrideSearchCriteria
The search criteria to be used to return hours of operations overrides.
31108 31109 31110 31111 31112 31113 31114 31115 31116 |
# File 'lib/aws-sdk-connect/types.rb', line 31108 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
31108 31109 31110 31111 31112 31113 31114 31115 31116 |
# File 'lib/aws-sdk-connect/types.rb', line 31108 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |