Class: Aws::Connect::Types::SearchHoursOfOperationOverridesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationOverridesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::HoursOfOperationOverrideSearchCriteria
The search criteria to be used to return hours of operations overrides.
-
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance.
29823 29824 29825 29826 29827 29828 29829 29830 29831 |
# File 'lib/aws-sdk-connect/types.rb', line 29823 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29823 29824 29825 29826 29827 29828 29829 29830 29831 |
# File 'lib/aws-sdk-connect/types.rb', line 29823 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29823 29824 29825 29826 29827 29828 29829 29830 29831 |
# File 'lib/aws-sdk-connect/types.rb', line 29823 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::HoursOfOperationOverrideSearchCriteria
The search criteria to be used to return hours of operations overrides.
29823 29824 29825 29826 29827 29828 29829 29830 29831 |
# File 'lib/aws-sdk-connect/types.rb', line 29823 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
29823 29824 29825 29826 29827 29828 29829 29830 29831 |
# File 'lib/aws-sdk-connect/types.rb', line 29823 class SearchHoursOfOperationOverridesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |