Class: Aws::Connect::Types::SearchHoursOfOperationOverridesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationOverridesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of hours of operations which matched your search query.
-
#hours_of_operation_overrides ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operations overrides.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of hours of operations which matched your search query.
31120 31121 31122 31123 31124 31125 31126 |
# File 'lib/aws-sdk-connect/types.rb', line 31120 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_overrides ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operations overrides.
31120 31121 31122 31123 31124 31125 31126 |
# File 'lib/aws-sdk-connect/types.rb', line 31120 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31120 31121 31122 31123 31124 31125 31126 |
# File 'lib/aws-sdk-connect/types.rb', line 31120 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |