Class: Aws::Connect::Types::SearchHoursOfOperationOverridesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationOverridesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of hours of operations which matched your search query.
-
#hours_of_operation_overrides ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operations overrides.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of hours of operations which matched your search query.
32047 32048 32049 32050 32051 32052 32053 |
# File 'lib/aws-sdk-connect/types.rb', line 32047 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_overrides ⇒ Array<Types::HoursOfOperationOverride>
Information about the hours of operations overrides.
32047 32048 32049 32050 32051 32052 32053 |
# File 'lib/aws-sdk-connect/types.rb', line 32047 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
32047 32048 32049 32050 32051 32052 32053 |
# File 'lib/aws-sdk-connect/types.rb', line 32047 class SearchHoursOfOperationOverridesResponse < Struct.new( :hours_of_operation_overrides, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |