Class: Aws::Connect::Types::SearchHoursOfOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::HoursOfOperationSearchCriteria
The search criteria to be used to return hours of operations.
-
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-connect/types.rb', line 31620 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-connect/types.rb', line 31620 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-connect/types.rb', line 31620 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::HoursOfOperationSearchCriteria
The search criteria to be used to return hours of operations.
31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-connect/types.rb', line 31620 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-connect/types.rb', line 31620 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |