Class: Aws::Connect::Types::SearchHoursOfOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchHoursOfOperationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::HoursOfOperationSearchCriteria
The search criteria to be used to return hours of operations.
-
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31172 31173 31174 31175 31176 31177 31178 31179 31180 |
# File 'lib/aws-sdk-connect/types.rb', line 31172 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31172 31173 31174 31175 31176 31177 31178 31179 31180 |
# File 'lib/aws-sdk-connect/types.rb', line 31172 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31172 31173 31174 31175 31176 31177 31178 31179 31180 |
# File 'lib/aws-sdk-connect/types.rb', line 31172 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::HoursOfOperationSearchCriteria
The search criteria to be used to return hours of operations.
31172 31173 31174 31175 31176 31177 31178 31179 31180 |
# File 'lib/aws-sdk-connect/types.rb', line 31172 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::HoursOfOperationSearchFilter
Filters to be applied to search results.
31172 31173 31174 31175 31176 31177 31178 31179 31180 |
# File 'lib/aws-sdk-connect/types.rb', line 31172 class SearchHoursOfOperationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |