Class: Aws::Connect::Types::SearchHoursOfOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of hours of operations which matched your search query.

Returns:

  • (Integer)


29298
29299
29300
29301
29302
29303
29304
# File 'lib/aws-sdk-connect/types.rb', line 29298

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#hours_of_operationsArray<Types::HoursOfOperation>

Information about the hours of operations.

Returns:



29298
29299
29300
29301
29302
29303
29304
# File 'lib/aws-sdk-connect/types.rb', line 29298

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


29298
29299
29300
29301
29302
29303
29304
# File 'lib/aws-sdk-connect/types.rb', line 29298

class SearchHoursOfOperationsResponse < Struct.new(
  :hours_of_operations,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end