Class: Aws::Connect::Types::SearchMetricsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchMetricsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::MetricSearchCriteria
The search criteria to filter the metrics.
-
#search_filter ⇒ Types::MetricSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31235 31236 31237 31238 31239 31240 31241 31242 31243 |
# File 'lib/aws-sdk-connect/types.rb', line 31235 class SearchMetricsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31235 31236 31237 31238 31239 31240 31241 31242 31243 |
# File 'lib/aws-sdk-connect/types.rb', line 31235 class SearchMetricsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31235 31236 31237 31238 31239 31240 31241 31242 31243 |
# File 'lib/aws-sdk-connect/types.rb', line 31235 class SearchMetricsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::MetricSearchCriteria
The search criteria to filter the metrics.
31235 31236 31237 31238 31239 31240 31241 31242 31243 |
# File 'lib/aws-sdk-connect/types.rb', line 31235 class SearchMetricsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::MetricSearchFilter
Filters to be applied to search results.
31235 31236 31237 31238 31239 31240 31241 31242 31243 |
# File 'lib/aws-sdk-connect/types.rb', line 31235 class SearchMetricsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |