Class: Aws::Connect::Types::SearchNotificationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchNotificationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::NotificationSearchCriteria
The search criteria to apply when searching for notifications.
-
#search_filter ⇒ Types::NotificationSearchFilter
Filters to apply to the search results, such as tag-based filters.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-connect/types.rb', line 29329 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page. Valid range is 1-100.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-connect/types.rb', line 29329 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response to retrieve the next page of results.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-connect/types.rb', line 29329 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::NotificationSearchCriteria
The search criteria to apply when searching for notifications. Supports filtering by notification ID and message content using comparison types such as STARTS_WITH, CONTAINS, and EXACT.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-connect/types.rb', line 29329 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::NotificationSearchFilter
Filters to apply to the search results, such as tag-based filters.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-connect/types.rb', line 29329 class SearchNotificationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |