Class: Aws::Connect::Types::SearchPredefinedAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchPredefinedAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::PredefinedAttributeSearchCriteria
The search criteria to be used to return predefined attributes.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30604 30605 30606 30607 30608 30609 30610 30611 |
# File 'lib/aws-sdk-connect/types.rb', line 30604 class SearchPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30604 30605 30606 30607 30608 30609 30610 30611 |
# File 'lib/aws-sdk-connect/types.rb', line 30604 class SearchPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30604 30605 30606 30607 30608 30609 30610 30611 |
# File 'lib/aws-sdk-connect/types.rb', line 30604 class SearchPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::PredefinedAttributeSearchCriteria
The search criteria to be used to return predefined attributes.
30604 30605 30606 30607 30608 30609 30610 30611 |
# File 'lib/aws-sdk-connect/types.rb', line 30604 class SearchPredefinedAttributesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria) SENSITIVE = [] include Aws::Structure end |