Class: Aws::Connect::Types::SearchPredefinedAttributesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchPredefinedAttributesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The approximate number of predefined attributes which matched your search query.
-
#next_token ⇒ String
The token for the next set of results.
-
#predefined_attributes ⇒ Array<Types::PredefinedAttribute>
Predefined attributes matched by the search criteria.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The approximate number of predefined attributes which matched your search query.
29410 29411 29412 29413 29414 29415 29416 |
# File 'lib/aws-sdk-connect/types.rb', line 29410 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29410 29411 29412 29413 29414 29415 29416 |
# File 'lib/aws-sdk-connect/types.rb', line 29410 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#predefined_attributes ⇒ Array<Types::PredefinedAttribute>
Predefined attributes matched by the search criteria.
29410 29411 29412 29413 29414 29415 29416 |
# File 'lib/aws-sdk-connect/types.rb', line 29410 class SearchPredefinedAttributesResponse < Struct.new( :predefined_attributes, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |