Class: Aws::Connect::Types::SearchPredefinedAttributesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The approximate number of predefined attributes which matched your search query.



28930
28931
28932
28933
28934
28935
28936
# File 'lib/aws-sdk-connect/types.rb', line 28930

class SearchPredefinedAttributesResponse < Struct.new(
  :predefined_attributes,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



28930
28931
28932
28933
28934
28935
28936
# File 'lib/aws-sdk-connect/types.rb', line 28930

class SearchPredefinedAttributesResponse < Struct.new(
  :predefined_attributes,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_attributesArray<Types::PredefinedAttribute>

Predefined attributes matched by the search criteria.



28930
28931
28932
28933
28934
28935
28936
# File 'lib/aws-sdk-connect/types.rb', line 28930

class SearchPredefinedAttributesResponse < Struct.new(
  :predefined_attributes,
  :next_token,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end