Class: Aws::Connect::Types::SearchPromptsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchPromptsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::PromptSearchCriteria
The search criteria to be used to return prompts.
-
#search_filter ⇒ Types::PromptSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31784 31785 31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31784 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31784 31785 31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31784 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31784 31785 31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31784 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::PromptSearchCriteria
The search criteria to be used to return prompts.
31784 31785 31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31784 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::PromptSearchFilter
Filters to be applied to search results.
31784 31785 31786 31787 31788 31789 31790 31791 31792 |
# File 'lib/aws-sdk-connect/types.rb', line 31784 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |