Class: Aws::Connect::Types::SearchPromptsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchPromptsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::PromptSearchCriteria
The search criteria to be used to return prompts.
-
#search_filter ⇒ Types::PromptSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
28978 28979 28980 28981 28982 28983 28984 28985 28986 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
28978 28979 28980 28981 28982 28983 28984 28985 28986 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
28978 28979 28980 28981 28982 28983 28984 28985 28986 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::PromptSearchCriteria
The search criteria to be used to return prompts.
28978 28979 28980 28981 28982 28983 28984 28985 28986 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::PromptSearchFilter
Filters to be applied to search results.
28978 28979 28980 28981 28982 28983 28984 28985 28986 |
# File 'lib/aws-sdk-connect/types.rb', line 28978 class SearchPromptsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |