Class: Aws::Connect::Types::SearchQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::QueueSearchCriteria
The search criteria to be used to return queues.
-
#search_filter ⇒ Types::QueueSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31853 31854 31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-connect/types.rb', line 31853 class SearchQueuesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31853 31854 31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-connect/types.rb', line 31853 class SearchQueuesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31853 31854 31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-connect/types.rb', line 31853 class SearchQueuesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::QueueSearchCriteria
The search criteria to be used to return queues.
name and description fields support "contains" queries
with a minimum of 2 characters and a maximum of 25 characters. Any
queries with character lengths outside of this range will throw
invalid results.
31853 31854 31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-connect/types.rb', line 31853 class SearchQueuesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::QueueSearchFilter
Filters to be applied to search results.
31853 31854 31855 31856 31857 31858 31859 31860 31861 |
# File 'lib/aws-sdk-connect/types.rb', line 31853 class SearchQueuesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |