Class: Aws::Connect::Types::SearchQuickConnectsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchQuickConnectsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::QuickConnectSearchCriteria
The search criteria to be used to return quick connects.
-
#search_filter ⇒ Types::QuickConnectSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30610 30611 30612 30613 30614 30615 30616 30617 30618 |
# File 'lib/aws-sdk-connect/types.rb', line 30610 class SearchQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30610 30611 30612 30613 30614 30615 30616 30617 30618 |
# File 'lib/aws-sdk-connect/types.rb', line 30610 class SearchQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30610 30611 30612 30613 30614 30615 30616 30617 30618 |
# File 'lib/aws-sdk-connect/types.rb', line 30610 class SearchQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::QuickConnectSearchCriteria
The search criteria to be used to return quick connects.
30610 30611 30612 30613 30614 30615 30616 30617 30618 |
# File 'lib/aws-sdk-connect/types.rb', line 30610 class SearchQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::QuickConnectSearchFilter
Filters to be applied to search results.
30610 30611 30612 30613 30614 30615 30616 30617 30618 |
# File 'lib/aws-sdk-connect/types.rb', line 30610 class SearchQuickConnectsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |