Class: Aws::Connect::Types::SearchRoutingProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchRoutingProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::RoutingProfileSearchCriteria
The search criteria to be used to return routing profiles.
-
#search_filter ⇒ Types::RoutingProfileSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30945 30946 30947 30948 30949 30950 30951 30952 30953 |
# File 'lib/aws-sdk-connect/types.rb', line 30945 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30945 30946 30947 30948 30949 30950 30951 30952 30953 |
# File 'lib/aws-sdk-connect/types.rb', line 30945 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30945 30946 30947 30948 30949 30950 30951 30952 30953 |
# File 'lib/aws-sdk-connect/types.rb', line 30945 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::RoutingProfileSearchCriteria
The search criteria to be used to return routing profiles.
name and description fields support "contains" queries
with a minimum of 2 characters and a maximum of 25 characters. Any
queries with character lengths outside of this range will throw
invalid results.
30945 30946 30947 30948 30949 30950 30951 30952 30953 |
# File 'lib/aws-sdk-connect/types.rb', line 30945 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::RoutingProfileSearchFilter
Filters to be applied to search results.
30945 30946 30947 30948 30949 30950 30951 30952 30953 |
# File 'lib/aws-sdk-connect/types.rb', line 30945 class SearchRoutingProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |