Class: Aws::Connect::Types::SearchRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::RulesSearchCriteria
The search criteria to be used to return rules.
-
#search_filter ⇒ Types::RulesSearchFilter
Filters to be applied to search results, such as tag-based filters.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31746 31747 31748 31749 31750 31751 31752 31753 31754 |
# File 'lib/aws-sdk-connect/types.rb', line 31746 class SearchRulesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31746 31747 31748 31749 31750 31751 31752 31753 31754 |
# File 'lib/aws-sdk-connect/types.rb', line 31746 class SearchRulesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31746 31747 31748 31749 31750 31751 31752 31753 31754 |
# File 'lib/aws-sdk-connect/types.rb', line 31746 class SearchRulesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::RulesSearchCriteria
The search criteria to be used to return rules.
31746 31747 31748 31749 31750 31751 31752 31753 31754 |
# File 'lib/aws-sdk-connect/types.rb', line 31746 class SearchRulesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::RulesSearchFilter
Filters to be applied to search results, such as tag-based filters.
31746 31747 31748 31749 31750 31751 31752 31753 31754 |
# File 'lib/aws-sdk-connect/types.rb', line 31746 class SearchRulesRequest < Struct.new( :instance_id, :max_results, :next_token, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |