Class: Aws::Connect::Types::SearchRulesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The total number of rules which matched your search query.

Returns:

  • (Integer)


31033
31034
31035
31036
31037
31038
31039
# File 'lib/aws-sdk-connect/types.rb', line 31033

class SearchRulesResponse < Struct.new(
  :rules,
  :approximate_total_count,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


31033
31034
31035
31036
31037
31038
31039
# File 'lib/aws-sdk-connect/types.rb', line 31033

class SearchRulesResponse < Struct.new(
  :rules,
  :approximate_total_count,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::RuleSearchSummary>

Information about the rules.

Returns:



31033
31034
31035
31036
31037
31038
31039
# File 'lib/aws-sdk-connect/types.rb', line 31033

class SearchRulesResponse < Struct.new(
  :rules,
  :approximate_total_count,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end