Class: Aws::Connect::Types::SearchRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of rules which matched your search query.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#rules ⇒ Array<Types::RuleSearchSummary>
Information about the rules.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of rules which matched your search query.
31033 31034 31035 31036 31037 31038 31039 |
# File 'lib/aws-sdk-connect/types.rb', line 31033 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
31033 31034 31035 31036 31037 31038 31039 |
# File 'lib/aws-sdk-connect/types.rb', line 31033 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::RuleSearchSummary>
Information about the rules.
31033 31034 31035 31036 31037 31038 31039 |
# File 'lib/aws-sdk-connect/types.rb', line 31033 class SearchRulesResponse < Struct.new( :rules, :approximate_total_count, :next_token) SENSITIVE = [] include Aws::Structure end |