Class: Aws::Connect::Types::SearchSecurityProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchSecurityProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::SecurityProfileSearchCriteria
The search criteria to be used to return security profiles.
-
#search_filter ⇒ Types::SecurityProfilesSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31080 31081 31082 31083 31084 31085 31086 31087 31088 |
# File 'lib/aws-sdk-connect/types.rb', line 31080 class SearchSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31080 31081 31082 31083 31084 31085 31086 31087 31088 |
# File 'lib/aws-sdk-connect/types.rb', line 31080 class SearchSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31080 31081 31082 31083 31084 31085 31086 31087 31088 |
# File 'lib/aws-sdk-connect/types.rb', line 31080 class SearchSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::SecurityProfileSearchCriteria
The search criteria to be used to return security profiles.
name field support "contains" queries with a minimum of 2
characters and maximum of 25 characters. Any queries with character
lengths outside of this range will throw invalid results.
FieldName: name
31080 31081 31082 31083 31084 31085 31086 31087 31088 |
# File 'lib/aws-sdk-connect/types.rb', line 31080 class SearchSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::SecurityProfilesSearchFilter
Filters to be applied to search results.
31080 31081 31082 31083 31084 31085 31086 31087 31088 |
# File 'lib/aws-sdk-connect/types.rb', line 31080 class SearchSecurityProfilesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_criteria, :search_filter) SENSITIVE = [] include Aws::Structure end |