Class: Aws::Connect::Types::SearchTestCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchTestCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::TestCaseSearchCriteria
The search criteria to be used to return test cases.
-
#search_filter ⇒ Types::TestCaseSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31892 31893 31894 31895 31896 31897 31898 31899 31900 |
# File 'lib/aws-sdk-connect/types.rb', line 31892 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31892 31893 31894 31895 31896 31897 31898 31899 31900 |
# File 'lib/aws-sdk-connect/types.rb', line 31892 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31892 31893 31894 31895 31896 31897 31898 31899 31900 |
# File 'lib/aws-sdk-connect/types.rb', line 31892 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::TestCaseSearchCriteria
The search criteria to be used to return test cases.
31892 31893 31894 31895 31896 31897 31898 31899 31900 |
# File 'lib/aws-sdk-connect/types.rb', line 31892 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::TestCaseSearchFilter
Filters to be applied to search results.
31892 31893 31894 31895 31896 31897 31898 31899 31900 |
# File 'lib/aws-sdk-connect/types.rb', line 31892 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |