Class: Aws::Connect::Types::SearchTestCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchTestCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::TestCaseSearchCriteria
The search criteria to be used to return test cases.
-
#search_filter ⇒ Types::TestCaseSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30889 30890 30891 30892 30893 30894 30895 30896 30897 |
# File 'lib/aws-sdk-connect/types.rb', line 30889 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30889 30890 30891 30892 30893 30894 30895 30896 30897 |
# File 'lib/aws-sdk-connect/types.rb', line 30889 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30889 30890 30891 30892 30893 30894 30895 30896 30897 |
# File 'lib/aws-sdk-connect/types.rb', line 30889 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::TestCaseSearchCriteria
The search criteria to be used to return test cases.
30889 30890 30891 30892 30893 30894 30895 30896 30897 |
# File 'lib/aws-sdk-connect/types.rb', line 30889 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::TestCaseSearchFilter
Filters to be applied to search results.
30889 30890 30891 30892 30893 30894 30895 30896 30897 |
# File 'lib/aws-sdk-connect/types.rb', line 30889 class SearchTestCasesRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |