Class: Aws::Connect::Types::SearchTestCasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchTestCasesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approximate_total_count ⇒ Integer
The total number of test cases which matched your search query.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
-
#test_cases ⇒ Array<Types::TestCase>
Information about the test cases.
Instance Attribute Details
#approximate_total_count ⇒ Integer
The total number of test cases which matched your search query.
29638 29639 29640 29641 29642 29643 29644 |
# File 'lib/aws-sdk-connect/types.rb', line 29638 class SearchTestCasesResponse < Struct.new( :test_cases, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
29638 29639 29640 29641 29642 29643 29644 |
# File 'lib/aws-sdk-connect/types.rb', line 29638 class SearchTestCasesResponse < Struct.new( :test_cases, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |
#test_cases ⇒ Array<Types::TestCase>
Information about the test cases.
29638 29639 29640 29641 29642 29643 29644 |
# File 'lib/aws-sdk-connect/types.rb', line 29638 class SearchTestCasesResponse < Struct.new( :test_cases, :next_token, :approximate_total_count) SENSITIVE = [] include Aws::Structure end |