Class: Aws::Connect::Types::SearchUserHierarchyGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchUserHierarchyGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::UserHierarchyGroupSearchCriteria
The search criteria to be used to return UserHierarchyGroups.
-
#search_filter ⇒ Types::UserHierarchyGroupSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
31950 31951 31952 31953 31954 31955 31956 31957 31958 |
# File 'lib/aws-sdk-connect/types.rb', line 31950 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
31950 31951 31952 31953 31954 31955 31956 31957 31958 |
# File 'lib/aws-sdk-connect/types.rb', line 31950 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
31950 31951 31952 31953 31954 31955 31956 31957 31958 |
# File 'lib/aws-sdk-connect/types.rb', line 31950 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::UserHierarchyGroupSearchCriteria
The search criteria to be used to return UserHierarchyGroups.
31950 31951 31952 31953 31954 31955 31956 31957 31958 |
# File 'lib/aws-sdk-connect/types.rb', line 31950 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::UserHierarchyGroupSearchFilter
Filters to be applied to search results.
31950 31951 31952 31953 31954 31955 31956 31957 31958 |
# File 'lib/aws-sdk-connect/types.rb', line 31950 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |