Class: Aws::Connect::Types::SearchUserHierarchyGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchUserHierarchyGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::UserHierarchyGroupSearchCriteria
The search criteria to be used to return UserHierarchyGroups.
-
#search_filter ⇒ Types::UserHierarchyGroupSearchFilter
Filters to be applied to search results.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instanceId in the ARN of the instance.
29923 29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-connect/types.rb', line 29923 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29923 29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-connect/types.rb', line 29923 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29923 29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-connect/types.rb', line 29923 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::UserHierarchyGroupSearchCriteria
The search criteria to be used to return UserHierarchyGroups.
29923 29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-connect/types.rb', line 29923 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::UserHierarchyGroupSearchFilter
Filters to be applied to search results.
29923 29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-connect/types.rb', line 29923 class SearchUserHierarchyGroupsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |