Class: Aws::Connect::Types::SearchViewsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchViewsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::ViewSearchCriteria
The search criteria, including field names and comparison types.
-
#search_filter ⇒ Types::ViewSearchFilter
Filters to apply to the search, such as tag-based filters.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
32067 32068 32069 32070 32071 32072 32073 32074 32075 |
# File 'lib/aws-sdk-connect/types.rb', line 32067 class SearchViewsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
32067 32068 32069 32070 32071 32072 32073 32074 32075 |
# File 'lib/aws-sdk-connect/types.rb', line 32067 class SearchViewsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
32067 32068 32069 32070 32071 32072 32073 32074 32075 |
# File 'lib/aws-sdk-connect/types.rb', line 32067 class SearchViewsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::ViewSearchCriteria
The search criteria, including field names and comparison types.
32067 32068 32069 32070 32071 32072 32073 32074 32075 |
# File 'lib/aws-sdk-connect/types.rb', line 32067 class SearchViewsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::ViewSearchFilter
Filters to apply to the search, such as tag-based filters.
32067 32068 32069 32070 32071 32072 32073 32074 32075 |
# File 'lib/aws-sdk-connect/types.rb', line 32067 class SearchViewsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |