Class: Aws::Connect::Types::SearchVocabulariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchVocabulariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#language_code ⇒ String
The language code of the vocabulary entries.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#name_starts_with ⇒ String
The starting pattern of the name of the vocabulary.
-
#next_token ⇒ String
The token for the next set of results.
-
#state ⇒ String
The current state of the custom vocabulary.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see What is Amazon Transcribe?
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#name_starts_with ⇒ String
The starting pattern of the name of the vocabulary.
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the custom vocabulary.
30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 |
# File 'lib/aws-sdk-connect/types.rb', line 30937 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |