Class: Aws::Connect::Types::SearchVocabulariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchVocabulariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#language_code ⇒ String
The language code of the vocabulary entries.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#name_starts_with ⇒ String
The starting pattern of the name of the vocabulary.
-
#next_token ⇒ String
The token for the next set of results.
-
#state ⇒ String
The current state of the custom vocabulary.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see [What is Amazon Transcribe?]
[1]: docs.aws.amazon.com/transcribe/latest/dg/transcribe-whatis.html
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#name_starts_with ⇒ String
The starting pattern of the name of the vocabulary.
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the custom vocabulary.
27977 27978 27979 27980 27981 27982 27983 27984 27985 27986 |
# File 'lib/aws-sdk-connect/types.rb', line 27977 class SearchVocabulariesRequest < Struct.new( :instance_id, :max_results, :next_token, :state, :name_starts_with, :language_code) SENSITIVE = [] include Aws::Structure end |