Class: Aws::Connect::Types::SearchWorkspaceAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchWorkspaceAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_criteria ⇒ Types::WorkspaceAssociationSearchCriteria
The search criteria, including workspace ID, resource ID, or resource type.
-
#search_filter ⇒ Types::WorkspaceAssociationSearchFilter
Filters to apply to the search, such as tag-based filters.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
29010 29011 29012 29013 29014 29015 29016 29017 29018 |
# File 'lib/aws-sdk-connect/types.rb', line 29010 class SearchWorkspaceAssociationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
29010 29011 29012 29013 29014 29015 29016 29017 29018 |
# File 'lib/aws-sdk-connect/types.rb', line 29010 class SearchWorkspaceAssociationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
29010 29011 29012 29013 29014 29015 29016 29017 29018 |
# File 'lib/aws-sdk-connect/types.rb', line 29010 class SearchWorkspaceAssociationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_criteria ⇒ Types::WorkspaceAssociationSearchCriteria
The search criteria, including workspace ID, resource ID, or resource type.
29010 29011 29012 29013 29014 29015 29016 29017 29018 |
# File 'lib/aws-sdk-connect/types.rb', line 29010 class SearchWorkspaceAssociationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |
#search_filter ⇒ Types::WorkspaceAssociationSearchFilter
Filters to apply to the search, such as tag-based filters.
29010 29011 29012 29013 29014 29015 29016 29017 29018 |
# File 'lib/aws-sdk-connect/types.rb', line 29010 class SearchWorkspaceAssociationsRequest < Struct.new( :instance_id, :next_token, :max_results, :search_filter, :search_criteria) SENSITIVE = [] include Aws::Structure end |