Class: Aws::Connect::Types::SearchWorkspacesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_total_countInteger

The approximate total number of workspaces that match the search criteria.

Returns:

  • (Integer)


31550
31551
31552
31553
31554
31555
31556
# File 'lib/aws-sdk-connect/types.rb', line 31550

class SearchWorkspacesResponse < Struct.new(
  :next_token,
  :workspaces,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are additional results, this is the token for the next set of results.

Returns:

  • (String)


31550
31551
31552
31553
31554
31555
31556
# File 'lib/aws-sdk-connect/types.rb', line 31550

class SearchWorkspacesResponse < Struct.new(
  :next_token,
  :workspaces,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end

#workspacesArray<Types::WorkspaceSearchSummary>

A list of workspaces that match the search criteria.

Returns:



31550
31551
31552
31553
31554
31555
31556
# File 'lib/aws-sdk-connect/types.rb', line 31550

class SearchWorkspacesResponse < Struct.new(
  :next_token,
  :workspaces,
  :approximate_total_count)
  SENSITIVE = []
  include Aws::Structure
end