Class: Aws::Connect::Types::SearchableRoutingCriteriaStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SearchableRoutingCriteriaStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Routing criteria of the contact to match on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_criteria ⇒ Types::SearchableAgentCriteriaStep
Agent matching the routing step of the routing criteria.
Instance Attribute Details
#agent_criteria ⇒ Types::SearchableAgentCriteriaStep
Agent matching the routing step of the routing criteria
28218 28219 28220 28221 28222 |
# File 'lib/aws-sdk-connect/types.rb', line 28218 class SearchableRoutingCriteriaStep < Struct.new( :agent_criteria) SENSITIVE = [] include Aws::Structure end |