Class: Aws::Connect::Types::SecurityProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SecurityProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a security profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_access_control_hierarchy_group_id ⇒ String
The identifier of the hierarchy group that a security profile uses to restrict access to resources in Amazon Connect.
-
#allowed_access_control_tags ⇒ Hash<String,String>
The list of tags that a security profile uses to restrict access to resources in Amazon Connect.
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the security profile.
-
#description ⇒ String
The description of the security profile.
-
#granular_access_control_configuration ⇒ Types::GranularAccessControlConfiguration
The granular access control configuration for the security profile, including data table permissions.
-
#hierarchy_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies hierarchy restrictions to in Amazon Connect.
-
#id ⇒ String
The identifier for the security profile.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#organization_resource_id ⇒ String
The organization resource identifier for the security profile.
-
#security_profile_name ⇒ String
The name for the security profile.
-
#tag_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies tag restrictions to in Amazon Connect.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#allowed_access_control_hierarchy_group_id ⇒ String
The identifier of the hierarchy group that a security profile uses to restrict access to resources in Amazon Connect.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#allowed_access_control_tags ⇒ Hash<String,String>
The list of tags that a security profile uses to restrict access to resources in Amazon Connect.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) for the security profile.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the security profile.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#granular_access_control_configuration ⇒ Types::GranularAccessControlConfiguration
The granular access control configuration for the security profile, including data table permissions.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#hierarchy_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies hierarchy restrictions to in Amazon Connect. Following are acceptable ResourceNames: ‘User`.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier for the security profile.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#organization_resource_id ⇒ String
The organization resource identifier for the security profile.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#security_profile_name ⇒ String
The name for the security profile.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#tag_restricted_resources ⇒ Array<String>
The list of resources that a security profile applies tag restrictions to in Amazon Connect.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
30499 30500 30501 30502 30503 30504 30505 30506 30507 30508 30509 30510 30511 30512 30513 30514 30515 |
# File 'lib/aws-sdk-connect/types.rb', line 30499 class SecurityProfile < Struct.new( :id, :organization_resource_id, :arn, :security_profile_name, :description, :tags, :allowed_access_control_tags, :tag_restricted_resources, :last_modified_time, :last_modified_region, :hierarchy_restricted_resources, :allowed_access_control_hierarchy_group_id, :granular_access_control_configuration) SENSITIVE = [] include Aws::Structure end |