Class: Aws::Connect::Types::SendChatIntegrationEventRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SendChatIntegrationEventRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_id ⇒ String
Chat system identifier, used in part to uniquely identify chat.
-
#event ⇒ Types::ChatEvent
Chat integration event payload.
-
#new_session_details ⇒ Types::NewSessionDetails
Contact properties to apply when starting a new chat.
-
#source_id ⇒ String
External identifier of chat customer participant, used in part to uniquely identify a chat.
-
#subtype ⇒ String
Classification of a channel.
Instance Attribute Details
#destination_id ⇒ String
Chat system identifier, used in part to uniquely identify chat. This is associated with the Amazon Connect instance and flow to be used to start chats. For Server Migration Service, this is the phone number destination of inbound Server Migration Service messages represented by an Amazon Web Services End User Messaging phone number ARN.
28590 28591 28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-connect/types.rb', line 28590 class SendChatIntegrationEventRequest < Struct.new( :source_id, :destination_id, :subtype, :event, :new_session_details) SENSITIVE = [] include Aws::Structure end |
#event ⇒ Types::ChatEvent
Chat integration event payload
28590 28591 28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-connect/types.rb', line 28590 class SendChatIntegrationEventRequest < Struct.new( :source_id, :destination_id, :subtype, :event, :new_session_details) SENSITIVE = [] include Aws::Structure end |
#new_session_details ⇒ Types::NewSessionDetails
Contact properties to apply when starting a new chat. If the integration event is handled with an existing chat, this is ignored.
28590 28591 28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-connect/types.rb', line 28590 class SendChatIntegrationEventRequest < Struct.new( :source_id, :destination_id, :subtype, :event, :new_session_details) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ String
External identifier of chat customer participant, used in part to uniquely identify a chat. For SMS, this is the E164 phone number of the chat customer participant.
28590 28591 28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-connect/types.rb', line 28590 class SendChatIntegrationEventRequest < Struct.new( :source_id, :destination_id, :subtype, :event, :new_session_details) SENSITIVE = [] include Aws::Structure end |
#subtype ⇒ String
Classification of a channel. This is used in part to uniquely identify chat.
Valid value: ‘[“connect:sms”, connect:“WhatsApp”]`
28590 28591 28592 28593 28594 28595 28596 28597 28598 |
# File 'lib/aws-sdk-connect/types.rb', line 28590 class SendChatIntegrationEventRequest < Struct.new( :source_id, :destination_id, :subtype, :event, :new_session_details) SENSITIVE = [] include Aws::Structure end |