Class: Aws::Connect::Types::SendChatIntegrationEventResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#initial_contact_idString

Identifier of chat contact used to handle integration event. This may be null if the integration event is not valid without an already existing chat contact.

Returns:

  • (String)


28613
28614
28615
28616
28617
28618
# File 'lib/aws-sdk-connect/types.rb', line 28613

class SendChatIntegrationEventResponse < Struct.new(
  :initial_contact_id,
  :new_chat_created)
  SENSITIVE = []
  include Aws::Structure
end

#new_chat_createdBoolean

Whether handling the integration event resulted in creating a new chat or acting on existing chat.

Returns:

  • (Boolean)


28613
28614
28615
28616
28617
28618
# File 'lib/aws-sdk-connect/types.rb', line 28613

class SendChatIntegrationEventResponse < Struct.new(
  :initial_contact_id,
  :new_chat_created)
  SENSITIVE = []
  include Aws::Structure
end