Class: Aws::Connect::Types::SendNotificationActionDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SendNotificationActionDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the send notification action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
Notification content.
-
#content_type ⇒ String
Content type format.
-
#delivery_method ⇒ String
Notification delivery method.
-
#exclusion ⇒ Types::NotificationRecipientType
Recipients to exclude from notification.
-
#recipient ⇒ Types::NotificationRecipientType
Notification recipient.
-
#subject ⇒ String
The subject of the email if the delivery method is
EMAIL.
Instance Attribute Details
#content ⇒ String
Notification content. Supports variable injection. For more information, see JSONPath reference in the Connect Customer Administrators Guide.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
Content type format.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#delivery_method ⇒ String
Notification delivery method.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#exclusion ⇒ Types::NotificationRecipientType
Recipients to exclude from notification.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#recipient ⇒ Types::NotificationRecipientType
Notification recipient.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |
#subject ⇒ String
The subject of the email if the delivery method is EMAIL. Supports
variable injection. For more information, see JSONPath
reference in the Connect Customer Administrators Guide.
31835 31836 31837 31838 31839 31840 31841 31842 31843 31844 |
# File 'lib/aws-sdk-connect/types.rb', line 31835 class SendNotificationActionDefinition < Struct.new( :delivery_method, :subject, :content, :content_type, :recipient, :exclusion) SENSITIVE = [] include Aws::Structure end |