Class: Aws::Connect::Types::SendOutboundEmailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SendOutboundEmailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_recipients ⇒ Types::OutboundAdditionalRecipients
The additional recipients address of the email in CC.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#destination_email_address ⇒ Types::EmailAddressInfo
The email address to send the email to.
-
#email_message ⇒ Types::OutboundEmailContent
The email message body to be sent to the newly created email.
-
#from_email_address ⇒ Types::EmailAddressInfo
The email address to be used for sending email.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#source_campaign ⇒ Types::SourceCampaign
A Campaign object need for Campaign traffic type.
-
#traffic_type ⇒ String
Denotes the class of traffic.
Instance Attribute Details
#additional_recipients ⇒ Types::OutboundAdditionalRecipients
The additional recipients address of the email in CC.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#destination_email_address ⇒ Types::EmailAddressInfo
The email address to send the email to.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_message ⇒ Types::OutboundEmailContent
The email message body to be sent to the newly created email.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#from_email_address ⇒ Types::EmailAddressInfo
The email address to be used for sending email.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_campaign ⇒ Types::SourceCampaign
A Campaign object need for Campaign traffic type.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |
#traffic_type ⇒ String
Denotes the class of traffic.
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 |
# File 'lib/aws-sdk-connect/types.rb', line 31849 class SendOutboundEmailRequest < Struct.new( :instance_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :traffic_type, :source_campaign, :client_token) SENSITIVE = [] include Aws::Structure end |