Class: Aws::Connect::Types::SendOutboundWebNotificationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#browser_idString

A unique identifier for the customer's web browser instance to which the notification is being sent.

Returns:

  • (String)


31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::WebNotificationContent

The content of the web notification, including the notification type, the view to render, and any optional attributes used to populate it.



31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#destinationTypes::WidgetDestination

The destination for the web notification, specifying the communication widget that delivers the notification and the customer profile of the recipient.



31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp, in Unix epoch time format, at which the web notification expires. After this time, the notification is no longer delivered to the customer's browser.

Returns:

  • (Time)


31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

A unique identifier for the customer's web session to which the notification is being sent.

Returns:

  • (String)


31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::WebNotificationSource

The source of the web notification. A SourceCampaign object identifies the campaign and outbound request that triggered this notification.



31804
31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
31815
# File 'lib/aws-sdk-connect/types.rb', line 31804

class SendOutboundWebNotificationRequest < Struct.new(
  :instance_id,
  :client_token,
  :browser_id,
  :session_id,
  :expires_at,
  :source,
  :destination,
  :content)
  SENSITIVE = []
  include Aws::Structure
end