Class: Aws::Connect::Types::StartAssistantContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_agentTypes::AiAgentInput

The AI agent configuration for this contact.

Returns:



33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#attributesHash<String,String>

A map of key-value pairs to associate with the contact. We make these attributes available to flows as standard contact attributes.

You can provide up to 32,768 UTF-8 bytes across all key-value pairs for each contact.

Returns:

  • (Hash<String,String>)


33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#initial_messageTypes::ChatMessage

The initial message to send to the newly created chat.

Returns:



33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#participant_detailsTypes::ParticipantDetails

The display name and other details that identify the chat participant.



33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#persistent_chatTypes::PersistentChat

The configuration that enables persistent chat. For more information about persistent chat and its use cases, see Enable persistent chat.



33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

The identifier of an Connect Customer contact related to the new assistant contact.

You cannot provide both RelatedContactId and PersistentChat.

Returns:

  • (String)


33582
33583
33584
33585
33586
33587
33588
33589
33590
33591
33592
33593
# File 'lib/aws-sdk-connect/types.rb', line 33582

class StartAssistantContactRequest < Struct.new(
  :instance_id,
  :ai_agent,
  :participant_details,
  :initial_message,
  :attributes,
  :client_token,
  :persistent_chat,
  :related_contact_id)
  SENSITIVE = []
  include Aws::Structure
end