Class: Aws::Connect::Types::StartAssistantContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartAssistantContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_agent ⇒ Types::AiAgentInput
The AI agent configuration for this contact.
-
#attributes ⇒ Hash<String,String>
A map of key-value pairs to associate with the contact.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#initial_message ⇒ Types::ChatMessage
The initial message to send to the newly created chat.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#participant_details ⇒ Types::ParticipantDetails
The display name and other details that identify the chat participant.
-
#persistent_chat ⇒ Types::PersistentChat
The configuration that enables persistent chat.
-
#related_contact_id ⇒ String
The identifier of an Connect Customer contact related to the new assistant contact.
Instance Attribute Details
#ai_agent ⇒ Types::AiAgentInput
The AI agent configuration for this contact.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A map of key-value pairs to associate with the contact. We make these attributes available to flows as standard contact attributes.
You can provide up to 32,768 UTF-8 bytes across all key-value pairs for each contact.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#initial_message ⇒ Types::ChatMessage
The initial message to send to the newly created chat.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
The display name and other details that identify the chat participant.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#persistent_chat ⇒ Types::PersistentChat
The configuration that enables persistent chat. For more information about persistent chat and its use cases, see Enable persistent chat.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#related_contact_id ⇒ String
The identifier of an Connect Customer contact related to the new assistant contact.
RelatedContactId and PersistentChat.
33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 |
# File 'lib/aws-sdk-connect/types.rb', line 33582 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |