Class: Aws::Connect::Types::StartAssistantContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartAssistantContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_agent ⇒ Types::AiAgentInput
The AI agent that participates in the contact.
-
#attributes ⇒ Hash<String,String>
A map of key-value pairs to associate with the contact.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#initial_message ⇒ Types::ChatMessage
The initial message to send to the newly created chat.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#participant_details ⇒ Types::ParticipantDetails
The display name and other details that identify the chat participant.
-
#persistent_chat ⇒ Types::PersistentChat
The configuration that enables persistent chat.
-
#related_contact_id ⇒ String
The identifier of an Connect Customer contact related to the new assistant contact.
Instance Attribute Details
#ai_agent ⇒ Types::AiAgentInput
The AI agent that participates in the contact.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A map of key-value pairs to associate with the contact. Amazon Connect makes these attributes available to flows as standard contact attributes.
You can provide up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can contain only alphanumeric characters, dashes, and underscores.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#initial_message ⇒ Types::ChatMessage
The initial message to send to the newly created chat.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
The display name and other details that identify the chat participant.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#persistent_chat ⇒ Types::PersistentChat
The configuration that enables persistent chat. For more information about persistent chat and its use cases, see Enable persistent chat.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |
#related_contact_id ⇒ String
The identifier of an Connect Customer contact related to the new assistant contact.
RelatedContactId and PersistentChat.
33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33218 class StartAssistantContactRequest < Struct.new( :instance_id, :ai_agent, :participant_details, :initial_message, :attributes, :client_token, :persistent_chat, :related_contact_id) SENSITIVE = [] include Aws::Structure end |