Class: Aws::Connect::Types::StartAssistantContactResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact within the Connect Customer instance.

Returns:

  • (String)


33621
33622
33623
33624
33625
33626
33627
33628
# File 'lib/aws-sdk-connect/types.rb', line 33621

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#continued_from_contact_idString

The identifier of the contact from which the chat continues, returned only for persistent chats.

Returns:

  • (String)


33621
33622
33623
33624
33625
33626
33627
33628
# File 'lib/aws-sdk-connect/types.rb', line 33621

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#participant_idString

The identifier of the chat participant. The participant identifier remains the same throughout the chat lifecycle.

Returns:

  • (String)


33621
33622
33623
33624
33625
33626
33627
33628
# File 'lib/aws-sdk-connect/types.rb', line 33621

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#participant_tokenString

The token that the chat participant uses with the CreateParticipantConnection operation. The token remains valid for the lifetime of the chat participant.

Returns:

  • (String)


33621
33622
33623
33624
33625
33626
33627
33628
# File 'lib/aws-sdk-connect/types.rb', line 33621

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end