Class: Aws::Connect::Types::StartAssistantContactResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact within the Connect Customer instance.

Returns:

  • (String)


33258
33259
33260
33261
33262
33263
33264
33265
# File 'lib/aws-sdk-connect/types.rb', line 33258

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#continued_from_contact_idString

For a persistent chat, the identifier of the contact from which the chat continues. Amazon Connect returns this field only for persistent chats.

Returns:

  • (String)


33258
33259
33260
33261
33262
33263
33264
33265
# File 'lib/aws-sdk-connect/types.rb', line 33258

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#participant_idString

The identifier of the chat participant. The participant identifier remains the same throughout the chat lifecycle.

Returns:

  • (String)


33258
33259
33260
33261
33262
33263
33264
33265
# File 'lib/aws-sdk-connect/types.rb', line 33258

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end

#participant_tokenString

The token that the chat participant uses to call the CreateParticipantConnection API. The token remains valid for the lifetime of the chat participant.

Returns:

  • (String)


33258
33259
33260
33261
33262
33263
33264
33265
# File 'lib/aws-sdk-connect/types.rb', line 33258

class StartAssistantContactResponse < Struct.new(
  :contact_id,
  :participant_id,
  :participant_token,
  :continued_from_contact_id)
  SENSITIVE = []
  include Aws::Structure
end