Class: Aws::Connect::Types::StartContactConversationalAnalyticsJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartContactConversationalAnalyticsJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The configuration for the conversational analytics job.
-
#analytics_modes ⇒ Array<String>
The analytics modes to run for the contact.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The configuration for the conversational analytics job.
34058 34059 34060 34061 34062 34063 34064 34065 34066 |
# File 'lib/aws-sdk-connect/types.rb', line 34058 class StartContactConversationalAnalyticsJobRequest < Struct.new( :instance_id, :contact_id, :analytics_modes, :analytics_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#analytics_modes ⇒ Array<String>
The analytics modes to run for the contact. Valid values:
PostContact.
34058 34059 34060 34061 34062 34063 34064 34065 34066 |
# File 'lib/aws-sdk-connect/types.rb', line 34058 class StartContactConversationalAnalyticsJobRequest < Struct.new( :instance_id, :contact_id, :analytics_modes, :analytics_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
34058 34059 34060 34061 34062 34063 34064 34065 34066 |
# File 'lib/aws-sdk-connect/types.rb', line 34058 class StartContactConversationalAnalyticsJobRequest < Struct.new( :instance_id, :contact_id, :analytics_modes, :analytics_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
34058 34059 34060 34061 34062 34063 34064 34065 34066 |
# File 'lib/aws-sdk-connect/types.rb', line 34058 class StartContactConversationalAnalyticsJobRequest < Struct.new( :instance_id, :contact_id, :analytics_modes, :analytics_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
34058 34059 34060 34061 34062 34063 34064 34065 34066 |
# File 'lib/aws-sdk-connect/types.rb', line 34058 class StartContactConversationalAnalyticsJobRequest < Struct.new( :instance_id, :contact_id, :analytics_modes, :analytics_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |