Class: Aws::Connect::Types::StartContactEvaluationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartContactEvaluationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_evaluation_configuration ⇒ Types::AutoEvaluationConfiguration
Whether automated evaluations are enabled.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#auto_evaluation_configuration ⇒ Types::AutoEvaluationConfiguration
Whether automated evaluations are enabled.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 |
# File 'lib/aws-sdk-connect/types.rb', line 34169 class StartContactEvaluationRequest < Struct.new( :instance_id, :contact_id, :evaluation_form_id, :auto_evaluation_configuration, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |