Class: Aws::Connect::Types::StartContactEvaluationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_evaluation_configurationTypes::AutoEvaluationConfiguration

Whether automated evaluations are enabled.



32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_form_idString

The unique identifier for the evaluation form.

Returns:

  • (String)


32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


32563
32564
32565
32566
32567
32568
32569
32570
32571
32572
# File 'lib/aws-sdk-connect/types.rb', line 32563

class StartContactEvaluationRequest < Struct.new(
  :instance_id,
  :contact_id,
  :evaluation_form_id,
  :auto_evaluation_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end