Class: Aws::Connect::Types::StartContactStreamingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartContactStreamingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#chat_streaming_configuration ⇒ Types::ChatStreamingConfiguration
The streaming configuration, such as the Amazon SNS streaming endpoint.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#chat_streaming_configuration ⇒ Types::ChatStreamingConfiguration
The streaming configuration, such as the Amazon SNS streaming endpoint.
34265 34266 34267 34268 34269 34270 34271 34272 |
# File 'lib/aws-sdk-connect/types.rb', line 34265 class StartContactStreamingRequest < Struct.new( :instance_id, :contact_id, :chat_streaming_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
34265 34266 34267 34268 34269 34270 34271 34272 |
# File 'lib/aws-sdk-connect/types.rb', line 34265 class StartContactStreamingRequest < Struct.new( :instance_id, :contact_id, :chat_streaming_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.
34265 34266 34267 34268 34269 34270 34271 34272 |
# File 'lib/aws-sdk-connect/types.rb', line 34265 class StartContactStreamingRequest < Struct.new( :instance_id, :contact_id, :chat_streaming_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
34265 34266 34267 34268 34269 34270 34271 34272 |
# File 'lib/aws-sdk-connect/types.rb', line 34265 class StartContactStreamingRequest < Struct.new( :instance_id, :contact_id, :chat_streaming_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |