Class: Aws::Connect::Types::StartOutboundChatContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes, and can be accessed in flows just like any other contact attributes.

Returns:

  • (Hash<String,String>)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#chat_duration_in_minutesInteger

The total duration of the newly started chat session. If not specified, the chat session duration defaults to 25 hour. The minimum configurable time is 60 minutes. The maximum configurable time is 10,080 minutes (7 days).

Returns:

  • (Integer)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow for the call. To see the ContactFlowId in the Connect Customer console user interface, on the navigation menu go to Routing, Contact Flows. Choose the flow. On the flow page, under the name of the flow, choose Show additional flow information. The ContactFlowId is the last part of the ARN, shown here in bold:

  • arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/123ec456-a007-89c0-1234-xxxxxxxxxxxx

^

Returns:

  • (String)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#destination_endpointTypes::Endpoint

Information about the endpoint.

Returns:



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#initial_system_messageTypes::ChatMessage

A chat message.

Returns:



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#initial_templated_system_messageTypes::TemplatedMessageConfig

Information about template message configuration.



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#participant_detailsTypes::ParticipantDetails

The customer's details.



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier for an Connect Customer contact. This identifier is related to the contact starting.

Returns:

  • (String)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#segment_attributesHash<String,Types::SegmentAttributeValue>

A set of system defined key-value pairs stored on individual contact segments using an attribute map. The attributes are standard Connect Customer attributes. They can be accessed in flows.

  • Attribute keys can include only alphanumeric, -, and _.

  • This field can be used to show channel subtype, such as connect:SMS and connect:WhatsApp.

Returns:



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_endpointTypes::Endpoint

Information about the endpoint.

Returns:



32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#supported_messaging_content_typesArray<String>

The supported chat message content types. Supported types are:

  • text/plain

  • text/markdown

  • application/json, application/vnd.amazonaws.connect.message.interactive

  • application/vnd.amazonaws.connect.message.interactive.response

Content types must always contain text/plain. You can then put any other supported type in the list. For example, all the following lists are valid because they contain text/plain:

  • [text/plain, text/markdown, application/json]

  • [text/markdown, text/plain]

  • [text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response]

Returns:

  • (Array<String>)


32971
32972
32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
# File 'lib/aws-sdk-connect/types.rb', line 32971

class StartOutboundChatContactRequest < Struct.new(
  :source_endpoint,
  :destination_endpoint,
  :instance_id,
  :segment_attributes,
  :attributes,
  :contact_flow_id,
  :chat_duration_in_minutes,
  :participant_details,
  :initial_system_message,
  :initial_templated_system_message,
  :related_contact_id,
  :supported_messaging_content_types,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end