Class: Aws::Connect::Types::StartOutboundChatContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartOutboundChatContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#chat_duration_in_minutes ⇒ Integer
The total duration of the newly started chat session.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_flow_id ⇒ String
The identifier of the flow for the call.
-
#destination_endpoint ⇒ Types::Endpoint
Information about the endpoint.
-
#initial_system_message ⇒ Types::ChatMessage
A chat message.
-
#initial_templated_system_message ⇒ Types::TemplatedMessageConfig
Information about template message configuration.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#participant_details ⇒ Types::ParticipantDetails
The customer’s details.
-
#related_contact_id ⇒ String
The unique identifier for an Amazon Connect contact.
-
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A set of system defined key-value pairs stored on individual contact segments using an attribute map.
-
#source_endpoint ⇒ Types::Endpoint
Information about the endpoint.
-
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in flows just like any other contact attributes.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#chat_duration_in_minutes ⇒ Integer
The total duration of the newly started chat session. If not specified, the chat session duration defaults to 25 hour. The minimum configurable time is 60 minutes. The maximum configurable time is 10,080 minutes (7 days).
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs]. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow for the call. To see the ContactFlowId in the Amazon Connect console user interface, on the navigation menu go to **Routing, Contact Flows**. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:
-
arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/123ec456-a007-89c0-1234-xxxxxxxxxxxx
^
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#destination_endpoint ⇒ Types::Endpoint
Information about the endpoint.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#initial_system_message ⇒ Types::ChatMessage
A chat message.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#initial_templated_system_message ⇒ Types::TemplatedMessageConfig
Information about template message configuration.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
The customer’s details.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#related_contact_id ⇒ String
The unique identifier for an Amazon Connect contact. This identifier is related to the contact starting.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A set of system defined key-value pairs stored on individual contact segments using an attribute map. The attributes are standard Amazon Connect attributes. They can be accessed in flows.
-
Attribute keys can include only alphanumeric, ‘-`, and `_`.
-
This field can be used to show channel subtype, such as ‘connect:SMS` and `connect:WhatsApp`.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_endpoint ⇒ Types::Endpoint
Information about the endpoint.
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |
#supported_messaging_content_types ⇒ Array<String>
The supported chat message content types. Supported types are:
-
‘text/plain`
-
‘text/markdown`
-
‘application/json, application/vnd.amazonaws.connect.message.interactive`
-
‘application/vnd.amazonaws.connect.message.interactive.response`
Content types must always contain ‘text/plain`. You can then put any other supported type in the list. For example, all the following lists are valid because they contain `text/plain`:
-
‘[text/plain, text/markdown, application/json]`
-
‘[text/markdown, text/plain]`
-
‘[text/plain, application/json, application/vnd.amazonaws.connect.message.interactive.response]`
29644 29645 29646 29647 29648 29649 29650 29651 29652 29653 29654 29655 29656 29657 29658 29659 29660 |
# File 'lib/aws-sdk-connect/types.rb', line 29644 class StartOutboundChatContactRequest < Struct.new( :source_endpoint, :destination_endpoint, :instance_id, :segment_attributes, :attributes, :contact_flow_id, :chat_duration_in_minutes, :participant_details, :initial_system_message, :initial_templated_system_message, :related_contact_id, :supported_messaging_content_types, :client_token) SENSITIVE = [] include Aws::Structure end |