Class: Aws::Connect::Types::StartOutboundEmailContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartOutboundEmailContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_recipients ⇒ Types::OutboundAdditionalRecipients
The additional recipients address of email in CC.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#destination_email_address ⇒ Types::EmailAddressInfo
The email address of the customer.
-
#email_message ⇒ Types::OutboundEmailContent
The email message body to be sent to the newly created email.
-
#from_email_address ⇒ Types::EmailAddressInfo
The email address associated with the Connect Customer instance.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#additional_recipients ⇒ Types::OutboundAdditionalRecipients
The additional recipients address of email in CC.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#destination_email_address ⇒ Types::EmailAddressInfo
The email address of the customer.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#email_message ⇒ Types::OutboundEmailContent
The email message body to be sent to the newly created email.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#from_email_address ⇒ Types::EmailAddressInfo
The email address associated with the Connect Customer instance.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 |
# File 'lib/aws-sdk-connect/types.rb', line 32805 class StartOutboundEmailContactRequest < Struct.new( :instance_id, :contact_id, :from_email_address, :destination_email_address, :additional_recipients, :email_message, :client_token) SENSITIVE = [] include Aws::Structure end |