Class: Aws::Connect::Types::StartOutboundVoiceContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartOutboundVoiceContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#answer_machine_detection_config ⇒ Types::AnswerMachineDetectionConfig
Configuration of the answering machine detection for this outbound call.
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#campaign_id ⇒ String
The campaign identifier of the outbound communication.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_flow_id ⇒ String
The identifier of the flow for the outbound call.
-
#description ⇒ String
A description of the voice contact that appears in the agent’s snapshot in the CCP logs.
-
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of a voice contact that is shown to an agent in the Contact Control Panel (CCP).
-
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
-
#queue_id ⇒ String
The queue for the call.
-
#references ⇒ Hash<String,Types::Reference>
A formatted URL that is shown to an agent in the Contact Control Panel (CCP).
-
#related_contact_id ⇒ String
The ‘contactId` that is related to this contact.
-
#ring_timeout_in_seconds ⇒ Integer
The maximum time the outbound call will wait for the destination to answer the call, in seconds.
-
#source_phone_number ⇒ String
The phone number associated with the Connect Customer instance, in E.164 format.
-
#traffic_type ⇒ String
Denotes the class of traffic.
Instance Attribute Details
#answer_machine_detection_config ⇒ Types::AnswerMachineDetectionConfig
Configuration of the answering machine detection for this outbound call.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes, and can be accessed in flows just like any other contact attributes.
There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#campaign_id ⇒ String
The campaign identifier of the outbound communication.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs]. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow for the outbound call. To see the ContactFlowId in the Connect Customer admin website, on the navigation menu go to Routing, **Contact Flows**. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:
arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
A description of the voice contact that appears in the agent’s snapshot in the CCP logs. For more information about CCP logs, see
- Download and review CCP logs][1
-
in the *Connect Customer
Administrator Guide*.
[1]: docs.aws.amazon.com/connect/latest/adminguide/download-ccp-logs.html
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#destination_phone_number ⇒ String
The phone number of the customer, in E.164 format.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of a voice contact that is shown to an agent in the Contact Control Panel (CCP).
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#outbound_strategy ⇒ Types::OutboundStrategy
Information about the outbound strategy.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#queue_id ⇒ String
The queue for the call. If you specify a queue, the phone displayed for caller ID is the phone number specified in the queue. If you do not specify a queue, the queue defined in the flow is used. If you do not specify a queue, you must specify a source phone number.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#references ⇒ Hash<String,Types::Reference>
A formatted URL that is shown to an agent in the Contact Control Panel (CCP). Contacts can have the following reference types at the time of creation: ‘URL` | `NUMBER` | `STRING` | `DATE` | `EMAIL`. `ATTACHMENT` is not a supported reference type during voice contact creation.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#related_contact_id ⇒ String
The ‘contactId` that is related to this contact. Linking voice, task, or chat by using `RelatedContactID` copies over contact attributes from the related contact to the new contact. All updates to user-defined attributes in the new contact are limited to the individual contact ID. There are no limits to the number of contacts that can be linked by using `RelatedContactId`.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#ring_timeout_in_seconds ⇒ Integer
The maximum time the outbound call will wait for the destination to answer the call, in seconds
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_phone_number ⇒ String
The phone number associated with the Connect Customer instance, in E.164 format. If you do not specify a source phone number, you must specify a queue.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |
#traffic_type ⇒ String
Denotes the class of traffic. Calls with different traffic types are handled differently by Connect Customer. The default value is ‘GENERAL`. Use `CAMPAIGN` if `EnableAnswerMachineDetection` is set to `true`. For all other cases, use `GENERAL`.
32221 32222 32223 32224 32225 32226 32227 32228 32229 32230 32231 32232 32233 32234 32235 32236 32237 32238 32239 32240 |
# File 'lib/aws-sdk-connect/types.rb', line 32221 class StartOutboundVoiceContactRequest < Struct.new( :name, :description, :references, :related_contact_id, :destination_phone_number, :contact_flow_id, :instance_id, :client_token, :source_phone_number, :queue_id, :attributes, :answer_machine_detection_config, :campaign_id, :traffic_type, :outbound_strategy, :ring_timeout_in_seconds) SENSITIVE = [:name, :description] include Aws::Structure end |