Class: Aws::Connect::Types::StartScreenSharingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartScreenSharingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
33555 33556 33557 33558 33559 33560 33561 |
# File 'lib/aws-sdk-connect/types.rb', line 33555 class StartScreenSharingRequest < Struct.new( :client_token, :instance_id, :contact_id) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
33555 33556 33557 33558 33559 33560 33561 |
# File 'lib/aws-sdk-connect/types.rb', line 33555 class StartScreenSharingRequest < Struct.new( :client_token, :instance_id, :contact_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
33555 33556 33557 33558 33559 33560 33561 |
# File 'lib/aws-sdk-connect/types.rb', line 33555 class StartScreenSharingRequest < Struct.new( :client_token, :instance_id, :contact_id) SENSITIVE = [] include Aws::Structure end |