Class: Aws::Connect::Types::StartTestCaseExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


33787
33788
33789
33790
33791
33792
33793
# File 'lib/aws-sdk-connect/types.rb', line 33787

class StartTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance.

Returns:

  • (String)


33787
33788
33789
33790
33791
33792
33793
# File 'lib/aws-sdk-connect/types.rb', line 33787

class StartTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_idString

The identifier of the test case to execute.

Returns:

  • (String)


33787
33788
33789
33790
33791
33792
33793
# File 'lib/aws-sdk-connect/types.rb', line 33787

class StartTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end