Class: Aws::Connect::Types::StartTestCaseExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartTestCaseExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#test_case_id ⇒ String
The identifier of the test case to execute.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33223 class StartTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33223 class StartTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
The identifier of the test case to execute.
33223 33224 33225 33226 33227 33228 33229 |
# File 'lib/aws-sdk-connect/types.rb', line 33223 class StartTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |