Class: Aws::Connect::Types::StartWebRTCContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StartWebRTCContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#allowed_capabilities ⇒ Types::AllowedCapabilities
Information about the video sharing capabilities of the participants (customer, agent).
-
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_flow_id ⇒ String
The identifier of the flow for the call.
-
#description ⇒ String
A description of the task that is shown to an agent in the Contact Control Panel (CCP).
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#participant_details ⇒ Types::ParticipantDetails
The details of the participant, including their display name.
-
#references ⇒ Hash<String,Types::Reference>
A formatted URL that is shown to an agent in the Contact Control Panel (CCP).
-
#related_contact_id ⇒ String
The unique identifier for an Connect Customer contact.
-
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A map of system-defined attributes for the WebRTC contact segment.
Instance Attribute Details
#allowed_capabilities ⇒ Types::AllowedCapabilities
Information about the video sharing capabilities of the participants (customer, agent).
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#attributes ⇒ Hash<String,String>
A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes, and can be accessed in flows just like any other contact attributes.
There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, -, and _ characters.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.
A suitable default value is auto-generated. You should normally not need to pass this option.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow for the call. To see the ContactFlowId in the Connect Customer admin website, on the navigation menu go to Routing, Flows. Choose the flow. On the flow page, under the name of the flow, choose Show additional flow information. The ContactFlowId is the last part of the ARN, shown here in bold:
arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description of the task that is shown to an agent in the Contact Control Panel (CCP).
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#participant_details ⇒ Types::ParticipantDetails
The details of the participant, including their display name.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#references ⇒ Hash<String,Types::Reference>
A formatted URL that is shown to an agent in the Contact Control
Panel (CCP). Tasks can have the following reference types at the
time of creation: URL | NUMBER | STRING | DATE |
EMAIL. ATTACHMENT is not a supported reference type during task
creation.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#related_contact_id ⇒ String
The unique identifier for an Connect Customer contact. This identifier is related to the contact starting.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |
#segment_attributes ⇒ Hash<String,Types::SegmentAttributeValue>
A map of system-defined attributes for the WebRTC contact segment.
Use the connect:Subtype attribute to specify the channel subtype,
such as connect:WebRTC.
35108 35109 35110 35111 35112 35113 35114 35115 35116 35117 35118 35119 35120 35121 |
# File 'lib/aws-sdk-connect/types.rb', line 35108 class StartWebRTCContactRequest < Struct.new( :attributes, :client_token, :contact_flow_id, :instance_id, :allowed_capabilities, :participant_details, :related_contact_id, :references, :description, :segment_attributes) SENSITIVE = [:description] include Aws::Structure end |