Class: Aws::Connect::Types::StartWebRTCContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_capabilitiesTypes::AllowedCapabilities

Information about the video sharing capabilities of the participants (customer, agent).



33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#attributesHash<String,String>

A custom key-value pair using an attribute map. The attributes are standard Connect Customer attributes, and can be accessed in flows just like any other contact attributes.

There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, -, and _ characters.

Returns:

  • (Hash<String,String>)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].

The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow for the call. To see the ContactFlowId in the Connect Customer admin website, on the navigation menu go to Routing, Flows. Choose the flow. On the flow page, under the name of the flow, choose **Show additional flow information**. The ContactFlowId is the last part of the ARN, shown here in bold:

arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx

Returns:

  • (String)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description of the task that is shown to an agent in the Contact Control Panel (CCP).

Returns:

  • (String)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#participant_detailsTypes::ParticipantDetails

The customer’s details.



33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#referencesHash<String,Types::Reference>

A formatted URL that is shown to an agent in the Contact Control Panel (CCP). Tasks can have the following reference types at the time of creation: ‘URL` | `NUMBER` | `STRING` | `DATE` | `EMAIL`. `ATTACHMENT` is not a supported reference type during task creation.

Returns:



33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

The unique identifier for an Connect Customer contact. This identifier is related to the contact starting.

Returns:

  • (String)


33057
33058
33059
33060
33061
33062
33063
33064
33065
33066
33067
33068
33069
# File 'lib/aws-sdk-connect/types.rb', line 33057

class StartWebRTCContactRequest < Struct.new(
  :attributes,
  :client_token,
  :contact_flow_id,
  :instance_id,
  :allowed_capabilities,
  :participant_details,
  :related_contact_id,
  :references,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end