Class: Aws::Connect::Types::StopContactStreamingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StopContactStreamingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact. This is the identifier of the contact that is associated with the first interaction with the contact center.
34113 34114 34115 34116 34117 34118 34119 |
# File 'lib/aws-sdk-connect/types.rb', line 34113 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
34113 34114 34115 34116 34117 34118 34119 |
# File 'lib/aws-sdk-connect/types.rb', line 34113 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
34113 34114 34115 34116 34117 34118 34119 |
# File 'lib/aws-sdk-connect/types.rb', line 34113 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |