Class: Aws::Connect::Types::StopContactStreamingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StopContactStreamingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact. This is the identifier of the contact that is associated with the first interaction with the contact center.
33549 33550 33551 33552 33553 33554 33555 |
# File 'lib/aws-sdk-connect/types.rb', line 33549 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
33549 33550 33551 33552 33553 33554 33555 |
# File 'lib/aws-sdk-connect/types.rb', line 33549 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
33549 33550 33551 33552 33553 33554 33555 |
# File 'lib/aws-sdk-connect/types.rb', line 33549 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |