Class: Aws::Connect::Types::StopContactStreamingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StopContactStreamingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact. This is the identifier of the contact that is associated with the first interaction with the contact center.
32359 32360 32361 32362 32363 32364 32365 |
# File 'lib/aws-sdk-connect/types.rb', line 32359 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
32359 32360 32361 32362 32363 32364 32365 |
# File 'lib/aws-sdk-connect/types.rb', line 32359 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |
#streaming_id ⇒ String
The identifier of the streaming configuration enabled.
32359 32360 32361 32362 32363 32364 32365 |
# File 'lib/aws-sdk-connect/types.rb', line 32359 class StopContactStreamingRequest < Struct.new( :instance_id, :contact_id, :streaming_id) SENSITIVE = [] include Aws::Structure end |