Class: Aws::Connect::Types::StopTestCaseExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


35370
35371
35372
35373
35374
35375
35376
35377
# File 'lib/aws-sdk-connect/types.rb', line 35370

class StopTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_execution_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance.

Returns:

  • (String)


35370
35371
35372
35373
35374
35375
35376
35377
# File 'lib/aws-sdk-connect/types.rb', line 35370

class StopTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_execution_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_execution_idString

The identifier of the test case execution to stop.

Returns:

  • (String)


35370
35371
35372
35373
35374
35375
35376
35377
# File 'lib/aws-sdk-connect/types.rb', line 35370

class StopTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_execution_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_idString

The identifier of the test case.

Returns:

  • (String)


35370
35371
35372
35373
35374
35375
35376
35377
# File 'lib/aws-sdk-connect/types.rb', line 35370

class StopTestCaseExecutionRequest < Struct.new(
  :instance_id,
  :test_case_execution_id,
  :test_case_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end