Class: Aws::Connect::Types::StopTestCaseExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::StopTestCaseExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#test_case_execution_id ⇒ String
The identifier of the test case execution to stop.
-
#test_case_id ⇒ String
The identifier of the test case.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
34153 34154 34155 34156 34157 34158 34159 34160 |
# File 'lib/aws-sdk-connect/types.rb', line 34153 class StopTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_execution_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
34153 34154 34155 34156 34157 34158 34159 34160 |
# File 'lib/aws-sdk-connect/types.rb', line 34153 class StopTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_execution_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#test_case_execution_id ⇒ String
The identifier of the test case execution to stop.
34153 34154 34155 34156 34157 34158 34159 34160 |
# File 'lib/aws-sdk-connect/types.rb', line 34153 class StopTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_execution_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
The identifier of the test case.
34153 34154 34155 34156 34157 34158 34159 34160 |
# File 'lib/aws-sdk-connect/types.rb', line 34153 class StopTestCaseExecutionRequest < Struct.new( :instance_id, :test_case_execution_id, :test_case_id, :client_token) SENSITIVE = [] include Aws::Structure end |