Class: Aws::Connect::Types::SubmitContactEvaluationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::SubmitContactEvaluationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
-
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
-
#submitted_by ⇒ Types::EvaluatorUserUnion
The ID of the user who submitted the contact evaluation.
Instance Attribute Details
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
34229 34230 34231 34232 34233 34234 34235 34236 34237 |
# File 'lib/aws-sdk-connect/types.rb', line 34229 class SubmitContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :submitted_by) SENSITIVE = [] include Aws::Structure end |
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
34229 34230 34231 34232 34233 34234 34235 34236 34237 |
# File 'lib/aws-sdk-connect/types.rb', line 34229 class SubmitContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :submitted_by) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
34229 34230 34231 34232 34233 34234 34235 34236 34237 |
# File 'lib/aws-sdk-connect/types.rb', line 34229 class SubmitContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :submitted_by) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
34229 34230 34231 34232 34233 34234 34235 34236 34237 |
# File 'lib/aws-sdk-connect/types.rb', line 34229 class SubmitContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :submitted_by) SENSITIVE = [] include Aws::Structure end |
#submitted_by ⇒ Types::EvaluatorUserUnion
The ID of the user who submitted the contact evaluation.
34229 34230 34231 34232 34233 34234 34235 34236 34237 |
# File 'lib/aws-sdk-connect/types.rb', line 34229 class SubmitContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :submitted_by) SENSITIVE = [] include Aws::Structure end |