Class: Aws::Connect::Types::TestCaseSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TestCaseSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains summary information about a test case.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the test case.
-
#id ⇒ String
The identifier of the test case.
-
#last_modified_region ⇒ String
The region in which the test case was last modified.
-
#last_modified_time ⇒ Time
The time at which the test case was last modified.
-
#name ⇒ String
The name of the test case.
-
#status ⇒ String
The status of the test case.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the test case.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the test case.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The region in which the test case was last modified.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time at which the test case was last modified.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test case.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the test case.
32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 |
# File 'lib/aws-sdk-connect/types.rb', line 32997 class TestCaseSummary < Struct.new( :id, :arn, :name, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |