Class: Aws::Connect::Types::TrafficDistributionGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a traffic distribution group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the traffic distribution group.

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The Amazon Resource Name (ARN).

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Whether this is the default traffic distribution group created during instance replication. The default traffic distribution group cannot be deleted by the DeleteTrafficDistributionGroup API. The default traffic distribution group is deleted as part of the process for deleting a replica.

The SignInConfig distribution is available only on a default TrafficDistributionGroup (see the IsDefault parameter in the TrafficDistributionGroup data type). If you call UpdateTrafficDistribution with a modified SignInConfig and a non-default TrafficDistributionGroup, an InvalidRequestException is returned.

Returns:

  • (Boolean)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the traffic distribution group.

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the traffic distribution group.

Returns:

  • (String)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


36462
36463
36464
36465
36466
36467
36468
36469
36470
36471
36472
36473
# File 'lib/aws-sdk-connect/types.rb', line 36462

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end