Class: Aws::Connect::Types::TrafficDistributionGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about a traffic distribution group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the traffic distribution group.

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The Amazon Resource Name (ARN).

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Whether this is the default traffic distribution group created during instance replication. The default traffic distribution group cannot be deleted by the DeleteTrafficDistributionGroup API. The default traffic distribution group is deleted as part of the process for deleting a replica.

<note markdown=“1”> The SignInConfig distribution is available only on a default TrafficDistributionGroup (see the IsDefault parameter in the

TrafficDistributionGroup][1

data type). If you call

UpdateTrafficDistribution with a modified SignInConfig and a non-default TrafficDistributionGroup, an InvalidRequestException is returned.

</note>

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_TrafficDistributionGroup.html

Returns:

  • (Boolean)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the traffic distribution group.

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the traffic distribution group.

  • CREATION_IN_PROGRESS means the previous

    CreateTrafficDistributionGroup][1

    operation is still in progress

    and has not yet completed.

  • ACTIVE means the previous [CreateTrafficDistributionGroup] operation has succeeded.

  • CREATION_FAILED indicates that the previous

    CreateTrafficDistributionGroup][1

    operation has failed.

  • PENDING_DELETION means the previous

    DeleteTrafficDistributionGroup][2

    operation is still in progress

    and has not yet completed.

  • DELETION_FAILED means the previous

    DeleteTrafficDistributionGroup][2

    operation has failed.

  • UPDATE_IN_PROGRESS means the previous

    UpdateTrafficDistribution][3

    operation is still in progress and

    has not yet completed.

[1]: docs.aws.amazon.com/connect/latest/APIReference/API_CreateTrafficDistributionGroup.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteTrafficDistributionGroup.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdateTrafficDistribution.html

Returns:

  • (String)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.

Returns:

  • (Hash<String,String>)


31645
31646
31647
31648
31649
31650
31651
31652
31653
31654
31655
31656
# File 'lib/aws-sdk-connect/types.rb', line 31645

class TrafficDistributionGroup < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :instance_arn,
  :status,
  :tags,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end