Class: Aws::Connect::Types::TrafficDistributionGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TrafficDistributionGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about a traffic distribution group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
-
#description ⇒ String
The description of the traffic distribution group.
-
#id ⇒ String
The identifier of the traffic distribution group.
-
#instance_arn ⇒ String
The Amazon Resource Name (ARN).
-
#is_default ⇒ Boolean
Whether this is the default traffic distribution group created during instance replication.
-
#name ⇒ String
The name of the traffic distribution group.
-
#status ⇒ String
The status of the traffic distribution group.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the traffic distribution group.
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The Amazon Resource Name (ARN).
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Whether this is the default traffic distribution group created during instance replication. The default traffic distribution group cannot be deleted by the DeleteTrafficDistributionGroup API. The default traffic distribution group is deleted as part of the process for deleting a replica.
<note markdown=“1”> The SignInConfig distribution is available only on a default TrafficDistributionGroup (see the IsDefault parameter in the
- TrafficDistributionGroup][1
-
data type). If you call
UpdateTrafficDistribution with a modified SignInConfig and a non-default TrafficDistributionGroup, an InvalidRequestException is returned.
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_TrafficDistributionGroup.html
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the traffic distribution group.
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the traffic distribution group.
-
CREATION_IN_PROGRESSmeans the previous- CreateTrafficDistributionGroup][1
-
operation is still in progress
and has not yet completed.
-
ACTIVEmeans the previous [CreateTrafficDistributionGroup] operation has succeeded. -
CREATION_FAILEDindicates that the previous- CreateTrafficDistributionGroup][1
-
operation has failed.
-
PENDING_DELETIONmeans the previous- DeleteTrafficDistributionGroup][2
-
operation is still in progress
and has not yet completed.
-
DELETION_FAILEDmeans the previous- DeleteTrafficDistributionGroup][2
-
operation has failed.
-
UPDATE_IN_PROGRESSmeans the previous- UpdateTrafficDistribution][3
-
operation is still in progress and
has not yet completed.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_CreateTrafficDistributionGroup.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteTrafficDistributionGroup.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_UpdateTrafficDistribution.html
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.
31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 |
# File 'lib/aws-sdk-connect/types.rb', line 31645 class TrafficDistributionGroup < Struct.new( :id, :arn, :name, :description, :instance_arn, :status, :tags, :is_default) SENSITIVE = [] include Aws::Structure end |