Class: Aws::Connect::Types::TrafficDistributionGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TrafficDistributionGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about traffic distribution groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
-
#id ⇒ String
The identifier of the traffic distribution group.
-
#instance_arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
-
#is_default ⇒ Boolean
Whether this is the default traffic distribution group created during instance replication.
-
#name ⇒ String
The name of the traffic distribution group.
-
#status ⇒ String
The status of the traffic distribution group.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The Amazon Resource Name (ARN) of the traffic distribution group.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Whether this is the default traffic distribution group created
during instance replication. The default traffic distribution group
cannot be deleted by the DeleteTrafficDistributionGroup API. The
default traffic distribution group is deleted as part of the process
for deleting a replica.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the traffic distribution group.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the traffic distribution group.
-
CREATION_IN_PROGRESSmeans the previous CreateTrafficDistributionGroup operation is still in progress and has not yet completed. -
ACTIVEmeans the previous CreateTrafficDistributionGroup operation has succeeded. -
CREATION_FAILEDindicates that the previous CreateTrafficDistributionGroup operation has failed. -
PENDING_DELETIONmeans the previous DeleteTrafficDistributionGroup operation is still in progress and has not yet completed. -
DELETION_FAILEDmeans the previous DeleteTrafficDistributionGroup operation has failed. -
UPDATE_IN_PROGRESSmeans the previous UpdateTrafficDistributionGroup operation is still in progress and has not yet completed.
36455 36456 36457 36458 36459 36460 36461 36462 36463 36464 |
# File 'lib/aws-sdk-connect/types.rb', line 36455 class TrafficDistributionGroupSummary < Struct.new( :id, :arn, :name, :instance_arn, :status, :is_default) SENSITIVE = [] include Aws::Structure end |