Class: Aws::Connect::Types::TrafficDistributionGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about traffic distribution groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.

Returns:

  • (String)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The Amazon Resource Name (ARN) of the traffic distribution group.

Returns:

  • (String)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Whether this is the default traffic distribution group created during instance replication. The default traffic distribution group cannot be deleted by the DeleteTrafficDistributionGroup API. The default traffic distribution group is deleted as part of the process for deleting a replica.

Returns:

  • (Boolean)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the traffic distribution group.

Returns:

  • (String)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the traffic distribution group.

Returns:

  • (String)


34965
34966
34967
34968
34969
34970
34971
34972
34973
34974
# File 'lib/aws-sdk-connect/types.rb', line 34965

class TrafficDistributionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :instance_arn,
  :status,
  :is_default)
  SENSITIVE = []
  include Aws::Structure
end