Class: Aws::Connect::Types::TransferContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

The identifier of the contact in this instance of Connect Customer.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The identifier for the queue.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The identifier for the user. This can be the ID or the ARN of the user.

Returns:

  • (String)


35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
# File 'lib/aws-sdk-connect/types.rb', line 35355

class TransferContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :queue_id,
  :user_id,
  :contact_flow_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end