Class: Aws::Connect::Types::TransferContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::TransferContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#contact_flow_id ⇒ String
The identifier of the flow.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#queue_id ⇒ String
The identifier for the queue.
-
#user_id ⇒ String
The identifier for the user.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The identifier for the queue.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier for the user. This can be the ID or the ARN of the user.
35332 35333 35334 35335 35336 35337 35338 35339 35340 35341 |
# File 'lib/aws-sdk-connect/types.rb', line 35332 class TransferContactRequest < Struct.new( :instance_id, :contact_id, :queue_id, :user_id, :contact_flow_id, :client_token) SENSITIVE = [] include Aws::Structure end |