Class: Aws::Connect::Types::UntagContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UntagContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#tag_keys ⇒ Array<String>
A list of tag keys.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UntagContactRequest < Struct.new( :contact_id, :instance_id, :tag_keys) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UntagContactRequest < Struct.new( :contact_id, :instance_id, :tag_keys) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
A list of tag keys. Existing tags on the contact whose keys are members of this list will be removed.
37030 37031 37032 37033 37034 37035 37036 |
# File 'lib/aws-sdk-connect/types.rb', line 37030 class UntagContactRequest < Struct.new( :contact_id, :instance_id, :tag_keys) SENSITIVE = [] include Aws::Structure end |