Class: Aws::Connect::Types::UpdateAgentStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateAgentStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_status_id ⇒ String
The identifier of the agent status.
-
#description ⇒ String
The description of the agent status.
-
#display_order ⇒ Integer
The display order of the agent status.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the agent status.
-
#reset_order_number ⇒ Boolean
A number indicating the reset order of the agent status.
-
#state ⇒ String
The state of the agent status.
Instance Attribute Details
#agent_status_id ⇒ String
The identifier of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#display_order ⇒ Integer
The display order of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#reset_order_number ⇒ Boolean
A number indicating the reset order of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the agent status.
35144 35145 35146 35147 35148 35149 35150 35151 35152 35153 35154 |
# File 'lib/aws-sdk-connect/types.rb', line 35144 class UpdateAgentStatusRequest < Struct.new( :instance_id, :agent_status_id, :name, :description, :state, :display_order, :reset_order_number) SENSITIVE = [] include Aws::Structure end |