Class: Aws::Connect::Types::UpdateAttachedFilesConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateAttachedFilesConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_scope ⇒ String
The scope of the attachment.
-
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
Instance Attribute Details
#attachment_scope ⇒ String
The scope of the attachment. Valid values are EMAIL, CHAT,
CASE, and TASK.
35181 35182 35183 35184 35185 35186 35187 35188 |
# File 'lib/aws-sdk-connect/types.rb', line 35181 class UpdateAttachedFilesConfigurationRequest < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
35181 35182 35183 35184 35185 35186 35187 35188 |
# File 'lib/aws-sdk-connect/types.rb', line 35181 class UpdateAttachedFilesConfigurationRequest < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35181 35182 35183 35184 35185 35186 35187 35188 |
# File 'lib/aws-sdk-connect/types.rb', line 35181 class UpdateAttachedFilesConfigurationRequest < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes. The minimum value is 1 and the maximum value is 104857600 (100 MB).
35181 35182 35183 35184 35185 35186 35187 35188 |
# File 'lib/aws-sdk-connect/types.rb', line 35181 class UpdateAttachedFilesConfigurationRequest < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration) SENSITIVE = [] include Aws::Structure end |