Class: Aws::Connect::Types::UpdateAttachedFilesConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateAttachedFilesConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_scope ⇒ String
The scope of the attachment.
-
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
-
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
Instance Attribute Details
#attachment_scope ⇒ String
The scope of the attachment.
34012 34013 34014 34015 34016 34017 34018 34019 34020 |
# File 'lib/aws-sdk-connect/types.rb', line 34012 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#extension_configuration ⇒ Types::ExtensionConfiguration
The configuration for allowed file extensions.
34012 34013 34014 34015 34016 34017 34018 34019 34020 |
# File 'lib/aws-sdk-connect/types.rb', line 34012 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
34012 34013 34014 34015 34016 34017 34018 34019 34020 |
# File 'lib/aws-sdk-connect/types.rb', line 34012 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the configuration was last modified.
34012 34013 34014 34015 34016 34017 34018 34019 34020 |
# File 'lib/aws-sdk-connect/types.rb', line 34012 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#maximum_size_limit_in_bytes ⇒ Integer
The maximum size limit for attached files in bytes.
34012 34013 34014 34015 34016 34017 34018 34019 34020 |
# File 'lib/aws-sdk-connect/types.rb', line 34012 class UpdateAttachedFilesConfigurationResponse < Struct.new( :instance_id, :attachment_scope, :maximum_size_limit_in_bytes, :extension_configuration, :last_modified_time) SENSITIVE = [] include Aws::Structure end |