Class: Aws::Connect::Types::UpdateAuthenticationProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateAuthenticationProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_ips ⇒ Array<String>
A list of IP address range strings that are allowed to access the instance.
-
#authentication_profile_id ⇒ String
A unique identifier for the authentication profile.
-
#blocked_ips ⇒ Array<String>
A list of IP address range strings that are blocked from accessing the instance.
-
#description ⇒ String
The description for the authentication profile.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name for the authentication profile.
-
#periodic_session_duration ⇒ Integer
The short lived session duration configuration for users logged in to Connect Customer, in minutes.
-
#session_inactivity_duration ⇒ Integer
The period, in minutes, before an agent is automatically signed out of the contact center when they go inactive.
-
#session_inactivity_handling_enabled ⇒ Boolean
Determines if automatic logout on user inactivity is enabled.
Instance Attribute Details
#allowed_ips ⇒ Array<String>
A list of IP address range strings that are allowed to access the instance. For more information on how to configure IP addresses, seeConfigure session timeouts in the Connect Customer Administrator Guide.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#authentication_profile_id ⇒ String
A unique identifier for the authentication profile.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#blocked_ips ⇒ Array<String>
A list of IP address range strings that are blocked from accessing the instance. For more information on how to configure IP addresses, For more information on how to configure IP addresses, see Configure IP-based access control in the Connect Customer Administrator Guide.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the authentication profile.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for the authentication profile.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#periodic_session_duration ⇒ Integer
The short lived session duration configuration for users logged in to Connect Customer, in minutes. This value determines the maximum possible time before an agent is authenticated. For more information, For more information on how to configure IP addresses, see Configure session timeouts in the Connect Customer Administrator Guide.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#session_inactivity_duration ⇒ Integer
The period, in minutes, before an agent is automatically signed out of the contact center when they go inactive.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |
#session_inactivity_handling_enabled ⇒ Boolean
Determines if automatic logout on user inactivity is enabled.
35590 35591 35592 35593 35594 35595 35596 35597 35598 35599 35600 35601 35602 |
# File 'lib/aws-sdk-connect/types.rb', line 35590 class UpdateAuthenticationProfileRequest < Struct.new( :authentication_profile_id, :instance_id, :name, :description, :allowed_ips, :blocked_ips, :periodic_session_duration, :session_inactivity_duration, :session_inactivity_handling_enabled) SENSITIVE = [] include Aws::Structure end |