Class: Aws::Connect::Types::UpdateContactEvaluationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactEvaluationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
-
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
-
#updated_by ⇒ Types::EvaluatorUserUnion
The ID of the user who updated the contact evaluation.
Instance Attribute Details
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
37062 37063 37064 37065 37066 37067 37068 37069 37070 |
# File 'lib/aws-sdk-connect/types.rb', line 37062 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
37062 37063 37064 37065 37066 37067 37068 37069 37070 |
# File 'lib/aws-sdk-connect/types.rb', line 37062 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37062 37063 37064 37065 37066 37067 37068 37069 37070 |
# File 'lib/aws-sdk-connect/types.rb', line 37062 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
37062 37063 37064 37065 37066 37067 37068 37069 37070 |
# File 'lib/aws-sdk-connect/types.rb', line 37062 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ Types::EvaluatorUserUnion
The ID of the user who updated the contact evaluation.
37062 37063 37064 37065 37066 37067 37068 37069 37070 |
# File 'lib/aws-sdk-connect/types.rb', line 37062 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |