Class: Aws::Connect::Types::UpdateContactEvaluationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactEvaluationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
-
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
-
#updated_by ⇒ Types::EvaluatorUserUnion
The ID of the user who updated the contact evaluation.
Instance Attribute Details
#answers ⇒ Hash<String,Types::EvaluationAnswerInput>
A map of question identifiers to answer value.
35278 35279 35280 35281 35282 35283 35284 35285 35286 |
# File 'lib/aws-sdk-connect/types.rb', line 35278 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#evaluation_id ⇒ String
A unique identifier for the contact evaluation.
35278 35279 35280 35281 35282 35283 35284 35285 35286 |
# File 'lib/aws-sdk-connect/types.rb', line 35278 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35278 35279 35280 35281 35282 35283 35284 35285 35286 |
# File 'lib/aws-sdk-connect/types.rb', line 35278 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ Hash<String,Types::EvaluationNote>
A map of question identifiers to note value.
35278 35279 35280 35281 35282 35283 35284 35285 35286 |
# File 'lib/aws-sdk-connect/types.rb', line 35278 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ Types::EvaluatorUserUnion
The ID of the user who updated the contact evaluation.
35278 35279 35280 35281 35282 35283 35284 35285 35286 |
# File 'lib/aws-sdk-connect/types.rb', line 35278 class UpdateContactEvaluationRequest < Struct.new( :instance_id, :evaluation_id, :answers, :notes, :updated_by) SENSITIVE = [] include Aws::Structure end |