Class: Aws::Connect::Types::UpdateContactFlowModuleContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactFlowModuleContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_flow_module_id ⇒ String
The identifier of the flow module.
-
#content ⇒ String
The JSON string that represents the content of the flow.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#settings ⇒ String
Serialized JSON string of the flow module Settings schema.
Instance Attribute Details
#contact_flow_module_id ⇒ String
The identifier of the flow module.
35874 35875 35876 35877 35878 35879 35880 35881 |
# File 'lib/aws-sdk-connect/types.rb', line 35874 class UpdateContactFlowModuleContentRequest < Struct.new( :instance_id, :contact_flow_module_id, :content, :settings) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The JSON string that represents the content of the flow. For an example, see Example flow in Connect Customer Flow language.
35874 35875 35876 35877 35878 35879 35880 35881 |
# File 'lib/aws-sdk-connect/types.rb', line 35874 class UpdateContactFlowModuleContentRequest < Struct.new( :instance_id, :contact_flow_module_id, :content, :settings) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35874 35875 35876 35877 35878 35879 35880 35881 |
# File 'lib/aws-sdk-connect/types.rb', line 35874 class UpdateContactFlowModuleContentRequest < Struct.new( :instance_id, :contact_flow_module_id, :content, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ String
Serialized JSON string of the flow module Settings schema.
35874 35875 35876 35877 35878 35879 35880 35881 |
# File 'lib/aws-sdk-connect/types.rb', line 35874 class UpdateContactFlowModuleContentRequest < Struct.new( :instance_id, :contact_flow_module_id, :content, :settings) SENSITIVE = [] include Aws::Structure end |