Class: Aws::Connect::Types::UpdateContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_idString

The identifier of the contact. This is the identifier of the contact associated with the first interaction with your contact center.

Returns:

  • (String)


34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#customer_endpointTypes::Endpoint

The endpoint of the customer for which the contact was initiated. For external audio contacts, this is usually the end customer’s phone number. This value can only be updated for external audio contacts. For more information, see [Amazon Connect Contact Lens integration] in the *Amazon Connect Administrator Guide*.

[1]: docs.aws.amazon.com/connect/latest/adminguide/contact-lens-integration.html

Returns:



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the contact.

Returns:

  • (String)


34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.

[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html

Returns:

  • (String)


34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the contact.

Returns:

  • (String)


34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#queue_infoTypes::QueueInfoInput

Information about the queue associated with a contact. This parameter can only be updated for external audio contacts. It is used when you integrate third-party systems with Contact Lens for analytics. For more information, see [Amazon Connect Contact Lens integration] in the Amazon Connect Administrator Guide.

[1]: docs.aws.amazon.com/connect/latest/adminguide/contact-lens-integration.html



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#referencesHash<String,Types::Reference>

Well-formed data on contact, shown to agents on Contact Control Panel (CCP).

Returns:



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#segment_attributesHash<String,Types::SegmentAttributeValue>

A set of system defined key-value pairs stored on individual contact segments (unique contact ID) using an attribute map. The attributes are standard Amazon Connect attributes. They can be accessed in flows.

Attribute keys can include only alphanumeric, -, and _.

This field can be used to show channel subtype, such as ‘connect:Guide`.

Contact Expiry, and user-defined attributes (String - String) that are defined in predefined attributes, can be updated by using the UpdateContact API.

Returns:



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#system_endpointTypes::Endpoint

External system endpoint for the contact was initiated. For external audio contacts, this is the phone number of the external system such as the contact center. This value can only be updated for external audio contacts. For more information, see [Amazon Connect Contact Lens integration] in the *Amazon Connect Administrator Guide*.

[1]: docs.aws.amazon.com/connect/latest/adminguide/contact-lens-integration.html

Returns:



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#user_infoTypes::UserInfo

Information about the agent associated with a contact. This parameter can only be updated for external audio contacts. It is used when you integrate third-party systems with Contact Lens for analytics. For more information, see [Amazon Connect Contact Lens integration] in the Amazon Connect Administrator Guide.

[1]: docs.aws.amazon.com/connect/latest/adminguide/contact-lens-integration.html

Returns:



34005
34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
# File 'lib/aws-sdk-connect/types.rb', line 34005

class UpdateContactRequest < Struct.new(
  :instance_id,
  :contact_id,
  :name,
  :description,
  :references,
  :segment_attributes,
  :queue_info,
  :user_info,
  :customer_endpoint,
  :system_endpoint)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end