Class: Aws::Connect::Types::UpdateContactRoutingDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateContactRoutingDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#queue_priority ⇒ Integer
Priority of the contact in the queue.
-
#queue_time_adjustment_seconds ⇒ Integer
The number of seconds to add or subtract from the contact's routing age.
-
#routing_criteria ⇒ Types::RoutingCriteriaInput
Updates the routing criteria on the contact.
Instance Attribute Details
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
35684 35685 35686 35687 35688 35689 35690 35691 35692 |
# File 'lib/aws-sdk-connect/types.rb', line 35684 class UpdateContactRoutingDataRequest < Struct.new( :instance_id, :contact_id, :queue_time_adjustment_seconds, :queue_priority, :routing_criteria) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
35684 35685 35686 35687 35688 35689 35690 35691 35692 |
# File 'lib/aws-sdk-connect/types.rb', line 35684 class UpdateContactRoutingDataRequest < Struct.new( :instance_id, :contact_id, :queue_time_adjustment_seconds, :queue_priority, :routing_criteria) SENSITIVE = [] include Aws::Structure end |
#queue_priority ⇒ Integer
Priority of the contact in the queue. The default priority for new contacts is 5. You can raise the priority of a contact compared to other contacts in the queue by assigning them a higher priority, such as 1 or 2.
35684 35685 35686 35687 35688 35689 35690 35691 35692 |
# File 'lib/aws-sdk-connect/types.rb', line 35684 class UpdateContactRoutingDataRequest < Struct.new( :instance_id, :contact_id, :queue_time_adjustment_seconds, :queue_priority, :routing_criteria) SENSITIVE = [] include Aws::Structure end |
#queue_time_adjustment_seconds ⇒ Integer
The number of seconds to add or subtract from the contact's routing age. Contacts are routed to agents on a first-come, first-serve basis. This means that changing their amount of time in queue compared to others also changes their position in queue.
35684 35685 35686 35687 35688 35689 35690 35691 35692 |
# File 'lib/aws-sdk-connect/types.rb', line 35684 class UpdateContactRoutingDataRequest < Struct.new( :instance_id, :contact_id, :queue_time_adjustment_seconds, :queue_priority, :routing_criteria) SENSITIVE = [] include Aws::Structure end |
#routing_criteria ⇒ Types::RoutingCriteriaInput
Updates the routing criteria on the contact. These properties can be used to change how a contact is routed within the queue.
35684 35685 35686 35687 35688 35689 35690 35691 35692 |
# File 'lib/aws-sdk-connect/types.rb', line 35684 class UpdateContactRoutingDataRequest < Struct.new( :instance_id, :contact_id, :queue_time_adjustment_seconds, :queue_priority, :routing_criteria) SENSITIVE = [] include Aws::Structure end |