Class: Aws::Connect::Types::UpdateDataTableAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateDataTableAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The current name of the attribute to update.
-
#data_table_id ⇒ String
The unique identifier for the data table.
-
#description ⇒ String
The updated description for the attribute.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#name ⇒ String
The new name for the attribute.
-
#primary ⇒ Boolean
Whether the attribute should be treated as a primary key.
-
#validation ⇒ Types::Validation
The updated validation rules for the attribute.
-
#value_type ⇒ String
The updated value type for the attribute.
Instance Attribute Details
#attribute_name ⇒ String
The current name of the attribute to update. Used as an identifier since attribute names can be changed.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#data_table_id ⇒ String
The unique identifier for the data table. Must also accept the table ARN with or without a version alias.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description for the attribute.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new name for the attribute. Must conform to Connect human readable string specification and be unique within the data table.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#primary ⇒ Boolean
Whether the attribute should be treated as a primary key. Converting to primary attribute requires existing values to maintain uniqueness.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#validation ⇒ Types::Validation
The updated validation rules for the attribute. Changes do not affect existing values until they are modified.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |
#value_type ⇒ String
The updated value type for the attribute. When changing value types, existing values are not deleted but may return default values if incompatible.
35653 35654 35655 35656 35657 35658 35659 35660 35661 35662 35663 35664 |
# File 'lib/aws-sdk-connect/types.rb', line 35653 class UpdateDataTableAttributeRequest < Struct.new( :instance_id, :data_table_id, :attribute_name, :name, :value_type, :description, :primary, :validation) SENSITIVE = [] include Aws::Structure end |