Class: Aws::Connect::Types::UpdateDataTableAttributeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lock_versionTypes::DataTableLockVersion

The new lock version for the attribute after the update.



36993
36994
36995
36996
36997
36998
# File 'lib/aws-sdk-connect/types.rb', line 36993

class UpdateDataTableAttributeResponse < Struct.new(
  :name,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The trimmed name and identifier for the updated attribute.

Returns:

  • (String)


36993
36994
36995
36996
36997
36998
# File 'lib/aws-sdk-connect/types.rb', line 36993

class UpdateDataTableAttributeResponse < Struct.new(
  :name,
  :lock_version)
  SENSITIVE = []
  include Aws::Structure
end