Class: Aws::Connect::Types::UpdateDataTablePrimaryValuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateDataTablePrimaryValuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_table_id ⇒ String
The unique identifier for the data table.
-
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
-
#lock_version ⇒ Types::DataTableLockVersion
The lock version information required for optimistic locking to prevent concurrent modifications.
-
#new_primary_values ⇒ Array<Types::PrimaryValue>
The new primary values for the record.
-
#primary_values ⇒ Array<Types::PrimaryValue>
The current primary values for the record.
Instance Attribute Details
#data_table_id ⇒ String
The unique identifier for the data table. Must also accept the table ARN with or without a version alias. If the version is provided as part of the identifier or ARN, the version must be one of the two available system managed aliases, $SAVED or $LATEST.
35023 35024 35025 35026 35027 35028 35029 35030 35031 |
# File 'lib/aws-sdk-connect/types.rb', line 35023 class UpdateDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :primary_values, :new_primary_values, :lock_version) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The unique identifier for the Amazon Connect instance.
35023 35024 35025 35026 35027 35028 35029 35030 35031 |
# File 'lib/aws-sdk-connect/types.rb', line 35023 class UpdateDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :primary_values, :new_primary_values, :lock_version) SENSITIVE = [] include Aws::Structure end |
#lock_version ⇒ Types::DataTableLockVersion
The lock version information required for optimistic locking to prevent concurrent modifications.
35023 35024 35025 35026 35027 35028 35029 35030 35031 |
# File 'lib/aws-sdk-connect/types.rb', line 35023 class UpdateDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :primary_values, :new_primary_values, :lock_version) SENSITIVE = [] include Aws::Structure end |
#new_primary_values ⇒ Array<Types::PrimaryValue>
The new primary values for the record. Required and must include values for all primary attributes. The combination must be unique within the table.
35023 35024 35025 35026 35027 35028 35029 35030 35031 |
# File 'lib/aws-sdk-connect/types.rb', line 35023 class UpdateDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :primary_values, :new_primary_values, :lock_version) SENSITIVE = [] include Aws::Structure end |
#primary_values ⇒ Array<Types::PrimaryValue>
The current primary values for the record. Required and must include values for all primary attributes. Fails if the table has primary attributes and some primary values are omitted.
35023 35024 35025 35026 35027 35028 35029 35030 35031 |
# File 'lib/aws-sdk-connect/types.rb', line 35023 class UpdateDataTablePrimaryValuesRequest < Struct.new( :instance_id, :data_table_id, :primary_values, :new_primary_values, :lock_version) SENSITIVE = [] include Aws::Structure end |