Class: Aws::Connect::Types::UpdateEmailAddressMetadataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :display_name]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Returns:

  • (String)


36068
36069
36070
36071
36072
36073
36074
36075
36076
# File 'lib/aws-sdk-connect/types.rb', line 36068

class UpdateEmailAddressMetadataRequest < Struct.new(
  :instance_id,
  :email_address_id,
  :description,
  :display_name,
  :client_token)
  SENSITIVE = [:description, :display_name]
  include Aws::Structure
end

#descriptionString

The description of the email address.

Returns:

  • (String)


36068
36069
36070
36071
36072
36073
36074
36075
36076
# File 'lib/aws-sdk-connect/types.rb', line 36068

class UpdateEmailAddressMetadataRequest < Struct.new(
  :instance_id,
  :email_address_id,
  :description,
  :display_name,
  :client_token)
  SENSITIVE = [:description, :display_name]
  include Aws::Structure
end

#display_nameString

The display name of email address.

Returns:

  • (String)


36068
36069
36070
36071
36072
36073
36074
36075
36076
# File 'lib/aws-sdk-connect/types.rb', line 36068

class UpdateEmailAddressMetadataRequest < Struct.new(
  :instance_id,
  :email_address_id,
  :description,
  :display_name,
  :client_token)
  SENSITIVE = [:description, :display_name]
  include Aws::Structure
end

#email_address_idString

The identifier of the email address.

Returns:

  • (String)


36068
36069
36070
36071
36072
36073
36074
36075
36076
# File 'lib/aws-sdk-connect/types.rb', line 36068

class UpdateEmailAddressMetadataRequest < Struct.new(
  :instance_id,
  :email_address_id,
  :description,
  :display_name,
  :client_token)
  SENSITIVE = [:description, :display_name]
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


36068
36069
36070
36071
36072
36073
36074
36075
36076
# File 'lib/aws-sdk-connect/types.rb', line 36068

class UpdateEmailAddressMetadataRequest < Struct.new(
  :instance_id,
  :email_address_id,
  :description,
  :display_name,
  :client_token)
  SENSITIVE = [:description, :display_name]
  include Aws::Structure
end