Class: Aws::Connect::Types::UpdateEvaluationFormRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateEvaluationFormRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#as_draft ⇒ Boolean
A boolean flag indicating whether to update evaluation form to draft state.
-
#auto_evaluation_configuration ⇒ Types::EvaluationFormAutoEvaluationConfiguration
Whether automated evaluations are enabled.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#create_new_version ⇒ Boolean
A flag indicating whether the operation must create a new version.
-
#description ⇒ String
The description of the evaluation form.
-
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
-
#evaluation_form_version ⇒ Integer
A version of the evaluation form to update.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#items ⇒ Array<Types::EvaluationFormItem>
Items that are part of the evaluation form.
-
#language_configuration ⇒ Types::EvaluationFormLanguageConfiguration
Configuration for language settings of the evaluation form.
-
#review_configuration ⇒ Types::EvaluationReviewConfiguration
Configuration for evaluation review settings of the evaluation form.
-
#scoring_strategy ⇒ Types::EvaluationFormScoringStrategy
A scoring strategy of the evaluation form.
-
#target_configuration ⇒ Types::EvaluationFormTargetConfiguration
Configuration that specifies the target for the evaluation form.
-
#title ⇒ String
A title of the evaluation form.
Instance Attribute Details
#as_draft ⇒ Boolean
A boolean flag indicating whether to update evaluation form to draft state.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_evaluation_configuration ⇒ Types::EvaluationFormAutoEvaluationConfiguration
Whether automated evaluations are enabled.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#create_new_version ⇒ Boolean
A flag indicating whether the operation must create a new version.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_id ⇒ String
The unique identifier for the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#evaluation_form_version ⇒ Integer
A version of the evaluation form to update.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::EvaluationFormItem>
Items that are part of the evaluation form. The total number of sections and questions must not exceed 100 each. Questions must be contained in a section.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#language_configuration ⇒ Types::EvaluationFormLanguageConfiguration
Configuration for language settings of the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#review_configuration ⇒ Types::EvaluationReviewConfiguration
Configuration for evaluation review settings of the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#scoring_strategy ⇒ Types::EvaluationFormScoringStrategy
A scoring strategy of the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#target_configuration ⇒ Types::EvaluationFormTargetConfiguration
Configuration that specifies the target for the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
A title of the evaluation form.
37388 37389 37390 37391 37392 37393 37394 37395 37396 37397 37398 37399 37400 37401 37402 37403 37404 37405 |
# File 'lib/aws-sdk-connect/types.rb', line 37388 class UpdateEvaluationFormRequest < Struct.new( :instance_id, :evaluation_form_id, :evaluation_form_version, :create_new_version, :title, :description, :items, :scoring_strategy, :auto_evaluation_configuration, :review_configuration, :as_draft, :client_token, :target_configuration, :language_configuration) SENSITIVE = [] include Aws::Structure end |