Class: Aws::Connect::Types::UpdateExtractionDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateExtractionDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#display ⇒ Types::ExtractionDefinitionDisplay
The display settings for the extraction definition.
-
#extraction_configuration ⇒ Types::ExtractionConfiguration
The configuration that defines how data is extracted, including the prompt hint and not-found behavior.
-
#extraction_definition_id ⇒ String
The identifier of the extraction definition to update.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the extraction definition.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field.
A suitable default value is auto-generated. You should normally not need to pass this option.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |
#display ⇒ Types::ExtractionDefinitionDisplay
The display settings for the extraction definition.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |
#extraction_configuration ⇒ Types::ExtractionConfiguration
The configuration that defines how data is extracted, including the prompt hint and not-found behavior.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |
#extraction_definition_id ⇒ String
The identifier of the extraction definition to update.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the extraction definition.
38406 38407 38408 38409 38410 38411 38412 38413 38414 38415 |
# File 'lib/aws-sdk-connect/types.rb', line 38406 class UpdateExtractionDefinitionRequest < Struct.new( :client_token, :extraction_definition_id, :instance_id, :name, :extraction_configuration, :display) SENSITIVE = [] include Aws::Structure end |