Class: Aws::Connect::Types::UpdateHoursOfOperationOverrideRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateHoursOfOperationOverrideRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config ⇒ Array<Types::HoursOfOperationOverrideConfig>
Configuration information for the hours of operation override: day, start time, and end time.
-
#description ⇒ String
The description of the hours of operation override.
-
#effective_from ⇒ String
The date from when the hours of operation override would be effective.
-
#effective_till ⇒ String
The date until the hours of operation override is effective.
-
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
-
#hours_of_operation_override_id ⇒ String
The identifier for the hours of operation override.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the hours of operation override.
-
#override_type ⇒ String
Whether the override will be defined as a standard or as a recurring event.
-
#recurrence_config ⇒ Types::RecurrenceConfig
Configuration for a recurring event.
Instance Attribute Details
#config ⇒ Array<Types::HoursOfOperationOverrideConfig>
Configuration information for the hours of operation override: day, start time, and end time.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the hours of operation override.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#effective_from ⇒ String
The date from when the hours of operation override would be effective.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#effective_till ⇒ String
The date until the hours of operation override is effective.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_id ⇒ String
The identifier for the hours of operation.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#hours_of_operation_override_id ⇒ String
The identifier for the hours of operation override.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the hours of operation override.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#override_type ⇒ String
Whether the override will be defined as a standard or as a recurring event.
For more information about how override types are applied, see Build your list of overrides in the Administrator Guide.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |
#recurrence_config ⇒ Types::RecurrenceConfig
Configuration for a recurring event.
37341 37342 37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 |
# File 'lib/aws-sdk-connect/types.rb', line 37341 class UpdateHoursOfOperationOverrideRequest < Struct.new( :instance_id, :hours_of_operation_id, :hours_of_operation_override_id, :name, :description, :config, :effective_from, :effective_till, :recurrence_config, :override_type) SENSITIVE = [] include Aws::Structure end |