Class: Aws::Connect::Types::UpdateInstanceStorageConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateInstanceStorageConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#resource_type ⇒ String
A valid resource type.
-
#storage_config ⇒ Types::InstanceStorageConfig
The storage configuration for the instance.
Instance Attribute Details
#association_id ⇒ String
The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
36294 36295 36296 36297 36298 36299 36300 36301 36302 |
# File 'lib/aws-sdk-connect/types.rb', line 36294 class UpdateInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
36294 36295 36296 36297 36298 36299 36300 36301 36302 |
# File 'lib/aws-sdk-connect/types.rb', line 36294 class UpdateInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
36294 36295 36296 36297 36298 36299 36300 36301 36302 |
# File 'lib/aws-sdk-connect/types.rb', line 36294 class UpdateInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
A valid resource type.
36294 36295 36296 36297 36298 36299 36300 36301 36302 |
# File 'lib/aws-sdk-connect/types.rb', line 36294 class UpdateInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |
#storage_config ⇒ Types::InstanceStorageConfig
The storage configuration for the instance.
36294 36295 36296 36297 36298 36299 36300 36301 36302 |
# File 'lib/aws-sdk-connect/types.rb', line 36294 class UpdateInstanceStorageConfigRequest < Struct.new( :instance_id, :association_id, :resource_type, :storage_config, :client_token) SENSITIVE = [] include Aws::Structure end |