Class: Aws::Connect::Types::UpdateInstanceStorageConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_idString

The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.

Returns:

  • (String)


36174
36175
36176
36177
36178
36179
36180
36181
36182
# File 'lib/aws-sdk-connect/types.rb', line 36174

class UpdateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :association_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


36174
36175
36176
36177
36178
36179
36180
36181
36182
# File 'lib/aws-sdk-connect/types.rb', line 36174

class UpdateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :association_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


36174
36175
36176
36177
36178
36179
36180
36181
36182
# File 'lib/aws-sdk-connect/types.rb', line 36174

class UpdateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :association_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

A valid resource type.

Returns:

  • (String)


36174
36175
36176
36177
36178
36179
36180
36181
36182
# File 'lib/aws-sdk-connect/types.rb', line 36174

class UpdateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :association_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configTypes::InstanceStorageConfig

The storage configuration for the instance.



36174
36175
36176
36177
36178
36179
36180
36181
36182
# File 'lib/aws-sdk-connect/types.rb', line 36174

class UpdateInstanceStorageConfigRequest < Struct.new(
  :instance_id,
  :association_id,
  :resource_type,
  :storage_config,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end