Class: Aws::Connect::Types::UpdateMetricContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateMetricContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#metric_calculation ⇒ Types::MetricCalculation
The updated calculation definition for the metric.
-
#metric_id ⇒ String
The identifier of the metric to update.
-
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted.
-
#unit ⇒ String
The updated display unit for the metric.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37672 37673 37674 37675 37676 37677 37678 37679 37680 |
# File 'lib/aws-sdk-connect/types.rb', line 37672 class UpdateMetricContentRequest < Struct.new( :instance_id, :metric_id, :metric_calculation, :unit, :positive_trend_indicator) SENSITIVE = [] include Aws::Structure end |
#metric_calculation ⇒ Types::MetricCalculation
The updated calculation definition for the metric.
37672 37673 37674 37675 37676 37677 37678 37679 37680 |
# File 'lib/aws-sdk-connect/types.rb', line 37672 class UpdateMetricContentRequest < Struct.new( :instance_id, :metric_id, :metric_calculation, :unit, :positive_trend_indicator) SENSITIVE = [] include Aws::Structure end |
#metric_id ⇒ String
The identifier of the metric to update. Adding the $SAVED
qualifier will update the saved version of the metric. Adding
$LATEST or omitting a qualifier will update the published version.
37672 37673 37674 37675 37676 37677 37678 37679 37680 |
# File 'lib/aws-sdk-connect/types.rb', line 37672 class UpdateMetricContentRequest < Struct.new( :instance_id, :metric_id, :metric_calculation, :unit, :positive_trend_indicator) SENSITIVE = [] include Aws::Structure end |
#positive_trend_indicator ⇒ String
How an increase in the metric value should be interpreted. Valid
values: POSITIVE, NEUTRAL, NEGATIVE.
37672 37673 37674 37675 37676 37677 37678 37679 37680 |
# File 'lib/aws-sdk-connect/types.rb', line 37672 class UpdateMetricContentRequest < Struct.new( :instance_id, :metric_id, :metric_calculation, :unit, :positive_trend_indicator) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The updated display unit for the metric.
37672 37673 37674 37675 37676 37677 37678 37679 37680 |
# File 'lib/aws-sdk-connect/types.rb', line 37672 class UpdateMetricContentRequest < Struct.new( :instance_id, :metric_id, :metric_calculation, :unit, :positive_trend_indicator) SENSITIVE = [] include Aws::Structure end |