Class: Aws::Connect::Types::UpdateMetricMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateMetricMetadataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description of the metric.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#metric_id ⇒ String
The identifier of the metric to update.
-
#name ⇒ String
The updated name of the metric.
Instance Attribute Details
#description ⇒ String
The updated description of the metric.
37711 37712 37713 37714 37715 37716 37717 37718 |
# File 'lib/aws-sdk-connect/types.rb', line 37711 class UpdateMetricMetadataRequest < Struct.new( :instance_id, :metric_id, :name, :description) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37711 37712 37713 37714 37715 37716 37717 37718 |
# File 'lib/aws-sdk-connect/types.rb', line 37711 class UpdateMetricMetadataRequest < Struct.new( :instance_id, :metric_id, :name, :description) SENSITIVE = [] include Aws::Structure end |
#metric_id ⇒ String
The identifier of the metric to update. Adding the $SAVED
qualifier will update the saved version of the metric. Adding
$LATEST or omitting a qualifier will update the published version.
37711 37712 37713 37714 37715 37716 37717 37718 |
# File 'lib/aws-sdk-connect/types.rb', line 37711 class UpdateMetricMetadataRequest < Struct.new( :instance_id, :metric_id, :name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the metric.
37711 37712 37713 37714 37715 37716 37717 37718 |
# File 'lib/aws-sdk-connect/types.rb', line 37711 class UpdateMetricMetadataRequest < Struct.new( :instance_id, :metric_id, :name, :description) SENSITIVE = [] include Aws::Structure end |