Class: Aws::Connect::Types::UpdateMetricMetadataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The updated description of the metric.

Returns:

  • (String)


37570
37571
37572
37573
37574
37575
37576
37577
# File 'lib/aws-sdk-connect/types.rb', line 37570

class UpdateMetricMetadataRequest < Struct.new(
  :instance_id,
  :metric_id,
  :name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37570
37571
37572
37573
37574
37575
37576
37577
# File 'lib/aws-sdk-connect/types.rb', line 37570

class UpdateMetricMetadataRequest < Struct.new(
  :instance_id,
  :metric_id,
  :name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#metric_idString

The identifier of the metric to update. Adding the $SAVED qualifier will update the saved version of the metric. Adding $LATEST or omitting a qualifier will update the published version.

Returns:

  • (String)


37570
37571
37572
37573
37574
37575
37576
37577
# File 'lib/aws-sdk-connect/types.rb', line 37570

class UpdateMetricMetadataRequest < Struct.new(
  :instance_id,
  :metric_id,
  :name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated name of the metric.

Returns:

  • (String)


37570
37571
37572
37573
37574
37575
37576
37577
# File 'lib/aws-sdk-connect/types.rb', line 37570

class UpdateMetricMetadataRequest < Struct.new(
  :instance_id,
  :metric_id,
  :name,
  :description)
  SENSITIVE = []
  include Aws::Structure
end