Class: Aws::Connect::Types::UpdateParticipantRoleConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateParticipantRoleConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_configuration ⇒ Types::UpdateParticipantRoleConfigChannelInfo
The Connect Customer channel you want to configure.
-
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
Instance Attribute Details
#channel_configuration ⇒ Types::UpdateParticipantRoleConfigChannelInfo
The Connect Customer channel you want to configure.
35357 35358 35359 35360 35361 35362 35363 |
# File 'lib/aws-sdk-connect/types.rb', line 35357 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
The identifier of the contact in this instance of Connect Customer.
35357 35358 35359 35360 35361 35362 35363 |
# File 'lib/aws-sdk-connect/types.rb', line 35357 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
35357 35358 35359 35360 35361 35362 35363 |
# File 'lib/aws-sdk-connect/types.rb', line 35357 class UpdateParticipantRoleConfigRequest < Struct.new( :instance_id, :contact_id, :channel_configuration) SENSITIVE = [] include Aws::Structure end |