Class: Aws::Connect::Types::UpdatePhoneNumberMetadataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


36961
36962
36963
36964
36965
36966
36967
# File 'lib/aws-sdk-connect/types.rb', line 36961

class UpdatePhoneNumberMetadataRequest < Struct.new(
  :phone_number_id,
  :phone_number_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_descriptionString

The description of the phone number.

Returns:

  • (String)


36961
36962
36963
36964
36965
36966
36967
# File 'lib/aws-sdk-connect/types.rb', line 36961

class UpdatePhoneNumberMetadataRequest < Struct.new(
  :phone_number_id,
  :phone_number_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

The Amazon Resource Name (ARN) or resource ID of the phone number.

Returns:

  • (String)


36961
36962
36963
36964
36965
36966
36967
# File 'lib/aws-sdk-connect/types.rb', line 36961

class UpdatePhoneNumberMetadataRequest < Struct.new(
  :phone_number_id,
  :phone_number_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end