Class: Aws::Connect::Types::UpdatePhoneNumberMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdatePhoneNumberMetadataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#phone_number_description ⇒ String
The description of the phone number.
-
#phone_number_id ⇒ String
The Amazon Resource Name (ARN) or resource ID of the phone number.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
35133 35134 35135 35136 35137 35138 35139 |
# File 'lib/aws-sdk-connect/types.rb', line 35133 class UpdatePhoneNumberMetadataRequest < Struct.new( :phone_number_id, :phone_number_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_description ⇒ String
The description of the phone number.
35133 35134 35135 35136 35137 35138 35139 |
# File 'lib/aws-sdk-connect/types.rb', line 35133 class UpdatePhoneNumberMetadataRequest < Struct.new( :phone_number_id, :phone_number_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
The Amazon Resource Name (ARN) or resource ID of the phone number.
35133 35134 35135 35136 35137 35138 35139 |
# File 'lib/aws-sdk-connect/types.rb', line 35133 class UpdatePhoneNumberMetadataRequest < Struct.new( :phone_number_id, :phone_number_description, :client_token) SENSITIVE = [] include Aws::Structure end |