Class: Aws::Connect::Types::UpdatePhoneNumberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


37006
37007
37008
37009
37010
37011
37012
37013
# File 'lib/aws-sdk-connect/types.rb', line 37006

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :target_arn,
  :instance_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance that phone numbers are claimed to. You can find the instance ID in the Amazon Resource Name (ARN) of the instance. You must enter InstanceId or TargetArn.

Returns:

  • (String)


37006
37007
37008
37009
37010
37011
37012
37013
# File 'lib/aws-sdk-connect/types.rb', line 37006

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :target_arn,
  :instance_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

A unique identifier for the phone number.

Returns:

  • (String)


37006
37007
37008
37009
37010
37011
37012
37013
# File 'lib/aws-sdk-connect/types.rb', line 37006

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :target_arn,
  :instance_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) for Connect Customer instances or traffic distribution groups that phone number inbound traffic is routed through. You must enter InstanceId or TargetArn.

Returns:

  • (String)


37006
37007
37008
37009
37010
37011
37012
37013
# File 'lib/aws-sdk-connect/types.rb', line 37006

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :target_arn,
  :instance_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end