Class: Aws::Connect::Types::UpdatePredefinedAttributeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdatePredefinedAttributeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the predefined attribute.
-
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes.
-
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
Instance Attribute Details
#attribute_configuration ⇒ Types::InputPredefinedAttributeConfiguration
Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Connect Customer admin website.
36156 36157 36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/aws-sdk-connect/types.rb', line 36156 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
36156 36157 36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/aws-sdk-connect/types.rb', line 36156 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the predefined attribute.
36156 36157 36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/aws-sdk-connect/types.rb', line 36156 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#purposes ⇒ Array<String>
Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Connect Customer admin website.
36156 36157 36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/aws-sdk-connect/types.rb', line 36156 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Types::PredefinedAttributeValues
The values of the predefined attribute.
36156 36157 36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/aws-sdk-connect/types.rb', line 36156 class UpdatePredefinedAttributeRequest < Struct.new( :instance_id, :name, :values, :purposes, :attribute_configuration) SENSITIVE = [] include Aws::Structure end |