Class: Aws::Connect::Types::UpdatePredefinedAttributeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_configurationTypes::InputPredefinedAttributeConfiguration

Custom metadata that is associated to predefined attributes to control behavior in upstream services, such as controlling how a predefined attribute should be displayed in the Amazon Connect admin website.



35239
35240
35241
35242
35243
35244
35245
35246
35247
# File 'lib/aws-sdk-connect/types.rb', line 35239

class UpdatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


35239
35240
35241
35242
35243
35244
35245
35246
35247
# File 'lib/aws-sdk-connect/types.rb', line 35239

class UpdatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the predefined attribute.

Returns:

  • (String)


35239
35240
35241
35242
35243
35244
35245
35246
35247
# File 'lib/aws-sdk-connect/types.rb', line 35239

class UpdatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#purposesArray<String>

Values that enable you to categorize your predefined attributes. You can use them in custom UI elements across the Amazon Connect admin website.

Returns:

  • (Array<String>)


35239
35240
35241
35242
35243
35244
35245
35246
35247
# File 'lib/aws-sdk-connect/types.rb', line 35239

class UpdatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#valuesTypes::PredefinedAttributeValues

The values of the predefined attribute.



35239
35240
35241
35242
35243
35244
35245
35246
35247
# File 'lib/aws-sdk-connect/types.rb', line 35239

class UpdatePredefinedAttributeRequest < Struct.new(
  :instance_id,
  :name,
  :values,
  :purposes,
  :attribute_configuration)
  SENSITIVE = []
  include Aws::Structure
end