Class: Aws::Connect::Types::UpdateRoutingProfileAgentAvailabilityTimerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_availability_timerString

Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time.

Returns:

  • (String)


37002
37003
37004
37005
37006
37007
37008
# File 'lib/aws-sdk-connect/types.rb', line 37002

class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37002
37003
37004
37005
37006
37007
37008
# File 'lib/aws-sdk-connect/types.rb', line 37002

class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profile_idString

The identifier of the routing profile.

Returns:

  • (String)


37002
37003
37004
37005
37006
37007
37008
# File 'lib/aws-sdk-connect/types.rb', line 37002

class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :agent_availability_timer)
  SENSITIVE = []
  include Aws::Structure
end