Class: Aws::Connect::Types::UpdateRoutingProfileAgentAvailabilityTimerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateRoutingProfileAgentAvailabilityTimerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_availability_timer ⇒ String
Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#routing_profile_id ⇒ String
The identifier of the routing profile.
Instance Attribute Details
#agent_availability_timer ⇒ String
Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time.
36761 36762 36763 36764 36765 36766 36767 |
# File 'lib/aws-sdk-connect/types.rb', line 36761 class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new( :instance_id, :routing_profile_id, :agent_availability_timer) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
36761 36762 36763 36764 36765 36766 36767 |
# File 'lib/aws-sdk-connect/types.rb', line 36761 class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new( :instance_id, :routing_profile_id, :agent_availability_timer) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile.
36761 36762 36763 36764 36765 36766 36767 |
# File 'lib/aws-sdk-connect/types.rb', line 36761 class UpdateRoutingProfileAgentAvailabilityTimerRequest < Struct.new( :instance_id, :routing_profile_id, :agent_availability_timer) SENSITIVE = [] include Aws::Structure end |