Class: Aws::Connect::Types::UpdateRoutingProfileQueuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


38419
38420
38421
38422
38423
38424
38425
# File 'lib/aws-sdk-connect/types.rb', line 38419

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end

#queue_configsArray<Types::RoutingProfileQueueConfig>

The queues to be updated for this routing profile. Queues must first be associated to the routing profile. You can do this using AssociateRoutingProfileQueues.



38419
38420
38421
38422
38423
38424
38425
# File 'lib/aws-sdk-connect/types.rb', line 38419

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profile_idString

The identifier of the routing profile.

Returns:

  • (String)


38419
38420
38421
38422
38423
38424
38425
# File 'lib/aws-sdk-connect/types.rb', line 38419

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end