Class: Aws::Connect::Types::UpdateRoutingProfileQueuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37496
37497
37498
37499
37500
37501
37502
# File 'lib/aws-sdk-connect/types.rb', line 37496

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end

#queue_configsArray<Types::RoutingProfileQueueConfig>

The queues to be updated for this routing profile. Queues must first be associated to the routing profile. You can do this using AssociateRoutingProfileQueues.



37496
37497
37498
37499
37500
37501
37502
# File 'lib/aws-sdk-connect/types.rb', line 37496

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profile_idString

The identifier of the routing profile.

Returns:

  • (String)


37496
37497
37498
37499
37500
37501
37502
# File 'lib/aws-sdk-connect/types.rb', line 37496

class UpdateRoutingProfileQueuesRequest < Struct.new(
  :instance_id,
  :routing_profile_id,
  :queue_configs)
  SENSITIVE = []
  include Aws::Structure
end