Class: Aws::Connect::Types::UpdateRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
-
#function ⇒ String
The conditions of the rule.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the rule.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
Instance Attribute Details
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The conditions of the rule.
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule. You can change the name only if
TriggerEventSource is one of the following values:
OnZendeskTicketCreate | OnZendeskTicketStatusUpdate |
OnSalesforceCaseCreate
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
38461 38462 38463 38464 38465 38466 38467 38468 38469 38470 |
# File 'lib/aws-sdk-connect/types.rb', line 38461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status) SENSITIVE = [] include Aws::Structure end |