Class: Aws::Connect::Types::UpdateRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
-
#function ⇒ String
The conditions of the rule.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the rule.
-
#pre_evaluation_filters ⇒ Types::PreEvaluationFilters
The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact.
-
#publish_status ⇒ String
The publish status of the rule.
-
#rule_id ⇒ String
A unique identifier for the rule.
Instance Attribute Details
#actions ⇒ Array<Types::RuleAction>
A list of actions to be run when the rule is triggered.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The conditions of the rule.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule. You can change the name only if
TriggerEventSource is one of the following values:
OnZendeskTicketCreate | OnZendeskTicketStatusUpdate |
OnSalesforceCaseCreate
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#pre_evaluation_filters ⇒ Types::PreEvaluationFilters
The pre-evaluation filters for the rule, that restrict the rule to be applied to only certain resources based on the resource's attributes, such as tags assigned to a contact. The pre-evaluation filters are applied even before rule conditions are evaluated and are used to enforce tag-based-access-control while applying rules.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#publish_status ⇒ String
The publish status of the rule.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
A unique identifier for the rule.
39461 39462 39463 39464 39465 39466 39467 39468 39469 39470 39471 |
# File 'lib/aws-sdk-connect/types.rb', line 39461 class UpdateRuleRequest < Struct.new( :rule_id, :instance_id, :name, :function, :actions, :publish_status, :pre_evaluation_filters) SENSITIVE = [] include Aws::Structure end |