Class: Aws::Connect::Types::UpdateTaskTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#constraintsTypes::TaskTemplateConstraints

Constraints that are applicable to the fields listed. Although this parameter is marked as optional in the API model, the service requires it when calling CreateTaskTemplate or UpdateTaskTemplate. The RequiredFields array must contain at least one element, and the field of type NAME must be included in RequiredFields.



37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow that runs by default when a task is created by referencing this template.

Although this parameter is marked as optional, the request must contain either a ContactFlowId or a field of type QUICK_CONNECT.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#defaultsTypes::TaskTemplateDefaults

The default values for fields when a task is created by referencing this template.



37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the task template.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsArray<Types::TaskTemplateField>

Fields that are part of the template.

The request must contain exactly one field of type NAME. This field must also be listed in the RequiredFields array within the Constraints parameter.

Returns:



37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the task template.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#self_assign_flow_idString

The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Marks a template as ACTIVE or INACTIVE for a task to refer to it. Tasks can only be created from ACTIVE templates. If a template is marked as INACTIVE, then a task that refers to this template cannot be created.

Although this parameter is marked as optional, the service requires it when calling UpdateTaskTemplate.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end

#task_template_idString

A unique identifier for the task template.

Returns:

  • (String)


37695
37696
37697
37698
37699
37700
37701
37702
37703
37704
37705
37706
37707
37708
# File 'lib/aws-sdk-connect/types.rb', line 37695

class UpdateTaskTemplateRequest < Struct.new(
  :task_template_id,
  :instance_id,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :status,
  :fields)
  SENSITIVE = []
  include Aws::Structure
end