Class: Aws::Connect::Types::UpdateTaskTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateTaskTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
-
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
-
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
-
#description ⇒ String
The description of the task template.
-
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#name ⇒ String
The name of the task template.
-
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it. -
#task_template_id ⇒ String
A unique identifier for the task template.
Instance Attribute Details
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the task template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to
it. Tasks can only be created from ACTIVE templates. If a template
is marked as INACTIVE, then a task that refers to this template
cannot be created.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |
#task_template_id ⇒ String
A unique identifier for the task template.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 |
# File 'lib/aws-sdk-connect/types.rb', line 37604 class UpdateTaskTemplateRequest < Struct.new( :task_template_id, :instance_id, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :status, :fields) SENSITIVE = [] include Aws::Structure end |