Class: Aws::Connect::Types::UpdateTaskTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateTaskTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the task template resource.
-
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed.
-
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
-
#created_time ⇒ Time
The timestamp when the task template was created.
-
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
-
#description ⇒ String
The description of the task template.
-
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
-
#id ⇒ String
The identifier of the task template resource.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#last_modified_time ⇒ Time
The timestamp when the task template was last modified.
-
#name ⇒ String
The name of the task template.
-
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
-
#status ⇒ String
Marks a template as
ACTIVEorINACTIVEfor a task to refer to it.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the task template resource.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#constraints ⇒ Types::TaskTemplateConstraints
Constraints that are applicable to the fields listed. Although this
parameter is marked as optional in the API model, the service
requires it when calling CreateTaskTemplate or
UpdateTaskTemplate. The RequiredFields array must contain at
least one element, and the field of type NAME must be included in
RequiredFields.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#contact_flow_id ⇒ String
The identifier of the flow that runs by default when a task is created by referencing this template.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the task template was created.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#defaults ⇒ Types::TaskTemplateDefaults
The default values for fields when a task is created by referencing this template.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the task template.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::TaskTemplateField>
Fields that are part of the template.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the task template resource.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the task template was last modified.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the task template.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#self_assign_flow_id ⇒ String
The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Marks a template as ACTIVE or INACTIVE for a task to refer to
it. Tasks can only be created from ACTIVE templates. If a template
is marked as INACTIVE, then a task that refers to this template
cannot be created.
39197 39198 39199 39200 39201 39202 39203 39204 39205 39206 39207 39208 39209 39210 39211 39212 39213 |
# File 'lib/aws-sdk-connect/types.rb', line 39197 class UpdateTaskTemplateResponse < Struct.new( :instance_id, :id, :arn, :name, :description, :contact_flow_id, :self_assign_flow_id, :constraints, :defaults, :fields, :status, :last_modified_time, :created_time) SENSITIVE = [] include Aws::Structure end |