Class: Aws::Connect::Types::UpdateTaskTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the task template resource.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#constraintsTypes::TaskTemplateConstraints

Constraints that are applicable to the fields listed.



37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#contact_flow_idString

The identifier of the flow that runs by default when a task is created by referencing this template.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The timestamp when the task template was created.

Returns:

  • (Time)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#defaultsTypes::TaskTemplateDefaults

The default values for fields when a task is created by referencing this template.



37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the task template.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsArray<Types::TaskTemplateField>

Fields that are part of the template.

Returns:



37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the task template resource.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the task template was last modified.

Returns:

  • (Time)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the task template.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#self_assign_flow_idString

The ContactFlowId for the flow that will be run if this template is used to create a self-assigned task.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Marks a template as ACTIVE or INACTIVE for a task to refer to it. Tasks can only be created from ACTIVE templates. If a template is marked as INACTIVE, then a task that refers to this template cannot be created.

Returns:

  • (String)


37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
# File 'lib/aws-sdk-connect/types.rb', line 37384

class UpdateTaskTemplateResponse < Struct.new(
  :instance_id,
  :id,
  :arn,
  :name,
  :description,
  :contact_flow_id,
  :self_assign_flow_id,
  :constraints,
  :defaults,
  :fields,
  :status,
  :last_modified_time,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end