Class: Aws::Connect::Types::UpdateTestCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateTestCaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The JSON string that represents the content of the test.
-
#description ⇒ String
The description of the test case.
-
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for your test.
-
#initialization_data ⇒ String
Defines the test attributes for precise data representation.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_region ⇒ String
The region in which the resource was last modified.
-
#last_modified_time ⇒ Time
The time at which the resource was last modified.
-
#name ⇒ String
The name of the test case.
-
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED.
-
#test_case_id ⇒ String
The identifier of the test case to update.
Instance Attribute Details
#content ⇒ String
The JSON string that represents the content of the test.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the test case.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#entry_point ⇒ Types::TestCaseEntryPoint
Defines the starting point for your test.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#initialization_data ⇒ String
Defines the test attributes for precise data representation.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The region in which the resource was last modified
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time at which the resource was last modified.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test case.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates the test status as either SAVED or PUBLISHED. The PUBLISHED status will initiate validation on the content. The SAVED status does not initiate validation of the content.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#test_case_id ⇒ String
The identifier of the test case to update.
37789 37790 37791 37792 37793 37794 37795 37796 37797 37798 37799 37800 37801 37802 |
# File 'lib/aws-sdk-connect/types.rb', line 37789 class UpdateTestCaseRequest < Struct.new( :instance_id, :test_case_id, :content, :entry_point, :initialization_data, :name, :description, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |