Class: Aws::Connect::Types::UpdateTrafficDistributionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateTrafficDistributionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_config ⇒ Types::AgentConfig
The distribution of agents between the instance and its replica(s).
-
#id ⇒ String
The identifier of the traffic distribution group.
-
#sign_in_config ⇒ Types::SignInConfig
The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).
-
#telephony_config ⇒ Types::TelephonyConfig
The distribution of traffic between the instance and its replica(s).
Instance Attribute Details
#agent_config ⇒ Types::AgentConfig
The distribution of agents between the instance and its replica(s).
37884 37885 37886 37887 37888 37889 37890 37891 |
# File 'lib/aws-sdk-connect/types.rb', line 37884 class UpdateTrafficDistributionRequest < Struct.new( :id, :telephony_config, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the traffic distribution group. This can be the ID or the ARN if the API is being called in the Region where the traffic distribution group was created. The ARN must be provided if the call is from the replicated Region.
37884 37885 37886 37887 37888 37889 37890 37891 |
# File 'lib/aws-sdk-connect/types.rb', line 37884 class UpdateTrafficDistributionRequest < Struct.new( :id, :telephony_config, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#sign_in_config ⇒ Types::SignInConfig
The distribution that determines which Amazon Web Services Regions should be used to sign in agents in to both the instance and its replica(s).
37884 37885 37886 37887 37888 37889 37890 37891 |
# File 'lib/aws-sdk-connect/types.rb', line 37884 class UpdateTrafficDistributionRequest < Struct.new( :id, :telephony_config, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |
#telephony_config ⇒ Types::TelephonyConfig
The distribution of traffic between the instance and its replica(s).
37884 37885 37886 37887 37888 37889 37890 37891 |
# File 'lib/aws-sdk-connect/types.rb', line 37884 class UpdateTrafficDistributionRequest < Struct.new( :id, :telephony_config, :sign_in_config, :agent_config) SENSITIVE = [] include Aws::Structure end |