Class: Aws::Connect::Types::UpdateUserConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateUserConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
-
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
-
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
-
#user_id ⇒ String
The identifier of the user account.
-
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
Instance Attribute Details
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel. ACW timeout specifies how many seconds agents have for after contact work, such as entering notes about the contact. The minimum setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter 0 for an indefinite amount of time, meaning agents must manually choose to end ACW.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel. When auto-accept is enabled for a channel, available agents are automatically connected to contacts from that channel without needing to manually accept. Auto-accept connects agents to contacts in less than one second.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
37943 37944 37945 37946 37947 37948 37949 37950 37951 37952 37953 |
# File 'lib/aws-sdk-connect/types.rb', line 37943 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |