Class: Aws::Connect::Types::UpdateUserConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateUserConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
-
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
-
#instance_id ⇒ String
The identifier of the Connect Customer instance.
-
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
-
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
-
#user_id ⇒ String
The identifier of the user account.
-
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
Instance Attribute Details
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel. ACW timeout specifies how many seconds agents have for after contact work, such as entering notes about the contact. The minimum setting is 1 second, and the maximum is 2,000,000 seconds (24 days). Enter 0 for an indefinite amount of time, meaning agents must manually choose to end ACW.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel. When auto-accept is enabled for a channel, available agents are automatically connected to contacts from that channel without needing to manually accept. Auto-accept connects agents to contacts in less than one second.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon Resource Name (ARN) of the instance.
[1]: docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user account.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'lib/aws-sdk-connect/types.rb', line 36355 class UpdateUserConfigRequest < Struct.new( :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :user_id, :instance_id) SENSITIVE = [] include Aws::Structure end |