Class: Aws::Connect::Types::UpdateUserNotificationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateUserNotificationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_region ⇒ String
The AWS Region where the notification status was last modified.
-
#last_modified_time ⇒ Time
The timestamp when the notification status was last modified.
-
#notification_id ⇒ String
The unique identifier for the notification.
-
#status ⇒ String
The new status for the notification.
-
#user_id ⇒ String
The identifier of the user whose notification status is being updated.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The AWS Region where the notification status was last modified. Used for cross-region replication.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the notification status was last modified. Used for cross-region replication and optimistic locking.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#notification_id ⇒ String
The unique identifier for the notification.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The new status for the notification. Valid values are READ, UNREAD, and HIDDEN.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user whose notification status is being updated.
39017 39018 39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/aws-sdk-connect/types.rb', line 39017 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |