Class: Aws::Connect::Types::UpdateUserNotificationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateUserNotificationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#last_modified_region ⇒ String
The AWS Region where the notification status was last modified.
-
#last_modified_time ⇒ Time
The timestamp when the notification status was last modified.
-
#notification_id ⇒ String
The unique identifier for the notification.
-
#status ⇒ String
The new status for the notification.
-
#user_id ⇒ String
The identifier of the user whose notification status is being updated.
Instance Attribute Details
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The AWS Region where the notification status was last modified. Used for cross-region replication.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the notification status was last modified. Used for cross-region replication and optimistic locking.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#notification_id ⇒ String
The unique identifier for the notification.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The new status for the notification. Valid values are READ, UNREAD, and HIDDEN.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The identifier of the user whose notification status is being updated.
38876 38877 38878 38879 38880 38881 38882 38883 38884 38885 |
# File 'lib/aws-sdk-connect/types.rb', line 38876 class UpdateUserNotificationStatusRequest < Struct.new( :instance_id, :notification_id, :user_id, :status, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |