Class: Aws::Connect::Types::UpdateWorkspacePageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateWorkspacePageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_data ⇒ String
A JSON string containing input parameters for the view.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#new_page ⇒ String
The new page identifier, if changing the page name.
-
#page ⇒ String
The current page identifier.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
-
#slug ⇒ String
The URL-friendly identifier for the page.
-
#workspace_id ⇒ String
The identifier of the workspace.
Instance Attribute Details
#input_data ⇒ String
A JSON string containing input parameters for the view.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#new_page ⇒ String
The new page identifier, if changing the page name.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#page ⇒ String
The current page identifier.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#slug ⇒ String
The URL-friendly identifier for the page.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace.
39858 39859 39860 39861 39862 39863 39864 39865 39866 39867 39868 |
# File 'lib/aws-sdk-connect/types.rb', line 39858 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |