Class: Aws::Connect::Types::UpdateWorkspacePageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateWorkspacePageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_data ⇒ String
A JSON string containing input parameters for the view.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#new_page ⇒ String
The new page identifier, if changing the page name.
-
#page ⇒ String
The current page identifier.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
-
#slug ⇒ String
The URL-friendly identifier for the page.
-
#workspace_id ⇒ String
The identifier of the workspace.
Instance Attribute Details
#input_data ⇒ String
A JSON string containing input parameters for the view.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#new_page ⇒ String
The new page identifier, if changing the page name.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#page ⇒ String
The current page identifier.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#slug ⇒ String
The URL-friendly identifier for the page.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace.
39154 39155 39156 39157 39158 39159 39160 39161 39162 39163 39164 |
# File 'lib/aws-sdk-connect/types.rb', line 39154 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |