Class: Aws::Connect::Types::UpdateWorkspacePageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UpdateWorkspacePageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_data ⇒ String
A JSON string containing input parameters for the view.
-
#instance_id ⇒ String
The identifier of the Amazon Connect instance.
-
#new_page ⇒ String
The new page identifier, if changing the page name.
-
#page ⇒ String
The current page identifier.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
-
#slug ⇒ String
The URL-friendly identifier for the page.
-
#workspace_id ⇒ String
The identifier of the workspace.
Instance Attribute Details
#input_data ⇒ String
A JSON string containing input parameters for the view.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#new_page ⇒ String
The new page identifier, if changing the page name.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#page ⇒ String
The current page identifier.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the view to associate with the page.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#slug ⇒ String
The URL-friendly identifier for the page.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace.
38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 |
# File 'lib/aws-sdk-connect/types.rb', line 38026 class UpdateWorkspacePageRequest < Struct.new( :instance_id, :workspace_id, :page, :new_page, :resource_arn, :slug, :input_data) SENSITIVE = [] include Aws::Structure end |