Class: Aws::Connect::Types::UseCase
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UseCase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains the use case.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#use_case_arn ⇒ String
The Amazon Resource Name (ARN) for the use case.
-
#use_case_id ⇒ String
The identifier for the use case.
-
#use_case_type ⇒ String
The type of use case to associate to the integration association.
Instance Attribute Details
#use_case_arn ⇒ String
The Amazon Resource Name (ARN) for the use case.
37133 37134 37135 37136 37137 37138 37139 |
# File 'lib/aws-sdk-connect/types.rb', line 37133 class UseCase < Struct.new( :use_case_id, :use_case_arn, :use_case_type) SENSITIVE = [] include Aws::Structure end |
#use_case_id ⇒ String
The identifier for the use case.
37133 37134 37135 37136 37137 37138 37139 |
# File 'lib/aws-sdk-connect/types.rb', line 37133 class UseCase < Struct.new( :use_case_id, :use_case_arn, :use_case_type) SENSITIVE = [] include Aws::Structure end |
#use_case_type ⇒ String
The type of use case to associate to the integration association. Each integration association can have only one of each use case type.
37133 37134 37135 37136 37137 37138 37139 |
# File 'lib/aws-sdk-connect/types.rb', line 37133 class UseCase < Struct.new( :use_case_id, :use_case_arn, :use_case_type) SENSITIVE = [] include Aws::Structure end |