Class: Aws::Connect::Types::User
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::User
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Contains information about a user account for an Connect Customer instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the user account.
-
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
-
#directory_user_id ⇒ String
The identifier of the user account in the directory used for identity management.
-
#hierarchy_group_id ⇒ String
The identifier of the hierarchy group for the user.
-
#id ⇒ String
The identifier of the user account.
-
#identity_info ⇒ Types::UserIdentityInfo
Information about the user identity.
-
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
-
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
-
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
-
#phone_config ⇒ Types::UserPhoneConfig
Information about the phone configuration for the user.
-
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
-
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
-
#security_profile_ids ⇒ Array<String>
The identifiers of the security profiles for the user.
-
#tags ⇒ Hash<String,String>
The tags.
-
#username ⇒ String
The user name assigned to the user account.
-
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
Instance Attribute Details
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the user account.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#directory_user_id ⇒ String
The identifier of the user account in the directory used for identity management.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#hierarchy_group_id ⇒ String
The identifier of the hierarchy group for the user.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user account.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#identity_info ⇒ Types::UserIdentityInfo
Information about the user identity.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_region ⇒ String
The Amazon Web Services Region where this resource was last modified.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when this resource was last modified.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#phone_config ⇒ Types::UserPhoneConfig
Information about the phone configuration for the user.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the routing profile for the user.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#security_profile_ids ⇒ Array<String>
The identifiers of the security profiles for the user.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The user name assigned to the user account.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
37679 37680 37681 37682 37683 37684 37685 37686 37687 37688 37689 37690 37691 37692 37693 37694 37695 37696 37697 37698 37699 |
# File 'lib/aws-sdk-connect/types.rb', line 37679 class User < Struct.new( :id, :arn, :username, :identity_info, :phone_config, :directory_user_id, :security_profile_ids, :routing_profile_id, :hierarchy_group_id, :tags, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs, :last_modified_time, :last_modified_region) SENSITIVE = [] include Aws::Structure end |