Class: Aws::Connect::Types::UserData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Data for a user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_slots_by_channelHash<String,Integer>

A map of active slots by channel. The key is a channel name. The value is an integer: the number of active slots.

Returns:

  • (Hash<String,Integer>)


40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#available_slots_by_channelHash<String,Integer>

A map of available slots by channel. The key is a channel name. The value is an integer: the available number of slots.

Returns:

  • (Hash<String,Integer>)


40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#contactsArray<Types::AgentContactReference>

A list of contact reference information.

Returns:



40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_pathTypes::HierarchyPathReference

Contains information about the levels of a hierarchy group assigned to a user.



40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#max_slots_by_channelHash<String,Integer>

A map of maximum slots by channel. The key is a channel name. The value is an integer: the maximum number of slots. This is calculated from MediaConcurrency of the RoutingProfile assigned to the agent.

Returns:

  • (Hash<String,Integer>)


40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#next_statusString

The Next status of the agent.

Returns:

  • (String)


40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profileTypes::RoutingProfileReference

Information about the routing profile that is assigned to the user.



40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::AgentStatusReference

The status of the agent that they manually set in their Contact Control Panel (CCP), or that the supervisor manually changes in the real-time metrics report.



40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end

#userTypes::UserReference

Information about the user for the data that is returned. It contains the resourceId and ARN of the user.



40013
40014
40015
40016
40017
40018
40019
40020
40021
40022
40023
40024
40025
# File 'lib/aws-sdk-connect/types.rb', line 40013

class UserData < Struct.new(
  :user,
  :routing_profile,
  :hierarchy_path,
  :status,
  :available_slots_by_channel,
  :max_slots_by_channel,
  :active_slots_by_channel,
  :contacts,
  :next_status)
  SENSITIVE = []
  include Aws::Structure
end