Class: Aws::Connect::Types::UserData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UserData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Data for a user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_slots_by_channel ⇒ Hash<String,Integer>
A map of active slots by channel.
-
#available_slots_by_channel ⇒ Hash<String,Integer>
A map of available slots by channel.
-
#contacts ⇒ Array<Types::AgentContactReference>
A list of contact reference information.
-
#hierarchy_path ⇒ Types::HierarchyPathReference
Contains information about the levels of a hierarchy group assigned to a user.
-
#max_slots_by_channel ⇒ Hash<String,Integer>
A map of maximum slots by channel.
-
#next_status ⇒ String
The Next status of the agent.
-
#routing_profile ⇒ Types::RoutingProfileReference
Information about the routing profile that is assigned to the user.
-
#status ⇒ Types::AgentStatusReference
The status of the agent that they manually set in their Contact Control Panel (CCP), or that the supervisor manually changes in the real-time metrics report.
-
#user ⇒ Types::UserReference
Information about the user for the data that is returned.
Instance Attribute Details
#active_slots_by_channel ⇒ Hash<String,Integer>
A map of active slots by channel. The key is a channel name. The value is an integer: the number of active slots.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#available_slots_by_channel ⇒ Hash<String,Integer>
A map of available slots by channel. The key is a channel name. The value is an integer: the available number of slots.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#contacts ⇒ Array<Types::AgentContactReference>
A list of contact reference information.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#hierarchy_path ⇒ Types::HierarchyPathReference
Contains information about the levels of a hierarchy group assigned to a user.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#max_slots_by_channel ⇒ Hash<String,Integer>
A map of maximum slots by channel. The key is a channel name. The
value is an integer: the maximum number of slots. This is calculated
from MediaConcurrency of the RoutingProfile assigned to the
agent.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#next_status ⇒ String
The Next status of the agent.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#routing_profile ⇒ Types::RoutingProfileReference
Information about the routing profile that is assigned to the user.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::AgentStatusReference
The status of the agent that they manually set in their Contact Control Panel (CCP), or that the supervisor manually changes in the real-time metrics report.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |
#user ⇒ Types::UserReference
Information about the user for the data that is returned. It
contains the resourceId and ARN of the user.
38332 38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 |
# File 'lib/aws-sdk-connect/types.rb', line 38332 class UserData < Struct.new( :user, :routing_profile, :hierarchy_path, :status, :available_slots_by_channel, :max_slots_by_channel, :active_slots_by_channel, :contacts, :next_status) SENSITIVE = [] include Aws::Structure end |