Class: Aws::Connect::Types::UserIdentityInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about the identity of a user.

For Connect Customer instances that are created with the EXISTING_DIRECTORY identity management type, FirstName, LastName, and Email cannot be updated from within Connect Customer because they are managed by the directory.

The FirstName and LastName length constraints below apply only to instances using SAML for identity management. If you are using Connect Customer for identity management, the length constraints are 1-255 for FirstName, and 1-256 for LastName.

Constant Summary collapse

SENSITIVE =
[:first_name, :last_name, :email, :secondary_email]

Instance Attribute Summary collapse

Instance Attribute Details

#emailString

The email address. If you are using SAML for identity management and include this parameter, an error is returned.

Returns:

  • (String)


38435
38436
38437
38438
38439
38440
38441
38442
38443
# File 'lib/aws-sdk-connect/types.rb', line 38435

class UserIdentityInfo < Struct.new(
  :first_name,
  :last_name,
  :email,
  :secondary_email,
  :mobile)
  SENSITIVE = [:first_name, :last_name, :email, :secondary_email]
  include Aws::Structure
end

#first_nameString

The first name. This is required if you are using Connect Customer or SAML for identity management. Inputs must be in Unicode Normalization Form C (NFC). Text containing characters in a non-NFC form (for example, decomposed characters or combining marks) are not accepted.

Returns:

  • (String)


38435
38436
38437
38438
38439
38440
38441
38442
38443
# File 'lib/aws-sdk-connect/types.rb', line 38435

class UserIdentityInfo < Struct.new(
  :first_name,
  :last_name,
  :email,
  :secondary_email,
  :mobile)
  SENSITIVE = [:first_name, :last_name, :email, :secondary_email]
  include Aws::Structure
end

#last_nameString

The last name. This is required if you are using Connect Customer or SAML for identity management. Inputs must be in Unicode Normalization Form C (NFC). Text containing characters in a non-NFC form (for example, decomposed characters or combining marks) are not accepted.

Returns:

  • (String)


38435
38436
38437
38438
38439
38440
38441
38442
38443
# File 'lib/aws-sdk-connect/types.rb', line 38435

class UserIdentityInfo < Struct.new(
  :first_name,
  :last_name,
  :email,
  :secondary_email,
  :mobile)
  SENSITIVE = [:first_name, :last_name, :email, :secondary_email]
  include Aws::Structure
end

#mobileString

The user's mobile number.

Returns:

  • (String)


38435
38436
38437
38438
38439
38440
38441
38442
38443
# File 'lib/aws-sdk-connect/types.rb', line 38435

class UserIdentityInfo < Struct.new(
  :first_name,
  :last_name,
  :email,
  :secondary_email,
  :mobile)
  SENSITIVE = [:first_name, :last_name, :email, :secondary_email]
  include Aws::Structure
end

#secondary_emailString

The user's secondary email address. If you provide a secondary email, the user receives email notifications - other than password reset notifications - to this email address instead of to their primary email address.

Pattern: (?=^.{0,265}$)[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,63}

Returns:

  • (String)


38435
38436
38437
38438
38439
38440
38441
38442
38443
# File 'lib/aws-sdk-connect/types.rb', line 38435

class UserIdentityInfo < Struct.new(
  :first_name,
  :last_name,
  :email,
  :secondary_email,
  :mobile)
  SENSITIVE = [:first_name, :last_name, :email, :secondary_email]
  include Aws::Structure
end