Class: Aws::Connect::Types::UserSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::UserSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Information about the returned users.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the user.
-
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
-
#directory_user_id ⇒ String
The directory identifier of the user.
-
#hierarchy_group_id ⇒ String
The identifier of the user's hierarchy group.
-
#id ⇒ String
The identifier of the user's summary.
-
#identity_info ⇒ Types::UserIdentityInfoLite
The user's first name and last name.
-
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
-
#phone_config ⇒ Types::UserPhoneConfig
Contains information about the phone configuration settings for a user.
-
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
-
#routing_profile_id ⇒ String
The identifier of the user's routing profile.
-
#security_profile_ids ⇒ Array<String>
The identifiers of the user's security profiles.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#username ⇒ String
The name of the user.
-
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
Instance Attribute Details
#after_contact_work_configs ⇒ Array<Types::AfterContactWorkConfigPerChannel>
The list of after contact work (ACW) timeout configuration settings for each channel.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the user.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#auto_accept_configs ⇒ Array<Types::AutoAcceptConfig>
The list of auto-accept configuration settings for each channel.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#directory_user_id ⇒ String
The directory identifier of the user.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#hierarchy_group_id ⇒ String
The identifier of the user's hierarchy group.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user's summary.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#identity_info ⇒ Types::UserIdentityInfoLite
The user's first name and last name.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#persistent_connection_configs ⇒ Array<Types::PersistentConnectionConfig>
The list of persistent connection configuration settings for each channel.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#phone_config ⇒ Types::UserPhoneConfig
Contains information about the phone configuration settings for a user.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#phone_number_configs ⇒ Array<Types::PhoneNumberConfig>
The list of phone number configuration settings for each channel.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#routing_profile_id ⇒ String
The identifier of the user's routing profile.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#security_profile_ids ⇒ Array<String>
The identifiers of the user's security profiles.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "Tags": "key2":"value2" }.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The name of the user.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |
#voice_enhancement_configs ⇒ Array<Types::VoiceEnhancementConfig>
The list of voice enhancement configuration settings for each channel.
40574 40575 40576 40577 40578 40579 40580 40581 40582 40583 40584 40585 40586 40587 40588 40589 40590 40591 40592 |
# File 'lib/aws-sdk-connect/types.rb', line 40574 class UserSearchSummary < Struct.new( :arn, :directory_user_id, :hierarchy_group_id, :id, :identity_info, :phone_config, :routing_profile_id, :security_profile_ids, :tags, :username, :auto_accept_configs, :after_contact_work_configs, :phone_number_configs, :persistent_connection_configs, :voice_enhancement_configs) SENSITIVE = [] include Aws::Structure end |