Class: Aws::Connect::Types::UserSearchSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the returned users.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_contact_work_configsArray<Types::AfterContactWorkConfigPerChannel>

The list of after contact work (ACW) timeout configuration settings for each channel.



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the user.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#auto_accept_configsArray<Types::AutoAcceptConfig>

The list of auto-accept configuration settings for each channel.

Returns:



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#directory_user_idString

The directory identifier of the user.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_group_idString

The identifier of the user’s hierarchy group.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the user’s summary.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#identity_infoTypes::UserIdentityInfoLite

The user’s first name and last name.



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#persistent_connection_configsArray<Types::PersistentConnectionConfig>

The list of persistent connection configuration settings for each channel.



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#phone_configTypes::UserPhoneConfig

Contains information about the phone configuration settings for a user.



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_configsArray<Types::PhoneNumberConfig>

The list of phone number configuration settings for each channel.

Returns:



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profile_idString

The identifier of the user’s routing profile.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_idsArray<String>

The identifiers of the user’s security profiles.

Returns:

  • (Array<String>)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.

Returns:

  • (Hash<String,String>)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

The name of the user.

Returns:

  • (String)


37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end

#voice_enhancement_configsArray<Types::VoiceEnhancementConfig>

The list of voice enhancement configuration settings for each channel.

Returns:



37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
# File 'lib/aws-sdk-connect/types.rb', line 37398

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username,
  :auto_accept_configs,
  :after_contact_work_configs,
  :phone_number_configs,
  :persistent_connection_configs,
  :voice_enhancement_configs)
  SENSITIVE = []
  include Aws::Structure
end