Class: Aws::Connect::Types::UserSearchSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Information about the returned users.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the user.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#directory_user_idString

The directory identifier of the user.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_group_idString

The identifier of the user’s hierarchy group.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the user’s summary.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#identity_infoTypes::UserIdentityInfoLite

The user’s first name and last name.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#phone_configTypes::UserPhoneConfig

Contains information about the phone configuration settings for a user.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#routing_profile_idString

The identifier of the user’s routing profile.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#security_profile_idsArray<String>

The identifiers of the user’s security profiles.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { “Tags”: “key2”:“value2” }.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

The name of the user.



36118
36119
36120
36121
36122
36123
36124
36125
36126
36127
36128
36129
36130
36131
# File 'lib/aws-sdk-connect/types.rb', line 36118

class UserSearchSummary < Struct.new(
  :arn,
  :directory_user_id,
  :hierarchy_group_id,
  :id,
  :identity_info,
  :phone_config,
  :routing_profile_id,
  :security_profile_ids,
  :tags,
  :username)
  SENSITIVE = []
  include Aws::Structure
end