Class: Aws::Connect::Types::ValidationEnum
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::ValidationEnum
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
Defines enumeration validation for attribute values. Allows specifying a list of permitted values and whether custom values beyond the enumerated list are allowed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#strict ⇒ Boolean
Boolean that defaults to false.
-
#values ⇒ Array<String>
A list of predefined values that are allowed for this attribute.
Instance Attribute Details
#strict ⇒ Boolean
Boolean that defaults to false. When true, only values specified in the enum list are allowed. When false, custom values beyond the enumerated list are permitted.
39353 39354 39355 39356 39357 39358 |
# File 'lib/aws-sdk-connect/types.rb', line 39353 class ValidationEnum < Struct.new( :strict, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
A list of predefined values that are allowed for this attribute. These values are always permitted regardless of the Strict setting.
39353 39354 39355 39356 39357 39358 |
# File 'lib/aws-sdk-connect/types.rb', line 39353 class ValidationEnum < Struct.new( :strict, :values) SENSITIVE = [] include Aws::Structure end |