Class: Aws::Connect::Types::ValidationEnum

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Defines enumeration validation for attribute values. Allows specifying a list of permitted values and whether custom values beyond the enumerated list are allowed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#strictBoolean

Boolean that defaults to false. When true, only values specified in the enum list are allowed. When false, custom values beyond the enumerated list are permitted.

Returns:

  • (Boolean)


34911
34912
34913
34914
34915
34916
# File 'lib/aws-sdk-connect/types.rb', line 34911

class ValidationEnum < Struct.new(
  :strict,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

A list of predefined values that are allowed for this attribute. These values are always permitted regardless of the Strict setting.

Returns:

  • (Array<String>)


34911
34912
34913
34914
34915
34916
# File 'lib/aws-sdk-connect/types.rb', line 34911

class ValidationEnum < Struct.new(
  :strict,
  :values)
  SENSITIVE = []
  include Aws::Structure
end