Class: Aws::Connect::Types::View
- Inherits:
-
Struct
- Object
- Struct
- Aws::Connect::Types::View
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connect/types.rb
Overview
A view resource object. Contains metadata and content necessary to render the view.
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the view.
-
#content ⇒ Types::ViewContent
View content containing all content necessary to render a view except for runtime input data.
-
#created_time ⇒ Time
The timestamp of when the view was created.
-
#description ⇒ String
The description of the view.
-
#id ⇒ String
The identifier of the view.
-
#last_modified_time ⇒ Time
Latest timestamp of the
UpdateViewContentorCreateViewVersionoperations. -
#name ⇒ String
The name of the view.
-
#status ⇒ String
Indicates the view status as either
SAVEDorPUBLISHED. -
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).
-
#type ⇒ String
The type of the view -
CUSTOMER_MANAGED. -
#version ⇒ Integer
Current version of the view.
-
#version_description ⇒ String
The description of the version.
-
#view_content_sha_256 ⇒ String
Indicates the checksum value of the latest published view content.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the view.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#content ⇒ Types::ViewContent
View content containing all content necessary to render a view except for runtime input data.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#created_time ⇒ Time
The timestamp of when the view was created.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#description ⇒ String
The description of the view.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#id ⇒ String
The identifier of the view.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#last_modified_time ⇒ Time
Latest timestamp of the UpdateViewContent or CreateViewVersion
operations.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the view.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#status ⇒ String
Indicates the view status as either SAVED or PUBLISHED. The
PUBLISHED status will initiate validation on the content.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the view resource (not specific to view version).
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#type ⇒ String
The type of the view - CUSTOMER_MANAGED.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#version ⇒ Integer
Current version of the view.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#version_description ⇒ String
The description of the version.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |
#view_content_sha_256 ⇒ String
Indicates the checksum value of the latest published view content.
38837 38838 38839 38840 38841 38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 |
# File 'lib/aws-sdk-connect/types.rb', line 38837 class View < Struct.new( :id, :arn, :name, :status, :type, :description, :version, :version_description, :content, :tags, :created_time, :last_modified_time, :view_content_sha_256) SENSITIVE = [:name] include Aws::Structure end |