Class: Aws::Connect::Types::Workspace

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connect/types.rb

Overview

Contains information about a workspace, which defines the user experience by mapping views to pages.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the workspace.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workspace.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the workspace.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_regionString

The Amazon Web Services Region where the workspace was last modified.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the workspace was last modified.

Returns:

  • (Time)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workspace.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for the workspace.

Returns:

  • (Hash<String,String>)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#themeTypes::WorkspaceTheme

The theme configuration for the workspace, including colors and styling.



35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title displayed for the workspace.

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#visibilityString

Controls who can access the workspace. Valid values are: ‘ALL` (all users), `ASSIGNED` (only assigned users and routing profiles), and `NONE` (not visible).

Returns:

  • (String)


35398
35399
35400
35401
35402
35403
35404
35405
35406
35407
35408
35409
35410
35411
# File 'lib/aws-sdk-connect/types.rb', line 35398

class Workspace < Struct.new(
  :visibility,
  :id,
  :name,
  :arn,
  :description,
  :theme,
  :title,
  :last_modified_time,
  :last_modified_region,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end